#!/bin/bash

# the SET level for CFHTLS collaboration data; 
#
# IMPORTANT NOTE:
# The script 'doscamp_field_surround.sh' has to be run
# BEFORE a call to this script!!

# 17.10.2008:
# I generalised the script to process also non i-band 
# data. Only for the i-band and g-band (lensing data) 
# we need to create masks for individual frames!
#
# 30.10.2008:
# I revised the selection of SDSS-R6 as astrometric
# catalogue; W4 does not have complete coverage but only
# pointings southern of W4..m0.
# 
# 24.11.2008:
# - I modified the SEEINGLIMIT estimation for the
#   prmary lensing i-band. We estimate the median for the
#   seeing distribution and reject everything which has
#   a seeing worse than median + 0.25 arcsec.
#
# - functions to estimate means, medians and sigmas were
#   moved to the bash_functions.include file
#
# 14.04.2009:
# - new command line argument to allow for a magnitude zeropoint
#   to be provided (we have now the possibility to use photometric
#   information from a global calibration which makes this feature
#   necessary)
# - new syntax of convert_mask.sh 
#
# 15.04.2009:
# The lensing bands are now a command line argument
#
# 16.09.2009:
# Inclusion of NGVS to the surveys being calibrated with SDSS.
# 
# 30.12.2009:
# extension of the script to incorporate processing of photo-z
# SLIP data
#
# 01.02.2010:
# I simplified the script a bit:
# - We only process ONE set with it. Hence the 4th argument now
#   can contain only one set, instead of a file listing multiple
#   sets (left-over from the rpedecessor script
# - The 4th argument is now two-fold. It contains the set to process
#   as well as the standard star catalogue to use. The calling script
#   sets this catalogue and hence there is no need to try to guess it
#   again in this script.
#
# 06.02.2013:
# I corrected a bug in the rejction of set images with a bad relative
# photometric zeropoint. In the rejection process all images (also
# short exposed that never enter the co-addition process) were taken
# into account. However, the selction needs to be limited to the images
# that have a chance to enter the co-addition process at all.
#
# 21.11.2013:
# The function 'mean_sigma' now uses a minimum sigma of 0.01. This
# allows to put an error estimate also on sets contaning only a
# single image. In this case the used error ould be zero which would
# prevent these sets from being processed further.

#$1: main directory where the set directories reside
#    (must be given as absolute path)
#$2: filter
#$3: SURVEY under consideration
#$4: The set to process
#$5: coadd identifier
#$6: lensing bands; bands for which co-addition by-products are
#    NOT cleaned up but used afterwards for a lensing analysis
#$7: median limit for rejections according to relative photometric
#    zeropoint
#$8: sigma limit for the rejection of frames accoring to ellipticity
#$9: magnitude zeropoint (OPTIONAL; by default it is estimated
#    from the zeropoints of the sets)

# function definitions:
. bash_functions.include

# set instrument:
export INSTRUMENT=MEGAPRIME

# setup variable containing SETS to process:
SET="`echo $4 | awk '{print $1}'`"
STANDARDCAT="`echo $4 | awk '{print $2}'`"

# co-addition identifier:
COADDIDENT=$5

# bands for which co-addition by-products are NOT cleaned
# up and for which masks are created:
LENSINGBANDS='"'$6'"'

# images which have a worse photometric zeropint
# than the median of all relative ZPS + RELZPLIMIT
# are rejected from co-addition:
RELZPLIMIT=$7

# we estimate means and sigma from the star ellipticity distributions
# in individual frames. Images deviating by more than ELLIPSIGMALIMIT
# from the mean are rejected
ELLIPSIGMALIMIT=$8

# Script main task starts here
# ============================

./create_stats_table.sh ${1}/${3}/${SET} $2 C \
  headers_scamp_${STANDARDCAT}

./create_absphotom_photometrix.sh ${1}/${3}/${SET} $2  

./make_checkplot_stats.sh ${1}/${3}/${SET} \
                          $2 chips.cat6 STATS $2

# Selection of frames for the co-addition process:
# 
# seeing:
# - lensing i-band: we estimate the median from the
#   seeing values and reject everything having a seeing
#   worse than 0.25+median.
# - all other bands: we include all frames within 3 sigmas
#   from the mean of the individual seeing values; absolute 
#   upper limit is 1.5 arcsec. 
#
# relative zeropoint:
# we estimate the median of the relative zeropoints and
# reject everything with a higher absorption than ${RELZPLIMIT} mag
# from the median.
#
# ellipticity distribution:
# we include everything within ${ELLIPSIGMALIMIT} sigmas from the 
# mean of the e1 and e2 ellipticity distributions. The 'distributions' are 
# made up from the means of all KSB ellipticity values for 
# stars within a MegaPrime exposure 
#
# exposure time:
# everything with an exposure time with less than 100 sec.
# is rejected (photometric pegs)
RELZP=-1.0
ldactoasc -i $1/$3/${SET}/$2/cat/chips.cat5 -b -t STATS -k RZP EXPTIME |\
   awk '($2 > 100) {print $1}' > rzp.asc_$$
modified_median rzp.asc_$$ "${RELZPLIMIT}" "-1.0"
RELZP=${G_MODMEDIAN}

# filter according for ellipticity distribution:
ldactoasc -i $1/$3/${SET}/$2/cat/chips.cat6 -b \
          -t STATS -k e1 > e1.asc_$$

mean_sigma e1.asc_$$ -1.0 1.0 ${ELLIPSIGMALIMIT} 0.01
E1MIN=`echo ${G_MEAN_SIGMA} | awk '{printf("%.3f", $1)}'` 
E1MAX=`echo ${G_MEAN_SIGMA} | awk '{printf("%.3f", $2)}'` 
ldactoasc -i $1/$3/${SET}/$2/cat/chips.cat6 -b \
          -t STATS -k e2 > e2.asc_$$

mean_sigma e2.asc_$$ -1.0 1.0 ${ELLIPSIGMALIMIT} 0.01
E2MIN=`echo ${G_MEAN_SIGMA} | awk '{printf("%.3f", $1)}'` 
E2MAX=`echo ${G_MEAN_SIGMA} | awk '{printf("%.3f", $2)}'` 


# filter according to seeing:
ldactoasc -i $1/$3/${SET}/$2/cat/chips.cat6 -b \
          -t STATS -k SEEING > seeing.asc_$$ 
if [ "$2" = "i" ] || [ "$2" = "y" ]; then
  modified_median seeing.asc_$$ 0.25 1.0
  SEEINGLIMIT=${G_MODMEDIAN}
else
  mean_sigma seeing.asc_$$ 0.0 1.5 3.0 0.01
  SEEINGLIMIT=`echo ${G_MEAN_SIGMA} | awk '{printf("%.2f", $2)}'`
fi

echo ${SET}, ${RELZP}, ${E1MIN}, ${E1MAX}, ${E2MIN}, ${E2MAX}, ${SEEINGLIMIT}

# for i-band and g-band reductions (lensing) we keep all 
# resampled individual fields
CLEAN=""
CLEAN=`awk 'BEGIN {if ('"${LENSINGBANDS}"' ~ /'${2}'/) { 
                     print "-noclean"; 
                   } else {
                     print "";
                   }}'`

# some fields cannot be photometrically calibrated with their own
# data; we determined ZPs from overlap sources; we assume here that
# ZPS did NOT change w.r.t. the original CARS surcey; tests suggest
# that this is indeed the case; the ZPs are stored in the file
# MANUAL_CARSZPS.txt which is included here:
MAGZP=""
source MANUAL_CARSZPS.txt
if [ "${MAGZP}_A" != "_A" ]; then
  MAGZP="-ma ${MAGZP}"
fi

# did we give a magnitude zeropoint on the command line? If yes, it
# overwrites any ZP:
if [ $# -eq 9 ] && [ ! -z $9 ]; then
  MAGZP="-ma $9"
fi

./doall_set_CFHTLS_single.sh -b $1 -fi ${SET} -f $2 -ci ${COADDIDENT} \
  -cc "((((((SEEING<${SEEINGLIMIT})AND(EXPTIME>100))AND(RZP>${RELZP}))AND(e1>${E1MIN}))AND(e1<${E1MAX}))AND(e2>${E2MIN})AND(e2<${E2MAX});" \
  -cm WEIGHTED -s $3 -www $1 -am SCAMP -a ${STANDARDCAT} ${CLEAN} ${MAGZP}\
  -m "COADD POSTCOADD COADDHEADERUPDATE CUTCOADD SETPAGES"

# create masks for individual, resampled frames (lensing bands only)
DOMASK=`awk 'BEGIN {if ('"${LENSINGBANDS}"' ~ /'${2}'/) { 
                     print 1; 
                   } else {
                     print 0;
                   }}'`

if [ ${DOMASK} -eq 1 ]; then
  MASKFILE=""
  for FILTERS in izrgu yzrgu irg ir
  do
    if [ -f $1/$3/${SET}/$2/masks_${COADDIDENT}/${SET}_lensingcandidate_${FILTERS}_wcs.reg ]
    then
      MASKFILE=$1/$3/${SET}/$2/masks_${COADDIDENT}/${SET}_lensingcandidate_${FILTERS}_wcs.reg
      ACTUFILTERS=${FILTERS}
    fi
    if [ -f $1/$3/${SET}/$2/masks_${COADDIDENT}/${SET}_lensingfinal_${FILTERS}_wcs.reg ]
    then
      MASKFILE=$1/$3/${SET}/$2/masks_${COADDIDENT}/${SET}_lensingfinal_${FILTERS}_wcs.reg
      ACTUFILTERS=${FILTERS}
    fi
  done
 
  if [ "${MASKFILE}_A" != "_A" ]; then
    sed -e '/yellow/d' \
        -e '/blue/d' \
        -e '/white/d' \
        -e '/black/d' ${MASKFILE} > tmp.reg_$$
 
    FRAMES=`find $1/$3/${SET}/$2/coadd_${COADDIDENT} \
            -name \*${COADDIDENT}.resamp.fits`
 
    imhead -b < \
    $1/$3/${SET}/$2/coadd_${COADDIDENT}/${SET}_${2}.${COADDIDENT}.swarp.cut.fits \
      > ./${SET}.head

    ./convert_mask.sh tmp.reg_$$ RADECPIX ./${SET}.head \
      $1/$3/${SET}/$2/masks_${COADDIDENT}/${SET}_lensingcandidate_${ACTUFILTERS}.reg 
 
    for FRAME in ${FRAMES}
    do
      BASE=`basename ${FRAME} C.sub.${COADDIDENT}.resamp.fits`
      imhead -b < ${FRAME} > ${BASE}.head
 
      ./convert_mask.sh tmp.reg_$$ RADECPIX ${BASE}.head \
   $1/$3/${SET}/$2/masks_${COADDIDENT}/${BASE}C.sub.${COADDIDENT}.resamp.reg
     
      rm ${BASE}.head
    done
    rm ${SET}.head    
    rm tmp.reg_$$
  fi
fi
test -f e1.asc_$$     && rm e1.asc_$$
test -f e2.asc_$$     && rm e2.asc_$$
test -f rzp.asc_$$    && rm rzp.asc_$$
test -f seeing.asc_$$ && rm seeing.asc_$$

