#!/bin/bash -u

# Wrapper script for run processing of MEGAPRIME data, especially for
# surveys such as CFHTLS or NGVS.

# 29.08.2007:
# Introduction of the SURVEY concept into the script
#
# 27.09.2007:
# I corrected a bug in the command line argument for the set base
# directory.
#
# 17.12.2007:
# I included the TESTREG mode in the run processing; see the script
# doall_run..... for further information.
#
# 01.10.2009:
# I added the CORRECTWEIGHTS mode.
#
# 31.12.2009:
# - I introduced the possibility to clean files which are not absolutely
#   necessary for SET processing. This is done at the end of RUN
#   processing. The change required the indtroduction of a new command
#   line argument.
# - A second new command line argument regulates whether satellite
#   track estimation should be skipped.
#
# 05.01.2009:
# - At Terapix we need to take into account a file with photometric zeropoints
#   in the splitting process. The script checks now whether we are at Terapix
#   and sets an appropriate switch.
# - I introduced the possibility to unzip Rice compressed images in the
#   ORIGINALS directory before RUN processing, and to zip them again after 
#   RUN processing. As Elixir processed images are stored in INT format,
#   this allows us to save significant disk space if processing many RUNS
#   consecutively.   
#
# 01.02.2010:
# Changes and fixes for special settings required at Terapix.
#
# 16.08.2010:
# I expanded the command line 'clean' argument. If set to CATCLEAN we
# cleans everything except single-frame catalogue files - useful if we
# only need catalogues for astrometric calibration
#
# 14.09.2010:
# For processing in CATCLEAN mode we removed the creation of
# sky-subtracted images and small mosaics from the run processing
# modes - we assume here that we do not need to check images
# manually.
#
# 22.08.2011:
# DIR processing at Edinburgh makes necessary that the SET structure
# is at a different location as the RUN structure. We therefore changed
# command line options to include the root for the SET directory structure.

# process all runs with a certain identifier.  we assume that run
# directories follow the naming convention $1/$2/run_QRUNID_identifier

# $1: main directory where the run directories reside
#     (must be given as absolute path)
# $2: filter
# $3: identifier of runs to process; We assume that runs are stored
#     in subdirectories ${MD}/${SURVEY}/${FILT}/run_XXXXXX_$3
# $4: SURVEY
# $5: main directory for SET structure (must be given as absolute path;
#     just give 'RUN' if the SET structure is at the same location as the
#     RUN structure
# $6: CATCLEAN/CLEAN/NOCLEAN; clean files which are NOT absolutely necessary
#     in the SET processing state; 'CATCLEAN' cleans out everything except
#     single-frame catalogue files - useful if we only need catalogues
#     for astrometric calibration 
# $7: TRACK/NOTRACK: When set to NOTRACK, no satellite track detection 
#     will be done. We assume that they are already available
# $8: ZIP/NOZIP: When set to ZIP we uncompress Elixir processed data
#     before RUN processing, and we zip (Rice compression) them again
#     after RUN processing. 
#     will be done. We assume that they are already available
# $9: run to process (OPTIONAL); if not given
#     all possible runs are processed

if [ $# -lt 7 ]; then
  echo "$0 MD FILT RUNIDENTIFIER SURVEY SD CLEANFLAG TRACKFLAG ZIPFLAG (RUN)"
fi

MD=$1
FILT=$2
RUNIDENT=$3
SURVEY=$4
if [ "$5" = "RUN" ]; then
  SD=${MD}
else
  SD=$5
fi
CLEANFLAG=$6

# region files are normally here; we introduce
# this variable because we have a special setting
# at Terapix
REGDIR=${MD}/regs

# we use ${TRACKFLAG} below, the use of an empty variable does not
# lead to an 'unbound variable' error!
TRACKFLAG=
if [ "$7" = "NOTRACK" ]; then 
  TRACKFLAG="-notracks"
fi

ZIPFLAG=$8

if [ $# = 9 ]; then
  PROCESSRUNS=$9
else
  ALLRUNS=`ls ${MD}/${SURVEY}/${FILT}`
  PROCESSRUNS=""

  for RUN in ${ALLRUNS}
  do
    RUNNAME=${RUN##/*/}
    # we assume that RUN names are constructed as:
    # run_RUNID_RUNIDENT, where there MUST NOT be any
    # underscores in RUNID!
    CURRRUNID=`echo ${RUNNAME} | awk -F_ 'BEGIN {str = ""} {
                                            for (i = 3; i < NF; i++) { 
                                              str = str  $i "_";
                                            }
                                            str = str $NF;
                                            print str;
                                          }'`

    if [ "${CURRRUNID}" = "${RUNIDENT}" ]; then
      PROCESSRUNS="${PROCESSRUNS} ${RUNNAME}"  
    fi
  done
fi

# see whether we are at Terapix where we want to use a special
# RUN process setting:
TERAPIXSETTING=
if [ "`domainname`" = "clic.iap.fr" ] && [ "${SURVEY}" = "CFHTLSDEEP" ]
then
  TERAPIXSETTING="-y `pwd`/yannick_zps.txt"
  REGDIR=/home/nis/erben/regs
fi

# try to get the number of processors on the machine; we need
# it to optimize zipping/unzipping of Elixirimages:
NPROC=1

# the following way to find the number of processors/cores 
# should work on all Linux machines:
if [ -f /proc/cpuinfo ]; then
  NPROC=`grep processor /proc/cpuinfo | wc -l`
fi

# finally, start with the scripts main task:
echo "Runs to process:"
echo ${PROCESSRUNS}
#
test -d ${MD}/regs || mkdir ${MD}/regs

for RUN in ${PROCESSRUNS}
do
  if [ "${ZIPFLAG}" = "ZIP" ]; then
    ./uncompress.sh \
      -s ${MD}/${SURVEY}/${FILT}/${RUN}/${SCIENCE}_${FILT}/ORIGINALS \
      -p ${NPROC} -m UNCOMPRESS -d
  fi

  PROCESSMODES="PREPARE SCIENCE SKYSUB MOSAICS GLOBALWEIGHTS TESTREG WEIGHTS 
                STRACK REGIONWEIGHTS CORRECTWEIGHTS SINGLEASTROM 
                RUNDISTRIBUTE RUNSCIENCEPAGES"

  if [ "${CLEANFLAG}" = "CATCLEAN" ]; then
    PROCESSMODES="PREPARE SCIENCE GLOBALWEIGHTS TESTREG WEIGHTS 
                  STRACK REGIONWEIGHTS CORRECTWEIGHTS SINGLEASTROM 
                  RUNDISTRIBUTE"
  fi

  ./doall_run_CFHTLS_single.sh -b ${MD} -f ${FILT} -r ${RUN} -psf Y\
  -w ${MD}/${SURVEY}/GLOBALWEIGHTS -set ${SD} -www ${MD} \
  -reg ${REGDIR} -s ${SURVEY} ${TRACKFLAG} ${TERAPIXSETTING}\
  -m "${PROCESSMODES}"

  if [ "${CLEANFLAG}" = "CLEAN" ] || [ "${CLEANFLAG}" = "CATCLEAN" ]; then
    find ${MD}/${SURVEY}/${FILT}/${RUN}/WEIGHTS/ \
      -name orig -type d | xargs rm -rf
    find ${MD}/${SURVEY}/${FILT}/${RUN}/WEIGHTS/ \
      -name \*.flag.fits | xargs rm 
    find ${MD}/${SURVEY}/${FILT}/${RUN}/SCIENCE_${FILT} \
      -name \*C.fits -type f | xargs rm 
    find ${MD}/${SURVEY}/${FILT}/${RUN}/SCIENCE_${FILT} \
      -name cat_maskcorr -type d | xargs rm -rf
  fi

  if [ "${CLEANFLAG}" = "CATCLEAN" ]; then
    find ${MD}/${SURVEY}/${FILT}/${RUN}/WEIGHTS/ \
      -name \*.weight.fits | xargs rm 
    find ${MD}/${SURVEY}/${FILT}/${RUN}/SCIENCE_${FILT} \
      -name \*C.sub.fits -type f | xargs rm 
  fi

  if [ "${ZIPFLAG}" = "ZIP" ]; then
    ./uncompress.sh \
      -s ${MD}/${SURVEY}/${FILT}/${RUN}/${SCIENCE}_${FILT}/ORIGINALS \
      -p ${NPROC} -m COMPRESS -d
  fi
done
