#!/bin/bash

# Wrapper script to process CFHTLS Wide data on
# the SET level

# 29.08.2007:
# Introduction of the SURVEY concet into the script.
#
# 13.09.2007:
# - The fith command line argument is now mandatory
#   and gives either a file or an individual set to
#   process. This avois to have to edit the file each 
#   time we want to process a single set only.
# - I export the INSTRUMENT variable. The 'check_badchips'
#   script needs it.
#
# 29.10.2007:
# - The default seeing threshold is set to 2.0 (it was 1.0
#   previously)
# - The new mode CUTCOADD was added to setprocessing. It is used
#   for the CFHTLS Wide survey.
#
# 10.01.2008:
# If we request processing type reference we do no processing
# IF the astrometric reference catalogue is already present. This
# allows to to process a listfile containing sets with existing 
# and non existing reference catalogues!
#
# 11.01.2008:
# I corrected a bug when testing whether to process a set (changes
# from 10.01.2008)
#
# 06.06.2008:
# The renamed astrom, photom and headers directory from a
# reference run now carry the name of the used standardstar
# catalogue.
#
# 13.09.2010:
# - There is a new command line argument giving the astrometric 
#   method to use: ASTROMETRIX or SCAMP
# - The second argument now can contain multiple filters (such as "g r")
#   In this case astrometry is estimated with scamp on all filters
#   simultaneously. The further processing steps are done one after 
#   the other on the individual filters.
# - The astrometric standard star catalogue was changed from USNOB1 
#   to 2MASS

#$1: main directory where the set directories reside
#    (must be given as absolute path)
#$2: filter(s)
#$3: REFERENCE/REGULAR; If REFERENCE then an astrometric
#    reference catalogue is extracted from the coadded image
#    and the coadd identifier is set to 'USNOB1_reference'.
#    Otherwise the identifier is 'V1.5A'.
#$4: SURVEY under consideration
#$5: Astrometric method (ASTROMETRIX or SCAMP)
#$6: File listing sets to process or a single set
#    The file lists on each line one set to process

# sanity check; processing MODE REFERENCE only makes sense
# with astrometric method ASTROMETRIX:
if [ "$3" = "REFERENCE" ] && [ "$5" != "ASTROMETRIX" ]
then
  echo "Mode REFERENCE only useful in connection with ASTROMETRIX"
  exit 1;
fi

# sanity check: run with multiple filters only makes sense
# with SCMAP:
NFILT=`echo $2 | awk '{print NF}'`
if [ ${NFILT} -gt 1 ] && [ "$5" != "SCAMP" ]; then
  echo "Multiple filter processing only possible with scamp!"
  exit 1;
fi 

# setup variable containing SETS to process:
SETS=""
if [ -f $6 ]; then
  while read SET DUMMY
  do
    SETS="${SETS} ${SET}"
  done < $6
else
  SETS=$6
fi

# The 'check_badchips' script needs the following
# setting:
export INSTRUMENT=MEGAPRIME

# for the moment all sets are processed with 2MASS
# as standardstar catalogue:
STANDARDCAT=2MASS

if [ "$3" = "REFERENCE" ]; then
  COADDIDENT=${STANDARDCAT}_reference
else
  COADDIDENT=V2.1A
fi

for SET in ${SETS}
do
  # If we run with type REFERENCE we do no processing if the 
  # astrometric reference catalogue is already present!
  if { [ $3 = "REFERENCE" ] && [ ! -s ${SET}_${STANDARDCAT}_astrometrix.asc ]; }\
     || [ $3 = "REGULAR" ]; then
  
    # First perform astrometric and photometric calibration
    MULTICHIP=""
    if [ ${NFILT} -gt 1 ] && [ "$5" != "SCAMP" ]; then
      MULTICHIP="-mf"  
    fi 
    
    ./doall_set_CFHTLS_single.sh -b $1 -fi ${SET} -f "$2" -am $5 \
       -m "ASTROMPHOTOM" -a ${STANDARDCAT} -s $4 ${MULTICHIP}

    for FILTER in $2
    do  
      ./doall_set_CFHTLS_single.sh -b $1 -fi ${SET} -f ${FILTER} -am $5 \
         -m "SETCHECKPLOT" -a ${STANDARDCAT} -s $4
  
      # Selection of frames for the co-addition process:
      # 
      # As we preselect CFHTLS images according to ELIXIRFLAGS
      # with a value of 1 or 2 most of the images should be fine
      # with respect to seeing and skybackground (TO BE REFINED).
      # For the moment we only check that none of the images has
      # a very high absorption. We do this by testing whether
      # an image has an absorption of worse than -0.1 w.r.t the
      # 'median' value of relative zeropoints. The 'median' is
      # thr rzp value of 50% of all images starting from the image
      # with least absorption.
      # We also reject images with less than 100 sec. exposure time
      # (photometric pegs)
      RELZP=-1.0
      RELZP=`ldactoasc -i $1/$4/${SET}/${FILTER}/cat/chips.cat5 \
                       -b -t STATS -k RZP |\
          gawk 'BEGIN {i=1} {a[i]=$1; i++}
          END {n=asort(a);
                if(n>2) {
                  if(n%2==0) {
                    print (a[n/2]+a[n/2+1])/2.-0.1
                  } else {
                    print a[int(n/2)]-0.1; 
                  }
                } else {
                  print "-1.0";
                }}'`
      echo ${SET}, ${RELZP}
      ./doall_set_CFHTLS_single.sh -b $1 -fi ${SET} -f ${FILTER} \
        -ci ${COADDIDENT} -noclean\
        -cc "((SEEING<2.0)AND(EXPTIME>100))AND(RZP>${RELZP});" \
        -cm WEIGHTED -s $4 -www $1 -am $5 -a ${STANDARDCAT} \
        -m "COADD POSTCOADD COADDHEADERUPDATE CUTCOADD SETPAGES"
 
  
      # additinal processing in case of the REFERENCE option:
      if [ "$3" = "REFERENCE" ]; then
        COADDDIR=$1/$4/${SET}/${FILTER}/coadd_${STANDARDCAT}_reference/
        ./do_astrometrix_cat.sh \
          ${COADDDIR}/${SET}_${FILTER}.${STANDARDCAT}_reference.swarp.fits \
          ${COADDDIR}/${SET}_${FILTER}.${STANDARDCAT}_reference.swarp.weight.fits \
          NONE 20 20 ${SET}_${STANDARDCAT}_astrometrix

        if [ -s ${SET}_${STANDARDCAT}_astrometrix.asc ]; then
          ./check_badchips.sh $1/$4/${SET}/ \
            ${FILTER} C.sub ${STANDARDCAT}_reference ${SET}_badchips.txt
        fi
      fi  
  
      # save astrom, photom and headers dirs in case we created an
      # astrometric reference frame:
      if [ "$3" = "REFERENCE" ]; then
        test -d $1/$4/${SET}/${FILTER}/astrom_reference || \
                 mv $1/$4/${SET}/${FILTER}/astrom  \
                    $1/$4/${SET}/${FILTER}/astrom_reference_${STANDARDCAT}
        test -d $1/$4/${SET}/${FILTER}/photom_reference || \
                 mv $1/$4/${SET}/${FILTER}/photom  \
                    $1/$4/${SET}/${FILTER}/photom_reference_${STANDARDCAT}
        test -d $1/$4/${SET}/${FILTER}/headers_reference || \
                mv $1/$4/${SET}/${FILTER}/headers \
                   $1/$4/${SET}/${FILTER}/headers_reference_${STANDARDCAT}
      fi
    done # for FILTER in  ....
  else
    echo "reference catalogue for ${SET} already present!"
    echo "Please delete it explicitely if you want to reprocess!"
  fi
done

