#!/bin/bash -xv

# checks images for integrity. For the moment this consists of
# calculating the mode and shifting images that are under/over a given
# mode to a BADMODE directory the script cannot be parallelised as
# chips in one parallel channel may be filtered and not in
# another. But we want to filter all chips of an image that has ONE or
# more bad chips
#
# This version is especially for Elixir processed MEGAPRIME/CFHTLS
# data.  If the mode is less than the 4th argument for a chip, its
# header keyword 'BADCCD' is set to '1'. Images are NOT moved to a
# BADMODE directory in this case.
#
# 29.09.2006:
# We also mark CCDs as bad whose lower quartile is below the BADCCD
# limit. It seems that for some CCDs one of the two readouts is dead
# from time to time.
#
# 23.03.2007:
# Images are marked as bad also if more than 5% of their pixels are
# saturated. Those images have VERY bright stars, cause many problems
# for astrometry and will not be used anyway.
#
# 02.05.2007:
# I introduced a security check in the case of setting the 'BADCCD'
# keyword: It may happen that the file to be updated has been moved
# before the update because of bad modes.  In this case the script
# produced empty files in the science directory leading to problems
# later on.
#
# 01.08.2007:
# some cleaning of not needed temporary files added
#
# 07.10.2010:
# I made the calls to imstats more efficient. I do not call them
# separately for each chip but once for all chips together.
#
# 17.10.2010:
# files to imstats are now passed within an image list. Before they
# were given on the command line which could lead to too long command
# lines in case of many images.
#
# 05.09.2011:
# the meaning of the 'imstats' columns changed because we added new ones.
# Accordingly this scripts needed adaption.

# $1: main directory (filter)
# $2: science directory
# $3: ending (OFCSFF etc.)
# $4: high limit for chips not being marked as
#     BADCCD
# $5: low limit of files labelled as GOOD
# $6: high limit of files labelled as GOOD

# preliminary work:
. ${INSTRUMENT:?}.ini
. bash_functions.include

test -f ${TEMPDIR}/alldata.dat_$$      && rm ${TEMPDIR}/alldata.dat_$$ 
test -f ${TEMPDIR}/allsaturated.dat_$$ && rm ${TEMPDIR}/allsaturated.dat_$$

i=1
while [ "${i}" -le "${NCHIPS}" ]
do
  if [ ${NOTUSE[${CHIP}]:=0} -eq 0 ] && [ ${NOTPROCESS[${CHIP}]:=0} -eq 0 ] 
  then
    # In the following we run 'imstats' two times. One time for
    # 'regular' statistics and another time to determine how many
    # percent of the image pixels are saturated:
    #
    ${P_FIND} /$1/$2/ -maxdepth 1 \( -type f -o -type l \) \
        -name \*_${i}$3.fits > ${TEMPDIR}/statsima.dat_$$
        
    # do the two imstats calls 'simultaneously':    
    {
      ${P_IMSTATS} -i ${TEMPDIR}/statsima.dat_$$ \
                   -s ${STATSXMIN} ${STATSXMAX} ${STATSYMIN} ${STATSYMAX} \
                   -o ${TEMPDIR}/immode.dat_$$

      cat ${TEMPDIR}/immode.dat_$$ >> ${TEMPDIR}/alldata.dat_$$
    } &

    # The run for saturated pixels has to be done on the whole image.
    # we count all pixels between 40000 and 100000; saturated pixels have
    # values around 65000.
    ${P_IMSTATS} -i ${TEMPDIR}/statsima.dat_$$ -t 40000 100000 \
                 -o ${TEMPDIR}/saturated.dat_$$

    cat ${TEMPDIR}/saturated.dat_$$ >> ${TEMPDIR}/allsaturated.dat_$$

    wait;
  else
    echo "Chip ${CHIP} will not be used in $0"  
  fi
  i=$(( $i + 1 ))
done

# now get all sets that have to be moved:
${P_GAWK} '($1 != "#") { if (($2 > '$4') && ($2 < '$5' || $2 > '$6')) {
            a = match($1, "_[0-9]*'$3'.fits"); 
            print substr($1,1,a-1)}
           }' ${TEMPDIR}/alldata.dat_$$ > ${TEMPDIR}/move_$$

# now do the moving
while read file
do
  DIR=`dirname ${file}`
  test -d ${DIR}/BADMODE || mkdir ${DIR}/BADMODE

  i=1
  while [ ${i} -le ${NCHIPS} ]
  do
    # the following 'if' is necessary as the
    # file(s) may already have been moved
    if [ -f "${file}_${i}$3.fits" ]; then
       mv ${file}_${i}$3.fits ${DIR}/BADMODE
    fi
    i=$(( $i + 1 ))
  done
done < ${TEMPDIR}/move_$$

# now get all CCDs that have to be marked as bad:
${P_GAWK} '($1 != "#") {if ($2 < '$4' || $3 < '$4') {print $1}}' \
       ${TEMPDIR}/alldata.dat_$$ > ${TEMPDIR}/bad_$$

# if more than 5% of the pixels are saturated we mark
# the image as 'bad' as well:
${P_GAWK} '($1 != "#") {if ($11 > 5) {print $1}}' \
       ${TEMPDIR}/allsaturated.dat_$$ >> ${TEMPDIR}/bad_$$

# now do the marking
while read file
do
  test -f ${file} && { writekey ${file} BADCCD "1" REPLACE; }
done < ${TEMPDIR}/bad_$$

# clean up:
test -f ${TEMPDIR}/alldata.dat_$$       && rm ${TEMPDIR}/alldata.dat_$$
test -f ${TEMPDIR}/move_$$              && rm ${TEMPDIR}/move_$$
test -f ${TEMPDIR}/immode.dat_$$        && rm ${TEMPDIR}/immode.dat_$$
test -f ${TEMPDIR}/bad_$$               && rm ${TEMPDIR}/bad_$$
test -f ${TEMPDIR}/allsaturated.dat_$$  && rm ${TEMPDIR}/allsaturated.dat_$$
test -f ${TEMPDIR}/saturated.dat_$$     && rm ${TEMPDIR}/saturated.dat_$$
test -f ${TEMPDIR}/statsima.dat_$$      && rm ${TEMPDIR}/statsima.dat_$$

exit 0
