#!/bin/bash

# script to copy CFHTLS collab data to 'release' directories

# 17.10.2008:
# - For i and g-band data we also copy individual resampled
#   images, for the other colours only co-added products
# - Science images are no longer gzipped; it does not save
#   much disk space.
#
# 30.10.2008:
# region files are no longer gzipped.
#
# 10.02.2009:
# I made the script suitable for the SLIP project which
# covers the D1 area.
#
# 14.04.2009:
# new command line argument to give the co-addition identifier
# to make the script a bit more flexible (see also problems and todos)
#
# 15.04.2009:
# All hardwired paths etc. are now command line arguments
#
# 18.04.2009:
# data from individual frames are now moved to the release directory
# instead of copied. We would simply delete them from the working directories
# anyway.
#
# 28.05.2009:
# We are now postprocessing data in the release directories; therefore
# the following changes:
# - co-added products are no longer gzipped
# - we give necessary rights so that everybody can create new 
#   files/directories within the created directory structures.
#
# 31.12.2009:
# I extended the script to use it on photo-z SLIP data processed at
# Terapix.
#
# 25.01.2010:
# I extended (simplified) the script to use it also with COSMOS
# (Deep 2 u-band) data.
#
# 12.09.2010:
# I include some checks on the presence of co-addition products that
# this script should copy. I do this to be able to check the return
# status of this script in 'process_field.sh'
#
# 21.09.2010:
# - data from sinlge frames are now copied OR moved to the release
#   directory (new command line argument). With the new possibility
#   to process fields with having all data on disk (instead of always
#   retrieving from CADC) it is useful to keep simgle-frame data in the
#   THELI structure if we want to redo some processing.
# - I now also copy the ${COADDIDENT}.cat and the chips_phot.cat5
#   to have some more possibility to trace later the data processing stage.
#
# 10.02.2013:
# - I introduced a new command line argument to indicate whether single
#   frame weights should be gzipped; for KIDS data zippint these weights
#   takes very long and the gain in disk space is small.
# - I do no longer copy resampled single images. They were never used!
#
# 12.02.2013:
# Pasted catalogues from the individual exposures (pasted are all the chips
# from a given exposure into one catalogue) are now considered.
#
# 02.05.2014:
# I introduce THELI logging into the script. We noticed that sometimes
# files seem not to be copied properly and we want to track this better.

#$1: field
#$2: filter
#$3: coadd identifier
#$4: lensing bands (bands for which single-frame products
#    are also copied)
#$5: CARSDIR
#$6: RELEASEDIR
#$7: FLAG whether single frame weights should be gzipped
#    (ZIPWEIGHTS if they should be zipped)
#$8: Flag whether to move or to copy single-frame date
#    (MOVE - move data; COPY - copy data)
#$9: name prefix in case of Deep fields or COSMOS

# initiate THELI logging:
. ./progs.ini
. ./bash_functions.include
theli_start "$*"

# give meaningful names to command line arguments:
FIELD=$1
FILT=$2
COADDIDENT=$3
LENSINGBANDS='"'$4'"'
CARSDIR=$5
RELEASEDIR=$6
TARGETIDENTIFIER=${FIELD}

ZIPWEIGHTS=0
if [ "$7" = "ZIPWEIGHTS" ]; then
  ZIPWEIGHTS=1
fi

if [ "$8" = "MOVE" ]; then
  SINGLEMOVE="mv"
else
  SINGLEMOVE="cp"
fi

if [ $# -eq 9 ]; then
  TARGETIDENTIFIER=$9
fi

# sanity checks:
if [ ! -d ${RELEASEDIR} ]; then
  theli_error "${RELEASEDIR} does not exist! Exiting $0"
  exit 1;
fi

# just to abbreviate:
SRCDIR=${CARSDIR}/${FIELD}/${FILT}
TARGETDIR=${RELEASEDIR}/${TARGETIDENTIFIER}/${FILT}

# some sanity tests:
BASE=${FIELD}_${FILT}.${COADDIDENT}
if [ ! -s ${SRCDIR}/coadd_${COADDIDENT}/${BASE}.swarp.cut.fits ] ||\
   [ ! -s ${SRCDIR}/coadd_${COADDIDENT}/${BASE}.swarp.cut.weight.fits ] ||\
   [ ! -s ${SRCDIR}/coadd_${COADDIDENT}/${BASE}.swarp.cut.flag.fits ] ||\
   [ ! -s ${SRCDIR}/coadd_${COADDIDENT}/${BASE}.swarp.cut.sum.fits ]
then
  theli_error "Some of the co-addition products for ${FIELD} do not exist!!"
  theli_error "Abborting script!"
  exit 1;
fi

if [ ! -d ${TARGETDIR}/coadd_${COADDIDENT} ]; then
  mkdir -p ${TARGETDIR}/coadd_${COADDIDENT}
  chmod a+rwxt ${TARGETDIR}

  BASE=${FIELD}_${FILT}.${COADDIDENT}
  TARGETBASE=${TARGETIDENTIFIER}_${FILT}.${COADDIDENT}

  cp ${SRCDIR}/coadd_${COADDIDENT}/${BASE}.swarp.cut.fits \
     ${TARGETDIR}/coadd_${COADDIDENT}/${TARGETBASE}.swarp.cut.fits
  cp ${SRCDIR}/coadd_${COADDIDENT}/${BASE}.swarp.cut.weight.fits \
     ${TARGETDIR}/coadd_${COADDIDENT}/${TARGETBASE}.swarp.cut.weight.fits
  gzip ${TARGETDIR}/coadd_${COADDIDENT}/${TARGETBASE}.swarp.cut.weight.fits
  cp ${SRCDIR}/coadd_${COADDIDENT}/${BASE}.swarp.cut.flag.fits \
     ${TARGETDIR}/coadd_${COADDIDENT}/${TARGETBASE}.swarp.cut.flag.fits
  gzip ${TARGETDIR}/coadd_${COADDIDENT}/${TARGETBASE}.swarp.cut.flag.fits
  cp ${SRCDIR}/coadd_${COADDIDENT}/${BASE}.swarp.cut.sum.fits \
     ${TARGETDIR}/coadd_${COADDIDENT}/${TARGETBASE}.swarp.cut.sum.fits
  gzip ${TARGETDIR}/coadd_${COADDIDENT}/${TARGETBASE}.swarp.cut.sum.fits

  cp -r ${SRCDIR}/postcoadd ${TARGETDIR}

  mkdir -p ${TARGETDIR}/cat
  cp ${SRCDIR}/cat/chips_phot.cat5 ${TARGETDIR}/cat
  cp ${SRCDIR}/cat/${COADDIDENT}.cat ${TARGETDIR}/cat
  
  # copy pasted catalogues from the individual exposures:
  CATS=`find ${SRCDIR}/cat/ -name \*cat | awk -F/ '{print $NF}' |\
        awk -F_ '(NF > 1) {$NF=""; print $0}' | sort | uniq`

  for CAT in ${CATS}
  do
    if [ -s ${SRCDIR}/cat/${CAT}.cat ]; then
      cp ${SRCDIR}/cat/${CAT}.cat ${TARGETDIR}/cat
    fi  
  done

  COPYSINGLE=`awk 'BEGIN {if ('"${LENSINGBANDS}"' ~ /'${FILT}'/) { 
                       print 1; 
                     } else {
                       print 0;
                     }}'`

  if [ ${COPYSINGLE} -eq 1 ]; then
    mkdir -p ${TARGETDIR}/masks_${COADDIDENT}
    #mkdir -p ${TARGETDIR}/resamp_${COADDIDENT}
    mkdir -p ${TARGETDIR}/single_${COADDIDENT}
    mkdir -p ${TARGETDIR}/headers_${COADDIDENT}

    # the single frames in the set directories are 'only' links:
    FILES=`find ${SRCDIR} -maxdepth 1 -name \*sub.fits`
    for FILE in ${FILES}
    do
      if [ -L ${FILE} ]; then
        ${SINGLEMOVE} `readlink ${FILE}` ${TARGETDIR}/single_${COADDIDENT}
      else
        ${SINGLEMOVE} ${FILE} ${TARGETDIR}/single_${COADDIDENT}
      fi
    done  

    FILES=`find ${CARSDIR}/${FIELD}/WEIGHTS_${FILT} \
           -maxdepth 1 -name \*.weight.fits`
    for FILE in ${FILES}
    do
      if [ -L ${FILE} ]; then
        ${SINGLEMOVE} `readlink ${FILE}` ${TARGETDIR}/single_${COADDIDENT}
      else
        ${SINGLEMOVE} ${FILE} ${TARGETDIR}/single_${COADDIDENT}
      fi
    done  

    if [ ${ZIPWEIGHTS} -eq 1 ]; then
      gzip ${TARGETDIR}/single_${COADDIDENT}/*.weight.fits
    fi
    #mv ${SRCDIR}/coadd_${COADDIDENT}/*${COADDIDENT}.resamp*fits \
    #   ${TARGETDIR}/resamp_${COADDIDENT}/
  
    #gzip ${TARGETDIR}/resamp_${COADDIDENT}/*weight.fits 

    cp ${SRCDIR}/masks_${COADDIDENT}/*reg \
       ${TARGETDIR}/masks_${COADDIDENT}/

    # copy astrometric headers:
    HEADERDIR=`find ${SRCDIR} -maxdepth 1 -type d -name headers_scamp\* |\
               grep -v astrom | grep -v photom`
    find ${HEADERDIR} -maxdepth 1 -name \*\[0-9\].head |\
      xargs cp --target-directory=${TARGETDIR}/headers_${COADDIDENT}
  fi 
else
  theli_error "${TARGETDIR}/coadd_${COADDIDENT} exists!"
  theli_error "delete explicitely if you want to overwrite!"
  exit 1;
fi

# everything went o.k.:
theli_end
exit 0;
