#!/bin/bash

# script to create the CFHTLS directory structure
# for set processing, i.e.
#
# CFHTLS
#  +----- D1 ---- u
#  +         ---- g
#  +
#  +----- W1m3m3 ---- u
#  +             ---- g
#
# The structure will be created below the directory
# where this script is called.

# HISTORY INFORMATION
# ===================
#
# 10.01.2007:
# I added entries for the W4 field
#
# 31.08.2007:
# I introduced different surveys to the script.
#
# 11.09.2007:
# I added new targets to the CLUSTERS survey
#
# 27.09.2007:
# I added two new targets to the CLUSTERS survey
#
# 07.11.2007:
# I corrected a bug in the W4 fields. They had a
# 'p0' instead of a 'm0' for zero fields.
#
# 10.01.2008:
# I added the COSMOS fields which represent u-band 
# observations for D2 CFHTLS Deep.
#
# 08.04.2008:
# I introduced code for the new i-band filter.
# It is called 'i_new'.
#
# 15.04.2008:
# I added the cluster A2259 and RCS2327
#
# 10.06.2008:
# I added the CFHTLS Presurvey
#
# 17.07.2008:
# I added MS0451 to the clusters
#
# 15.08.2008:
# I added A2163 to the clusters
#
# 21.11.2008:
# I renamed the new i-band filter from
# 'i_new' to 'y' to be in accordance with
# Terapix definition.
#
# 10.12.2008:
# I included the CFHTLSPHOTOSURVEY consisting of
# Presurvey-like data in the filters u,g,r,y and z.
#
# 16.04.2009:
# addition of several MACS clusters for the collaboration
# with Anja.
#
# 06.09.2009:
# inclusion of COSMOS to the known surveys
#
# 15.09.2009:
# - Inclusion of the first four pointings of NGVS
# - Inclusion of A2744 to the galaxy clusters
#
# 18.09.2009:
# I added 49 new NGVS fields
#
# 01.10.2009
# I improved script output messages.
#
# 01.02.2010:
# I added a survey STARFIELDS for SLIP processing.
#
# 29.03.2010:
# I added Mischas SCL2241 supercluster to the clusters
# target list
#
# 06.10.2010:
# I added Ludos Stripe 82 survey
#
# 17.10.2010:
# I added NGVS 2nd year fieldnames
#
# 02.11.2010:
# I deleted a 'NGVSm0p0' field
#
# 01.02.2011:
# I added several clusters observed with WFI to the CLUSTERS list.
# In this way we can also use this script to create survey structures
# for other instruments.
#
# 08.02.2011:
# I added the eight CFHTLS Wide fields that overlap with STRIPE82
# to the STRIPE82 survey
#
# 22.06.2011:
# addition of A2465 to the cluster objects
#
# 25.07.2011:
# addition of the RCS survey
#
# 08.11.2011:
# addition of some RCS2 survey fields
#
# 01.03.2012:
# addition of Hendriks SPARCS survey
#
# 05.04.2012:
# I introduced the DEEP2 survey
#
# 07.05.2012:
# I introduced the CODEX survey
#
# 13.11.2012:
# I completed the NGVS survey
#
# 03.03.2013:
# I included Patrick Halls Stripe82 program
#
# 19.03.2013:
# I added Eric Jullos HATLAS survey
#
# 13.09.2013:
# I added more CODEC fields
#
# 07.11.2013:
# revision of CODEX fields
#
# 31.01.2014:
# addition of two new fields to the DEEP2 survey.
#
# 10.06.2014:
# addition of a QUASARS survey (project from Sherry).
#
# 21.04.2015:
# update of CODEX field list.
#
# 11.06.2015:
# - update of the script to also create structures for the
#   new 40-chip MEGAPRIME mode.
# - update of CLUSTERS list with a new cluster from Albertos recent
#   CFHT observations.

function filter_dirs {
  # first argument to the function are the filter
  # names as one argument within double quotes

  for FILT in $1
  do
    test -d ${FILT} || mkdir ${FILT}
    test -d WEIGHTS_${FILT} || mkdir WEIGHTS_${FILT}
  done  
}

KNOWNSURVEYS="CFHTLSDEEP CFHTLSWIDE CFHTLSPRESURVEY CFHTLSPHOTSURVEY CLUSTERS\
              COSMOS NGVS STARFIELDS STRIPE82 RCS SPARCS DEEP2 CODEX
              STRIPE82HALL HATLAS QUASARS"

if [ $# -lt 2 ]; then
  echo ""
  echo "The script creates the necessary directory structure"
  echo "to process a survey from the MEGAPRIME@CFHT instrument"
  echo "with THELI."
  echo "First script argument is the survey to process. Second"
  echo "argument is 'mode1' or 'mode2'. In mode 2 you would like"
  echo "process 36 chip and/or 40 chip MEGARPIME data. In mode 1"
  echo "you only have old mode 1 data. The difference is in the"
  echo "filter naming scheme."
  echo ""
  echo "Currently known surveys are:"
  for TESTSURVEY in ${KNOWNSURVEYS}
  do
    echo ${TESTSURVEY}  
  done
  echo ""
  echo "try again with: $0 'survey_to_process' 'mode1/mode2'"
  exit 1
fi

SURVEY=$1
SURVEYOK=0
for TESTSURVEY in ${KNOWNSURVEYS}
do
  if [ "${SURVEY}" = "${TESTSURVEY}" ]; then
    SURVEYOK=1  
  fi
done

if [ ${SURVEYOK} -ne 1 ]; then
  echo "Unknown Survey! Exiting!"
  exit 1
fi

MODE=$2
if [ "${MODE}" != "mode1" ] && [ "${MODE}" != "mode2" ]; then
  echo "Unknown mode! Exiting!"
  exit 1;
fi

if [ "${MODE}" = "mode1" ]; then
  FILTERS="u g r i y z"
else
  FILTERS="u.MP9301 g.MP9401 r.MP9601 i.MP9701 i.MP9702 z.MP9801 \
           u.MP9302 g.MP9402 r.MP9602 i.MP9703 z.MP9901"  
fi

if [ ! -d ${SURVEY} ]; then
  mkdir ${SURVEY}
fi

if [ "${SURVEY}" = "QUASARS" ]; then
  FIELDS="HE1104"
fi

if [ "${SURVEY}" = "HATLAS" ]; then
  FIELDS="HATLAS_000 HATLAS_001 HATLAS_002 HATLAS_003 \
  HATLAS_004 HATLAS_005 HATLAS_006 HATLAS_007 \
  HATLAS_008 HATLAS_009 HATLAS_010 HATLAS_011 \
  HATLAS_012 HATLAS_013 HATLAS_014 HATLAS_015 \
  HATLAS_016 HATLAS_017 HATLAS_018 HATLAS_019 \
  HATLAS_020 HATLAS_021 HATLAS_022 HATLAS_023 \
  HATLAS_024 HATLAS_025 HATLAS_026 HATLAS_027 \
  HATLAS_029 HATLAS_031 "
fi

if [ "${SURVEY}" = "CODEX" ]; then
  FIELDS=" CODEX09208 CODEX12451 CODEX12887 CODEX13062 \
  CODEX13452 CODEX16384 CODEX16463 CODEX16566 \
  CODEX16984 CODEX18127 CODEX24747 CODEX24865 \
  CODEX24872 CODEX24877 CODEX24925 CODEX24981 \
  CODEX25252 CODEX25424 CODEX25953 CODEX27938 \
  CODEX27940 CODEX27955 CODEX27958 CODEX27969 \
  CODEX27974 CODEX28045 CODEX29284 CODEX29673 \
  CODEX29734 CODEX29811 CODEX34071 CODEX35213 \
  CODEX35361 CODEX35399 CODEX35646 CODEX36818 \
  CODEX37098 CODEX37287 CODEX38791 CODEX38795 \
  CODEX39141 CODEX39326 CODEX39570 CODEX39879 \
  CODEX41843 CODEX41911 CODEX43403 CODEX43576 \
  CODEX43881 CODEX43951 CODEX46328 CODEX46649 \
  CODEX47981 CODEX48272 CODEX48564 CODEX50492 \
  CODEX50502 CODEX50514 CODEX52442 CODEX52480 \
  CODEX52484 CODEX53495 CODEX53498 CODEX53585 \
  CODEX53588 CODEX54752 CODEX54795 CODEX55181 \
  CODEX56934 CODEX57892 CODEX58014 CODEX58083 \
  CODEX58114 CODEX59915 CODEX64232 CODEX64360 \
  CODEX25094 CODEX20622"
fi

if [ "${SURVEY}" = "DEEP2" ]; then
  FIELDS="DEEP2_P1 DEEP2_P2 DEEP2_P3 DEEP2_P4 DEEP2_P5"
fi

if [ "${SURVEY}" = "SPARCS" ]; then
  FIELDS=" ELAISN1_P1 ELAISN1_P2 ELAISN1_P3 ELAISN1_P4 \
  ELAISN1_P5 ELAISN1_P6 ELAISN1_P7 ELAISN1_P8 \
  ELAISN1_P9 ELAISN1_P10 ELAISN1_P11 ELAISN1_P12 \
  ELAIS_N2_P1 ELAIS_N2_P2 ELAIS_N2_P3 ELAIS_N2_P4 \
  ELAIS_N2_P5 XMM_LSS_A XMM_LSS_B XMM_LSS_C \
  Lockmann_P1 Lockmann_P2 Lockmann_P3 Lockmann_P4 \
  Lockmann_P5 Lockmann_P6 Lockmann_P7 Lockmann_P8 \
  Lockmann_P9 Lockmann_P10 Lockmann_P11 Lockmann_P12 \
  Lockmann_P13 Lockmann_P14 Lockmann_P15 "
fi

if [ "${SURVEY}" = "CFHTLSDEEP" ]; then
  FIELDS="D1 D2 D3 D4"
fi

if [ "${SURVEY}" = "CFHTLSPRESURVEY" ] || [ "${SURVEY}" = "CFHTLSPHOTSURVEY" ]
then
  FIELDS="W1 W2 W3 W4"
fi

if [ "${SURVEY}" = "CFHTLSWIDE" ]; then 
  FIELDS="W1m4m4 W1m4m3 W1m4m2 \
  W1m4m1 W1m4m0 W1m4p1 W1m4p2 W1m4p3 W1m3m4 W1m3m3 W1m3m2 W1m3m1 \
  W1m3m0 W1m3p1 W1m3p2 W1m3p3 W1m2m4 W1m2m3 W1m2m2 W1m2m1 W1m2m0 \
  W1m2p1 W1m2p2 W1m2p3 W1m1m4 W1m1m3 W1m1m2 W1m1m1 W1m1m0 W1m1p1 \
  W1m1p2 W1m1p3 W1m0m4 W1m0m3 W1m0m2 W1m0m1 W1m0m0 W1m0p1 W1m0p2 \
  W1m0p3 W1p1m4 W1p1m3 W1p1m2 W1p1m1 W1p1m0 W1p1p1 W1p1p2 W1p1p3 \
  W1p2m4 W1p2m3 W1p2m2 W1p2m1 W1p2m0 W1p2p1 W1p2p2 W1p2p3 W1p3m4 \
  W1p3m3 W1p3m2 W1p3m1 W1p3m0 W1p3p1 W1p3p2 W1p3p3 W1p4m4 W1p4m3 \
  W1p4m2 W1p4m1 W1p4m0 W1p4p1 W1p4p2 W1p4p3 W2m3m3 W2m3m2 W2m3m1 \
  W2m3m0 W2m3p1 W2m3p2 W2m3p3 W2m2m3 W2m2m2 W2m2m1 W2m2m0 W2m2p1 \
  W2m2p2 W2m2p3 W2m1m3 W2m1m2 W2m1m1 W2m1m0 W2m1p1 W2m1p2 W2m1p3 \
  W2m0m3 W2m0m2 W2m0m1 W2m0m0 W2m0p1 W2m0p2 W2m0p3 W2p1m3 W2p1m2 \
  W2p1m1 W2p1m0 W2p1p1 W2p1p2 W2p1p3 W2p2m3 W2p2m2 W2p2m1 W2p2m0 \
  W2p2p1 W2p2p2 W2p2p3 W2p3m3 W2p3m2 W2p3m1 W2p3m0 W2p3p1 W2p3p2 \
  W2p3p3 W3m3m3 W3m3m2 W3m3m1 W3m3m0 W3m3p1 W3m3p2 W3m3p3 W3m2m3 \
  W3m2m2 W3m2m1 W3m2m0 W3m2p1 W3m2p2 W3m2p3 W3m1m3 W3m1m2 W3m1m1 \
  W3m1m0 W3m1p1 W3m1p2 W3m1p3 W3m0m3 W3m0m2 W3m0m1 W3m0m0 W3m0p1 \
  W3m0p2 W3m0p3 W3p1m3 W3p1m2 W3p1m1 W3p1m0 W3p1p1 W3p1p2 W3p1p3 \
  W3p2m3 W3p2m2 W3p2m1 W3p2m0 W3p2p1 W3p2p2 W3p2p3 W3p3m3 W3p3m2 \
  W3p3m1 W3p3m0 W3p3p1 W3p3p2 W3p3p3 W4p2m2 W4p2m1 W4p2m0 W4p1m2 \
  W4p1m1 W4p1m0 W4p1p1 W4m0m2 W4m0m1 W4m0m0 W4m0p1 W4m1m2 W4m1m1 \
  W4m1m0 W4m1p1 W4m1p2 W4m1p3 W4m2m0 W4m2p1 W4m2p2 W4m2p3 W4m3m0 \
  W4m3p1 W4m3p2 W4m3p3" 
fi

if [ "${SURVEY}" = "CLUSTERS" ]; then
  FIELDS=" A115 A1758 A1835 A1914 \
  A1942 A2111 A2163 A2259 \
  A226 A2537 A2597 A2744 \
  A3404 A611 A851 CDE1645 \
  CL0318m0302 CL0809p2811 CL0853p5759 CL0926p1242 \
  CL0956p4107 CL1002p6858 CL1003p3253 CL1120p2326 \
  CL1120p4318 CL1202p5751 CL1221p4918 CL1222p2709 \
  CL1312p3900 CL1334p5031 CL1354m0221 CL1357p6232 \
  CL1416p4446 CL1524p0957 CL1641p4001 CL1701p6414 \
  MACS0018p16 MACS0025m12 MACS0257m23 MACS0329m02 \
  MACS0647p70 MACS0717p37 MACS0744p39 MACS0949p17 \
  MACS1149p22 MACS1423p24 MACS1532p30 MACS1621p38 \
  MACS1720p35 MACS1731p22 MACS1931m26 MACS2129m07 \
  MACS2140m23 MACS2211m03 MACS2214m13 MS0451 \
  RCS2327 RXCJ0232 RXCJ2014 RXJ1347 \
  SCL2241 ZWCL2341 CL1212p2733"
fi

if [ "${SURVEY}" = "COSMOS" ]; then
  FIELDS="COSMOS_C COSMOS_UR COSMOS_LR COSMOS_LL COSMOS_UL"
fi

if [ "${SURVEY}" = "NGVS" ]; then 
  FIELDS=" NGVSm0m0 NGVSm0m1 NGVSm0m2 NGVSm0m3 \
  NGVSm0m4 NGVSm0m5 NGVSm0m6 NGVSm0m7 \
  NGVSm0p1 NGVSm0p2 NGVSm0p3 NGVSm0p4 \
  NGVSm0p5 NGVSm0p6 NGVSm1m0 NGVSm1m1 \
  NGVSm1m2 NGVSm1m3 NGVSm1m4 NGVSm1m5 \
  NGVSm1m6 NGVSm1m7 NGVSm1p1 NGVSm1p2 \
  NGVSm1p3 NGVSm1p4 NGVSm1p5 NGVSm2m0 \
  NGVSm2m1 NGVSm2m2 NGVSm2m3 NGVSm2m4 \
  NGVSm2m5 NGVSm2m6 NGVSm2m7 NGVSm2p1 \
  NGVSm2p2 NGVSm2p3 NGVSm2p4 NGVSm2p5 \
  NGVSm3m0 NGVSm3m1 NGVSm3m2 NGVSm3m3 \
  NGVSm3m4 NGVSm3m5 NGVSm3m6 NGVSm3p1 \
  NGVSm3p2 NGVSm3p3 NGVSm3p4 NGVSm3p5 \
  NGVSm4m0 NGVSm4m1 NGVSm4m2 NGVSm4m3 \
  NGVSm4m4 NGVSm4m5 NGVSm4p1 NGVSm4p2 \
  NGVSm4p3 NGVSm4p4 NGVSm5m0 NGVSm5m1 \
  NGVSm5m2 NGVSm5p1 NGVSm5p2 NGVSm5p3 \
  NGVSm6m0 NGVSm6p1 NGVSp1m0 NGVSp1m1 \
  NGVSp1m2 NGVSp1m3 NGVSp1m4 NGVSp1m5 \
  NGVSp1m6 NGVSp1m7 NGVSp1p1 NGVSp1p2 \
  NGVSp1p3 NGVSp1p4 NGVSp1p5 NGVSp2m0 \
  NGVSp2m1 NGVSp2m2 NGVSp2m3 NGVSp2m4 \
  NGVSp2m5 NGVSp2m6 NGVSp2p1 NGVSp2p2 \
  NGVSp2p3 NGVSp2p4 NGVSp2p5 NGVSp3m0 \
  NGVSp3m1 NGVSp3m2 NGVSp3m3 NGVSp3m4 \
  NGVSp3p1 NGVSp3p2 NGVSp3p3 NGVSp3p4 \
  NGVSp3p5 NGVSp4m0 NGVSp4m1 NGVSp4m2 \
  NGVSp4m3 NGVSp4p1 NGVSp4p2 NGVSp4p3 \
  NGVSp4p4 NGVSp5m0 NGVSp5m1 NGVSp5p1 \
  NGVSp5p2 NGVS_BG_1 NGVS_BG_2 NGVS_BG_3 \
  NGVS_BG_4 "
fi

if [ "${SURVEY}" = "STARFIELDS" ]; then 
  FIELDS="STAR01 STAR02 STAR03 STAR04 STAR05 STAR06 STAR07 STAR08 STAR09 \
  STAR10 STAR11 STAR12 STAR13 STAR14" 
fi

if [ "${SURVEY}" = "STRIPE82" ]; then 
  FIELDS="S82m39m S82m38m S82m3m S82m3p S82p0p S82p0m S82p28m S82p33p
  S82p39p S82p34m S82p45p S82p46p S82p47p S82p48p S82p1m S82p2m S82p3m
  S82p4m S82p5m S82p6m S82p7m S82p8m S82p9m S82p10m S82p11m S82p12m
  S82p13m S82p14m S82p15m S82p16m S82p17m S82p18m S82p19m S82p20m
  S82p21m S82p22m S82p23m S82p24m S82p25m S82p26m S82p27m S82p29m
  S82p30m S82p31m S82p32m S82p33m S82p35m S82p36m S82p37m S82p38m
  S82p39m S82p40m S82p41m S82p42m S82p43m S82m0m S82m1m S82m2m S82m4m
  S82m5m S82m6m S82m7m S82m8m S82m9m S82m10m S82m11m S82m12m S82m13m
  S82m14m S82m15m S82m16m S82m17m S82m18m S82m19m S82m20m S82m21m
  S82m22m S82m23m S82m24m S82m25m S82m26m S82m27m S82m28m S82m29m
  S82m30m S82m31m S82m32m S82m33m S82m34m S82m35m S82m36m S82m37m
  S82p1p S82p2p S82p3p S82p4p S82p5p S82p6p S82p8p S82p9p S82p10p
  S82p11p S82p12p S82p13p S82p14p S82p15p S82p16p S82p17p S82p18p
  S82p19p S82p20p S82p21p S82p22p S82p23p S82p24p S82p25p S82p27p
  S82p28p S82p29p S82p30p S82p31p S82p32p S82p34p S82p35p S82p36p
  S82p37p S82p38p S82p40p S82p41p S82p42p S82p43p S82p44p S82p7p
  S82p26p S82m24p S82m0p S82m1p S82m2p S82m4p S82m5p S82m6p S82m7p
  S82m8p S82m9p S82m10p S82m11p S82m12p S82m13p S82m14p S82m15p
  S82m16p S82m17p S82m18p S82m19p S82m20p S82m21p S82m23p S82m25p
  S82m26p S82m27p S82m28p S82m29p S82m30p S82m31p S82m32p S82m33p
  S82m34p S82m36p S82m22p S82m35p W4m0m1 W4m0m2 W4m1m1 W4p1m1 W4m1m2
  W4p1m2 W4p2m1 W4p2m2"
fi

if [ "${SURVEY}" = "STRIPE82HALL" ]; then
  FIELDS=" S82_1004 S82_1006 S82_1007 S82_1011 \
  S82_1013 S82_1015 S82_1016 S82_1018 \
  S82_1019 S82_1020 S82_1021 S82_1022 \
  S82_1023 S82_1024 S82_1025 S82_1028 \
  S82_1030 S82_1031 S82_1033 S82_1034 \
  S82_1035 S82_1036 S82_1039 S82_1040 \
  S82_1044 S82_1045 S82_1046 S82_1047 \
  S82_1048 S82_1050 S82_1053 S82_1054 \
  S82_1055 S82_1056 S82_1058 S82_1060 \
  S82_1061 S82_1062 S82_1064 S82_1065 \
  S82_1066 S82_1068 S82_1070 S82_1071 \
  S82_1072 S82_1073 S82_1074 S82_1075 \
  S82_1076 S82_1077 S82_1078 S82_1079 \
  S82_1081 S82_1082 S82_1083 S82_1085 \
  S82_1086 S82_1087 S82_1088 S82_1090 \
  S82_1091 S82_1093 S82_1094 S82_1095 \
  S82_1096 S82_1097 S82_1098 S82_1101 \
  S82_1102 S82_1106 S82_1107 S82_1108 \
  S82_1109 S82_1110 S82_1111 S82_1112 \
  S82_1113 S82_1116 S82_1117 S82_1118 \
  S82_1119 S82_2005 S82_2008 S82_2015 \
  S82_2016 S82_2017 S82_2018 S82_2020 \
  S82_2023 S82_2025 S82_2026 S82_2027 \
  S82_2029 S82_2030 S82_2032 S82_2033 \
  S82_2034 S82_2038 S82_2040 S82_2048 \
  S82_2049 S82_2050 S82_2051 S82_2052 \
  S82_2053 S82_2054 S82_2055 S82_2058 \
  S82_2061 S82_2062 S82_2064 S82_2065 \
  S82_2066 S82_2067 S82_2068 S82_2070 \
  S82_2074 S82_2076 S82_2077 S82_2078 \
  S82_2079 S82_2081 S82_2083 S82_2085 \
  S82_2087 S82_2088 S82_2089 S82_2090 \
  S82_2092 S82_2095 S82_2096 S82_2097 \
  S82_2098 S82_2099 S82_2100 S82_2101 \
  S82_2103 S82_2104 S82_2105 S82_2107 \
  S82_2108 S82_2109 S82_2110 S82_2111 \
  S82_2116 S82_2117 S82_3001 S82_3002 \
  S82_3004 S82_3005 S82_3006 S82_3007 \
  S82_3008 S82_3009 S82_3015 S82_3019 \
  S82_3022 S82_3024 S82_3025 S82_3026 \
  S82_3027 S82_3028 S82_3029 S82_3030 \
  S82_3031 S82_3032 S82_3033 S82_3035 \
  S82_3038 S82_3039 S82_3040 S82_3042 \
  S82_3045 S82_3046 S82_3049 S82_3050 \
  S82_3052 S82_3053 S82_3054 S82_3056 \
  S82_3059 S82_3060 S82_3061 S82_3062 \
  S82_3064 S82_3065 S82_3066 S82_3067 \
  S82_3068 S82_3069 S82_3070 S82_3075 \
  S82_3076 S82_3077 S82_3078 S82_3079 \
  S82_3080 S82_3084 S82_3086 S82_3087 \
  S82_3088 S82_3089 S82_3090 S82_3091 \
  S82_3092 S82_3093 S82_3094 S82_3095 \
  S82_3096 S82_3097 S82_3098 S82_3100 \
  S82_3101 S82_3102 S82_3103 S82_3104 \
  S82_3105 S82_3106 S82_3107 S82_3110 \
  S82_3111 S82_3114 S82_3115 S82_3118 \
  S82_3119"
fi

if [ "${SURVEY}" = "RCS" ]; then 
FIELDS=" CSP0320A3 CSP0320A4 CSP0320A5 CSP0320B2 CSP0320B3 CSP0320B4 \
  CSP0320B5 CSP0320C1 CSP0320C2 CSP0320C3 CSP0320C4 CSP0320C5 \
  CSP0320D0 CSP0320D4 CSP0320D5 CSP0320E4 CSP0320E5 CSP0320F3 \
  CSP0320F4 CSP0320F5 CSP0320G3 CSP0320G4 CSP0320G5 CSP0320H0 \
  CSP0320H1 CSP0320H2 CSP0320H3 CSP0320H4 CSP0320H5 CSP0320I5 \
  CDE0047A0 CDE0047A1 CDE0047A2 CDE0047A3 CDE0047A4 CDE0047A5 \
  CDE0047A6 CDE0047A7 CDE0047A8 CDE0047B0 CDE0047B1 CDE0047B2 \
  CDE0047B3 CDE0047B4 CDE0047B5 CDE0047B6 CDE0047B7 CDE0047B8 \
  CDE0047C0 CDE0047C1 CDE0047C2 CDE0047C3 CDE0047C4 CDE0047C5 \
  CDE0047C6 CDE0047C7 CDE0047C8 CDE0047D0 CDE0047D1 CDE0047D2 \
  CDE0047D3 CDE0047D4 CDE0047D5 CDE0047D6 CDE0047D7 CDE0047D8 \
  CDE0047E0 CDE0047E1 CDE0047E2 CDE0047E3 CDE0047E4 CDE0047E5 \
  CDE0047E7 CDE0047E8 CDE0047F0 CDE0047F1 CDE0047F2 CDE0047F3 \
  CDE0047F4 CDE0047F5 CDE0047F8 CDE0047G0 CDE0047G1 CDE0047G2 \
  CDE0047G3 CDE0047G4 CDE0047G5 CDE0047G6 CDE0047G7 CDE0047G8 \
  CDE0047H0 CDE0047H1 CDE0047H2 CDE0047H3 CDE0047H4 CDE0047H5 \
  CDE0047H6 CDE0047H7 CDE0047H8 CDE0047I0 CDE0047I1 CDE0047I2 \
  CDE0047I3 CDE0047I4 CDE0047I5 CDE0047I6 CDE0047I7 CDE0047I8 \
  CDE0133A0 CDE0133A1 CDE0133A2 CDE0133A3 CDE0133A4 CDE0133A5 \
  CDE0133B0 CDE0133B1 CDE0133B2 CDE0133B3 CDE0133B4 CDE0133B5 \
  CDE0133C0 CDE0133C1 CDE0133C2 CDE0133C3 CDE0133C4 CDE0133C5 \
  CDE0133D0 CDE0133D1 CDE0133D2 CDE0133D3 CDE0133D4 CDE0133D5 \
  CDE0133E0 CDE0133E1 CDE0133E2 CDE0133E3 CDE0133E4 CDE0133E5 \
  CDE0133F0 CDE0133F1 CDE0133F2 CDE0133F3 CDE0133F4 CDE0133F5 \
  CDE0310A0 CDE0310A1 CDE0310A2 CDE0310A3 CDE0310A4 CDE0310A5 \
  CDE0310A6 CDE0310A7 CDE0310A8 CDE0310B0 CDE0310B1 CDE0310B2 \
  CDE0310B3 CDE0310B4 CDE0310B5 CDE0310B6 CDE0310B7 CDE0310B8 \
  CDE0310C0 CDE0310C1 CDE0310C2 CDE0310C3 CDE0310C4 CDE0310C5 \
  CDE0310C6 CDE0310C7 CDE0310C8 CDE0310D0 CDE0310D1 CDE0310D2 \
  CDE0310D3 CDE0310D4 CDE0310D5 CDE0310D6 CDE0310D7 CDE0310D8 \
  CDE0310E0 CDE0310E1 CDE0310E2 CDE0310E3 CDE0310E4 CDE0310E5 \
  CDE0310E6 CDE0310E7 CDE0310E8 CDE0310F0 CDE0310F1 CDE0310F2 \
  CDE0310F3 CDE0310F4 CDE0310F5 CDE0310F6 CDE0310F7 CDE0310F8 \
  CDE0310G0 CDE0310G1 CDE0310G2 CDE0310G3 CDE0310G4 CDE0310G5 \
  CDE0310G6 CDE0310G7 CDE0310G8 CDE0310H0 CDE0310H1 CDE0310H2 \
  CDE0310H3 CDE0310H4 CDE0310H5 CDE0310H6 CDE0310H7 CDE0310H8 \
  CDE0310I0 CDE0310I1 CDE0310I2 CDE0310I3 CDE0310I4 CDE0310I5 \
  CDE0310I6 CDE0310I7 CDE0310I8 CDE0357A0 CDE0357A1 CDE0357A2 \
  CDE0357A3 CDE0357A4 CDE0357A5 CDE0357B0 CDE0357B1 CDE0357B2 \
  CDE0357B3 CDE0357B4 CDE0357B5 CDE0357C0 CDE0357C1 CDE0357C2 \
  CDE0357C3 CDE0357C4 CDE0357C5 CDE0357D0 CDE0357D1 CDE0357D2 \
  CDE0357D3 CDE0357D4 CDE0357D5 CDE0357E0 CDE0357E1 CDE0357E2 \
  CDE0357E3 CDE0357E4 CDE0357E5 CDE0357F0 CDE0357F1 CDE0357F2 \
  CDE0357F3 CDE0357F4 CDE0357F5 CDE1040A0 CDE1040A1 CDE1040A2 \
  CDE1040A3 CDE1040A4 CDE1040A5 CDE1040B0 CDE1040B1 CDE1040B2 \
  CDE1040B3 CDE1040B4 CDE1040B5 CDE1040C0 CDE1040C1 CDE1040C2 \
  CDE1040C3 CDE1040C4 CDE1040C5 CDE1040D0 CDE1040D1 CDE1040D2 \
  CDE1040D3 CDE1040D4 CDE1040D5 CDE1040E0 CDE1040E1 CDE1040E2 \
  CDE1040E3 CDE1040E4 CDE1040E5 CDE1040F0 CDE1040F1 CDE1040F2 \
  CDE1040F3 CDE1040F4 CDE1040F5 CDE1111A0 CDE1111A1 CDE1111A2 \
  CDE1111A3 CDE1111A4 CDE1111A5 CDE1111A6 CDE1111A7 CDE1111A8 \
  CDE1111B0 CDE1111B1 CDE1111B2 CDE1111B3 CDE1111B4 CDE1111B5 \
  CDE1111B6 CDE1111B7 CDE1111B8 CDE1111C0 CDE1111C1 CDE1111C2 \
  CDE1111C3 CDE1111C4 CDE1111C5 CDE1111C6 CDE1111C7 CDE1111C8 \
  CDE1111D0 CDE1111D1 CDE1111D2 CDE1111D3 CDE1111D4 CDE1111D5 \
  CDE1111D6 CDE1111D7 CDE1111D8 CDE1111E0 CDE1111E1 CDE1111E2 \
  CDE1111E3 CDE1111E4 CDE1111E5 CDE1111E6 CDE1111E7 CDE1111E8 \
  CDE1111F0 CDE1111F1 CDE1111F2 CDE1111F3 CDE1111F4 CDE1111F5 \
  CDE1111F6 CDE1111F7 CDE1111F8 CDE1111G0 CDE1111G1 CDE1111G2 \
  CDE1111G3 CDE1111G4 CDE1111G5 CDE1111G6 CDE1111G7 CDE1111G8 \
  CDE1111H0 CDE1111H1 CDE1111H2 CDE1111H3 CDE1111H4 CDE1111H5 \
  CDE1111H6 CDE1111H7 CDE1111H8 CDE1111I0 CDE1111I1 CDE1111I2 \
  CDE1111I3 CDE1111I4 CDE1111I5 CDE1111I6 CDE1111I7 CDE1111I8 \
  CDE1303A3 CDE1303A4 CDE1303B3 CDE1303C0 CDE1303C3 CDE1303C4 \
  CDE1303D0 CDE1303D3 CDE1303D4 CDE1303E0 CDE1303E4 CDE1303E8 \
  CDE1303F0 CDE1303F4 CDE1303F8 CDE1303G0 CDE1303G4 CDE1303G8 \
  CDE1303H0 CDE1303H4 CDE1303H8 CDE1303I0 CDE1303I1 CDE1303I4 \
  CDE1303I7 CDE1303I8 CDE1514A0 CDE1514A1 CDE1514A2 CDE1514A3 \
  CDE1514A4 CDE1514A5 CDE1514A6 CDE1514A7 CDE1514A8 CDE1514B0 \
  CDE1514B1 CDE1514B2 CDE1514B3 CDE1514B4 CDE1514B5 CDE1514B6 \
  CDE1514B7 CDE1514B8 CDE1514C0 CDE1514C1 CDE1514C2 CDE1514C3 \
  CDE1514C4 CDE1514C5 CDE1514C6 CDE1514C7 CDE1514C8 CDE1514D0 \
  CDE1514D1 CDE1514D2 CDE1514D3 CDE1514D4 CDE1514D5 CDE1514D6 \
  CDE1514D7 CDE1514D8 CDE1514E0 CDE1514E1 CDE1514E2 CDE1514E3 \
  CDE1514E4 CDE1514E5 CDE1514E6 CDE1514E7 CDE1514E8 CDE1514F0 \
  CDE1514F1 CDE1514F2 CDE1514F3 CDE1514F4 CDE1514F5 CDE1514F6 \
  CDE1514F7 CDE1514F8 CDE1514F9 CDE1514G0 CDE1514G1 CDE1514G2 \
  CDE1514G3 CDE1514G4 CDE1514G5 CDE1514G6 CDE1514G7 CDE1514G8 \
  CDE1514H0 CDE1514H1 CDE1514H2 CDE1514H3 CDE1514H4 CDE1514H5 \
  CDE1514H6 CDE1514H7 CDE1514H8 CDE1514I0 CDE1514I1 CDE1514I2 \
  CDE1514I3 CDE1514I4 CDE1514I5 CDE1514I6 CDE1514I7 CDE1514I8 \
  CDE1613A0 CDE1613A1 CDE1613A2 CDE1613A3 CDE1613A4 CDE1613A5 \
  CDE1613B0 CDE1613B1 CDE1613B2 CDE1613B3 CDE1613B4 CDE1613B5 \
  CDE1613C0 CDE1613C1 CDE1613C2 CDE1613C3 CDE1613C4 CDE1613C5 \
  CDE1613D0 CDE1613D1 CDE1613D2 CDE1613D3 CDE1613D3P23 CDE1613D4 \
  CDE1613D5 CDE1613E0 CDE1613E1 CDE1613E2 CDE1613E3 CDE1613E4 \
  CDE1613E5 CDE1613F0 CDE1613F1 CDE1613F2 CDE1613F3 CDE1613F4 \
  CDE1613F5 CDE1645A0 CDE1645A1 CDE1645A2 CDE1645A3 CDE1645A4 \
  CDE1645A5 CDE1645B0 CDE1645B1 CDE1645B2 CDE1645B3 CDE1645B4 \
  CDE1645B5 CDE1645C0 CDE1645C1 CDE1645C2 CDE1645C3 CDE1645C4 \
  CDE1645C5 CDE1645D0 CDE1645D1 CDE1645D3 CDE1645D4 CDE1645D5 \
  CDE1645E0 CDE1645E1 CDE1645E2 CDE1645E3 CDE1645E4 CDE1645E5 \
  CDE1645F0 CDE1645F1 CDE1645F2 CDE1645F3 CDE1645F4 CDE1645F5 \
  CDE2143A0 CDE2143A1 CDE2143A2 CDE2143A3 CDE2143A3P01 CDE2143A4 \
  CDE2143A5 CDE2143A6 CDE2143A7 CDE2143A8 CDE2143AA CDE2143B0 \
  CDE2143B1 CDE2143B2 CDE2143B2P01 CDE2143B3 CDE2143B4 CDE2143B5 \
  CDE2143B6 CDE2143B7 CDE2143B8 CDE2143BA CDE2143C0 CDE2143C1 \
  CDE2143C2 CDE2143C3 CDE2143C4 CDE2143C5 CDE2143C6 CDE2143C7 \
  CDE2143C7P18 CDE2143C8 CDE2143CA CDE2143D0 CDE2143D1 CDE2143D2 \
  CDE2143D3 CDE2143D4 CDE2143D5 CDE2143D6 CDE2143D7 CDE2143D8 \
  CDE2143DA CDE2143E0 CDE2143E1 CDE2143E2 CDE2143E3 CDE2143E4 \
  CDE2143E5 CDE2143E6 CDE2143E7 CDE2143E8 CDE2143EA CDE2143F0 \
  CDE2143F1 CDE2143F2 CDE2143F3 CDE2143F4 CDE2143F5 CDE2143F6 \
  CDE2143F7 CDE2143F8 CDE2143FA CDE2143G0 CDE2143G1 CDE2143G2 \
  CDE2143G3 CDE2143G4 CDE2143G5 CDE2143G6 CDE2143G7 CDE2143G8 \
  CDE2143GA CDE2143H0 CDE2143H1 CDE2143H2 CDE2143H3 CDE2143H4 \
  CDE2143H5 CDE2143H6 CDE2143H7 CDE2143H8 CDE2143HA CDE2143I0 \
  CDE2143I1 CDE2143I2 CDE2143I3 CDE2143I4 CDE2143I5 CDE2143I6 \
  CDE2143I7 CDE2143I8 CDE2143IA CDE2143J0 CDE2143J1 CDE2143J2 \
  CDE2143J2P17 CDE2143J3 CDE2143J4 CDE2143J5 CDE2143J6 CDE2143J6P28 \
  CDE2143J7 CDE2143J8 CDE2143JA CDE2329A0 CDE2329A1 CDE2329A2 \
  CDE2329A3 CDE2329A4 CDE2329A5 CDE2329B0 CDE2329B1 CDE2329B2 \
  CDE2329B3 CDE2329B4 CDE2329B5 CDE2329C0 CDE2329C1 CDE2329C2 \
  CDE2329C3 CDE2329C4 CDE2329C5 CDE2329D0 CDE2329D1 CDE2329D2 \
  CDE2329D3 CDE2329D4 CDE2329D5 CDE2329E0 CDE2329E1 CDE2329E2 \
  CDE2329E3 CDE2329E4 CDE2329E5 CDE2329F0 CDE2329F1 CDE2329F2 \
  CDE2329F3 CDE2329F4 CDE2329F5 CDE2329G0 CDE2329G1 CDE2329G2 \
  CDE2329G3 CDE2329G4 CDE2329G5 CDE2329H0 CDE2329H1 CDE2329H2 \
  CDE2329H3 CDE2329H4 CDE2329H5 CDE2338A0 CDE2338A1 CDE2338A2 \
  CDE2338A3 CDE2338A4 CDE2338A5 CDE2338A6 CDE2338A7 CDE2338A8 \
  CDE2338B0 CDE2338B1 CDE2338B2 CDE2338B3 CDE2338B4 CDE2338B5 \
  CDE2338B6 CDE2338B7 CDE2338B8 CDE2338C0 CDE2338C1 CDE2338C2 \
  CDE2338C3 CDE2338C4 CDE2338C5 CDE2338C6 CDE2338C7 CDE2338C8 \
  CDE2338D0 CDE2338D1 CDE2338D2 CDE2338D3 CDE2338D4 CDE2338D6 \
  CDE2338D7 CDE2338E0 CDE2338E1 CDE2338E2 CDE2338E3 CDE2338E4 \
  CDE2338E5 CDE2338E6 CDE2338E7 CDE2338E8 CDE2338F0 CDE2338F1 \
  CDE2338F2 CDE2338F3 CDE2338F4 CDE2338F5 CDE2338F6 CDE2338F7 \
  CDE2338F8 CDE2338G0 CDE2338G1 CDE2338G2 CDE2338G3 CDE2338G4 \
  CDE2338G5 CDE2338G6 CDE2338G7 CDE2338G8 CDE2338H0 CDE2338H1 \
  CDE2338H2 CDE2338H3 CDE2338H4 CDE2338H5 CDE2338H6 CDE2338H7 \
  CDE2338H8 CDE2338I0 CDE2338I1 CDE2338I2 CDE2338I3 CDE2338I4 \
  CDE2338I5 CDE2338I6 CDE2338I7 CDE2338I8 \
  CDE1514A9 CDE1514B9 CDE1514C9 CDE1514D9 CDE1514E9 CDE1514F9 \
  CDE1514G9 CDE1514H9 CDE1514I9"
fi

cd ${SURVEY}
for DIRECTORY in ${FIELDS}
do
  if [ ! -d ${DIRECTORY} ]; then
    echo "Creating directories for ${SURVEY} survey target: ${DIRECTORY}";
    mkdir ${DIRECTORY};
  fi

  cd ${DIRECTORY}
  filter_dirs "${FILTERS}"
  cd ..
done
