#!/bin/bash -xv

# the scripts creates catalogs used for astrometry with the
# ASTROMETRIX tool. To create clean catalogs we use the
# WEIGHT maps. We run SExtractor two times: The first run to 
# determine a reasonable value for the image seeing that
# is used in the second run.
#
# This special version for CFHTLS has configurable SExtractor
# thresholds for low- and long-exposed images. Often, short exposed
# images are obtained for photometric calibration of sets. To reach
# that the catalogues of those images contain about the same number
# of objects as the catalogues from the long-exposed science data
# we use a lower detection threshold. This is important for astrometric
# calibration where a large difference in object number for
# individual frames can pose problems. Note that these calibration
# images will not enter final co-addition but need astrometric
# calibration to enable photometric calibration later on!!!

#
# 28.04.2006:
# - I commented the creation of 'clean' catalogs (all objects with
#   a SExtractor flag larger than 1 filtered from the raw detections).
#   Those catalogs are currently not used within the pipeline
# - I removed the errorneous removal of a temporary catalogue
#
# 29.09.2006:
# CCDs which are marked as BAD (keyword BADCCD) are not included
# in the catalogue extraction process.

#$1: main directory
#$2: science dir.
#$3: image extension (ext) on ..._iext.fits (i is the chip number)
#$4: WEIGHTS directory
#$5: image extension for weight images 
#$6; thresshold for short exposed images (less than 100s)
#$7; thresshold for long exposed images (more than 100s)
#$8: chips to work on


. ${INSTRUMENT:?}.ini 

if [ ! -d "/$1/$2/cat" ]; then
  mkdir /$1/$2/cat
fi

for CHIP in ${!#}
do
  ${P_FIND} /$1/$2/ -maxdepth 1 -name \*_${CHIP}$3.fits > ${TEMPDIR}/astromimages_$$
  
  cat ${TEMPDIR}/astromimages_$$ |\
  {
    while read file
    do
      # check for BADCCD; if an image has a BADCCD mark of '1' it is
      # NOT included in the catalogue extraction process

      BADCCD=`${P_DFITS} ${file} | ${P_FITSORT} BADCCD | ${P_GAWK} '($1!="FILE") {print $2}'`

      if [ "${BADCCD}" != "1" ]; then

        BASE=`basename ${file} .fits`
        WBASE=`basename ${file} $3.fits`
        #
        # now run sextractor to determine the seeing:
        ${P_SEX} ${file} -c ${DATACONF}/singleastrom.conf.sex \
  			 -CATALOG_NAME ${TEMPDIR}/seeing_$$.cat \
  	                 -FILTER_NAME ${DATACONF}/default.conv\
  			 -CATALOG_TYPE "ASCII" \
  			 -DETECT_MINAREA 5 -DETECT_THRESH 5.\
  			 -ANALYSIS_THRESH 1.2 \
  			 -PARAMETERS_NAME ${DATACONF}/singleastrom.ascii.param.sex\
  	                 -WEIGHT_IMAGE /$1/$4/${WBASE}$5.fits\
                         -WEIGHT_TYPE MAP_WEIGHT
  
        NLINES=`wc ${TEMPDIR}/seeing_$$.cat | ${P_GAWK} '{print $1}'`
        fwhm=`${P_GAWK} 'BEGIN {binsize=10./'${NLINES}'; 
  			  nbins=int(((3.0-0.3)/binsize)+0.5);
  			  for(i=1; i<=nbins; i++) bin[i]=0}
  			 { if(($3*'${PIXSCALE}' > 0.3) && ($3*'${PIXSCALE}' < 3.0)) 
                           {
  			     actubin=int(($3*'${PIXSCALE}'-0.3)/binsize);
  			     bin[actubin]+=1; 
                           }
                         }
  		         END {max=0; k=0 
  			 for(i=1;i<=nbins; i++)
  			 {
  			   if(bin[i]>max)
  			   { 
  			     max=bin[i];
  			     k=i;
  			   }
  			 }
  			 print 0.3+k*binsize}' ${TEMPDIR}/seeing_$$.cat`
  
        if [ "A${fwhm}" = "A0.0" ]; then
  	  fwhm=1.0
        fi
        
        #now run sextractor to extract the objects
	#
	# check for short and long exposed images:

        EXPTIME=`${P_DFITS} ${file} | ${P_FITSORT} EXPTIME | ${P_GAWK} '($1!="FILE") {print int($2)}'`
	
	if [ ${EXPTIME} -le 100 ]; then
	    THRESH=$6
            MINAREA=$6
	else
	    THRESH=$7
            MINAREA=$7
	fi

        ${P_SEX} ${file} -c ${DATACONF}/singleastrom.conf.sex\
  		         -CATALOG_NAME /$1/$2/cat/${BASE}.cat\
  		         -SEEING_FWHM $fwhm \
  		         -DETECT_MINAREA ${THRESH} -DETECT_THRESH ${MINAREA}\
  	                 -WEIGHT_IMAGE /$1/$4/${WBASE}$5.fits\
                         -WEIGHT_TYPE MAP_WEIGHT
        
        rm ${TEMPDIR}/seeing_$$.cat
      fi
    done
  }
done

rm ${TEMPDIR}/singleastromimages_$$

exit 0;


