#!/bin/bash -xv

. ${INSTRUMENT:?}.ini

# this script performs astrometry by using astrometrix 
# this version performs operations only on the images contained
# in a list (typically a run)
#
# This version is special for the CFHTLS Deep data.
# It takes into account that this survey consists of so many
# images that processing time of a 'normal' ASTROMETRIX
# calibration is unaccatably long.
# For this survey we therefore split a set in several subsets
# that are processed separately. For PHOTOMETRIX, however,
# we need to 'artificially' create ONE large set. This involvs,
# in connection with PHOTOMETRIX some 'nasty' and 'unhandy'
# copying and rearranging of catalogue files. For this to be clean
# the ASTROMETRIX and PHOTOMETRIX codes would need to be rewritten.
# Until this is done we keep these scripts as special versions for
# the particular CFHTLS Deep survey.

# 28.07.2007
# Bug fix for a wrong check of a variable count in building up
# the 'LISTS' variable.
#
# 03.08.2007:
# Increase of the maximum number of standardstar objects retrieved
# via the net. We now reject objects fainter than mag 20 within
# ASTROMETRIX. Hence, there is no reason to not request all available
# objects first.
#
# 22.08.2007:
# The executable of SExtractor is set to 'sex_theli' as
# it is called now within the THELI pipeline.


# $1: main dir.
# $2: science dir. (the cat dir is a subdirectory of this)
# $3: extension
# $4: standardstar catalog to use (default to USNO)
# $5: 'ending' of the directory name where this program runs.
#     The final directory is called /$1/$2/astrom_$5
# $6-$#: lists of files to be processed (the lists have to contain the
#        BASENAMES of the files, i.e. filename=BASENAME_${CHIP}$3.fits;
#        the lists have to be given together with the full path)

STARCAT=$4
LISTS=""
DIR=`pwd`

# preliminary work:

cd /$1/$2/

if [ ! -d "astrom_$5" ]; then
  mkdir astrom_$5
  mkdir astrom_$5/$2
fi

# we need an 'astrom' directory to store all necessary
# data from all set groups for PHOTOMETRIX at one place:
test -d /$1/$2/astrom || \
{
  mkdir /$1/$2/astrom
  mkdir /$1/$2/astrom/$2
  mkdir /$1/$2/astrom/astglob
}

cd astrom_$5/$2

# create links for the catalogs as those have
# already been created for the LDAC astrometric
# solution

FILES=`${P_FIND} /$1/$2/cat/ -maxdepth 1 -name \*$3.cat`

for CAT in ${FILES}
do
  BASE=`basename ${CAT} .cat`
  ${P_LDACFILTER} -i ${CAT} -t LDAC_OBJECTS \
                  -c "((FLAGS<2)OR(FLAGS=16))AND(B_IMAGE>2.0);" \
                  -o ${BASE}.ldac

  # The following copy is needed for PHOTOMETRIX
  cp ${BASE}.ldac /$1/$2/astrom/$2/${BASE}.ldac
done

cd ..

# now run 'astrom -initk' on all runs individually:
j=6
while [ "${j}" -le "$#" ]
do
  # first create the astrometrix filelist from the run
  # to be considered:
  
  LISTBASE=`basename ${!j} .txt`
  
  # build list argument for global astrometry call:
  if [ "${j}" -eq "6" ]; then
    LISTS="$2_${LISTBASE}.list"    
  else
    LISTS="${LISTS},$2_${LISTBASE}.list"  
  fi 
  
  # count the number of objects in each exposure
  # We want to choose that with the largest number
  # of objects as the reference for determining 
  # a first order solution.
  BASE=`basename ${!j}`
  test -f nobjs_${!j} && rm nobjs_${BASE}

  while read file
  do
    i=1
    NOBJ=0
    while [ "${i}" -le "${NCHIPS}" ]
    do
      NOBJIM=`${P_LDACTOASC} -b -i ./$2/${file}_${i}$3.ldac \
                             -t LDAC_OBJECTS -k NUMBER | wc -l`
      NOBJ=`${P_GAWK} 'BEGIN{print '${NOBJ}'+('${NOBJIM}'+0)}'`
      i=$(( $i + 1 )) 
    done
    echo ${file}" "${NOBJ} >> nobjs_${BASE}
  done < ${!j}

  # sort according to object number and put the
  # exposure with the largest object number on top of
  # the list so that ASTROMETRIX uses it as reference.
  ${P_SORT} -g -r -k 2,2 nobjs_${BASE} | \
  ${P_GAWK} '{print $1}' > sort_nobjs_${BASE}

  while read file
  do
    i=1
    while [ "${i}" -le "${NCHIPS}" ]
    do
      echo $2/${file}_${i}$3.fits >> $2_${LISTBASE}.list
      # create also a global list for photometrix in the 
      # 'astrom' directory:
      echo $2/${file}_${i}$3.fits >> /$1/$2/astrom/$2.list
      i=$(( $i + 1 )) 
    done
  done < sort_nobjs_${BASE}
  
  perl ${S_ASTROMETRIX} \
   -initk -s table=$2_${LISTBASE}.dat -s list=$2_${LISTBASE}.list \
   -s fits_dir=$1 -s catalog=${STARCAT} \
   -s narrow=n -s thresh=10 -s radius=65 -s groupccd=y -s cats_dir="" \
   -s MAXNUM_LIN=100000 -s outdir_top=/$1/$2/astrom_$5 -s pstol=3. \
   -s SEX=sex_theli

  j=$(( $j + 1 ))
done

perl ${S_ASTROMETRIX} -global -s list=${LISTS}

cd ..

# copy headers and cleaned catalogues and master catalogs to the 
# 'astrom' directory for PHOTOMETRIX:
${P_FIND} ./astrom_$5/astglob/ -name \*head -exec cp {} /$1/$2/astrom/astglob \;
${P_FIND} ./astrom_$5/$2/ -name x\*ldac -exec cp {} /$1/$2/astrom/$2 \;

# finally copy the astrometrix headers to the right place
# and rename them

test -d headers || mkdir headers;

${P_FIND} ./astrom_$5/astglob/ -name \*head -exec cp {} ./headers \;

cd ./headers
${P_FIND} . -name \*_1$3.head -print > files_$$

while read file
do
  i=1
  BASE=`basename ${file} _1$3.head`
  while [ "${i}" -le "${NCHIPS}" ]
  do
    mv ${BASE}_${i}$3.head ${BASE}_${i}.head
    i=$(( $i + 1 )) 
  done
done < files_$$

rm files_$$

cd ${DIR}



