#!/bin/bash -xv

# script to run scamp on the CFHTLS, NGVS and Stripe82 Survey fields
# and to produce scamp headers! For the small CFHTLS Wide patches, W2,
# W4, and NGVS (at least for the first year data) we run scamp
# simultaneously on all pointings and all colours. For the big Wide
# patches W1 and W3 we run scamp on the individual colours plus the
# r-band. The r-band contains the presurvey and hence contributes most
# to the astrometric solution.  For CFHTLS Deep, we currentlly run
# this script on a per colour basis.  Stripe 82 only contains i-band
# data.
# There are two modes for this script:
# prepare and final. 'prepare' scamp is run only to optimise the
# estimation of relative photometric zeropoints. It is intended to
# reject bad images after that (for instance with script
# reject_bad_wide.sh) and to rerun in mode 'final' only with good
# images.
#
# Update:
# Starting from the second year we process NGVS as the large CFHTLS 
# patches W1 and W3. 
#
# NOTE: 
# The directory structure for this script is:
# ../W1/u/cat, ../W1/g/cat, ../W1/r/cat ......, .../NGVS/u/cat,
# ../NGVS_BG_1/u/cat, .../NGVS_BG_2/u/cat, ...D1/y/cat, .....
# i.e. all catalogues from all pointings go to a field/colour/cat
# structure. You need to copy them over from the standrad THELI
# processing structure!! Note that for NGVS, you need to create
# different directories for the NGVS 'main' field, and for the four
# background fields!

# HISTORY COMMENTS
# ================
#
# 17.09.2010:
# I adapted calls to create_scamp_astrom_photom.sh to the new
# syntax of the script (maximun positional accuracy as command
# line argument)
#
# 05.10.2010:
# SDSS-R6 -> SDSS-R7; update to scamp 1.7.0
#
# 07.01.2011:
# I added code to process the STRIPE82 survey. It requires usage of
# a 'maunal' astrometric standard star catalogue.
#
# 27.04.2011:
# We use 'normal' scamp processing (no split in astrom/photom parts)
# for Stripe82.

#$1: main directory (including the SURVEY!)
#$2: field to process W1-W4
#$3: filters to process
#$4: processing mode: prepare or final

MD=$1
FIELD=$2
FILTERS="$3"
MODE=$4

export INSTRUMENT=MEGAPRIME

# set the standardstar catalogue to use; if we do not
# have SLOAN, we use 2MASS:
STDCAT=2MASS
STDCATID=2MASS # for the header directory identifier;
               # we need a special variable because of STRIPE82
if [ "${FIELD}" = "W3" ] || [ "${FIELD}" = "D3" ] ||\
   [[ "${FIELD}" =~ "NGVS" ]]; then
  STDCAT=SDSS-R7
  STDCATID=SDSS-R7
fi

# for Stripe 82 we have a manually created standardstar catalogue:
if [[ "${FIELD}" =~ "STRIPE82" ]]; then
  STDCAT=`pwd`/STRIPE82_ref.cat
  STDCATID=MANUAL
fi

if [[ "${FIELD}" =~ /COSMOS/ ]]; then
  SCAMPLINERAW="${MD}/COSMOS_C filt C \
                ${MD}/COSMOS_LL filt C \
                ${MD}/COSMOS_LR filt C \
                ${MD}/COSMOS_UL filt C \
                ${MD}/COSMOS_UR filt C"
  PROCESSFIELDS="COSMOS_C COSMOS_LL COSMOS_LR COSMOS_UL COSMOS_UR"
else
  SCAMPLINERAW="${MD}/${FIELD} filt C"
  PROCESSFIELDS=${FIELD}
fi

# finally do the scamp run with field-specific settings:
if [ ${FIELD} = "W1" ] || [ ${FIELD} = "W3" ] ||\
 [[ "${FIELD}" =~ "NGVS" ]]; then
  for FILT in ${FILTERS}
  do
    SCAMPLINE=`echo ${SCAMPLINERAW} | sed -e "s/filt/${FILT}/g"`
    if ( [ ${FIELD} = "W1" ] || [ ${FIELD} = "W3" ] ) && \
        [ "${FILT}" != "r" ]; then
      SCAMPLINE="${SCAMPLINE} ${MD}/${FIELD} r C"
    fi

    if [[ "${FIELD}" =~ "NGVS" ]] && [ "${FILT}" != "y" ]; then
      SCAMPLINE="${SCAMPLINE} ${MD}/${FIELD} y C"
    fi

    ./create_scamp_astrom_photom.sh \
       ${SCAMPLINE} 2.0 ${STDCAT} photom

    if [ "${MODE}" = "final" ]; then
      ./create_scamp_astrom_photom.sh \
         ${SCAMPLINE} 2.0 ${STDCAT} astrom
    fi
  done
else
  SCAMPLINE=""
  for FILT in ${FILTERS}
  do
    SCAMPLINE="${SCAMPLINE} `echo ${SCAMPLINERAW} |\
      sed -e 's/filt/'${FILT}'/g'`"
  done

  # for STRIPE82 we use 'normal' processing. It turned out
  # that splitting processing in astrom/photom gives bad results
  # for relative photometry here:
  if [ "${FIELD}" = "STRIPE82" ]; then
    ./create_scamp_astrom_photom.sh \
        ${SCAMPLINE} 2.0 ${STDCAT}
  else
    ./create_scamp_astrom_photom.sh \
        ${SCAMPLINE} 2.0 ${STDCAT} photom
  
    if [ "${MODE}" = "final" ]; then
      ./create_scamp_astrom_photom.sh \
         ${SCAMPLINE} 2.0 ${STDCAT} astrom
    fi
  fi
fi

for FILT in ${FILTERS}
do
  for CURRFIELD in ${PROCESSFIELDS}
  do 
    HEADERS=headers_scamp_${STDCATID}
    if [ "${MODE}" != "final" ] && [ "${FIELD}" != "STRIPE82" ]; then
      HEADERS=headers_scamp_${STDCATID}_photom
    fi
    if [ "${MODE}" = "final" ]; then
      ./merge_scamp_cats.sh ${MD}/${CURRFIELD} ${FILT} \
        headers_scamp_${STDCATID}_astrom \
        headers_scamp_${STDCATID}_photom \
        headers_scamp_${STDCATID}
    fi
    ./create_stats_table.sh  ${MD}/${CURRFIELD} ${FILT} C \
      ${HEADERS}
    ./create_absphotom_photometrix.sh ${MD}/${CURRFIELD} ${FILT}
    ./make_checkplot_stats.sh ${MD}/${CURRFIELD} ${FILT} \
      chips.cat6 STATS ${FILT}
  done
done
