#!/bin/bash

# the script gives the reduction steps for a run reduction of a
# MEGAPRIME survey run.  It is assumed that data are avilable in
# Elixir processed form. It is intended to be used on a single
# processor machine (or on a single machine containing several
# processors) but NOT on a distributed cluster.

# HISTORY COMMENTS:
#
# 14.09.2006:
# I changed a call to check_files_CFHTLS.sh to check_files_MEGAPRIME.sh
#
# 17.09.2006:
# I extended the documentation and made more variables configurable
# from the command line.
#
# 28.09.2006:
# I modidied the call to create_weights_para.sh to use a special
# retina filter for CFHTLS images.
#
# 21.03.2007:
# - For the u filter we use lower threshholds to identify 'good'
#   frames (because of the lower throughput in u)
# - Weight maps are stored in 8-bit now. This is possible because
#   up to now we do not use a normalised flat as basis for weights
#   but only a bad pixel mask containing only zero and one values.
# - astrometric catalogues are created with different detection
#   thressholds for short (photometric pegs) and long-exposed images.
#   (we use a lower thresshold in the shorter exposres to have more
#   sources for astrometry) 
#
# 15.05.2007:
# I corrected a bug in the call of 'create_bitpixchange.sh'.
# '*' as PREFIX led to giving the files in the reduce directory
# as PREFIX argument.
#
# 25.06.2007:
# I started to make the script more general to also use it with
# MEGAPRIME data not obtained within the CFHTLS. I generalised the
# 'process_split_CFHTLS...'  script to also accept frames not obtained
# within that survey and hence without quality and skyprobe
# information.  That script is now called 'process_split_MEGAPRIME..'
#
# 26.07.2007:
# - I improved the handling of command line arguments: Up to now the
#   script continued if either all arguments were checked OR if an
#   unknown argument option occured. The latter case is now handled
#   with an error message.
#
# 01.08.2007:
# I included a section STRACK for automatic track detection with
# Patricks STRACK tools. An associated new section REGIONWEIGHTS was
# introduced to recreate weights with the masks included (in case this
# is necessary at all).
#
# 03.08.2007:
# Bug fix. Some 'find maxdepth' options were not placed correctly.
#
# 21.08.2007:
# Bug Fix: The default value of SETROOT needs to be set AFTER reading
# command line arguments, not before. It uses BASEDIR as default
# value. This might be modified with command line options.
#
# 27.08.2007:
# I introduced the survey concept to this script. It affects
# the names/meanings of several variables and the call
# to link_set:
# old BASEDIR -> BASEDIRROOT; BASEDIR is now BASEDIRROOT/SURVEY
# old SETROOT -> SETDIRROOT; new variable SETDIR is SETDIRROOT/SURVEY
# old WEBDIR -> WEBDIRROOT; new variable WEBDIR is WEBDIRROOT/{SURVEY}WWW
#
# 29.08.2007:
# - For the surveys CFHTLSDEEP and CFHTLSWIDE we automatically choose
#   Deep_Wide.cat in ${REDDIR} as PHOTCAT.
# - The files to be deleted during the STRACK step are adapted to the
#   new version of the STRACKTOOLS.
# - I modified the minimum counts to pass 'good frames' statistics
#   check. Good, short exposed photometric frames can have counts below 100. 
#
# 27.09.2007:
# The skybackground subtraction and the script 'create_skysub_para.sh',
# and hence the corresponding section in this script, changed.
#
# 02.10.2007:
# The STRACK section was made more robust by ceating the needed default
# Hough weight imnage outside main scripts. When creating it within the
# scripts it could happen that parallel channels wanted to create the
# file at the same time leading to a corrupted file.
#
# 18.10.2007:
# The changes from 02.10. are reverted. The STRACK weight creation was
# imporved in the HOUGH main scripts.
#
# 17.12.2007:
# I included a new mode TESTREG to test the presence of region files.
# I introduced a 'mode' so that the check can be skipped on purpose.
# If it is run reg files are defined to be present if the follwing three
# condition are met:
# - The corresponding reg file directory does exist
# - The corresponding reg file directory does exist and
#   is not empty
# - There are not only reg files for short exposures (less than
#   100 sec.)  
#
# 07.10.2008:
# call to script create_astromcats_CFHTLS_weights_para.sh.raw 
# substituted with create_astromcats_weights_para.sh.raw; this script
# now contains the special functionality (adaption of detection threshold
# with image exposure time) of the former 
#
# 13.10.2008:
# The call to create_strack_mask.sh was substituted to one of 
# create_strack_mask_exposurepara.sh
#
# 25.10.2008:
# detection threshholds for CFHTLSWIDE data in 'i' and 'u' deviate
# from the default value of 5, 'i'-band data have many more detection
# than all the other bands, u-band data typically much less.
#
# 04.01.2009:
# - The detection threshold for the new i-band filter (called 'y')
#   was set to 7 as for the i-band filter
# - new command line option 'notracks'. If set to 'y' we assume in any
#   case that region files (satellite tracks) have been created before.
#   This is useful for small runs where the satellite track module is
#   run each time although we know that there are no tracks in the images. 
#
# 19.02.2009:
# - I introduced a flag 'tracks' which forces satellite track detection!   
# - I lowered the threshold for accepted, low exposed u-band data 
#   (20 -> 15 counts)
# - In the SINGLEASTROM step I now delete an old cat subdirectory if present.
#   I saw in previous reductions that catalogues merged from SExtractor and 
#   KSB were messed up when old catalogues were present. This, up to now,
#   did not happen with a clean catalogue creation.
#
# 13.03.2009:
# I lowered the threshhold for accepted frames from 50 to 30 (all filters
# except u). It turned out that some good, short exposed photometric-peg 
# images have modes between 30 and 50!
#
# 16.04.2009:
# - The CFHTLS exposure catalogue was changed from Deep_Wide.cat to
#   Deep_Wide_VeryWide_Phot.cat to also include Very Wide and CFHTLS
#   photometric data; the validity of this catalogue was extended to
#   the surveys CFHTLSPRESURVEY and CFHTLSPHOTSURVEY.
# - splitted images are now, by default, deleted at the end of the
#   SCIENCE step; we never needed them! This can be prevented by useing
#   the new command line option '-noclean'.
#
# 15.07.2009:
# - calls to catalogue creation scripts adapted to new syntax of these
#   scripts. The catalogue directory now is a command line 
#   argument; changes were necessary because we use them for the
#   'CORRECTWEIGHTS' mode which creates another set of catalogues in
#   other subdirectories
# - I added a check for the GLOBALWEIGHTS directory. I forgot to create
#   this directory and to copy corresponding files too often.
# - New mode 'CORRECTWEIGHTS': It tries to circumvent a cosmic ray mask
#   mask problem. In very good seeing conditions (better than 0.65 arcsec)
#   many good stars are confused as cosmic rays.
#
# 30.07.2009
# I adapted the call to fix_stars_weights_para.sh to the new syntax of
# that script.
#
# 25.09.2009:
# The REGIONWEIGHTS step is always done now (if region files are present).
# Before, I skipped this step if the REGPRESENT variable was 0. This,
# however, gives wrong results if processing MODES are done one after the
# other. 
#
# 05.10.2009:
# - For NGVS we allow images with a mode as low as 20 in the processing.
#   This survey contains very short exposures for which this low values
#   for a mode are valid.
# - I lowered again the NGVS threshold for allowed images from 20 to 18!
#   In 'g' we saw a lot of images with a mode of 19!
#
# 10.10.2009:
# The satellite track detection can now be done in chunks of 'N'
# images; 'N' is hardwired at 40 at the moment. We introduced this
# possibiliry because this step creates VERY large files and hence
# often causes disk space problems for large runs.
#
# 07.01.2010:
# - I introduced a new command lne argument to allow special processing
#   at Terapix (photometric zeropoints for some data are there stored in
#   separate text files, instead of in the image headers) 
# - I adapted the call to 'process_split_MEGAPRIME_eclipse.sh' to the new
#   syntax of that script.
#
# 01.02.2010:
# - Fix in the command line argument setting '-y'
#
# 03.02.2010:
# I adapted the call to 'create_astromcats_weights.sh' to the new calling
# syntax of that script.
#
# 01.06.2010:
# The CORRECTWEIGHTS mode is now done also for the z-band. We discovered
# a problematic z-band within CFHTLS/CARS.
#
# 14.09.2010:
# The REGIONWEIGHTS mode definitely does not need to be executed
# if the user sets the 'notracks' flag. We can safely assume that
# 'final' weights are then created with the WEIGHTS mode (see also
# changes from 25.09.2009)
#
# 24.09.2010:
# We now create links for the global weight images instead of copying
# them. Similarily for global flag images.
#
# 02.02.2011:
# Bug fix in the call to 'create_strack_mask_exposurepara.sh'. We gave a
# command line argument (MIN_WIDTH) that is never used in the script.
# VERY surprising that this bug escaped my attention so far!!
#
# 05.02.2011:
# I introduced a quality catalogue for the STRIPE82 survey.
#
# 10.08.2011:
# - Bug fix: The STRACK mode was faulty when several instances of this script
#            were run in parallel.
# - The script now uses a temporary directory for temporary files. If the
#   environment variable TEMPDIR is not set we use the directory where
#   this script was launched for (small) temporary files.
#
# 05.09.2011:
# The RUNDISTRIBUTE mode now checks whether pipelog.py is present before
# trying to execute that script.
#
# 07.04.2014:
# The syntax of script 'create_weights_flags_para.sh' changed. I adapted
# this script accordingly.
#
# 10.06.2015:
# - The script now also support processing of the new 40-chip configuration
#   of MEGAPRIME!
# - The script create_bitpixchange.sh was renamed to
#   create_bitpixchange_para.sh and this script was adapted
#   accordingly.  Moreover there was a bug in the calling sequence of
#   that script (proper quoting of an exclamation mark)
# - common code in the WEIGHTS and REGIONWEIGHTS modes was restructured
#   to a bash function.

# the script is called with 
# ./doall_run_CFHTLS_single.sh OPTIONS -m "MODE1 MODE2 ...."
# See below for a description of the options.

# The different modes are the following:
#
# - PREPARE:
#   splits data, checks whether the
#   modes of images are within given limits
#   and marks potentially bad CCDs
#
# - SCIENCE
#   does the preprocessing on science frames
#   which, in the case of Elixir preprocessed 
#   MEGAPRIME images, only consits of trimming images
# 
# - SKYSUB
#   subtracts the sky from science images. From these images
#   the small quick-look mosaics are created.
#
# - MOSAICS
#   creates small, binned mosaics from the SCIENCE images
#   These can be used for quick-look checks. The are also put
#   into the RUN webpages!
#
# - TESTREG
#   test for the existence of region files. The presence 
#   (or non presence) has influence on weight creation and
#   satellite track detection. The latter can be skipped
#   if region files are already available.
#
# - GLOBALWEIGHTS
#   'creates' global weight images. In the case of 
#   MEGAPRIME@CFHT this currently consists of copying predefined
#   bad pixel masks to the WEIGHTS directory.
#
# - WEIGHTS
#   creates weight images for all individual science images
#
# - STRACK
#   detect satellite tracks with Patrick Hudelots STRACK
#   tools.
#
# - REGIONWEIGHTS
#   recreate weight images after satellite tracks have
#   been detected (STRACK step).
#
# - CORRECTWEIGHTS
#   We saw that our cosmic ray detector within the WEIGHTS creation 
#   setp is too aggressive. It also flags the cores of stars in this 
#   case. This step tries to correct this.
# 
# - SINGLEASTROM
#   create object catalogues which will be used for astrometric
#   calibration within the set processing. We do this step here
#   as we need some image statistics (sseing, background, stellar
#   ellipticities) for the RUN WWW pages.
# 
# - RUNSCIENCEPAGES (NEEDS ADDITIONAL PROGRAMS/INSTALLATIONS)
#   create WEB pages for the SCIENCE frames of a RUN
# 
# - RUNDISTRIBUTE
#   distribute s current CFHTLS run into the MEGAPRIME@CFHT
#   set structure  
# 
# - CLEANORIG (OBSOLTETE)
#   restore the original state of the run directories
#   after Elixir processed files were moved to them,
#

#
# definitions
#

# Note that we need to define an instrument and include some files
# here. We might overwrite the instrument below if we work with
# 'mode 2' (40-chip) data!
export INSTRUMENT=MEGAPRIME

# inclusions
. ./${INSTRUMENT:?}.ini
. ./bash_functions.include
theli_start "$*"

#
# The six variables BASEDIR, RUN, WEBDIR, PHOTCAT, GLOBALWEIGHTDIR,
# FILTER, SETDIRROOT, PSFANALYSIS are typically passed on the command line. 
# If they are not passed the following 'defaults' are used:
BASEDIRROOT=/raid2/thomas     # Base root directory for image data
                              # The later basedir is ocmposed of
                              # basedirroot and survey.
FILTER="i"                    # Filter to be processed. They
                              # are typically u, g, r, i, z
RUN=run_03BQ03_W1             # The RUN to be processed

# catalog with information whether a CFHTLS
# frame was obtained under photometric conditions.
# The variable has to be initialised to an empty string 
# so that the call to 'process_split_MEGAPRIME..' is
# correct if no PHOTCAT is available.
PHOTCAT=

# An ASCII file with imagename, photometric zeropoint and
# 'is photometric?' flag. It overrides information in the
# PHOTCAT. This is probably only useful for image processings
# at Terapix.
YANNICKZP=

# The directory with the templates for global weight
# images requires additional programs/installations NOT 
# included in the standard THELI/CFHTLS distribution.
GLOBALWEIGHTDIR=/raid1/thomas/CFHTLS/GLOBALWEIGHTS

# root directory for region files created by Patrick Hudelots
# Strack tools. If, for a specific run, region files
# are already present we do not need to recreate them.
REGDIR=/home/thomas/CFHTLS_regs
REGPRESENT=0  # if '1' then region files for the run under 
              # consideration are present. The variable is finally
              # set in the TESTREG MODE below.

# root directory for WEB pages. The script has full processing
# capabilities WITHOUT this definition. Note that WEB Page
# creation 
WEBDIRROOT=/home/www/public_html/CFHTLS

# Shall we do PSF analysis. Note that this requires additional
# programs NOT included in the standard THELI/CFHTLS distribution.
PSFANALYSIS=N # set to 'Y' if you want PSF analysis turned on

# Default Survey:
SURVEY=CFHTLSWIDE

#
# DOT NOT MODIFY BELOW THIS LINE!!!

#
# read command line arguments
#
MODE=""
NOTRACKS=0
TRACKS=0
CLEANUP=1
GoOn=0
while [ $GoOn = 0 ]
do
  case $1 in
  -b)
    BASEDIRROOT=${2}
    shift 2
    ;;
  -f)       
    FILTER=${2}
    shift 2
    ;; 
  -m)
    MODE=${2}
    shift 2
    ;;
  -noclean)
    CLEANUP=0
    shift 1
    ;;
  -notracks)
    NOTRACKS=1  
    shift 1
    ;;
  -p)
    PHOTCAT="-cat ${2}"
    shift 2
    ;;
  -psf)
    PSFANALYSIS=${2}
    shift 2
    ;;
  -r)
    RUN=${2}
    shift 2
    ;; 
  -reg)
    REGDIR=${2}
    shift 2
    ;;
  -s)
    SURVEY=${2}
    shift 2
    ;;
  -set)
    SETDIRROOT=${2}
    shift 2
    ;;
  -tracks)
    TRACKS=1  
    shift 1
    ;;
  -w)
    GLOBALWEIGHTDIR=${2}
    shift 2
    ;;
  -www)
    WEBDIRROOT=${2}
    shift 2
    ;;
  -y)
    YANNICKZP="-yannickzp ${2}"
    shift 2
    ;;
   *)
    if [ $# -ge 1 ]; then
      echo "Unknown command line option: ${1}"
      exit 1	   
    else
      GoOn=1
    fi
    ;;
  esac
done

# sanity checks:
if [ "${MODE}_A" = "_A" ]; then
  echo "nothing to do: exiting!"
  exit 1
fi

if [ "${TRACKS}" -eq 1 ] && [ "${NOTRACKS}" -eq 1 ]; then
  echo "TRACKS and NOTRACKS are both set! Please correct!"
  echo "Exiting!"
  exit 1
fi

# check for the existence of the GLOBALWEIGHTS directory
# If it does not exist we probably forgot to copy globalweight
# images what will lead into trouble of quite some processing:
if [ ! -d ${GLOBALWEIGHTDIR} ]; then
  echo "You probably forgot to create the GLOBALWEIGHTS directory!!"
  echo "Exiting!!"
  exit 1
fi

# The Base directory for sets.  Put it to BASEDIR as default if no
# SETROOT was set explicitely:
SETDIRROOT=${SETDIRROOT:-${BASEDIRROOT}}

# append the survey to basedirroot, webdirroot and setdirroot:
BASEDIR=${BASEDIRROOT}/${SURVEY}
SETDIR=${SETDIRROOT}/${SURVEY}
WEBDIR=${WEBDIRROOT}/${SURVEY}WWW

export BASEDIR
export FILTER
export RUN
export SETDIR
export MD=${BASEDIR}/${FILTER}/${RUN}

# check whether we work with 36-chip or 40-chip MEGAPRIME data.
# We identify 40-chip data by the filter name:
FILTER=`${P_FIND} ${MD}/SCIENCE_${FILTER}/ORIGINALS/ \
   -name \*p.fits | head -1 | \
   xargs ${P_DFITS} | ${P_FITSORT} -d FILTER | cut -f 2`

if [ "${FILTER}" = "" ]; then
  theli_error "No images present in ${MD}/SCIENCE_${FILTER}! Exiting!"
  exit 1;
fi

if [ "${FILTER}" = "u.MP9302" ] || [ "${FILTER}" = "g.MP9402" ] || \
   [ "${FILTER}" = "r.MP9602" ] || [ "${FILTER}" = "i.MP9703" ] || \
   [ "${FILTER}" = "z.MP9901" ]; then
  export INSTRUMENT=MEGAPRIME_FOURTYCHIP  
  . ./${INSTRUMENT:?}.ini
fi

# special retina filter for MEGAPRIME reductions:
REDDIR=`pwd`
RETINAFILTER=${REDDIR}/megacam.ret

# directory for temporary files. If it is not defined we use the
# present work directory
if [ -z "${TEMPDIR}" ]; then
  TEMPDIR=`pwd`
fi

# special settings for individual surveys:

# First quality catalogs for several large surveys:
if [ "${SURVEY}" = "CFHTLSWIDE" ] || \
   [ "${SURVEY}" = "CFHTLSDEEP" ] || \
   [ "${SURVEY}" = "CFHTLSPRESURVEY" ] || \
   [ "${SURVEY}" = "CFHTLSPHOTSURVEY" ]
then
  PHOTCAT="-cat ${REDDIR}/Deep_Wide_VeryWide_Phot.cat"
fi

if [ "${SURVEY}" = "NGVS" ]; then
  PHOTCAT="-cat ${REDDIR}/NGVS_05_01_10.cat"
fi

if [ "${SURVEY}" = "STRIPE82" ]; then
  PHOTCAT="-cat ${REDDIR}/STRIPE82_quality.cat"
fi

# the minimum ADU accepted for an image to be included                          
# into processing                                                               
LOWCOUNTACCEPT=30

# NGVS contains very short exposures:                                           
if [ "${SURVEY}" = "NGVS" ]; then
  LOWCOUNTACCEPT=18
fi

# function definitions
#

# function to create weights, test for images having mostly
# weight zero images and to change the BITPIX of weights / flags
# to 8-bit. This function is used in the WEIGHTS and REGIONWEIGHTS
# modes
function create_weights {
  ./parallel_manager.sh ./create_weights_flags_para.sh ${MD} \
           SCIENCE_${FILTER} "C" WEIGHTS_FLAGS HIGHSN ${RETINAFILTER} 

  # mark as bad science images whose weights consist of zeros
  # for more than 15% of their area:

  # delete first old badchips file if necessary:
  test -f ./${RUN}_${FILTER}_badchip.txt && rm ./${RUN}_${FILTER}_badchip.txt
  
  ./determine_badchips_exposurepara.sh ${MD} WEIGHTS \
          C.weight -0.5 0.5 15 ./${RUN}_${FILTER}_badchip.txt

  if [ -s ./${RUN}_${FILTER}_badchip.txt ]; then
    while read IMAGE
    do
      BASE=`basename ${IMAGE} .weight.fits`
      if [ -f ${MD}/SCIENCE_${FILTER}/${BASE}.fits ]; then
        value "1"
        writekey ${MD}/SCIENCE_${FILTER}/${BASE}.fits \
                 BADCCD "${VALUE}" REPLACE
        writekey ${MD}/SCIENCE_${FILTER}/${BASE}.sub.fits \
                 BADCCD "${VALUE}" REPLACE
      fi
    done < ./${RUN}_${FILTER}_badchip.txt  
  fi

  # For MEGARPIME weights only consist of zeros and ones so that
  # we can save a lot of space ehen converting weights to 8 bits:
  ./parallel_manager.sh ./create_bitpixchange_para.sh ${MD} WEIGHTS \
           "\?" "C.weight." 8  
}

#
## Here starts the real work !!!!
#

# preparatory work (splitting of images; checking of integrity)
for mode in ${MODE}
do
  if [ "${mode}" = "PREPARE" ]; then
    ./process_split_MEGAPRIME_eclipse.sh -md ${MD} -sd SCIENCE_${FILTER} \
                                             ${PHOTCAT} ${YANNICKZP}

    # for the u filter the lower threshhold for good frames has
    # to be significantly lower than for the other filters. Short
    # photometric frames can have counts as low as 20!
    if [ "${FILTER}" = "u" ]; then 
      ./check_files_MEGAPRIME.sh ${MD} SCIENCE_${FILTER} "" 10 15 10000
    else
      ./check_files_MEGAPRIME.sh ${MD} SCIENCE_${FILTER} "" \
        10 ${LOWCOUNTACCEPT} 10000
    fi
  fi
done

# preprocessing of science frames
for mode in ${MODE}
do
  if [ "${mode}" = "SCIENCE" ]; then
    ./parallel_manager.sh ./process_cut_eclipse_para.sh ${MD} \
      SCIENCE_${FILTER}

    # by default remove splitted images: 
    if [ ${CLEANUP} -eq 1 ]; then
      find ${MD}/SCIENCE_${FILTER} -name SPLIT_IMAGES -type d | xargs rm -rf
    fi
  fi
done

# create sky subtracted images
for mode in ${MODE}
do
  if [ "${mode}" = "SKYSUB" ]; then
    ./parallel_manager.sh ./create_skysub_para.sh  \
       ${MD} SCIENCE_${FILTER} "C" ".sub" ONEPASS
  fi
done

# create binned mosaics
for mode in ${MODE}
do
  if [ "${mode}" = "MOSAICS" ]; then
    ./create_binnedmosaics_exposurepara.sh ${MD} SCIENCE_${FILTER} "" \
       C.sub 8 -32  
  fi
done

# create global weight images
for mode in ${MODE}
do
  if [ "${mode}" = "GLOBALWEIGHTS" ]; then
    test -d ${MD}/WEIGHTS || mkdir ${MD}/WEIGHTS
    if [ "${INSTRUMENT}" = "MEGAPRIME" ]; then
      ln -s ${GLOBALWEIGHTDIR}/36_chip/globalw*fits ${MD}/WEIGHTS
    else
      ln -s ${GLOBALWEIGHTDIR}/40_chip/globalw*fits ${MD}/WEIGHTS
    fi
 
    # create global flag images; simply 1's for the whole
    # field at the moment. We also use here implicitely that
    # all weight/flag image have the same size:
    ic -p 8 '%1 0 *' ${MD}/WEIGHTS/globalweight_1.fits > \
        ${MD}/WEIGHTS/globalflag_1.fits 

    # just links for all global flag images but the first one:
    for i in `seq 2 ${NCHIPS}`
    do
      ln -s ${MD}/WEIGHTS/globalflag_1.fits ${MD}/WEIGHTS/globalflag_$i.fits
    done
  fi
done

# check for the existence of region files
for mode in ${MODE}
do
  if [ "${mode}" = "TESTREG" ]; then
    # If track detection is forced the tests can/need be skipped:  
    if [ ${TRACKS} -eq 0 ]; then
      if [ ${NOTRACKS} -eq 1 ]; then
        REGPRESENT=1
      else  
        # REG files are 'defined' to not be present if:
        # - The corresponding reg file directory does not exist
        # - The corresponding reg file directory does exist but
        #   is empty
        # - There are only reg files for short exposures (less than
        #   100 sec.)  
        REGPRESENT=0  
        if [ -d ${REGDIR}/${FILTER}/${RUN} ]; then
          for REGFILE in `find ${REGDIR}/${FILTER}/${RUN} -name \*reg`
          do
            # check exptime of all FITS files of which reg files
            # exist
            FITSFILE=${MD}/SCIENCE_${FILTER}/`basename ${REGFILE} .reg`C.fits
            if [ -f ${FITSFILE} ]; then
              SCIENCE_FILE=`dfits ${FITSFILE} | fitsort -d EXPTIME\
                            | awk '{if($2 > 100.0) { print 1} else {print 0}}'`
  
              if [ ${SCIENCE_FILE} -eq 1 ]; then
                REGPRESENT=1
              fi
            fi 
          done
        fi
      fi
    fi
  fi
done

# create initial weight images
for mode in ${MODE}
do
  if [ "${mode}" = "WEIGHTS" ]; then
    # use region files if present:
    if [ ${REGPRESENT} -eq 1 ]; then
      test -d ${MD}/SCIENCE_${FILTER}/reg || mkdir ${MD}/SCIENCE_${FILTER}/reg
      cp ${REGDIR}/${FILTER}/${RUN}/*reg ${MD}/SCIENCE_${FILTER}/reg
    fi

    # the rest is done by the create_weights function (defined above)
    create_weights
  fi
done

# create Satellite TRACK images
for mode in ${MODE}
do
  if [ "${mode}" = "STRACK" ]; then

    # do nothing if region files are already available:
    if [ ${REGPRESENT} -eq 0 ]; then
      # because the satellite track detection creates very large files
      # we split up the process in junks of 'NFILES' files.
      NSTRACKFILES=40
      
      find ${MD}/SCIENCE_${FILTER} -name \*C.fits |\
        awk -F/ '{print $NF}' | awk -F_ '{print $1}' | sort | uniq |\
        awk 'BEGIN { n = 1; name = "'${TEMPDIR}'/" "SEG_images_" n "_'$$'"; } {
               print $0 >> name;
               if(NR == n * '${NSTRACKFILES}') {
                 n++;
                 name = "SEG_images_" n "_'$$'";
               }
             }'

      for FILE in ${TEMPDIR}/SEG_images*_$$
      do
        # Create the hough images
        ./parallel_manager.sh ./create_hough_para.sh \
          ${MD} SCIENCE_${FILTER} C ${FILE}
    
        # Detect the tracks
        ./create_strack_mask_exposurepara.sh \
          ${MD} SCIENCE_${FILTER} C ${FILE}
    
        # delete not needes stuff from the track detection.
        # Especially the 'SEG' images are very large:
        ./cleanfiles.sh ${MD}/SCIENCE_${FILTER} '*' "C_SEG."
        ./cleanfiles.sh ${MD}/SCIENCE_${FILTER} '*' "C_SEG_hSN."
        ./cleanfiles.sh ${MD}/SCIENCE_${FILTER} '*' "C_SEG.fits_weight_ref."
        find ${MD}/SCIENCE_${FILTER} -maxdepth 1 -name default\* | xargs rm
        find ${MD}/SCIENCE_${FILTER} -maxdepth 1 -name tmp\* | xargs rm
        find ${MD}/SCIENCE_${FILTER}/cat -maxdepth 1 \
             -name seeing\*cat | xargs rm
        find ${MD}/SCIENCE_${FILTER} -maxdepth 1 -name \*LOG | xargs rm
        find ${MD}/SCIENCE_${FILTER} -maxdepth 1 -name log\* | xargs rm
        find ${MD}/SCIENCE_${FILTER} -maxdepth 1 -name HTweight\*fits\* \
             | xargs rm
  
        # copy region files to appropriate subdirs of REGDIR
        # and to a reg subdirectory:
        test -d ${MD}/SCIENCE_${FILTER}/reg || mkdir ${MD}/SCIENCE_${FILTER}/reg
        test -d ${REGDIR}/${FILTER}         || mkdir ${REGDIR}/${FILTER}
        test -d ${REGDIR}/${FILTER}/${RUN}  || mkdir ${REGDIR}/${FILTER}/${RUN}
    
        FILES=`find ${MD}/SCIENCE_${FILTER}/STRACK -name \*C.reg`
          
        for FILE in ${FILES}
        do
          BASE=`basename ${FILE} C.reg`
          cp ${FILE} ${MD}/SCIENCE_${FILTER}/reg/${BASE}.reg
          cp ${FILE} ${REGDIR}/${FILTER}/${RUN}/${BASE}.reg
        done
      done
      rm ${TEMPDIR}/SEG_images*_$$
    fi
  fi
done

# create initial weight images
for mode in ${MODE}
do
  if [ "${mode}" = "REGIONWEIGHTS" ]; then
    # we definitely do not need to execute this mode  
    # if the user forces notrcks:
    if [ ${NOTRACKS} -ne 1 ]; then  
      if [ -d  ${MD}/SCIENCE_${FILTER}/reg ]; then
        # first delete old weight/flag files:
        ./cleanfiles.sh ${MD}/WEIGHTS '*' "C.weight."
        ./cleanfiles.sh ${MD}/WEIGHTS '*' "C.flag."

        create_weights
      fi
    fi
  fi
done

# 'correct' weight/flag images for too agressive stellar masking
# in very good seeing conditions (cosmic ray mask problem)
for mode in ${MODE}
do
  if [ "${mode}" = "CORRECTWEIGHTS" ]; then
    # first create catalogues WITHOUT the weights: as we aim for high
    # S/N stars we omit details on thresholds for different filters;
    #
    # Only do it for g, r, i, y and z filters:
    if [[ ${FILTER} = g* ]] || [[ ${FILTER} = r* ]] ||\
       [[ ${FILTER} = i* ]] || [ "${FILTER}" = "y" ] ||\
       [[ ${FILTER} = z* ]]; then
      ./parallel_manager.sh ./create_astromcats_weights_para.sh ${MD} \
                                  SCIENCE_${FILTER} C cat_maskcorr\
                                  NONE NONE NONE 10 200 3
  
      # we 'abuse' the check PSF script to create KSB catalogues. We
      # need different stepsizes to locate the stellar branch in the
      # rh-mag diagram in the 36-chip and the 40-chip camera setups:
      #
      STEPSIZE=0.15
      if [ "${INSTRUMENT}" = "MEGAPRIME_FOURTYCHIP" ]; then
        STEPSIZE=0.12  
      fi
      ./parallel_manager.sh ./check_science_PSF_para.sh ${MD} \
               SCIENCE_${FILTER} C cat_maskcorr ${STEPSIZE}
          
  
      ./merge_sex_ksb.sh ${MD} SCIENCE_${FILTER} C cat_maskcorr 
  
      # The '4.1' in the following call is the fixed radius around stars
      # in which weights/flags are 'fixed'.  
      ./parallel_manager.sh ./fix_stars_weights_para.sh \
                             ${MD} SCIENCE_${FILTER} C cat_maskcorr \
                             WEIGHTS C.weight C.flag 4.1 2.0
    fi
  fi
done

# create catalogues for astrometric calibration during SET
# processing
for mode in ${MODE}
do
  if [ "${mode}" = "SINGLEASTROM" ]; then
    # delete old catalogues if present:
    test -d ${MD}/SCIENCE_${FILTER}/cat && rm -rf ${MD}/SCIENCE_${FILTER}/cat

    # default threshhold is 5 pixels with 5 sigma
    # (for 'normal' data)
    THRESH=5 

    if [ "${SURVEY}" = "CFHTLSWIDE" ]; then
      if [ "${FILTER}" = "i" ] || [ "${FILTER}" = "y" ]; then
        THRESH=7
      fi
      if [ "${FILTER}" = "u" ]; then
        THRESH=4
      fi       
    fi

    ./parallel_manager.sh ./create_astromcats_weights_para.sh ${MD} \
                                SCIENCE_${FILTER} C cat\
                                WEIGHTS C.weight NONE ${THRESH} 200 3
    #
    # to make things simple for the WEB page creation we create
    # PSF checkplots for all colours 
    #
    if [ "${PSFANALYSIS}" = "Y" ]; then
      # We need different stepsizes to locate the stellar branch in
      # the rh-mag diagram in the 36-chip and the 40-chip camera
      # setups:
      #
      STEPSIZE=0.15
      if [ "${INSTRUMENT}" = "MEGAPRIME_FOURTYCHIP" ]; then
        STEPSIZE=0.12  
      fi

      ./parallel_manager.sh ./check_science_PSF_para.sh ${MD} \
                                SCIENCE_${FILTER} C cat ${STEPSIZE}

      ./check_science_PSF_plot.sh ${MD} \
                      SCIENCE_${FILTER} C cat
      ./merge_sex_ksb.sh ${MD} SCIENCE_${FILTER} C cat
    fi
    ./create_stats_table.sh ${MD} SCIENCE_${FILTER} C
  fi
done

# Create web pages for SCIENCE frames
for mode in ${MODE}
do
  if [ "${mode}" = "RUNSCIENCEPAGES" ]; then
    if [ -x ./pipelog.py ]; then  
      ./pipelog.py -n 36 -a runscience -f ${FILTER} -o ${WEBDIR} \
                   -b ${BASEDIR} -r ${RUN} -e C
      ./pipelog.py -n 36 -a runindex -f ${FILTER} -o ${WEBDIR} \
                   -b ${BASEDIR} -r ${RUN}
    fi
  fi
done

# distribute current run. In the CFHTLS case we only create links
# in the set directories
for mode in ${MODE}
do
  if [ "${mode}" = "RUNDISTRIBUTE" ]; then
    # At the DIR machine in Edinburgh we need to set the MD to the set directory
    # (link and mount structure on these machines):
    LINKMD=${MD}
    if [[ "`hostname`" =~ 'lensing-compute' ]]; then
      LINKMD=${SETDIR}/${FILTER}/${RUN}
    fi    
    ./parallel_manager.sh ./link_sets_CFHTLS_para.sh ${LINKMD} \
                           SCIENCE_${FILTER} \
                           C ${FILTER} ${SETDIR} ${SURVEY}
  fi
done

# remove all 'derived' products and restore the state after data
# have been moved to the ORIGINALS directory.
#
# We basically NEVER use this MODE - probably OBSOLETE
for mode in ${MODE}
do
  if [ "${mode}" = "CLEANORIG" ]; then
    ./cleanfiles.sh ${MD}/SCIENCE_${FILTER}/SPLIT_IMAGES '*' "."
    rmdir ${MD}/SCIENCE_${FILTER}/SPLIT_IMAGES
    ./cleanfiles.sh ${MD}/SCIENCE_${FILTER}/ '*' "C."
    ./cleanfiles.sh ${MD}/SCIENCE_${FILTER}/ '*' "C.sub."
      
    if [ -d ${MD}/SCIENCE_${FILTER}/cat ]; then
      rm -rf ${MD}/SCIENCE_${FILTER}/cat
    fi

    if [ -d ${MD}/SCIENCE_${FILTER}/BINNED ]; then
      rm -rf ${MD}/SCIENCE_${FILTER}/BINNED
    fi

    if [ -d ${MD}/WEIGHTS ]; then
      ./cleanfiles.sh ${MD}/WEIGHTS "global" "."
      ./cleanfiles.sh ${MD}/WEIGHTS '*' "C.weight."
      rmdir ${MD}/WEIGHTS
    fi
  fi
done

theli_end
exit 0;
