#!/bin/bash

# the script gives the reduction steps for a set reduction of a
# MEGAPRIME@CFHT 'survey'. This version is for use on a single
# processor machine

#
# HISTORY COMMENTS:
#
# 28.08.2006:
# If a special astrometric catalogue for the field under consideration
# exists it is used instead of USNO in the ASTROMETRIX run.  The
# special astrometry file has to be an ASCII file with a list of
# objects in ASTROMETRIX format, i.e.  it has to contain three columns
# with Ra, Dec (both in sexagesimal notation) and Mag. Its name has to
# be ${FIELD}_astrometrix.asc and it needs to be in ${REDDIR}.
#
# 30.08.2006:
# I adapted the call to mag_distribution_korr.sh to account for an
# additional command line argument.
#
# 03.09.2006:
# If the create_stats_table script creates a 'chips.cat6' 
# catalogue (i.e. ellipticity information on the stars is available)
# we use it to create quality plots.
#
# 21.09.2006:
# - I adapted the call to the script create_run_list.sh to its
#   new syntax.
# - I extended the documentation within this script.
#
# 29.09.2006:
# I set the co-addition type to MEDIAN (it was WEIGHTED before
# but for CFHTLS data we do not mask satellite tracks for the
# moment)
#
# 23.11.2006:
# - For CFHTLS we use the i-band as reference. We process it with
#   USNO-A2 and later extract an astrometric catalogue for the other
#   colours. This catalogue is named FIELD_astrometrix.asc. If such
#   a catalogue is present in REDDIR we automatically use it. 
#   The coaddition identifier in this case is replaced by
#   ${COADDIDENT}_astrom.
# - I fixed a bug in the handling of magnitude zeropoints (inconsistencies
#   if a non-existent magnitude zeropoint was expressed by "-1" or
#   "-1.0").
#
# 08.01.2007:
# I added W4 fields to the centre coordinates
#
# 21.03.2007:
# - The standard astrometric catalogue is now USNOB1, no longer
#   USNOA2.
#   Extracted astrometric catalogues now have names
#   ${FIELD}_USNOB1_astrometrix.asc instead of ${FIELD}_astrometrix.asc.
# - The 'default' MAGZP is now '-1.0' instead of '-1'. '-1' leads
#   to an integer Header keyword but the MAGZP should be FLOAT.
# - I introduced a new command line option '-chips' which allows
#   the co-addition of selected chips. The chips to be coadded have
#   to be given in parenthese, i.e. '-chips "1 2 3"'. The default
#   value for this variable is "ALL" which means co-addition of all
#   available chips.
# - If we process non i-band data we require an extracted astrometric
#   standardstar catalogue to be present.
# - I corrected a bug in the call of 'create_modesub...' during the
#   co-addition phase.
# - 'Bad' chips are marked at the start of the astrometric phase.
#   Chips are 'bad' if the corresponding chip in the astrometric
#   reference band (i) is bad and hence no astrometric information
#   is available in certain image areas.
#
# 09.05.2007:
# I corrected a bug when checking the astrometric catalogue for non
# i-band CFHTLS data.
#
# 15.05.2007:
# - I introduced the command line arguments
#   'ci' (coaddition identifier; former 'c')
#   'cc' (coaddition condition; former 'co')
#   'cm' (coaddition method (MEDIAN; WEIGHTED); new argument)
# 
# - I introduced a pecial astrometric treatment of DEEP sets.
#
# - At the moment we use the USNOB1 as standardstar catalogue
#   for all DEEP pointings AND colours.
#
# 04.07.2007:
# I changed checking for a not present MAGZP from
# [ "${MAGZP}" != "0" ] to [ "${MAGZP}" != "-1.0" ]
# The concrete case where this led to problems is unknown now
# but the old test was obviously wrong.
#
# 26.07.2007:
# - I improved the handling of command line arguments:
#   Up to now the script continued if either all
#   arguments were checked OR if an unknown argument option
#   occured. The latter case is now handled with an
#   error message.
#
# 02.08.2007:
# I introduced a new keyword SURVEY (defaulted to CFHTLS 
# and changeable via the command line option '-s'). It allows
# for special settings in particulat surveys (e.g. COADDIDENT
# settings etc. for CFHTLS). This is part of the efforts to 
# make the script also usable for other data than the CFHTLS.
#
# 19.08.2007:
# I added a missing W2p1m1 field to the target coordinates.
#
# 21.08.2007:
# - I split the CFHTLS 'survey' option to CFHTLSDEEP and
#   CFHTLSWIDE as they need different processings.
# - If a reference USNOB1 catalogue is present it always overrides
#   the set standardstar catalogue
# - The WEBDIR can now be configured via the 'www' command line
#   option.
#
# 27.08.2007:
# I introduced the concept of a SURVEY.
# It influences the known sets and several directory settings.
# This concept allows us to treat different surveys with the
# same script and we do not need new scripts (containing a lot
# of redundant information) for each survey.
#
# 10.09.2007:
# A badchip file for individual filters can now be handled
# (marking of not usable chips).
#
# 11.09.2007:
# - I added new targets in the CLUSTER survey section
# - I adaptes the call to mark_badchips.sh' to the new syntax
#   of that script.
#
# 15.09.2007:
# I adapted calls to create_stats_table.sh and prepare_coadd_swarp.sh
# to their new command line syntax. The directory containing
# ASTROMETRIX headers has to be provided explicitely (availability
# of scamp within THELI)
#
# 27.09.2007:
# I added A1835 and A2537 to the cluster survey fields.
#
# 15.10.2007:
# Two changes for producing release images of the CFHTLSWIDE
# survey:
# - A new mode 'CUTCOADD' to cut all CFHTLSWIDE co-added images
#   to the same size
# - A special script to update headers was written (additional
#   keywords necessary for data release)
#
# 07.11.2007:
# I corrected a bug in the W4 fields. They had a
# 'p0' instead of a 'm0' for zero fields.
#
# 17.12.2007:
# I included the possibility to use scamp (as a replacement for ASTROMETRIX) 
# for astrometric and photometric calibration. The user has to indicate via
# the '-am' command line option that he wants to use scamp. The used reference
# catalogue has to be given in the SCAMPCAT variable below. Different from
# ASTROMETRIX this catalogue is used ALWAYS, also if ASCII catalogues from the
# field under consideration are present in the reduce directory, i.e. the
# field ASCII catalogues are currently not used with scamp calibration.
#
# 30.12.2007:
# If a file ${FIELD}_${FILTER}_phot.txt is present in the reduce directory
# it is interpreted as containing a string with a combination of photometric
# nights and photometric solutions. It is then used by the 
# create_absphotom_photometrix script. This allows us to provide photometric
# information for SETS where no standard calibration is present as for CFHTLS, 
# e.g. the CLUSTER survey.
#
# 10.01.2008:
# I added coordinates for the COSMOS fields which represent the
# u-band observations for the CFHTLS D2 u-band.
#
# 25.01.2008:
# I added the coordinates for the RXJ1347 cluster.
#
# 17.02.2008:
# - I exchanged the call to resample_coadd_swarp_CFHTLS_para.sh
#   to resample_coadd_swarp_para.sh. I adapted this script so
#   that it can deal with the requirements of CFHTLS processing
#   (no following of links in this script)
#
# 15.04.2008:
# - I added data for the cluster A2259 and RCS2327
# - When scamp is used I introduced the possibility to process multi-colour 
#   data at the ASTROMPHOTOM step.
#
# 06.05.2008:
# After co-addition I delete all resampled individual images.
# Up to now we do not need them and they occupy a lot of disk
# space.
#
# 11.06.2008:
# I added MS0451 to the clusters
#
# 18.06.2008:
# - I introduced a new variable (and corresponding command line argument)
#   to possibly cleanup intermediary products.
# - The variable ASTROMADD also can be set via a command line argument (-aa)
#
# 18.07.2008:
# I unified the ASTROMETRIXCAT and SCAMPCAT variables to 'ASTROMETRYCAT'.
# The separation was not really necessary and only confusing.
#
# 19.07.2008:
# - I adapted the call to the 'update_coadd_header' script which now puts
#   supplementary informations to image headers
# - I corrected a bug in setting the ASTROMREFCAT variable which is used
#   to set the ASTRCAT variable in headers of co-added images.
#
# 22.07.2008:
# header directories for scamp processing now carry the name of the used
# standardstar catalogue.
#
# 15.08.2008:
# I added A2163 to the cluster list
#
# 04.09.2008:
# I modified the coadd section to produce a 'sum' context map of
# the co-added science image.
#
# 23.09.2008:
# - new ASTROMETRYCATALOGUE Option 'BEST'
#   (currently available only for the CFHTLSWIDE survey);
#   It is set to SDSS-R6 for W3 and W4 and 2MASS for W1 and W2
# - If we do not clean resampled images (end of co-addition section)
#   we remove the flxscale out of them (we rescale them so that
#   the flxscale is '1'). 
#
# 19.12.2008:
# - observation date information is transfered to resampled and rescaled
#   single frames (request from T. Schrabback within the shear collaboration)
# - The BEST astrometric catalogue option for the CFHTLS-Wide survey
#   is refined.
#
# 16.04.2009:
# addition of several MACS clusters to the cluster coordinates
# (collaboration with Anja)
#
# 06.09.2009:
# Before cleaning up resampled files (after co-addition) I try to check
# whether the co-addition succeeded. I now lost resampled images too often
# because a coaddition did not succeed due to too small open file descriptor
# limits.
#
# 15.09.2009:
# - Before co-addition we check whether enough file descriptors
#   for the final swarp run can be allocated.
# - Before cleaning resampled images (COADD step) we check the
#   coadded image for integrity
# - I added A2744 to the galaxy clusters
# - I added the first four pointings of the Next Generation Virgo
#   Survey
# - Bug fix in the CLEANUP process of the COADD section.
# - adapation in the call of create_scamp_astrom_photom
#   (ASTROMPHOTOM section)
#
# 18.09.2009:
# I added 49 new NGVS fields
#
# 25.09.2009:
# - The CUTCOADD image has no more restriction on the CFHTLS
#   Wide survey. We basically always 'cutted' co-added MEGAPRIME 
#   images to a size of 21kx21k.
# - The CUTCOADD mode now delets the original images in the script 
#   CLEANUP mode. Before deleting old images, the new ones are checked
#   for integrity with fitsverify.
#
# 13.10.2009:
# Bug fix in the call to 'makesubimage'
#
# 07.11.2009:
# In the POSTCOADD step we check whether we need to do it with the cutted,
# or uncutted version of the co-added images (the CUTCOADD step probably
# deleted the original images).
#
# 07.01.2010:
# The POSTCOADD step is now done always with the .swarp.cut versions of the
# images if they exist. It can happen that cutted, and uncutted
# image versions were present. In this case, for some colours the cutted, and
# for others, the uncutted data were used.
#
# 01.02.2010:
# I added a survey STARFIELDS for SLIP processing.
#
# 05.02.2010:
# I adapted the call to 'create_scamp_astrom_photom' to the new syntax
# of that script; an estimate for the maximum positional offset os now
# a command line argument.
#
# 26.03.2010:
# I added Mischas SCL2241 to the clusters list
#
# 01.05.2010:
# - I included Mischas resample_swarpfilter script
# - new command line option '-sf' to activate Mischas 'swarpfilter'.
#
# 05.10.2010:
# SDSS-R6 -> SDSS-R7. SDSS-R6 is outdated now.
#
# 06.10.2010:
# I added Ludos Stripe 82 survey
#
# 17.10.2010:
# I added 2nd year NGVS field definitions
#
# 02.11.2010:
# There was a faulty NGVSm0p0 field in the NGVS descriptions
#
# 08.02.2011:
# STRIPE82 overlaps with eight W4 fields from CFHTLS. I added
# those eight fields to the STRIPE82 survey.
#
# 11.02.2011:
# The final co-additions of the science and the sum frame now happen
# in parallel.
#
# 05.05.2011:
# I adapted the call to 'perform_coadd_swarp' to the new syntax of that
# script (new command line option specifying the location of 'coadd.head'
# file).
#
# 22.06.2011:
# addition of A2465 to the cluster objects
#
# 25.07.2011:
# I added RCS to the known surveys of this script. To keep the size
# of this script reasonable I put the field corrdinates of the surveys in
# a separate file that is sourced into this script.
#
# 09.03.2012:
# The final conversion of the sum image from float to int now happens
# with 'ic' instead of 'iofits'. iofits does not work properly if the
# image size exceeds 2GB.
#
# 13.11.2012:
# I corrected a bug in the parallel cutting of final co-added images.
#
# 15.09.2013:
# The script 'mag_distribution_korr.sh' was renamed to
# 'create_mag_distribution_korr.sh.'. I adapted this script
# accordingly.
#
# 18.09.2013:
# I corrected a major bug in the 'FINALCLEAN' mode. If a directory
# was not present the complete 'pwd' could be deleted!!
#
# 03.04.2014:
# With the new parallel manager (GNU parallel) giving a '?' as a command line
# option to create_modesub_para.sh made difficulties - fixed by proper quoting
# of the '?'.
#
# 25.04.2014:
# The calling syntax to create_scamp_astrom_photom.sh changed. I adapted this
# script accordingly.
#
# 06.05.2014:
# bug fix in mode CUTCOADD: unmapped pixels from flag images must get
# a default value of 1, all other image types must get a 0. Up to now
# also the flags got a zero indicating that these (unmapped) pixels
# are valid (a '1' is necessary to indicate that they are invalid!).
#
# 27.04.2015:
# I added astrometry checkplots (POSTCOADD step).
#
# 11.06.2015:
# - I updated the script so that data from the new MEGAPRIME 40-chip
#   configuration can be processed.
# - new astrometry checkplots are created in the post-coaddition step.
#
# 22.06.2015:
# I added a missing astrometry update in the refinements from 11.06.2015
# for use with multiple instruments.

# the script is called with 
# ./doall_set_CFHTLS_single.sh -m "MODE1 MODE2 ...."
# the different modes are the following:
#
# - ASTROMPHOTOM
#   does astrometric and photometric calibration
#   via ASTROMETRIX and PHOTOMETRIX
#
# - SETCHECKPLOT
#   creates checkplot (with seeing dist., ellipticities
#   etc.) for to set to be processed 
#  
# - COADD
#   do image coaddition with eisdrizzle or swarp
#
# - POSTCOADD
#   create a first SExtractor catalog and produce basic
#   science verification of data (mag-rh diagram,
#   galaxy number counts)
#   (NOT YET DONE PROPERLY)
#
# - COADDHEADERUPDATE
#   updates the final coadded image header with EXPTIME
#   GAIN and MAGZP information
#   (NOT YET DONE PROPERLY; e.g. the gain is not correct
#   when data are not co-added with a mean co-addition)
#
# - SETPAGES
#   create WEB pages for the sets
#
# - CLEANORIG
#   restore the original state of the run directories
#   after Elixir processed files were moved to them,
#
# - CLEANNEWCOADD
#   remove all 'derived' products except final files
#   from the co-addition process. This mode should be 
#   used if the same set directory has to be reused for
#   a completely new co-addition (e.g. Ludo's PSF project).
#
# - FINALCLEAN
#   delete completely the contents of the set and setweights
#   directories.

#
# Definitions and default variable values
#

# Note that we test below again whether we need to work with the traidtional
# MEGAPRIME 36-chip or the new 40-chip setup. We define here an instrument
# to be able to initiate THELI logging:
export INSTRUMENT=MEGAPRIME
. ./${INSTRUMENT:?}.ini
. ./bash_functions.include
theli_start "$*"

# The variables MD, WEBDIR, COADDIDENT, COADDCONDITION,
# FIELD and FILTER are typically passed on the command line.
# If they are not passed the following 'defaults' are used: 

# Main directory for SET
# data. 
# Below, the set MDROOT is modified to MDROOT/${SURVEY} which
# is called MD then.
MDROOT=/raid1/thomas/

# root directory for WEB pages. It will be modified
# below to WEBDIR=${WEBDIRROOT}/${SURVEY}WWW to give
# the final location of WWW pages.
WEBDIRROOT=/home/www/public_html/

# default identifier for coaddition)
COADDIDENT="V1.0A"

# default method for final image coaddition used
# by swarp
COADDMETHOD=MEDIAN
 
#
# default field selection for coaddition (LDAC filter format)
COADDCONDITION="(SEEING<2.0);"

# which field should be processed
FIELD=W1p4p3

# Survey to process; below we have special settings for
# each known survey. This includs special processing
# and directory settings.
SURVEY=CFHTLSWIDE

# band to be processed (filters are u, g, r, i, z)
FILTER="i"
MULTIFILTER=0  # if '1' (command line option 'mf') multiple
               # colours can be processed simultaneously.
               # (for the moment only astrometry)

# dummy setting for magnitude zeropoint. We need this
# to detect if the zeropoint was given on the command line. 
MAGZP=-1.0

#
# default catalog used for astrometric calibration
# Note that names are slightly different for ASTROMETRIX
# and scamp, e.g. USNOB1 (ASTROMETRIX) but USNO-B1 (scamp)
ASTROMETRYCAT=USNOB1

#
# default method for astrometry (possible are ASTROMETRIX and SCAMP
ASTROMETRYMETHOD=ASTROMETRIX
ASTROMADD="" # for scamp headers etc. are in a directory header_scamp
             # If ASTROMETRYMETHOD=SCAMP this variable will be set to
             # "_scamp" and used at appropriate places. The variable 
             # also can be modified via a command line argument.

#
# by default we co-add all the chips:
CHIPS="ALL"

#
# by default we clean up some intermediary products:
CLEANUP=1

#
# by default we do not use Mischas swarpfilter:
SWARPFILTER=0

#
# read command line arguments
#
MODE=""
GoOn=0
while [ $GoOn = 0 ]
do
   case $1 in
   -aa)
       ASTROMADD=${2}
       shift 2
       ;;
   -a)
       ASTROMETRYCAT=${2}
       shift 2
       ;;
   -am)
       ASTROMETRYMETHOD=${2}
       shift 2
       ;;
   -b)
       MDROOT=${2}
       shift 2
       ;;
   -fi)
       FIELD=${2}
       shift 2
       ;;
   -f)
       FILTER=${2}
       shift 2
       ;;
   -cc)
       COADDCONDITION=${2}
       shift 2
       ;;
   -ci)
       COADDIDENT=${2}
       shift 2
       ;;
   -chips)
       CHIPS="${2}"
       shift 2
       ;;
   -cm)
       COADDMETHOD=${2}
       shift 2
       ;;
   -m)
       MODE=${2}
       shift 2
       ;;
   -ma)
       MAGZP=${2}
       shift 2
       ;;
   -mf)
       MULTIFILTER=1
       FILTER="${2}"
       shift 2
       ;;
   -noclean)
       CLEANUP=0
       shift 1
       ;;
   -s)
       SURVEY=${2}
       shift 2
       ;;
   -sf)
       SWARPFILTER=1
       shift 1
       ;;
   -www)
       WEBDIRROOT=${2}
       shift 2
       ;;
    *)
       if [ $# -ge 1 ]; then
         echo "Unknown command line option: ${1}"
         exit 1	   
       else
         GoOn=1
       fi
       ;;
   esac
done

export FILTER
export FIELD
export COADDIDENT

# determine the instrument: Note that in the case that MULTIFILTER is
# set we only perform astrometric calibration of a multi-colour
# observation. In that case the astrometry part of this script takes
# care of the instruments:
if [ ${MULTIFILTER} -ne 1 ]; then
  if [ "${FILTER}" = "u.MP9302" ] || [ "${FILTER}" = "g.MP9402" ] || \
     [ "${FILTER}" = "r.MP9602" ] || [ "${FILTER}" = "i.MP9703" ] || \
     [ "${FILTER}" = "z.MP9901" ]; then
    export INSTRUMENT=MEGAPRIME_FOURTYCHIP  
    . ./${INSTRUMENT:?}.ini
  fi
fi

# sanity checks:
if [ "${MODE}_A" = "_A" ]; then
  echo "nothing to do: exiting!"
  exit 1
fi

if [ "${ASTROMETRYMETHOD}" != "ASTROMETRIX" ] && \
   [ "${ASTROMETRYMETHOD}" != "SCAMP" ]; then
  echo "Unknown astrometry method! Only SCAMP and ASTROMETRIX are supported!"
  exit 1;
fi

if [ "${ASTROMETRYCAT}" = "BEST" ] && [ "${SURVEY}" != "CFHTLSWIDE" ] &&\
   [ "${ASTROMETRYMETHOD}" != "SCAMP" ]; then
  echo "ASTROMETRYCAT 'BEST' currently only supported for scamp"
  echo "and the CFHTLSWIDE survey!"
  exit 1;  
fi
 
if [ ${MULTIFILTER} -eq 1 ] && [ "${ASTROMETRYMETHOD}" != "SCAMP" ]; then
  echo "only scamp can handle simultaneously multiple filters in astrometry!"
  exit 1;    
fi

if [ ${MULTIFILTER} -eq 1 ] && [ "${MODE}" != "ASTROMPHOTOM" ]; then
  echo "only mode ASTROMPHOTOM supports for multi-filter processing!"
  exit 1;    
fi

if [ "${ASTROMETRYMETHOD}" = "SCAMP" ] && [ "${ASTROMADD}" = "" ]; then
  ASTROMADD="_scamp_${ASTROMETRYCAT}"
fi
 
# center coordinates for the different surveys: They are included from
# a separate file to keep the size of this script reasonably large
if [ -f doall_set_CFHTLS_survey_coord.txt ]; then
  source doall_set_CFHTLS_survey_coord.txt
else
  echo "coordinate definition file 'doall_set_CFHTLS_survey_coord.txt'"
  echo "not present! Aborting!"
  exit 1;
fi

# root directory for WEB pages (not absolutely necessary;
# the script has full reduction capabilities without the
# WWW option). The WEBDIR is dependent on the set SURVEY.
# Therefore this variable is set here.
WEBDIR=${WEBDIRROOT}/${SURVEY}WWW

# Main directory for SET
# data. 
# The actual images to
# process reside in ${MD}/${FIELD}/${FILTER}
# and the weights in ${MD}/${FIELD}/WEIGHTS_${FILTER}.
export MD=${MDROOT}/${SURVEY}

# set the reduce directory. We assume that this script
# is called within the reduce directory:
export REDDIR=`pwd`

# set the ASTROMREFCAT variable which will give the ASTRCAT header
# variable; some fiddeling is necessary to be consistent with keys
# used up to now (e.g. we used always the string USNO-B1 here as for
# ASTROMETRIX it would be USNOB1):
ASTROMREFCAT="${ASTROMETRYCAT}"
if [ "${ASTROMETRYMETHOD}" = "ASTROMETRIX" ]; then
  if [ "${ASTROMETRYCAT}" = "USNOB1" ]; then
    ASTROMREFCAT="USNO-B1"
  elif [ "${ASTROMETRYCAT}" = "SDSS5" ]; then
    ASTROMREFCAT="SDSS-R5"      
  fi
fi  

# reset ASTROMETRIX standardstar catalogue if an extracted
# starcatalogue is available (for Astrometrix processing):
if [ "${ASTROMETRYMETHOD}" = "ASTROMETRIX" ]; then
  if [ -s ${REDDIR}/${FIELD}_${ASTROMETRYCAT}_astrometrix.asc ]; then
    ASTROMETRYCAT=${REDDIR}/${FIELD}_${ASTROMETRYCAT}_astrometrix.asc
  fi
fi
  
# some special settings for the CFHTLS-Wide survey only:
if [ "${SURVEY}" = "CFHTLSWIDE" ]; then
  # if the filter equals to 'i' and the standardstar catalogue is
  # USNOB1 we set the coaddition identifier automatically to
  # 'USNOB1_reference':
  if [ "${ASTROMETRYMETHOD}" = "ASTROMETRIX" ] && \
     [ "${ASTROMETRYCAT}" = "USNOB1" ] && \
     [ "${FILTER}" = "i" ] && \
     [ "${CHIPS}" = "ALL" ]
  then
    echo "We assume that you create an astrometric reference catalogue!"
    echo "Co-addition identifier set to 'USNOB1_reference'"
    COADDIDENT="USNOB1_reference"
  fi
   
  #
  # we process other colours than i ONLY with a reference catalogue
  # extracted from a reference i-band. Hence, leave if a non i-band
  # set should be processed but the reference catalogue is not there!
  #
  # This applies to Wide data only! For Deep we use USNOB1 throughout.
  if [ "${ASTROMETRYMETHOD}" = "ASTROMETRIX" ] && \
     [ "${ASTROMETRYCAT}" = "USNOB1" ] && \
     [ "${FILTER}" != "i" ]
  then
    echo "You try to process non i-band data."
    echo "However, no reference astrometric catalogue is present!"
    exit 1;
  fi

  # if the ASTROMETRYCAT is set to BEST (and astrometrymethod is
  # scamp; this is tested above already) we choose for W1 and W2 2MASS
  # and for W3 and W4 SDSS-R7
  if [ "${ASTROMETRYCAT}" = "BEST" ]; then
    ASTROMETRYCAT=`gawk 'BEGIN { if ('${FIELD}' ~ /W3/ ||\
                                     '${FIELD}' ~ /W4..m[1-9]/ ) {
                                   print "SDSS-R7"
                                 } else {
                                   print "2MASS"
                                 }}'`
    ASTROMADD="_scamp_${ASTROMETRYCAT}"
  fi
fi
#
# ENDING has to be .sub. here. DO NOT EDIT!!
export ENDING=".sub"

#
# here starts the real work !!
#
for mode in ${MODE}
do
  if [ "${mode}" = "ASTROMPHOTOM" ]; then
    #
    # mark bad chips if necessary!
    # Our strategy is to mark chips as bad which were bad in the reference
    # image. Hence, also chips that are physically ok in other colours can be
    # marked as bad!
    for BADCHIPFILE in ${FIELD}_badchips.txt ${FIELD}_${FILTER}_badchips.txt
    do
      if [ -f ${BADCHIPFILE} ]; then
        ./mark_badchips.sh ${MD}/${FIELD} ${FILTER} C.sub 1 ${BADCHIPFILE}
        ./mark_badchips.sh ${MD}/${FIELD} ${FILTER} C 1 ${BADCHIPFILE}
      fi
    done  

    if [ "${ASTROMETRYMETHOD}" = "ASTROMETRIX" ]; then
      # initial SExtractor catalogues were already created during the
      # RUN phase and copied to the SET directories!!
      #
      ./create_run_list.sh ${MD}/${FIELD} ${FILTER} C GABODSID \
                             uniqruns_$$.txt NOSPLIT
    
      # build the string containing the individual runs in this set
      RUNS=""
      NRUNS=0
      while read run
      do
        RUNS="${RUNS} ${REDDIR}/${run}.txt"
        NRUNS=$(( ${NRUNS} + 1 ))
      done < uniqruns_$$.txt
   
      # For the CFHTLS DEEP fields we need to split the sets in astrometric
      # subsets. The reason is that ASTROMETRIX is way too slow to
      # process the large amounts of images (several hundred) 
      # in some of the deep sets. 
      if [ "${SURVEY}" = "CFHTLSDEEP" ]; then
        # Strategy:
        # We split the whole set in subsets with about NIMASUBSET
        # images. We split existing 'RUNS' into these subsets so that
        # the image number in each subset reaches 'NIMASUBSET' as close
        # as possible.
        # We assume that the image number in each RUN is apprximately 
        # equal. The subsets consist of 'randomly chosen' RUNS, not
        # consecutively observed RUNS! This is to prevent that only
        # RUNS with very tight dither patterns are in a special
        # subset.
        NIMASUBSET=30
        # count the total number of images and determine how many
        # "RUN subsets we need":
        NSUBSETS=`wc -w ${RUNS} |\
                  awk 'END {
                         bestnimasets = int(($1/'${NIMASUBSET}')+0.5);
                         if (bestnimasets < 1) { bestnimasets = 1; }
                         if (bestnimasets >= '${NRUNS}') {
                           print '${NRUNS}';
                         } else {
                           print bestnimasets;
                         }}'`
   
        NRUNSSUBSET=`gawk 'BEGIN{print int(('${NRUNS}'/'${NSUBSETS}')+0.5)}'`
   
        # the following ensures better balancing if the ratios
        # of RUNS and best splitting would lead to a very unbalanced
        # set. This concerns cases where 'NIMASUBSET' is chosen to be small:
        RATIO=`awk 'BEGIN {
                      print int(('${NRUNS}' % '${NSUBSETS}')/'${NRUNSSUBSET}')
                    }'`
   
        if [ ${RATIO} -ge 2 ]; then
          NRUNSSUBSET=$(( ${NRUNSSUBSET} + 1 ))
        fi
   
        # The following 'awk' program does the 'random'
        # grouping of existing RUNS into subsets:
        gawk 'BEGIN { i = 0; srand() }
              { run[i] = $0; i++ }
              END {count = NR; 
                   for (j = 1; j < '${NSUBSETS}'; j++) {
                     filename = "rungroup_" j "_'$$'.txt"
                     for (k = 1; k <= '${NRUNSSUBSET}'; k++) {
                       if (count > 0) {
                         element = int(rand()*count);
                         print run[element] >> filename;
                         count--;
                         for (l = element; l < count; l++) {
                           run[l]=run[l+1];
                         }
                       } 
                     }
                   }
                   # put all remaining runs in a last group
                   if (count > 0) {
                     filename = "rungroup_" '${NSUBSETS}' "_'$$'.txt"
                     for(k = 0; k < count; k++) {
                       print run[k] >> filename;
                     }
                   }}' uniqruns_$$.txt
   
   	 SUBSET=1
   	 while [ ${SUBSET} -le ${NSUBSETS} ]
   	 do
          RUNS=""
          while read run
          do
            RUNS="${RUNS} ${REDDIR}/${run}.txt"
          done < rungroup_${SUBSET}_$$.txt	     

          ./create_astrometrix_astrom_run_CFHTLS.sh ${MD}/${FIELD} \
                              ${FILTER} C ${ASTROMETRYCAT} \
                              rungroup_${SUBSET} ${RUNS}
          SUBSET=$(( ${SUBSET} + 1 ))
        done
        ./create_photometrix_CFHTLS.sh ${MD}/${FIELD} ${FILTER} C	 
      else # von CFHTLSDEEP
        ./create_astrometrix_astrom_run.sh ${MD}/${FIELD} ${FILTER} C \
                 ${ASTROMETRYCAT} ${RUNS}
        ./create_photometrix.sh ${MD}/${FIELD} ${FILTER} C
      fi # von CFHTLSDEEP
    else   # von ASTROMETRYMETHOD
      LINE=""
      for FILTERACTU in ${FILTER}
      do
        if [ "${FILTERACTU}" = "u.MP9302" ] || \
           [ "${FILTERACTU}" = "g.MP9402" ] || \
           [ "${FILTERACTU}" = "r.MP9602" ] || \
           [ "${FILTERACTU}" = "i.MP9703" ] || \
           [ "${FILTERACTU}" = "z.MP9901" ]; then
          LINE="${LINE} -i MEGAPRIME_FOURTYCHIP \
                        -d ${MD}/${FIELD} ${FILTERACTU} C"
        else
          LINE="${LINE} -i MEGAPRIME -d ${MD}/${FIELD} ${FILTERACTU} C"
        fi
      done

      ./create_scamp_astrom_photom_multiinst.sh ${LINE} \
                 -p 1.5 -k LONG -c ${ASTROMETRYCAT} -m photom

      ./create_scamp_astrom_photom_multiinst.sh ${LINE} \
                 -p 1.5 -k LONG -c ${ASTROMETRYCAT} -m astrom
    fi     # von ASTROMETRYMETHOD

    for FILTERACTU in ${FILTER}
    do
      ./merge_scamp_cats.sh ${MD}/${FIELD} ${FILTERACTU} \
                            headers${ASTROMADD}_astrom \
                            headers${ASTROMADD}_photom \
                            headers${ASTROMADD}              

      ./create_stats_table.sh ${MD}/${FIELD} ${FILTERACTU} \
                            C headers${ASTROMADD}
   
      PHOTFLAG=""
      if [ -f ${FIELD}_${FILTERACTU}_phot.txt ]; then
        PHOTFLAG=`cat ${FIELD}_${FILTERACTU}_phot.txt`
      fi
   
      ./create_absphotom_photometrix.sh ${MD}/${FIELD} ${FILTERACTU} \
                                      ${PHOTFLAG}
    done
  fi # von ASTROMPHOTOM
done

for mode in ${MODE}
do
  if [ "${mode}" = "SETCHECKPLOT" ]; then
    CAT=chips.cat5
    if [ -f ${MD}/${FIELD}/${FILTER}/cat/chips.cat6 ]; then
      CAT=chips.cat6
    fi
    ./make_checkplot_stats.sh ${MD}/${FIELD} ${FILTER} ${CAT} STATS ${FILTER}
  fi
done

# do the coaddition (SWARP)
for mode in ${MODE}
do
  if [ "${mode}" = "COADD" ]; then
    RA=`echo ${!FIELD} | awk '{print $1}'`
    DEC=`echo ${!FIELD} | awk '{print $2}'`

    # The following definition of TWO variables appears
    # because I did not succeed in passing command line
    # arguments properly to the following prepare_coadd ...
    # script when trying with only one variable (paranthesis
    # issues)
    if [ "${CHIPS}" = "ALL" ]; then
      CHIPSCOADDFLAG=""
      CHIPSCOADD=""
    else
      CHIPSCOADDFLAG=-c
      CHIPSCOADD="${CHIPS}"
    fi

    if [ "${COADDCONDITION}_A" = "_A" ]; then
      ./prepare_coadd_swarp.sh 
        -m ${MD}/${FIELD} \
        -s ${FILTER} -eh headers${ASTROMADD}\
        -e "C${ENDING}" -n ${COADDIDENT} \
        -w "${ENDING}" \
        -wd WEIGHTS_${FILTER} -r ${RA} \
        -d ${DEC} \
        ${CHIPSCOADDFLAG} "${CHIPSCOADD}"
    else
      if [ -f ${MD}/${FIELD}/${FILTER}/cat/chips.cat6 ]; then
        CAT=chips.cat6
      else
        CAT=chips.cat5	 
      fi
  
      ./prepare_coadd_swarp.sh \
        -m ${MD}/${FIELD} -s ${FILTER} \
        -e "C${ENDING}" \
        -n ${COADDIDENT} -w "${ENDING}" \
        -wd WEIGHTS_${FILTER} -r ${RA} -d ${DEC} \
        -eh headers${ASTROMADD}\
        -l ${MD}/${FIELD}/${FILTER}/cat/${CAT} STATS\
           ${COADDCONDITION} \
           ${MD}/${FIELD}/${FILTER}/cat/${COADDIDENT}.cat \
           ${CHIPSCOADDFLAG} "${CHIPSCOADD}"
    fi

    # see whether we have enough 'file descriptors' to perform
    # the co-addition:
    #
    # available system descriptos:
    AVAIDESC=`ulimit -n`
    # needed descriptors; the '2' in the final 'awk' takes into
    # account the weights:
    NEEDEDDESC=`find ${MD}/${FIELD}/${FILTER}/coadd_${COADDIDENT} \
                     -name \*C${ENDING}.fits | wc | awk '{print $1 * 2}'`

    if [ ${AVAIDESC} -lt ${NEEDEDDESC} ]; then
      echo "Not enough file descriptors for co-addition."
      echo "We need ${NEEDEDDESC} but there are only ${AVAIDESC}."
      exit 1;  
    fi

    ./parallel_manager.sh ./resample_coadd_swarp_para.sh ${MD}/${FIELD} \
                            ${FILTER} "C${ENDING}" ${COADDIDENT} ${REDDIR}\
                            NOFOLLOWLINK

    ./parallel_manager.sh ./create_modesub_para.sh ${MD}/${FIELD}/${FILTER} \
                           coadd_${COADDIDENT} "'?'" \
                           C${ENDING}.${COADDIDENT}.resamp.

    ./parallel_manager.sh ./create_zero_flag_para.sh \
                           ${MD}/${FIELD}/${FILTER} \
                           coadd_${COADDIDENT} \
                           C${ENDING}.${COADDIDENT}.resamp. \
                           C${ENDING}.${COADDIDENT}.sum.resamp.

    # get rid of FLXSCALE keywords in the zero flagged images:
    find ${MD}/${FIELD}/${FILTER}/coadd_${COADDIDENT} -maxdepth 1\
         -name \*sum.resamp.fits \
         -exec replacekey {} "FLXSCALE=                  1.0" FLXSCALE \;

    if [ ${SWARPFILTER} -eq 1 ]; then 
      ./resample_filtercosmics.sh ${MD}/${FIELD}/ ${FILTER} ${COADDIDENT} \
        ${MD}/${FIELD}/${FILTER}/coadd_${COADDIDENT}/coadd.head
    fi

    # first co-add science data
    ./perform_coadd_swarp.sh ${MD}/${FIELD} ${FILTER} ${COADDIDENT} \
                             C${ENDING}.${COADDIDENT}.resamp. \
                             "" ${REDDIR} MAP_WEIGHT FLAG ${COADDMETHOD} &

    # now the zero-flag images to get a 'number of input images'
    # context map:
    ./perform_coadd_swarp.sh ${MD}/${FIELD} ${FILTER} ${COADDIDENT} \
                             C${ENDING}.${COADDIDENT}.sum.resamp. \
                             "sum." ${REDDIR} NONE NOFLAG SUM

    wait;

    DIR=`pwd`
    cd ${MD}/${FIELD}/${FILTER}/coadd_${COADDIDENT}
    mv coadd.fits ${FIELD}_${FILTER}.${COADDIDENT}.swarp.fits
    mv coadd.flag.fits ${FIELD}_${FILTER}.${COADDIDENT}.swarp.flag.fits
    mv coadd.weight.fits ${FIELD}_${FILTER}.${COADDIDENT}.swarp.weight.fits
      
    # convert the sum image to an integer format; see whether we
    # need INT (16-bit) or whether 8-bit is enough:
    MAXVAL=`stats < coadd.sum.fits | awk '($1 == "min") {print $6}'`

    if [ ${MAXVAL} -gt 255 ]; then
      ic -p 16 '%1' coadd.sum.fits >\
             ${FIELD}_${FILTER}.${COADDIDENT}.swarp.sum.fits
    else
      ic -p 8 '%1' coadd.sum.fits >\
             ${FIELD}_${FILTER}.${COADDIDENT}.swarp.sum.fits
    fi

    rm coadd.sum.fits
    rm coadd.sum.weight.fits

    cd ${DIR}

    # delete by default all resampled images! It turned out that
    # so far we never needed them and they occupy a lot of disk
    # space!
    #
    # If we do not remove these images we take out the FLXSCALE
    # of them. This brings them to the same photometric system as
    # the co-added image:
    if [ ${CLEANUP} -eq 1 ]; then
      # another check whether result images were created
      # correctly:
      TESTIMAGE=${MD}/${FIELD}/${FILTER}/coadd_${COADDIDENT}
      TESTIMAGE=${TESTIMAGE}/${FIELD}_${FILTER}.${COADDIDENT}.swarp.fits
      fitsverify ${TESTIMAGE}
      
      # only delete if the last fitsverify was successful:
      if [ $? -eq 0 ]; then
        find ${MD}/${FIELD}/${FILTER}/coadd_${COADDIDENT}\
             -name \*resamp\*fits | xargs rm
      fi
    else
      ./parallel_manager.sh ./rescale_flxscale_para.sh \
        ${MD}/${FIELD}/${FILTER}/ coadd_${COADDIDENT} \
        "\?" C.sub.${COADDIDENT}.resamp. FLXSCALE

      # transfer observation date information to the
      # resampled images:
      ./transfer_header_keywords.sh \
        ${MD}/${FIELD}/${FILTER}/ \
        coadd_${COADDIDENT} \
        C.sub. C.sub.${COADDIDENT}.resamp. \
        GABODSID DATE-OBS
    fi
  fi
done

# update header from the final coadded images
#
for mode in ${MODE}
do
  if [ "${mode}" = "COADDHEADERUPDATE" ]; then
    if [ "${MAGZP}" = "-1.0" ]; then 
      if [ -f ${MD}/${FIELD}/${FILTER}/cat/chips_phot.cat5 ]; then
        MAGZP=`ldactoasc -i ${MD}/${FIELD}/${FILTER}/cat/chips_phot.cat5 \
               -t ABSPHOTOM -k COADDZP | tail -n 1`
      fi
    fi

    if [ "${SURVEY}" = "CFHTLSWIDE" ]; then
      ./update_coadd_header_CFHTLSWIDE.sh ${MD}/${FIELD} ${FILTER} \
                               ${COADDIDENT} STATS \
                               ${FIELD}_${FILTER}.${COADDIDENT}.swarp \
                               ${MAGZP} AB ${COADDCONDITION} ${ASTROMREFCAT}
    else
      ./update_coadd_header.sh ${MD}/${FIELD} ${FILTER} ${COADDIDENT} STATS\
                               ${FIELD}_${FILTER}.${COADDIDENT}.swarp \
                               ${MAGZP} AB ${COADDCONDITION} \
                               "${ASTROMREFCAT}" MegaPrime "CFHT_3.6m"
    fi
  fi
done

# The cut mode should be called AFTER COADDHEADERUPDATE so that
# the cutted image profit from the new headers
for mode in ${MODE}
do
  if [ "${mode}" = "CUTCOADD" ]; then
    # cut images to a size of 21000x21000

    DIR=`pwd`
    cd ${MD}/${FIELD}/${FILTER}/coadd_${COADDIDENT}

    IMAGES="${FIELD}_${FILTER}.${COADDIDENT}.swarp.fits
            ${FIELD}_${FILTER}.${COADDIDENT}.swarp.weight.fits
            ${FIELD}_${FILTER}.${COADDIDENT}.swarp.flag.fits
            ${FIELD}_${FILTER}.${COADDIDENT}.swarp.sum.fits"

    for IMAGE in ${IMAGES}
    do
      RESULT=`echo ${IMAGE} | sed -e 's/.swarp./.swarp.cut./'`

      if [ -f ${IMAGE} ]; then
        # perform image cutting in parallel:
        {
          # unmapped pixels from the flag need to get a value of '1'
          # (meaning the pixel is invalid).
          # In all other images, these pixels must get a value of zero:
          UNMAPPED=0.0
          if [[ ${IMAGE} == *flag.fits ]]; then
            UNMAPPED=1  
          fi

          # image cutting is different for the 36 and the 40-chip MEGAPRIME
          # modes:
          if [ "${INSTRUMENT}" = "MEGAPRIME" ]; then
            makesubimage -10500 -10500 21000 21000 -o ${UNMAPPED} -c \
            < ${IMAGE} > ${RESULT}
          else
            makesubimage -12500 -10750 25000 21500 -o ${UNMAPPED} -c \
            < ${IMAGE} > ${RESULT}
          fi

          # delete original images in cleaning mode:
          if [ ${CLEANUP} -eq 1 ]; then
            # test whether the new image passes fitsverify 
            # before deleting the old one:
            fitsverify ${RESULT}

            if [ $? -eq 0 ]; then
              rm ${IMAGE}
            fi
          fi
        } &
      fi
    done

    # collect all parallel image cuttings
    wait;

    cd ${DIR}
  fi
done

# do the postcoaddition (catalog creation and basic science
# verification)
#
for mode in ${MODE}
do
  if [ "${mode}" = "POSTCOADD" ]; then
    if [ "${MAGZP}" = "-1.0" ]; then 
      if [ -f ${MD}/${FIELD}/${FILTER}/cat/chips_phot.cat5 ]; then
        MAGZP=`ldactoasc -i ${MD}/${FIELD}/${FILTER}/cat/chips_phot.cat5 \
               -t ABSPHOTOM -k COADDZP | tail -n 1`
      fi
    fi

    # check whether we need to do postcoadd with cutted images:
    IMAGEPREFIX=${FIELD}_${FILTER}.${COADDIDENT}.swarp
    if [ -s ${MD}/${FIELD}/${FILTER}/coadd_${COADDIDENT}/${IMAGEPREFIX}.cut.fits ]
    then
      IMAGEPREFIX=${FIELD}_${FILTER}.${COADDIDENT}.swarp.cut
    fi

    ./create_catalogue.sh ${MD}/${FIELD} ${FILTER} ${MAGZP} \
                          ${COADDIDENT} ${IMAGEPREFIX}

    if [ "${MAGZP}" != "-1.0" ]; then
      ./create_checkplot_rh_mag.sh ${MD}/${FIELD} ${FILTER} ${IMAGEPREFIX} \
                          0.95 5.5 17.5
      ./create_mag_distribution_korr.sh ${MD}/${FIELD} ${FILTER} \
                          ${IMAGEPREFIX} ${FILTER} 0.95 5.5 17.5 \
                          "number counts from first year D1 data"
    fi
    ldacfilter -i ${MD}/${FIELD}/${FILTER}/cat/${COADDIDENT}.cat \
               -o ${MD}/${FIELD}/${FILTER}/cat/${COADDIDENT}_filt.cat \
               -t STATS -c "(${COADDIDENT}=1);"

    # statistics checkplot
    ./make_checkplot_stats.sh ${MD}/${FIELD} ${FILTER} \
               ${COADDIDENT}_filt.cat STATS coadd_${COADDIDENT}
    rm ${MD}/${FIELD}/${FILTER}/cat/${COADDIDENT}_filt.cat

    # astrometry checkplot
    ./wrap_check_astrom.sh ${MD}/${FIELD} ${FILTER} \
          ${ASTROMETRYCAT} ${COADDIDENT} C ${FIELD}_${FILTER}_astromcheck
  fi
done

for mode in ${MODE}
do
  if [ "${mode}" = "SETPAGES" ]; then
    if [ -f ./pipelog.py ]; then
      ./pipelog.py -a setpages -f ${FILTER} -e C -o ${WEBDIR} -b ${MD} \
                   -d sub -r ${FIELD} -i ${COADDIDENT} 
    fi
  fi
done

# remove all 'derived' products and restore the state after data
# have been moved from the run directories.
for mode in ${MODE}
do
  if [ "${mode}" = "CLEANORIG" ]; then
    if [ -d ${MD}/${FIELD}/${FILTER}/astrom ]; then
      rm -rf ${MD}/${FIELD}/${FILTER}/astrom
    fi

    if [ -d ${MD}/${FIELD}/${FILTER}/photom ]; then
      rm -rf ${MD}/${FIELD}/${FILTER}/photom
    fi

    if [ -d ${MD}/${FIELD}/${FILTER}/headers ]; then
      rm -rf ${MD}/${FIELD}/${FILTER}/headers
    fi

    if [ -d ${MD}/${FIELD}/${FILTER}/plots ]; then
      rm -rf ${MD}/${FIELD}/${FILTER}/plots
    fi

    if [ -d ${MD}/${FIELD}/${FILTER}/postcoadd ]; then
      rm -rf ${MD}/${FIELD}/${FILTER}/postcoadd
    fi

    COADDDIRS=`find ${MD}/${FIELD}/${FILTER}/ -type d -name coadd_\*`
    for dir in ${COADDDIRS}
    do
      rm -rf ${dir}
    done
  fi
done

# remove all 'derived' products except final files
# from the co-addition process.
for mode in ${MODE}
do
  if [ "${mode}" = "CLEANNEWCOADD" ]; then
    if [ -d ${MD}/${FIELD}/${FILTER}/astrom ]; then
      rm -rf ${MD}/${FIELD}/${FILTER}/astrom
    fi

    if [ -d ${MD}/${FIELD}/${FILTER}/photom ]; then
      rm -rf ${MD}/${FIELD}/${FILTER}/photom
    fi

    if [ -d ${MD}/${FIELD}/${FILTER}/headers ]; then
      rm -rf ${MD}/${FIELD}/${FILTER}/headers
    fi

    CURDIR=`pwd`
    COADDDIRS=`find ${MD}/${FIELD}/${FILTER}/ -type d -name coadd_\*`
    for dir in ${COADDDIRS}
    do
      cd ${dir}
      rm *resamp*fits
      rm *sub*fits
      rm *head
    done
    cd ${CURDIR}
  fi
done

# clean up set and setweights directories completely
for mode in ${MODE}
do
  if [ "${mode}" = "FINALCLEAN" ]; then
    DIR=`pwd` 

    if [ -d ${MD}/${FIELD}/${FILTER} ]; then
      cd ${MD}/${FIELD}/${FILTER} 
      rm -rf *
    fi
    
    if [ -d ${MD}/${FIELD}/WEIGHTS_${FILTER} ]; then
      cd ${MD}/${FIELD}/WEIGHTS_${FILTER} 
      rm -rf *
    fi

    cd ${DIR}
  fi
done

# and bye:
theli_end
exit 0;
