#!/bin/bash

# the script collects header keywords of a directory with fits files
# and redistributes them according to the set they belong to.  In the
# case of CFHTLS 'redistribute' means that links are created in the
# set drectories but no physical file moving/copying is done.  The
# script does this by comparing coordinates in the image headers to
# given field coordinates (see below).  The coordinates have to be
# given in degrees in keywords CRVAL1 and CRVAL2 (this can be changed
# below).
# 
# This version is especially written for processing of
# the CFHTLS survey with Elixir preprocessed images.

#
# 26.07.2007:
# I included coordinates for the W4 field.
#
# 19.08.2007:
# I added a missing W2p1m1 field to the target descriptions
#
# 28.08.2007:
# The script obtains now the survey under consideration as
# additional argument. In this way we can split the field
# definitions according to the survey under consideration
# and the script is not limited to CFHTLS anymore.
#
# 11.09.2007:
# I included new cluster targets
#
# 27.09.2007:
# I added A1835 and A2537 to the cluster survey fields
#
# 23.10.2007:
# Bug fix: I needed to check for links, not for files in three
# places of the script.
#
# 07.11.2007:
# I corrected a bug in the W4 fields. They had a
# 'p0' instead of a 'm0' for zero fields.
#
# 10.01.2008:
# I added coordinates for the COSMOS fields (CFHT u-band)
#
# 25.01.2008:
# I added the coordinates for the RXJ1347 cluster.
#
# 15.04.2008:
# I added data for the cluster A2259 and RCS2327
#
# 04.06.2008:
# I corrected a bug concerning the COSMOS survey
#
# 10.06.2008:
# I included the CFHTLS presurvey
#
# 11.06.2008:
# I added MS0451 to the cluster list
#
# 15.08.2008:
# I added A2163 to the cluster list
#
# 06.10.2008:
# temporary files are deleted at the end of the script
#
# 11.10.2008
# temporary files go to TEMPDIR now.
#
# 10.12.2008:
# I included the CFHTLSPHOTOSURVEY consisting of
# Presurvey-like data in the filters u,g,r,y and z.
#
# 14.04.2009:
# addition of MACS clusters (collaboration with Anja)
#
# 15.09.2009:
# - I added A2744 to the galaxy clusters
# - I added the first four pointings of the Next Generation Virgo
#   Survey
#
# 18.09.2009:
# I added 49 new NGVS fields
#
# 01.02.1010:
# I added a survey STARFIELDS for SLIP analysis
#
# 26.03.2010:
# I added Mischas SCL2241 to the clusters list
#
# 06.10.2010:
# I added Ludos Stripe 82 survey
#
# 17.10.2010:
# I added 2nd year NGVS data
#
# 02.11.2010:
# There was a faulty NGVSm0p0 field in the NGVS descriptions.
#
# 08.02.2011:
# STRIPE82 overlaps with eight W4 fields from CFHTLS. I added
# those eight fields to the STRIPE82 survey.
#
# 22.06.2011:
# addition of A2465 to the cluster objects
#
# 25.07.2011:
# addition of RCS survey
#
# 08.11.2011:
# correction of some RCS2 survey coordinates
#
# 01.03.2012:
# I added Hendriks SPARCS survey
#
# 05.04.2012:
# addition of the DEEP2 survey
#
# 07.05.2012:
# addition of CODEX fields
#
# 13.11.2012:
# I completed the NGVS fields
#
# 03.03.2013:
# I included Patrick Halls Stripe82 program
#
# 19.03.2013:
# I added Eric Jullos HATLAS survey
#
# 13.09.2013:
# I added more CODEX fields
#
# 07.11.2013:
# revision of CODEX coordinates
#
# 25.11.2013:
# addition of new CLUSTERS coordinates (Albertos 400d program)
#
# 31.01.2014:
# addition of two new fields to the DEEP2 survey.
#
# 26.02.2014:
# correction of two corrdinates in the RCS survey.
#
# 27.02.2014:
# correction of the coordinates for CL1120p4318 in the CLUSTERS survey.
#
# 10.06.2014:
# I added the QUASARS survey (project from Sherry)
#
# 21.04.2015:
# update of CODEX field list.
#
# 28.04.2015:
# now also PSF checkplots are copied from run to set directories.
# As in the run directories they are under .../cat/PSFcheck
#
# 10.06.2015:
# There was a bug in the copy process of the PSF checkplots
# (modifications from 28.04.2015) - fixed.
#
# 11.06.2015:
# I updated the cluster coordinate list (one new cluster from Albertos new
# CFHT observations)

#$1: main directory
#$2: science directory (of RUN data)
#$3: image extension (ext) on ..._iext.fits (i is the chip number)
#    We create links for the given extension and for the extension
#    '$3.sub'.
#$4: filter
#$5: root directory for SET data
#    (the final path will be /$5/${FIELD[${INDEX}]}/$4 for science
#     frames and /$5/${FIELD[${INDEX}]}/WEIGHTS_$4 for weights.)
#$6: The survey under consideration
#$7: chips to work on

. ${INSTRUMENT:?}.ini

# configuration parameters:

RAKEY="CRVAL1"
DECKEY="CRVAL2"

# maximum distance of a field to the nearest position
# (in degrees times 10); the variable can be modified for
# some survey if necessary (see e.g. the CFHTLS PreSurvey below):
MAXDIST=7

#
# positions for "listed surveys and sets":
if [[ $6 != CFHTLSDEEP* ]]      && [[ $6 != CFHTLSWIDE* ]] && \
   [[ $6 != CLUSTERS* ]]        && [[ $6 != COSMOS* ]] &&\
   [[ $6 != CFHTLSPRESURVEY* ]] && [[ $6 != CFHTLSPHOTSURVEY* ]] &&\
   [[ $6 != NGVS* ]]            && [[ $6 != STRIPE82* ]] &&\
   [[ $6 != RCS* ]]             && [[ $6 != SPARCS* ]] &&\
   [[ $6 != DEEP2* ]]           && [[ $6 != CODEX* ]] &&\
   [[ $6 != STRIPE82HALL* ]]    && [[ $6 != HATLAS* ]] &&\
   [[ $6 != QUASARS* ]]
then
  echo "Unknown Survey!! Exiting!!"
  exit 1
fi

if [[ $6 =~ QUASARS* ]]; then
  NFIELDS=1

  FIELD=([1]="HE1104")

  RA=([1]=166.64308292)

  DEC=([1]=-18.24169300)
fi

if [[ $6 =~ HATLAS* ]]; then
  NFIELDS=30

  FIELD=( [1]="HATLAS_000" [2]="HATLAS_001" [3]="HATLAS_002" \
  [4]="HATLAS_003" [5]="HATLAS_004" [6]="HATLAS_005" \
  [7]="HATLAS_006" [8]="HATLAS_007" [9]="HATLAS_008" \
  [10]="HATLAS_009" [11]="HATLAS_010" [12]="HATLAS_011" \
  [13]="HATLAS_012" [14]="HATLAS_013" [15]="HATLAS_014" \
  [16]="HATLAS_015" [17]="HATLAS_016" [18]="HATLAS_017" \
  [19]="HATLAS_018" [20]="HATLAS_019" [21]="HATLAS_020" \
  [22]="HATLAS_021" [23]="HATLAS_022" [24]="HATLAS_023" \
  [25]="HATLAS_024" [26]="HATLAS_025" [27]="HATLAS_026" \
  [28]="HATLAS_027" [29]="HATLAS_029" [30]="HATLAS_031")
  
  RA=( [1]=192.62720000 [2]=192.75380000 [3]=192.88050000 \
  [4]=193.00720000 [5]=193.13390000 [6]=193.26060000 \
  [7]=193.38730000 [8]=193.51360000 [9]=193.64070000 \
  [10]=193.52830000 [11]=193.65450000 [12]=193.78170000 \
  [13]=193.90910000 [14]=194.03570000 [15]=194.16230000 \
  [16]=194.28900000 [17]=194.41510000 [18]=194.54190000 \
  [19]=194.42950000 [20]=194.55610000 [21]=194.68110000 \
  [22]=194.80950000 [23]=194.93100000 [24]=195.06290000 \
  [25]=195.18960000 [26]=195.31520000 [27]=195.44410000 \
  [28]=195.33060000 [29]=195.58320000 [30]=195.83730000)
  
  DEC=( [1]=25.81270000 [2]=26.71380000 [3]=27.61490000 \
  [4]=28.51600000 [5]=29.41720000 [6]=30.31840000 \
  [7]=31.21950000 [8]=32.12210000 [9]=33.02180000 \
  [10]=25.68600000 [11]=26.58880000 [12]=27.48830000 \
  [13]=28.38670000 [14]=29.28850000 [15]=30.18960000 \
  [16]=31.09120000 [17]=31.99400000 [18]=32.89510000 \
  [19]=25.55930000 [20]=26.46050000 [21]=27.36790000 \
  [22]=28.26280000 [23]=29.18270000 [24]=30.06500000 \
  [25]=30.96620000 [26]=31.87110000 [27]=32.76480000 \
  [28]=25.43270000 [29]=27.23770000 [30]=29.03730000)
fi

if [[ $6 =~ CODEX* ]]; then
  NFIELDS=78

  FIELD=( [1]="CODEX09208" [2]="CODEX12451" [3]="CODEX12887" \
  [4]="CODEX13062" [5]="CODEX13452" [6]="CODEX16384" \
  [7]="CODEX16463" [8]="CODEX16566" [9]="CODEX16984" \
  [10]="CODEX18127" [11]="CODEX24747" [12]="CODEX24865" \
  [13]="CODEX24872" [14]="CODEX24877" [15]="CODEX24925" \
  [16]="CODEX24981" [17]="CODEX25252" [18]="CODEX25424" \
  [19]="CODEX25953" [20]="CODEX27938" [21]="CODEX27940" \
  [22]="CODEX27955" [23]="CODEX27958" [24]="CODEX27969" \
  [25]="CODEX27974" [26]="CODEX28045" [27]="CODEX29284" \
  [28]="CODEX29673" [29]="CODEX29734" [30]="CODEX29811" \
  [31]="CODEX34071" [32]="CODEX35213" [33]="CODEX35361" \
  [34]="CODEX35399" [35]="CODEX35646" [36]="CODEX36818" \
  [37]="CODEX37098" [38]="CODEX37287" [39]="CODEX38791" \
  [40]="CODEX38795" [41]="CODEX39141" [42]="CODEX39326" \
  [43]="CODEX39570" [44]="CODEX39879" [45]="CODEX41843" \
  [46]="CODEX41911" [47]="CODEX43403" [48]="CODEX43576" \
  [49]="CODEX43881" [50]="CODEX43951" [51]="CODEX46328" \
  [52]="CODEX46649" [53]="CODEX47981" [54]="CODEX48272" \
  [55]="CODEX48564" [56]="CODEX50492" [57]="CODEX50502" \
  [58]="CODEX50514" [59]="CODEX52442" [60]="CODEX52480" \
  [61]="CODEX52484" [62]="CODEX53495" [63]="CODEX53498" \
  [64]="CODEX53585" [65]="CODEX53588" [66]="CODEX54752" \
  [67]="CODEX54795" [68]="CODEX55181" [69]="CODEX56934" \
  [70]="CODEX57892" [71]="CODEX58014" [72]="CODEX58083" \
  [73]="CODEX58114" [74]="CODEX59915" [75]="CODEX64232" \
  [76]="CODEX64360" [77]="CODEX25094" [78]="CODEX20622")
  
  RA=( [1]=181.92300000 [2]=120.98500000 [3]=168.63900000 \
  [4]=186.04500000 [5]=226.82000000 [6]=123.09500000 \
  [7]=120.69700000 [8]=130.46400000 [9]=172.82300000 \
  [10]=254.08000000 [11]=120.28900000 [12]=125.55000000 \
  [13]=126.49614000 [14]=126.35700000 [15]=128.76200000 \
  [16]=134.00800000 [17]=158.46700000 [18]=172.62200000 \
  [19]=210.79300000 [20]=4.46089000 [21]=4.91520000 \
  [22]=3.86718000 [23]=4.45100000 [24]=2.82050000 \
  [25]=2.11974000 [26]=11.86422000 [27]=120.75200000 \
  [28]=151.57400000 [29]=159.96500000 [30]=166.40500000 \
  [31]=128.58000000 [32]=213.53700000 [33]=223.93400000 \
  [34]=225.67400000 [35]=245.89900000 [36]=334.97100000 \
  [37]=349.69900000 [38]=7.00300000 [39]=124.58114000 \
  [40]=124.87300000 [41]=150.52800000 [42]=170.87400000 \
  [43]=185.45800000 [44]=210.21900000 [45]=355.07700000 \
  [46]=5.64687000 [47]=122.47400000 [48]=137.76400000 \
  [49]=169.02700000 [50]=175.39300000 [51]=0.83596708 \
  [52]=23.71580000 [53]=129.90300000 [54]=156.63000000 \
  [55]=178.08829167 [56]=349.18988000 [57]=350.08500000 \
  [58]=352.95300000 [59]=145.12300000 [60]=143.54900000 \
  [61]=141.62000000 [62]=219.83884000 [63]=219.73200000 \
  [64]=226.18732000 [65]=226.08500000 [66]=165.11591667 \
  [67]=345.46600000 [68]=11.29340000 [69]=133.02400000 \
  [70]=199.26400000 [71]=211.67100000 [72]=214.96300000 \
  [73]=216.51700000 [74]=21.14980000 [75]=10.52780000 \
  [76]=22.13630000 [77]=143.95892000 [78]=128.57438000)

  DEC=( [1]=61.21310000 [2]=53.28730000 [3]=53.21310000 \
  [4]=54.18840000 [5]=57.80840000 [6]=52.15390000 \
  [7]=48.15660000 [8]=47.70550000 [9]=50.64330000 \
  [10]=47.66020000 [11]=36.35220000 [12]=41.33710000 \
  [13]=40.25539000 [14]=40.10530000 [15]=36.74520000 \
  [16]=37.91320000 [17]=38.73670000 [18]=38.28070000 \
  [19]=38.32960000 [20]=35.16390000 [21]=34.76990000 \
  [22]=33.58160000 [23]=33.72540000 [24]=32.41140000 \
  [25]=32.07830000 [26]=32.42131000 [27]=32.90410000 \
  [28]=31.89190000 [29]=33.95810000 [30]=33.42730000 \
  [31]=26.06750000 [32]=26.95130000 [33]=30.22240000 \
  [34]=27.78820000 [35]=26.56610000 [36]=27.22310000 \
  [37]=28.07180000 [38]=24.80808000 [39]=23.52621000 \
  [40]=23.27010000 [41]=20.37470000 [42]=23.94760000 \
  [43]=24.18530000 [44]=24.90540000 [45]=20.75340000 \
  [46]=14.64680000 [47]=18.12140000 [48]=17.74560000 \
  [49]=18.22360000 [50]=19.53640000 [51]=9.90818000 \
  [52]=8.67543000 [53]=8.50649000 [54]=9.14944000 \
  [55]=9.38944444 [56]=12.78653000 [57]=11.83570000 \
  [58]=10.46330000 [59]=7.61094000 [60]=5.55183000 \
  [61]=4.89401000 [62]=6.63964000 [63]=6.50912000 \
  [64]=4.59762000 [65]=4.46236000 [66]=-3.05497222 \
  [67]=7.90877000 [68]=-1.86369000 [69]=-0.98333300 \
  [70]=-2.16012000 [71]=-0.38455400 [72]=0.80849800 \
  [73]=-1.60033000 [74]=-5.65984000 [75]=-11.19840000 \
  [76]=-8.88932000 [77]=36.65642000 [78]=45.40635000)
fi

if [[ $6 =~ DEEP2* ]]; then
  NFIELDS=5

  FIELD=( [1]="DEEP2_P1" [2]="DEEP2_P2" [3]="DEEP2_P3" \
   [4]="DEEP2_P4" [5]="DEEP2_P5")
  
  RA=( [1]=252.20693000 [2]=37.02611000 [3]=37.97169000 \
   [4]=352.05128083 [5]=353.01690250)
  
  DEC=( [1]=34.94852778 [2]=0.59386897 [3]=0.62126369 \
   [4]=0.18957122 [5]=0.18984528)
fi

if [[ $6 = SPARCS* ]]; then
  NFIELDS=35
  
  FIELD=( [1]="ELAISN1_P1" [2]="ELAISN1_P2" [3]="ELAISN1_P3" \
  [4]="ELAISN1_P4" [5]="ELAISN1_P5" [6]="ELAISN1_P6" \
  [7]="ELAISN1_P7" [8]="ELAISN1_P8" [9]="ELAISN1_P9" \
  [10]="ELAISN1_P10" [11]="ELAISN1_P11" [12]="ELAISN1_P12" \
  [13]="ELAIS_N2_P1" [14]="ELAIS_N2_P2" [15]="ELAIS_N2_P3" \
  [16]="ELAIS_N2_P4" [17]="ELAIS_N2_P5" [18]="XMM_LSS_A" \
  [19]="XMM_LSS_B" [20]="XMM_LSS_C" [21]="Lockmann_P1" \
  [22]="Lockmann_P2" [23]="Lockmann_P3" [24]="Lockmann_P4" \
  [25]="Lockmann_P5" [26]="Lockmann_P6" [27]="Lockmann_P7" \
  [28]="Lockmann_P8" [29]="Lockmann_P9" [30]="Lockmann_P10" \
  [31]="Lockmann_P11" [32]="Lockmann_P12" [33]="Lockmann_P13" \
  [34]="Lockmann_P14" [35]="Lockmann_P15")
  
  RA=( [1]=243.60000000 [2]=241.86566667 [3]=244.40000000 \
  [4]=242.70729167 [5]=241.01570833 [6]=244.36500000 \
  [7]=242.71166667 [8]=241.05433333 [9]=246.05491667 \
  [10]=239.36516667 [11]=243.60400000 [12]=241.98400000 \
  [13]=249.52000000 [14]=248.24679167 [15]=249.52000000 \
  [16]=248.26462500 [17]=250.79025000 [18]=35.60279167 \
  [19]=36.56204167 [20]=34.05991667 [21]=162.00000000 \
  [22]=160.09991667 [23]=163.84212500 [24]=162.00000000 \
  [25]=160.15150000 [26]=158.31679167 [27]=165.58825000 \
  [28]=163.79412500 [29]=162.00000000 [30]=160.19987500 \
  [31]=158.41275000 [32]=163.74900000 [33]=162.00000000 \
  [34]=160.24537500 [35]=162.00000000)
  
  DEC=( [1]=56.50000000 [2]=56.50000000 [3]=55.54977778 \
  [4]=55.56277778 [5]=55.54977778 [6]=54.60952778 \
  [7]=54.62152778 [8]=54.60952778 [9]=55.02555556 \
  [10]=55.02555556 [11]=53.67633333 [12]=53.67633333 \
  [13]=41.60000000 [14]=41.25000000 [15]=40.66277778 \
  [16]=40.31277778 [17]=41.10000000 [18]=-3.26072222 \
  [19]=-3.26372222 [20]=-3.26158333 [21]=59.75000000 \
  [22]=59.75000000 [23]=58.69277778 [24]=58.81277778 \
  [25]=58.81277778 [26]=58.68277778 [27]=57.75555556 \
  [28]=57.75555556 [29]=57.87555556 [30]=57.87555556 \
  [31]=57.74555556 [32]=56.81833333 [33]=56.93833333 \
  [34]=56.93833333 [35]=56.00111111)
fi

if [[ $6 =~ CFHTLSDEEP* ]]; then
  NFIELDS=4

  FIELD=([1]="D1" [2]="D2" [3]="D3" [4]="D4")
  RA=([1]=36.50000000 [2]=150.12083333 [3]=214.86666667 [4]=333.87916667)
  DEC=([1]=-4.50000000 [2]=2.20583333 [3]=52.67805556 [4]=-17.73500000)
fi

if [[ $6 =~ CFHTLSWIDE* ]]; then
  NFIELDS=195

  FIELD=( [1]="W1m4m4" [2]="W1m4m3" [3]="W1m4m2" [4]="W1m4m1" \
  [5]="W1m4m0" [6]="W1m4p1" [7]="W1m4p2" [8]="W1m4p3" \
  [9]="W1m3m4" [10]="W1m3m3" [11]="W1m3m2" [12]="W1m3m1" \
  [13]="W1m3m0" [14]="W1m3p1" [15]="W1m3p2" [16]="W1m3p3" \
  [17]="W1m2m4" [18]="W1m2m3" [19]="W1m2m2" [20]="W1m2m1" \
  [21]="W1m2m0" [22]="W1m2p1" [23]="W1m2p2" [24]="W1m2p3" \
  [25]="W1m1m4" [26]="W1m1m3" [27]="W1m1m2" [28]="W1m1m1" \
  [29]="W1m1m0" [30]="W1m1p1" [31]="W1m1p2" [32]="W1m1p3" \
  [33]="W1m0m4" [34]="W1m0m3" [35]="W1m0m2" [36]="W1m0m1" \
  [37]="W1m0m0" [38]="W1m0p1" [39]="W1m0p2" [40]="W1m0p3" \
  [41]="W1p1m4" [42]="W1p1m3" [43]="W1p1m2" [44]="W1p1m1" \
  [45]="W1p1m0" [46]="W1p1p1" [47]="W1p1p2" [48]="W1p1p3" \
  [49]="W1p2m4" [50]="W1p2m3" [51]="W1p2m2" [52]="W1p2m1" \
  [53]="W1p2m0" [54]="W1p2p1" [55]="W1p2p2" [56]="W1p2p3" \
  [57]="W1p3m4" [58]="W1p3m3" [59]="W1p3m2" [60]="W1p3m1" \
  [61]="W1p3m0" [62]="W1p3p1" [63]="W1p3p2" [64]="W1p3p3" \
  [65]="W1p4m4" [66]="W1p4m3" [67]="W1p4m2" [68]="W1p4m1" \
  [69]="W1p4m0" [70]="W1p4p1" [71]="W1p4p2" [72]="W1p4p3" \
  [73]="W2m3m3" [74]="W2m3m2" [75]="W2m3m1" [76]="W2m3m0" \
  [77]="W2m3p1" [78]="W2m3p2" [79]="W2m3p3" [80]="W2m2m3" \
  [81]="W2m2m2" [82]="W2m2m1" [83]="W2m2m0" [84]="W2m2p1" \
  [85]="W2m2p2" [86]="W2m2p3" [87]="W2m1m3" [88]="W2m1m2" \
  [89]="W2m1m1" [90]="W2m1m0" [91]="W2m1p1" [92]="W2m1p2" \
  [93]="W2m1p3" [94]="W2m0m3" [95]="W2m0m2" [96]="W2m0m1" \
  [97]="W2m0m0" [98]="W2m0p1" [99]="W2m0p2" [100]="W2m0p3" \
  [101]="W2p1m3" [102]="W2p1m2" [103]="W2p1m1" [104]="W2p1m0" \
  [105]="W2p1p1" [106]="W2p1p2" [107]="W2p1p3" [108]="W2p2m3" \
  [109]="W2p2m2" [110]="W2p2m1" [111]="W2p2m0" [112]="W2p2p1" \
  [113]="W2p2p2" [114]="W2p2p3" [115]="W2p3m3" [116]="W2p3m2" \
  [117]="W2p3m1" [118]="W2p3m0" [119]="W2p3p1" [120]="W2p3p2" \
  [121]="W2p3p3" [122]="W3m3m3" [123]="W3m3m2" [124]="W3m3m1" \
  [125]="W3m3m0" [126]="W3m3p1" [127]="W3m3p2" [128]="W3m3p3" \
  [129]="W3m2m3" [130]="W3m2m2" [131]="W3m2m1" [132]="W3m2m0" \
  [133]="W3m2p1" [134]="W3m2p2" [135]="W3m2p3" [136]="W3m1m3" \
  [137]="W3m1m2" [138]="W3m1m1" [139]="W3m1m0" [140]="W3m1p1" \
  [141]="W3m1p2" [142]="W3m1p3" [143]="W3m0m3" [144]="W3m0m2" \
  [145]="W3m0m1" [146]="W3m0m0" [147]="W3m0p1" [148]="W3m0p2" \
  [149]="W3m0p3" [150]="W3p1m3" [151]="W3p1m2" [152]="W3p1m1" \
  [153]="W3p1m0" [154]="W3p1p1" [155]="W3p1p2" [156]="W3p1p3" \
  [157]="W3p2m3" [158]="W3p2m2" [159]="W3p2m1" [160]="W3p2m0" \
  [161]="W3p2p1" [162]="W3p2p2" [163]="W3p2p3" [164]="W3p3m3" \
  [165]="W3p3m2" [166]="W3p3m1" [167]="W3p3m0" [168]="W3p3p1" \
  [169]="W3p3p2" [170]="W3p3p3" [171]="W4p2m2" [172]="W4p2m1" \
  [173]="W4p2m0" [174]="W4p1m2" [175]="W4p1m1" [176]="W4p1m0" \
  [177]="W4p1p1" [178]="W4m0m2" [179]="W4m0m1" [180]="W4m0m0" \
  [181]="W4m0p1" [182]="W4m1m2" [183]="W4m1m1" [184]="W4m1m0" \
  [185]="W4m1p1" [186]="W4m1p2" [187]="W4m1p3" [188]="W4m2m0" \
  [189]="W4m2p1" [190]="W4m2p2" [191]="W4m2p3" [192]="W4m3m0" \
  [193]="W4m3p1" [194]="W4m3p2" [195]="W4m3p3")
  
  RA=( [1]=30.67145833 [2]=30.67145833 [3]=30.67145833 [4]=30.67145833 \
  [5]=30.67145833 [6]=30.67145833 [7]=30.67145833 [8]=30.67145833 \
  [9]=31.62858333 [10]=31.62858333 [11]=31.62858333 [12]=31.62858333 \
  [13]=31.62858333 [14]=31.62858333 [15]=31.62858333 [16]=31.62858333 \
  [17]=32.58575000 [18]=32.58575000 [19]=32.58575000 [20]=32.58575000 \
  [21]=32.58575000 [22]=32.58575000 [23]=32.58575000 [24]=32.58575000 \
  [25]=33.54287500 [26]=33.54287500 [27]=33.54287500 [28]=33.54287500 \
  [29]=33.54287500 [30]=33.54287500 [31]=33.54287500 [32]=33.54287500 \
  [33]=34.50000000 [34]=34.50000000 [35]=34.50000000 [36]=34.50000000 \
  [37]=34.50000000 [38]=34.50000000 [39]=34.50000000 [40]=34.50000000 \
  [41]=35.45712500 [42]=35.45712500 [43]=35.45712500 [44]=35.45712500 \
  [45]=35.45712500 [46]=35.45712500 [47]=35.45712500 [48]=35.45712500 \
  [49]=36.41425000 [50]=36.41425000 [51]=36.41425000 [52]=36.41425000 \
  [53]=36.41425000 [54]=36.41425000 [55]=36.41425000 [56]=36.41425000 \
  [57]=37.37141667 [58]=37.37141667 [59]=37.37141667 [60]=37.37141667 \
  [61]=37.37141667 [62]=37.37141667 [63]=37.37141667 [64]=37.37141667 \
  [65]=38.32854167 [66]=38.32854167 [67]=38.32854167 [68]=38.32854167 \
  [69]=38.32854167 [70]=38.32854167 [71]=38.32854167 [72]=38.32854167 \
  [73]=130.64216667 [74]=130.64216667 [75]=130.64216667 [76]=130.64216667 \
  [77]=130.64216667 [78]=130.64216667 [79]=130.64216667 [80]=131.59475000 \
  [81]=131.59475000 [82]=131.59475000 [83]=131.59475000 [84]=131.59475000 \
  [85]=131.59475000 [86]=131.59475000 [87]=132.54737500 [88]=132.54737500 \
  [89]=132.54737500 [90]=132.54737500 [91]=132.54737500 [92]=132.54737500 \
  [93]=132.54737500 [94]=133.50000000 [95]=133.50000000 [96]=133.50000000 \
  [97]=133.50000000 [98]=133.50000000 [99]=133.50000000 [100]=133.50000000 \
  [101]=134.45262500 [102]=134.45262500 [103]=134.45262500 [104]=134.45262500 \
  [105]=134.45262500 [106]=134.45262500 [107]=134.45262500 [108]=135.40525000 \
  [109]=135.40525000 [110]=135.40525000 [111]=135.40525000 [112]=135.40525000 \
  [113]=135.40525000 [114]=135.40525000 [115]=136.35787500 [116]=136.35787500 \
  [117]=136.35787500 [118]=136.35787500 [119]=136.35787500 [120]=136.35787500 \
  [121]=136.35787500 [122]=210.06783333 [123]=209.98091667 [124]=209.88920833 \
  [125]=209.79245833 [126]=209.69020833 [127]=209.58208333 [128]=209.46758333 \
  [129]=211.53687500 [130]=211.47895833 [131]=211.41779167 [132]=211.35329167 \
  [133]=211.28512500 [134]=211.21304167 [135]=211.13675000 [136]=213.00595833 \
  [137]=212.97695833 [138]=212.94641667 [139]=212.91416667 [140]=212.88008333 \
  [141]=212.84400000 [142]=212.80587500 [143]=214.47500000 [144]=214.47500000 \
  [145]=214.47500000 [146]=214.47500000 [147]=214.47500000 [148]=214.47500000 \
  [149]=214.47500000 [150]=215.94404167 [151]=215.97304167 [152]=216.00358333 \
  [153]=216.03587500 [154]=216.06995833 [155]=216.10600000 [156]=216.14412500 \
  [157]=217.41312500 [158]=217.47104167 [159]=217.53216667 [160]=217.59670833 \
  [161]=217.66487500 [162]=217.73695833 [163]=217.81325000 [164]=218.88220833 \
  [165]=218.96912500 [166]=219.06079167 [167]=219.15754167 [168]=219.25979167 \
  [169]=219.36791667 [170]=219.48241667 [171]=335.22408333 [172]=335.22404167 \
  [173]=335.22450000 [174]=334.27404167 [175]=334.27404167 [176]=334.27425000 \
  [177]=334.27475000 [178]=333.32400000 [179]=333.32400000 [180]=333.32400000 \
  [181]=333.32400000 [182]=332.37395833 [183]=332.37400000 [184]=332.37375000 \
  [185]=332.37329167 [186]=332.37254167 [187]=332.37154167 [188]=331.42350000 \
  [189]=331.42254167 [190]=331.42108333 [191]=331.41908333 [192]=330.47325000 \
  [193]=330.47179167 [194]=330.46958333 [195]=330.46662500)
  
  DEC=( [1]=-10.73333333 [2]=-9.80000000 [3]=-8.86666667 [4]=-7.93333333 \
  [5]=-7.00000000 [6]=-6.06666667 [7]=-5.13333333 [8]=-4.20000000 \
  [9]=-10.73333333 [10]=-9.80000000 [11]=-8.86666667 [12]=-7.93333333 \
  [13]=-7.00000000 [14]=-6.06666667 [15]=-5.13333333 [16]=-4.20000000 \
  [17]=-10.73333333 [18]=-9.80000000 [19]=-8.86666667 [20]=-7.93333333 \
  [21]=-7.00000000 [22]=-6.06666667 [23]=-5.13333333 [24]=-4.20000000 \
  [25]=-10.73333333 [26]=-9.80000000 [27]=-8.86666667 [28]=-7.93333333 \
  [29]=-7.00000000 [30]=-6.06666667 [31]=-5.13333333 [32]=-4.20000000 \
  [33]=-10.73333333 [34]=-9.80000000 [35]=-8.86666667 [36]=-7.93333333 \
  [37]=-7.00000000 [38]=-6.06666667 [39]=-5.13333333 [40]=-4.20000000 \
  [41]=-10.73333333 [42]=-9.80000000 [43]=-8.86666667 [44]=-7.93333333 \
  [45]=-7.00000000 [46]=-6.06666667 [47]=-5.13333333 [48]=-4.20000000 \
  [49]=-10.73333333 [50]=-9.80000000 [51]=-8.86666667 [52]=-7.93333333 \
  [53]=-7.00000000 [54]=-6.06666667 [55]=-5.13333333 [56]=-4.20000000 \
  [57]=-10.73333333 [58]=-9.80000000 [59]=-8.86666667 [60]=-7.93333333 \
  [61]=-7.00000000 [62]=-6.06666667 [63]=-5.13333333 [64]=-4.20000000 \
  [65]=-10.73333333 [66]=-9.80000000 [67]=-8.86666667 [68]=-7.93333333 \
  [69]=-7.00000000 [70]=-6.06666667 [71]=-5.13333333 [72]=-4.20000000 \
  [73]=-7.05000000 [74]=-6.11666667 [75]=-5.18333333 [76]=-4.25000000 \
  [77]=-3.31666667 [78]=-2.38333333 [79]=-1.45000000 [80]=-7.05000000 \
  [81]=-6.11666667 [82]=-5.18333333 [83]=-4.25000000 [84]=-3.31666667 \
  [85]=-2.38333333 [86]=-1.45000000 [87]=-7.05000000 [88]=-6.11666667 \
  [89]=-5.18333333 [90]=-4.25000000 [91]=-3.31666667 [92]=-2.38333333 \
  [93]=-1.45000000 [94]=-7.05000000 [95]=-6.11666667 [96]=-5.18333333 \
  [97]=-4.25000000 [98]=-3.31666667 [99]=-2.38333333 [100]=-1.45000000 \
  [101]=-7.05000000 [102]=-6.11666667 [103]=-5.18333333 [104]=-4.25000000 \
  [105]=-3.31666667 [106]=-2.38333333 [107]=-1.45000000 [108]=-7.05000000 \
  [109]=-6.11666667 [110]=-5.18333333 [111]=-4.25000000 [112]=-3.31666667 \
  [113]=-2.38333333 [114]=-1.45000000 [115]=-7.05000000 [116]=-6.11666667 \
  [117]=-5.18333333 [118]=-4.25000000 [119]=-3.31666667 [120]=-2.38333333 \
  [121]=-1.45000000 [122]=51.70861111 [123]=52.64194444 [124]=53.57527778 \
  [125]=54.50861111 [126]=55.44194444 [127]=56.37527778 [128]=57.30861111 \
  [129]=51.70861111 [130]=52.64194444 [131]=53.57527778 [132]=54.50861111 \
  [133]=55.44194444 [134]=56.37527778 [135]=57.30861111 [136]=51.70861111 \
  [137]=52.64194444 [138]=53.57527778 [139]=54.50861111 [140]=55.44194444 \
  [141]=56.37527778 [142]=57.30861111 [143]=51.70861111 [144]=52.64194444 \
  [145]=53.57527778 [146]=54.50861111 [147]=55.44194444 [148]=56.37527778 \
  [149]=57.30861111 [150]=51.70861111 [151]=52.64194444 [152]=53.57527778 \
  [153]=54.50861111 [154]=55.44194444 [155]=56.37527778 [156]=57.30861111 \
  [157]=51.70861111 [158]=52.64194444 [159]=53.57527778 [160]=54.50861111 \
  [161]=55.44194444 [162]=56.37527778 [163]=57.30861111 [164]=51.70861111 \
  [165]=52.64194444 [166]=53.57527778 [167]=54.50861111 [168]=55.44194444 \
  [169]=56.37527778 [170]=57.30861111 [171]=-0.51666667 [172]=0.38333333 \
  [173]=1.31666667 [174]=-0.51666667 [175]=0.38333333 [176]=1.31666667 \
  [177]=2.25000000 [178]=-0.51666667 [179]=0.38333333 [180]=1.31666667 \
  [181]=2.25000000 [182]=-0.51666667 [183]=0.38333333 [184]=1.31666667 \
  [185]=2.25000000 [186]=3.18333333 [187]=4.11666667 [188]=1.31666667 \
  [189]=2.25000000 [190]=3.18333333 [191]=4.11666667 [192]=1.31666667 \
  [193]=2.25000000 [194]=3.18333333 [195]=4.11666667)
fi

if [[ $6 =~ CFHTLSPRESURVEY* ]] || [[ $6 =~ CFHTLSPHOTSURVEY* ]]; then
  NFIELDS=4
  MAXDIST=1000

  FIELD=([1]="W1" [2]="W2" [3]="W3" [4]="W4")
  RA=([1]=34.5  [2]=131.25 [3]=214.475     [4]=333.32400000)
  DEC=([1]=-7.0 [2]=-4.25  [3]=54.50861111 [4]=1.31666667)
fi

if [[ $6 =~ CLUSTERS* ]]; then
  NFIELDS=63

  FIELD=( [1]="A115" [2]="A1758" [3]="A1835" \
  [4]="A1914" [5]="A1942" [6]="A2111" \
  [7]="A2163" [8]="A2259" [9]="A226" \
  [10]="A2537" [11]="A2597" [12]="A2744" \
  [13]="A3404" [14]="A611" [15]="A851" \
  [16]="CDE1645" [17]="CL0318m0302" [18]="CL0809p2811" \
  [19]="CL0853p5759" [20]="CL0926p1242" [21]="CL0956p4107" \
  [22]="CL1002p6858" [23]="CL1003p3253" [24]="CL1120p2326" \
  [25]="CL1120p4318" [26]="CL1202p5751" [27]="CL1221p4918" \
  [28]="CL1222p2709" [29]="CL1312p3900" [30]="CL1334p5031" \
  [31]="CL1354m0221" [32]="CL1357p6232" [33]="CL1416p4446" \
  [34]="CL1524p0957" [35]="CL1641p4001" [36]="CL1701p6414" \
  [37]="MACS0018p16" [38]="MACS0025m12" [39]="MACS0257m23" \
  [40]="MACS0329m02" [41]="MACS0647p70" [42]="MACS0717p37" \
  [43]="MACS0744p39" [44]="MACS0949p17" [45]="MACS1149p22" \
  [46]="MACS1423p24" [47]="MACS1532p30" [48]="MACS1621p38" \
  [49]="MACS1720p35" [50]="MACS1731p22" [51]="MACS1931m26" \
  [52]="MACS2129m07" [53]="MACS2140m23" [54]="MACS2211m03" \
  [55]="MACS2214m13" [56]="MS0451" [57]="RCS2327" \
  [58]="RXCJ0232" [59]="RXCJ2014" [60]="RXJ1347" \
  [61]="SCL2241" [62]="ZWCL2341" [63]="CL1212p2733")
  
  RA=( [1]=13.99791667 [2]=203.14000000 [3]=210.25833333 \
  [4]=216.50916667 [5]=219.60541667 [6]=234.93375000 \
  [7]=243.89208333 [8]=260.03791667 [9]=24.74166667 \
  [10]=347.06791667 [11]=351.33166667 [12]=3.58333333 \
  [13]=101.37208333 [14]=120.24750000 [15]=145.77916667 \
  [16]=250.84791667 [17]=49.63958333 [18]=122.42166667 \
  [19]=133.30875000 [20]=141.65500000 [21]=149.01500000 \
  [22]=150.53666667 [23]=150.76875000 [24]=170.24500000 \
  [25]=170.03166667 [26]=180.56166667 [27]=185.35666667 \
  [28]=185.51000000 [29]=198.08166667 [30]=203.58583333 \
  [31]=208.57291667 [32]=209.33291667 [33]=214.11875000 \
  [34]=231.16750000 [35]=250.46875000 [36]=255.34375000 \
  [37]=4.62875000 [38]=6.36750000 [39]=44.23875000 \
  [40]=52.41958333 [41]=101.92666667 [42]=109.39083333 \
  [43]=116.19458333 [44]=147.48250000 [45]=177.41458333 \
  [46]=215.94541667 [47]=233.22458333 [48]=245.34125000 \
  [49]=260.05791667 [50]=262.91125000 [51]=292.95416667 \
  [52]=322.35333333 [53]=325.06166667 [54]=332.92333333 \
  [55]=333.72708333 [56]=73.54541667 [57]=351.98083333 \
  [58]=38.07833333 [59]=303.70708333 [60]=206.88916667 \
  [61]=340.41833333 [62]=356.03541667 [63]=183.08000000)
  
  DEC=( [1]=26.32055556 [2]=50.51777778 [3]=2.87861111 \
  [4]=37.83472222 [5]=3.64361111 [6]=34.41555556 \
  [7]=-6.12388889 [8]=27.66916667 [9]=-10.24666667 \
  [10]=-2.17888889 [11]=-12.12388889 [12]=-30.38805556 \
  [13]=-54.21888889 [14]=36.05027778 [15]=46.99750000 \
  [16]=40.05000000 [17]=-3.16750000 [18]=28.19750000 \
  [19]=57.99361111 [20]=12.71416667 [21]=41.11694444 \
  [22]=68.97833333 [23]=32.89333333 [24]=23.44083333 \
  [25]=43.30194444 [26]=57.86222222 [27]=49.30000000 \
  [28]=27.15333333 [29]=39.01388889 [30]=50.51611111 \
  [31]=-2.36444444 [32]=62.54305556 [33]=44.77527778 \
  [34]=9.95972222 [35]=40.02277778 [36]=64.23555556 \
  [37]=16.43750000 [38]=-12.38444444 [39]=-23.38916667 \
  [40]=-2.20722222 [41]=70.24583333 [42]=37.74638889 \
  [43]=39.44833333 [44]=17.11861111 [45]=22.39305556 \
  [46]=24.07638889 [47]=30.35138889 [48]=38.16027778 \
  [49]=35.60194444 [50]=22.87222222 [51]=-26.58027778 \
  [52]=-7.69583333 [53]=-23.66277778 [54]=-3.83750000 \
  [55]=-14.00500000 [56]=-3.01861111 [57]=-2.19861111 \
  [58]=-44.34472222 [59]=-24.50750000 [60]=-11.79611111 \
  [61]=-9.49805556 [62]=0.28194444 [63]=27.55388889)
fi

if [[ $6 =~ COSMOS* ]]; then
  NFIELDS=5

  FIELD=( [1]="COSMOS_C" [2]="COSMOS_UR" [3]="COSMOS_LR" [4]="COSMOS_LL" \
   [5]="COSMOS_UL")
  
  RA=( [1]=150.12083333 [2]=149.70833333 [3]=149.70833333 [4]=150.44166667 \
   [5]=150.44166667)
  
  DEC=( [1]=2.20583333 [2]=2.43333333 [3]=1.83333333 [4]=1.83333333 \
   [5]=2.43333333)
fi

if [[ $6 =~ NGVS* ]]; then
  NFIELDS=121

  FIELD=( [1]="NGVSm0m0" [2]="NGVSm0m1" [3]="NGVSm0m2" \
  [4]="NGVSm0m3" [5]="NGVSm0m4" [6]="NGVSm0m5" \
  [7]="NGVSm0m6" [8]="NGVSm0m7" [9]="NGVSm0p1" \
  [10]="NGVSm0p2" [11]="NGVSm0p3" [12]="NGVSm0p4" \
  [13]="NGVSm0p5" [14]="NGVSm0p6" [15]="NGVSm1m0" \
  [16]="NGVSm1m1" [17]="NGVSm1m2" [18]="NGVSm1m3" \
  [19]="NGVSm1m4" [20]="NGVSm1m5" [21]="NGVSm1m6" \
  [22]="NGVSm1m7" [23]="NGVSm1p1" [24]="NGVSm1p2" \
  [25]="NGVSm1p3" [26]="NGVSm1p4" [27]="NGVSm1p5" \
  [28]="NGVSm2m0" [29]="NGVSm2m1" [30]="NGVSm2m2" \
  [31]="NGVSm2m3" [32]="NGVSm2m4" [33]="NGVSm2m5" \
  [34]="NGVSm2m6" [35]="NGVSm2m7" [36]="NGVSm2p1" \
  [37]="NGVSm2p2" [38]="NGVSm2p3" [39]="NGVSm2p4" \
  [40]="NGVSm2p5" [41]="NGVSm3m0" [42]="NGVSm3m1" \
  [43]="NGVSm3m2" [44]="NGVSm3m3" [45]="NGVSm3m4" \
  [46]="NGVSm3m5" [47]="NGVSm3m6" [48]="NGVSm3p1" \
  [49]="NGVSm3p2" [50]="NGVSm3p3" [51]="NGVSm3p4" \
  [52]="NGVSm3p5" [53]="NGVSm4m0" [54]="NGVSm4m1" \
  [55]="NGVSm4m2" [56]="NGVSm4m3" [57]="NGVSm4m4" \
  [58]="NGVSm4m5" [59]="NGVSm4p1" [60]="NGVSm4p2" \
  [61]="NGVSm4p3" [62]="NGVSm4p4" [63]="NGVSm5m0" \
  [64]="NGVSm5m1" [65]="NGVSm5m2" [66]="NGVSm5p1" \
  [67]="NGVSm5p2" [68]="NGVSm5p3" [69]="NGVSm6m0" \
  [70]="NGVSm6p1" [71]="NGVSp1m0" [72]="NGVSp1m1" \
  [73]="NGVSp1m2" [74]="NGVSp1m3" [75]="NGVSp1m4" \
  [76]="NGVSp1m5" [77]="NGVSp1m6" [78]="NGVSp1m7" \
  [79]="NGVSp1p1" [80]="NGVSp1p2" [81]="NGVSp1p3" \
  [82]="NGVSp1p4" [83]="NGVSp1p5" [84]="NGVSp2m0" \
  [85]="NGVSp2m1" [86]="NGVSp2m2" [87]="NGVSp2m3" \
  [88]="NGVSp2m4" [89]="NGVSp2m5" [90]="NGVSp2m6" \
  [91]="NGVSp2p1" [92]="NGVSp2p2" [93]="NGVSp2p3" \
  [94]="NGVSp2p4" [95]="NGVSp2p5" [96]="NGVSp3m0" \
  [97]="NGVSp3m1" [98]="NGVSp3m2" [99]="NGVSp3m3" \
  [100]="NGVSp3m4" [101]="NGVSp3p1" [102]="NGVSp3p2" \
  [103]="NGVSp3p3" [104]="NGVSp3p4" [105]="NGVSp3p5" \
  [106]="NGVSp4m0" [107]="NGVSp4m1" [108]="NGVSp4m2" \
  [109]="NGVSp4m3" [110]="NGVSp4p1" [111]="NGVSp4p2" \
  [112]="NGVSp4p3" [113]="NGVSp4p4" [114]="NGVSp5m0" \
  [115]="NGVSp5m1" [116]="NGVSp5p1" [117]="NGVSp5p2" \
  [118]="NGVS_BG_1" [119]="NGVS_BG_2" [120]="NGVS_BG_3" \
  [121]="NGVS_BG_4")
  
  RA=( [1]=188.05040000 [2]=188.05060000 [3]=188.05140000 \
  [4]=188.05080000 [5]=188.05130000 [6]=188.05030000 \
  [7]=188.05030000 [8]=188.05010000 [9]=188.05030000 \
  [10]=188.05110000 [11]=188.05010000 [12]=188.05060000 \
  [13]=188.05070000 [14]=188.05040000 [15]=187.07840000 \
  [16]=187.08210000 [17]=187.08550000 [18]=187.08880000 \
  [19]=187.09150000 [20]=187.09290000 [21]=187.09480000 \
  [22]=187.09630000 [23]=187.07490000 [24]=187.07260000 \
  [25]=187.06780000 [26]=187.06290000 [27]=187.05890000 \
  [28]=186.10880000 [29]=186.11440000 [30]=186.12060000 \
  [31]=186.12630000 [32]=186.13120000 [33]=186.13530000 \
  [34]=186.13860000 [35]=186.14180000 [36]=186.10130000 \
  [37]=186.09400000 [38]=186.08450000 [39]=186.07590000 \
  [40]=186.06690000 [41]=185.13770000 [42]=185.14660000 \
  [43]=185.15520000 [44]=185.16320000 [45]=185.17070000 \
  [46]=185.17740000 [47]=185.18280000 [48]=185.12640000 \
  [49]=185.11450000 [50]=185.10220000 [51]=185.08890000 \
  [52]=185.07480000 [53]=184.16590000 [54]=184.17830000 \
  [55]=184.19070000 [56]=184.20150000 [57]=184.21080000 \
  [58]=184.21990000 [59]=184.15160000 [60]=184.13580000 \
  [61]=184.11920000 [62]=184.10120000 [63]=183.19430000 \
  [64]=183.21080000 [65]=183.22550000 [66]=183.17630000 \
  [67]=183.15750000 [68]=183.13720000 [69]=182.22320000 \
  [70]=182.20170000 [71]=189.02170000 [72]=189.01860000 \
  [73]=189.01640000 [74]=189.01330000 [75]=189.01100000 \
  [76]=189.00790000 [77]=189.00670000 [78]=189.00450000 \
  [79]=189.02530000 [80]=189.02970000 [81]=189.03330000 \
  [82]=189.03800000 [83]=189.04250000 [84]=189.99360000 \
  [85]=189.98660000 [86]=189.98050000 [87]=189.97460000 \
  [88]=189.96990000 [89]=189.96630000 [90]=189.96220000 \
  [91]=190.00020000 [92]=190.00780000 [93]=190.01660000 \
  [94]=190.02510000 [95]=190.03450000 [96]=190.96510000 \
  [97]=190.95440000 [98]=190.94560000 [99]=190.93750000 \
  [100]=190.93050000 [101]=190.97530000 [102]=190.98640000 \
  [103]=190.99930000 [104]=191.01250000 [105]=191.02780000 \
  [106]=191.93480000 [107]=191.92200000 [108]=191.91020000 \
  [109]=191.89950000 [110]=191.94940000 [111]=191.96520000 \
  [112]=191.98210000 [113]=191.99970000 [114]=192.90670000 \
  [115]=192.89040000 [116]=192.92410000 [117]=192.94350000 \
  [118]=202.10660000 [119]=181.14320000 [120]=171.76480000 \
  [121]=203.39300000)

  DEC=( [1]=12.00530000 [2]=11.05560000 [3]=10.10810000 \
  [4]=9.15490000 [5]=8.20600000 [6]=7.25570000 \
  [7]=6.30540000 [8]=5.35560000 [9]=12.95590000 \
  [10]=13.90630000 [11]=14.85570000 [12]=15.80600000 \
  [13]=16.75490000 [14]=17.70480000 [15]=12.00440000 \
  [16]=11.05440000 [17]=10.10650000 [18]=9.15530000 \
  [19]=8.20560000 [20]=7.25700000 [21]=6.30550000 \
  [22]=5.35670000 [23]=12.95430000 [24]=13.90670000 \
  [25]=14.85690000 [26]=15.80460000 [27]=16.75530000 \
  [28]=12.00770000 [29]=11.05550000 [30]=10.10540000 \
  [31]=9.15590000 [32]=8.20450000 [33]=7.25820000 \
  [34]=6.30700000 [35]=5.35760000 [36]=12.95670000 \
  [37]=13.90710000 [38]=14.85660000 [39]=15.80490000 \
  [40]=16.75620000 [41]=12.00640000 [42]=11.05610000 \
  [43]=10.10560000 [44]=9.15530000 [45]=8.20600000 \
  [46]=7.25680000 [47]=6.30760000 [48]=12.95660000 \
  [49]=13.90390000 [50]=14.85640000 [51]=15.80940000 \
  [52]=16.75630000 [53]=12.00680000 [54]=11.05680000 \
  [55]=10.10600000 [56]=9.15730000 [57]=8.20620000 \
  [58]=7.25610000 [59]=12.95520000 [60]=13.90670000 \
  [61]=14.85530000 [62]=15.80530000 [63]=12.00690000 \
  [64]=11.05550000 [65]=10.10600000 [66]=12.95630000 \
  [67]=13.90820000 [68]=14.85720000 [69]=12.00600000 \
  [70]=12.95630000 [71]=12.00670000 [72]=11.05660000 \
  [73]=10.10720000 [74]=9.15530000 [75]=8.20880000 \
  [76]=7.25680000 [77]=6.30530000 [78]=5.35590000 \
  [79]=12.95640000 [80]=13.90560000 [81]=14.85680000 \
  [82]=15.80700000 [83]=16.75740000 [84]=12.00740000 \
  [85]=11.05550000 [86]=10.10650000 [87]=9.15470000 \
  [88]=8.20470000 [89]=7.25660000 [90]=6.30790000 \
  [91]=12.95680000 [92]=13.90510000 [93]=14.85410000 \
  [94]=15.80640000 [95]=16.75600000 [96]=12.00760000 \
  [97]=11.05640000 [98]=10.10580000 [99]=9.15630000 \
  [100]=8.20610000 [101]=12.95500000 [102]=13.90510000 \
  [103]=14.85460000 [104]=15.80590000 [105]=16.74640000 \
  [106]=12.00430000 [107]=11.05590000 [108]=10.10480000 \
  [109]=9.15680000 [110]=12.95680000 [111]=13.90700000 \
  [112]=14.85630000 [113]=15.80680000 [114]=12.00690000 \
  [115]=11.05610000 [116]=12.95530000 [117]=13.90840000 \
  [118]=21.01910000 [119]=27.35610000 [120]=15.65350000 \
  [121]=6.76170000)
fi

if [[ $6 =~ STARFIELDS* ]]; then
  NFIELDS=14

  FIELD=( [1]="STAR01" [2]="STAR02" [3]="STAR03" [4]="STAR04" \
  [5]="STAR05" [6]="STAR06" [7]="STAR07" [8]="STAR08" \
  [9]="STAR09" [10]="STAR10" [11]="STAR11" [12]="STAR12" \
  [13]="STAR13" [14]="STAR14")
  
  RA=( [1]=4.15133333 [2]=1.52652917 [3]=0.22740000 [4]=358.93847500 \
  [5]=289.37082500 [6]=288.40124167 [7]=288.88603333 [8]=288.88602500 \
  [9]=287.91161667 [10]=289.86045417 [11]=287.92090000 [12]=289.85115833 \
  [13]=287.43161667 [14]=290.34045000)
  
  DEC=( [1]=44.10122333 [2]=43.93678667 [3]=43.83303000 [4]=43.71679667 \
  [5]=-16.43397806 [6]=-16.43397278 [7]=-17.36397806 [8]=-15.50397806 \
  [9]=-17.36397194 [10]=-17.36397194 [11]=-15.50396611 [12]=-15.50395389 \
  [13]=-16.43397611 [14]=-16.43397806)
fi

if [[ $6 =~ STRIPE82* ]]; then
  NFIELDS=178

  FIELD=( [1]="S82m39m" [2]="S82m38m" [3]="S82m3m" [4]="S82m3p" \
  [5]="S82p0p" [6]="S82p0m" [7]="S82p28m" [8]="S82p33p" \
  [9]="S82p39p" [10]="S82p34m" [11]="S82p45p" [12]="S82p46p" \
  [13]="S82p47p" [14]="S82p48p" [15]="S82p1m" [16]="S82p2m" \
  [17]="S82p3m" [18]="S82p4m" [19]="S82p5m" [20]="S82p6m" \
  [21]="S82p7m" [22]="S82p8m" [23]="S82p9m" [24]="S82p10m" \
  [25]="S82p11m" [26]="S82p12m" [27]="S82p13m" [28]="S82p14m" \
  [29]="S82p15m" [30]="S82p16m" [31]="S82p17m" [32]="S82p18m" \
  [33]="S82p19m" [34]="S82p20m" [35]="S82p21m" [36]="S82p22m" \
  [37]="S82p23m" [38]="S82p24m" [39]="S82p25m" [40]="S82p26m" \
  [41]="S82p27m" [42]="S82p29m" [43]="S82p30m" [44]="S82p31m" \
  [45]="S82p32m" [46]="S82p33m" [47]="S82p35m" [48]="S82p36m" \
  [49]="S82p37m" [50]="S82p38m" [51]="S82p39m" [52]="S82p40m" \
  [53]="S82p41m" [54]="S82p42m" [55]="S82p43m" [56]="S82m0m" \
  [57]="S82m1m" [58]="S82m2m" [59]="S82m4m" [60]="S82m5m" \
  [61]="S82m6m" [62]="S82m7m" [63]="S82m8m" [64]="S82m9m" \
  [65]="S82m10m" [66]="S82m11m" [67]="S82m12m" [68]="S82m13m" \
  [69]="S82m14m" [70]="S82m15m" [71]="S82m16m" [72]="S82m17m" \
  [73]="S82m18m" [74]="S82m19m" [75]="S82m20m" [76]="S82m21m" \
  [77]="S82m22m" [78]="S82m23m" [79]="S82m24m" [80]="S82m25m" \
  [81]="S82m26m" [82]="S82m27m" [83]="S82m28m" [84]="S82m29m" \
  [85]="S82m30m" [86]="S82m31m" [87]="S82m32m" [88]="S82m33m" \
  [89]="S82m34m" [90]="S82m35m" [91]="S82m36m" [92]="S82m37m" \
  [93]="S82p1p" [94]="S82p2p" [95]="S82p3p" [96]="S82p4p" \
  [97]="S82p5p" [98]="S82p6p" [99]="S82p8p" [100]="S82p9p" \
  [101]="S82p10p" [102]="S82p11p" [103]="S82p12p" [104]="S82p13p" \
  [105]="S82p14p" [106]="S82p15p" [107]="S82p16p" [108]="S82p17p" \
  [109]="S82p18p" [110]="S82p19p" [111]="S82p20p" [112]="S82p21p" \
  [113]="S82p22p" [114]="S82p23p" [115]="S82p24p" [116]="S82p25p" \
  [117]="S82p27p" [118]="S82p28p" [119]="S82p29p" [120]="S82p30p" \
  [121]="S82p31p" [122]="S82p32p" [123]="S82p34p" [124]="S82p35p" \
  [125]="S82p36p" [126]="S82p37p" [127]="S82p38p" [128]="S82p40p" \
  [129]="S82p41p" [130]="S82p42p" [131]="S82p43p" [132]="S82p44p" \
  [133]="S82p7p" [134]="S82p26p" [135]="S82m24p" [136]="S82m0p" \
  [137]="S82m1p" [138]="S82m2p" [139]="S82m4p" [140]="S82m5p" \
  [141]="S82m6p" [142]="S82m7p" [143]="S82m8p" [144]="S82m9p" \
  [145]="S82m10p" [146]="S82m11p" [147]="S82m12p" [148]="S82m13p" \
  [149]="S82m14p" [150]="S82m15p" [151]="S82m16p" [152]="S82m17p" \
  [153]="S82m18p" [154]="S82m19p" [155]="S82m20p" [156]="S82m21p" \
  [157]="S82m23p" [158]="S82m25p" [159]="S82m26p" [160]="S82m27p" \
  [161]="S82m28p" [162]="S82m29p" [163]="S82m30p" [164]="S82m31p" \
  [165]="S82m32p" [166]="S82m33p" [167]="S82m34p" [168]="S82m36p" \
  [169]="S82m22p" [170]="S82m35p" [171]="W4m0m2" [172]="W4m0m1" \
  [173]="W4m1m2" [174]="W4m1m1" [175]="W4p1m2" [176]="W4p1m1" \
  [177]="W4p2m2" [178]="W4p2m1")
  
  RA=( [1]=317.97000000 [2]=318.90000000 [3]=355.58000000 [4]=356.03000000 \
  [5]=0.17000000 [6]=0.61000000 [7]=29.29000000 [8]=29.37000000 \
  [9]=34.83000000 [10]=35.20000000 [11]=41.99000000 [12]=42.85000000 \
  [13]=43.71000000 [14]=44.57000000 [15]=2.04000000 [16]=2.97000000 \
  [17]=3.88000000 [18]=4.80000000 [19]=5.71000000 [20]=6.62000000 \
  [21]=7.54000000 [22]=8.45000000 [23]=10.09000000 [24]=11.00000000 \
  [25]=11.91000000 [26]=13.35000000 [27]=14.26000000 [28]=15.17000000 \
  [29]=16.08000000 [30]=16.99000000 [31]=17.90000000 [32]=18.81000000 \
  [33]=19.72000000 [34]=22.26000000 [35]=23.17000000 [36]=24.08000000 \
  [37]=24.99000000 [38]=25.85000000 [39]=26.71000000 [40]=27.57000000 \
  [41]=28.43000000 [42]=30.15000000 [43]=31.61000000 [44]=32.47000000 \
  [45]=33.38000000 [46]=34.29000000 [47]=36.12000000 [48]=37.53000000 \
  [49]=38.44000000 [50]=39.35000000 [51]=40.27000000 [52]=41.19000000 \
  [53]=42.10000000 [54]=43.01000000 [55]=44.50000000 [56]=359.01000000 \
  [57]=358.10000000 [58]=357.19000000 [59]=354.67000000 [60]=353.76000000 \
  [61]=352.86000000 [62]=351.95000000 [63]=351.04000000 [64]=350.12000000 \
  [65]=349.26000000 [66]=348.40000000 [67]=347.54000000 [68]=346.68000000 \
  [69]=345.82000000 [70]=344.96000000 [71]=344.05000000 [72]=343.14000000 \
  [73]=342.23000000 [74]=341.32000000 [75]=340.41000000 [76]=339.50000000 \
  [77]=337.92000000 [78]=337.01000000 [79]=336.10000000 [80]=330.64000000 \
  [81]=329.73000000 [82]=328.81000000 [83]=327.89000000 [84]=326.97000000 \
  [85]=326.05000000 [86]=325.13000000 [87]=324.21000000 [88]=323.29000000 \
  [89]=322.37000000 [90]=321.45000000 [91]=320.74000000 [92]=319.82000000 \
  [93]=1.07000000 [94]=1.99000000 [95]=2.90000000 [96]=3.81000000 \
  [97]=4.71000000 [98]=5.62000000 [99]=7.42000000 [100]=8.32000000 \
  [101]=9.23000000 [102]=10.15000000 [103]=11.06000000 [104]=11.92000000 \
  [105]=12.78000000 [106]=13.64000000 [107]=14.50000000 [108]=15.36000000 \
  [109]=16.27000000 [110]=17.18000000 [111]=18.09000000 [112]=19.00000000 \
  [113]=19.91000000 [114]=20.82000000 [115]=21.73000000 [116]=22.64000000 \
  [117]=24.21000000 [118]=25.07000000 [119]=25.93000000 [120]=26.79000000 \
  [121]=27.65000000 [122]=28.51000000 [123]=30.28000000 [124]=31.19000000 \
  [125]=32.10000000 [126]=33.01000000 [127]=33.92000000 [128]=36.28000000 \
  [129]=37.19000000 [130]=38.10000000 [131]=39.01000000 [132]=41.13000000 \
  [133]=6.54000000 [134]=23.43000000 [135]=331.53000000 [136]=359.29000000 \
  [137]=357.85000000 [138]=356.94000000 [139]=355.17000000 [140]=354.26000000 \
  [141]=353.35000000 [142]=351.78000000 [143]=350.17000000 [144]=349.31000000 \
  [145]=348.45000000 [146]=347.59000000 [147]=346.73000000 [148]=345.87000000 \
  [149]=344.48000000 [150]=343.62000000 [151]=342.76000000 [152]=341.90000000 \
  [153]=341.04000000 [154]=340.18000000 [155]=339.32000000 [156]=337.91000000 \
  [157]=336.09000000 [158]=329.57000000 [159]=328.65000000 [160]=326.90000000 \
  [161]=325.33000000 [162]=324.41000000 [163]=323.49000000 [164]=322.57000000 \
  [165]=321.65000000 [166]=320.73000000 [167]=319.81000000 [168]=317.97000000 \
  [169]=337.00000000 [170]=318.89000000 [171]=333.32400000 [172]=333.32400000 \
  [173]=332.37395833 [174]=332.37400000 [175]=334.27404167 [176]=334.27404167 \
  [177]=335.22408333 [178]=335.22404167)
  
  DEC=( [1]=-0.51000000 [2]=-0.51000000 [3]=-0.51000000 [4]=0.41000000 \
  [5]=0.41000000 [6]=-0.51000000 [7]=-0.51000000 [8]=0.41000000 \
  [9]=0.41000000 [10]=-0.51000000 [11]=0.41000000 [12]=0.41000000 \
  [13]=0.50000000 [14]=0.41000000 [15]=-0.51000000 [16]=-0.51000000 \
  [17]=-0.51000000 [18]=-0.51000000 [19]=-0.51000000 [20]=-0.68000000 \
  [21]=-0.51000000 [22]=-0.51000000 [23]=-0.51000000 [24]=-0.51000000 \
  [25]=-0.78000000 [26]=-0.51000000 [27]=-0.51000000 [28]=-0.51000000 \
  [29]=-0.51000000 [30]=-0.51000000 [31]=-0.51000000 [32]=-0.51000000 \
  [33]=-0.51000000 [34]=-0.51000000 [35]=-0.51000000 [36]=-0.51000000 \
  [37]=-0.51000000 [38]=-0.51000000 [39]=-0.51000000 [40]=-0.51000000 \
  [41]=-0.51000000 [42]=-0.51000000 [43]=-0.51000000 [44]=-0.51000000 \
  [45]=-0.51000000 [46]=-0.76000000 [47]=-0.77000000 [48]=-0.51000000 \
  [49]=-0.51000000 [50]=-0.51000000 [51]=-0.19000000 [52]=-0.51000000 \
  [53]=-0.51000000 [54]=-0.51000000 [55]=-0.51000000 [56]=-0.51000000 \
  [57]=-0.51000000 [58]=-0.51000000 [59]=-0.51000000 [60]=-0.51000000 \
  [61]=-0.51000000 [62]=-0.51000000 [63]=-0.51000000 [64]=-0.51000000 \
  [65]=-0.51000000 [66]=-0.51000000 [67]=-0.51000000 [68]=-0.51000000 \
  [69]=-0.51000000 [70]=-0.51000000 [71]=-0.51000000 [72]=-0.51000000 \
  [73]=-0.51000000 [74]=-0.51000000 [75]=-0.51000000 [76]=-0.51000000 \
  [77]=-0.51000000 [78]=-0.66000000 [79]=-0.51000000 [80]=-0.51000000 \
  [81]=-0.51000000 [82]=-0.51000000 [83]=-0.51000000 [84]=-0.51000000 \
  [85]=-0.51000000 [86]=-0.51000000 [87]=-0.51000000 [88]=-0.51000000 \
  [89]=-0.51000000 [90]=-0.78000000 [91]=-0.51000000 [92]=-0.51000000 \
  [93]=0.41000000 [94]=0.41000000 [95]=0.41000000 [96]=0.41000000 \
  [97]=0.41000000 [98]=0.41000000 [99]=0.41000000 [100]=0.41000000 \
  [101]=0.41000000 [102]=0.41000000 [103]=0.41000000 [104]=0.41000000 \
  [105]=0.41000000 [106]=0.41000000 [107]=0.41000000 [108]=0.41000000 \
  [109]=0.41000000 [110]=0.41000000 [111]=0.41000000 [112]=0.41000000 \
  [113]=0.41000000 [114]=0.41000000 [115]=0.41000000 [116]=0.41000000 \
  [117]=0.41000000 [118]=0.41000000 [119]=0.41000000 [120]=0.41000000 \
  [121]=0.41000000 [122]=0.41000000 [123]=0.41000000 [124]=0.41000000 \
  [125]=0.41000000 [126]=0.41000000 [127]=0.41000000 [128]=0.41000000 \
  [129]=0.41000000 [130]=0.41000000 [131]=0.41000000 [132]=0.41000000 \
  [133]=0.62000000 [134]=0.70000000 [135]=0.40000000 [136]=0.41000000 \
  [137]=0.41000000 [138]=0.41000000 [139]=0.41000000 [140]=0.41000000 \
  [141]=0.41000000 [142]=0.41000000 [143]=0.41000000 [144]=0.41000000 \
  [145]=0.41000000 [146]=0.41000000 [147]=0.41000000 [148]=0.41000000 \
  [149]=0.41000000 [150]=0.41000000 [151]=0.41000000 [152]=0.41000000 \
  [153]=0.41000000 [154]=0.41000000 [155]=0.41000000 [156]=0.41000000 \
  [157]=0.41000000 [158]=0.42000000 [159]=0.42000000 [160]=0.42000000 \
  [161]=0.42000000 [162]=0.42000000 [163]=0.42000000 [164]=0.42000000 \
  [165]=0.42000000 [166]=0.42000000 [167]=0.42000000 [168]=0.42000000 \
  [169]=0.63000000 [170]=0.66000000 [171]=-0.51666667 [172]=0.38333333 \
  [173]=-0.51666667 [174]=0.38333333 [175]=-0.51666667 [176]=0.38333333 \
  [177]=-0.51666667 [178]=0.38333333)
fi

if [[ $6 =~ STRIPE82HALL* ]]; then
  NFIELDS=225

  FIELD=( [1]="S82_1004" [2]="S82_1006" [3]="S82_1007" \
  [4]="S82_1011" [5]="S82_1013" [6]="S82_1015" \
  [7]="S82_1016" [8]="S82_1018" [9]="S82_1019" \
  [10]="S82_1020" [11]="S82_1021" [12]="S82_1022" \
  [13]="S82_1023" [14]="S82_1024" [15]="S82_1025" \
  [16]="S82_1028" [17]="S82_1030" [18]="S82_1031" \
  [19]="S82_1033" [20]="S82_1034" [21]="S82_1035" \
  [22]="S82_1036" [23]="S82_1039" [24]="S82_1040" \
  [25]="S82_1044" [26]="S82_1045" [27]="S82_1046" \
  [28]="S82_1047" [29]="S82_1048" [30]="S82_1050" \
  [31]="S82_1053" [32]="S82_1054" [33]="S82_1055" \
  [34]="S82_1056" [35]="S82_1058" [36]="S82_1060" \
  [37]="S82_1061" [38]="S82_1062" [39]="S82_1064" \
  [40]="S82_1065" [41]="S82_1066" [42]="S82_1068" \
  [43]="S82_1070" [44]="S82_1071" [45]="S82_1072" \
  [46]="S82_1073" [47]="S82_1074" [48]="S82_1075" \
  [49]="S82_1076" [50]="S82_1077" [51]="S82_1078" \
  [52]="S82_1079" [53]="S82_1081" [54]="S82_1082" \
  [55]="S82_1083" [56]="S82_1085" [57]="S82_1086" \
  [58]="S82_1087" [59]="S82_1088" [60]="S82_1090" \
  [61]="S82_1091" [62]="S82_1093" [63]="S82_1094" \
  [64]="S82_1095" [65]="S82_1096" [66]="S82_1097" \
  [67]="S82_1098" [68]="S82_1101" [69]="S82_1102" \
  [70]="S82_1106" [71]="S82_1107" [72]="S82_1108" \
  [73]="S82_1109" [74]="S82_1110" [75]="S82_1111" \
  [76]="S82_1112" [77]="S82_1113" [78]="S82_1116" \
  [79]="S82_1117" [80]="S82_1118" [81]="S82_1119" \
  [82]="S82_2005" [83]="S82_2008" [84]="S82_2015" \
  [85]="S82_2016" [86]="S82_2017" [87]="S82_2018" \
  [88]="S82_2020" [89]="S82_2023" [90]="S82_2025" \
  [91]="S82_2026" [92]="S82_2027" [93]="S82_2029" \
  [94]="S82_2030" [95]="S82_2032" [96]="S82_2033" \
  [97]="S82_2034" [98]="S82_2038" [99]="S82_2040" \
  [100]="S82_2048" [101]="S82_2049" [102]="S82_2050" \
  [103]="S82_2051" [104]="S82_2052" [105]="S82_2053" \
  [106]="S82_2054" [107]="S82_2055" [108]="S82_2058" \
  [109]="S82_2061" [110]="S82_2062" [111]="S82_2064" \
  [112]="S82_2065" [113]="S82_2066" [114]="S82_2067" \
  [115]="S82_2068" [116]="S82_2070" [117]="S82_2074" \
  [118]="S82_2076" [119]="S82_2077" [120]="S82_2078" \
  [121]="S82_2079" [122]="S82_2081" [123]="S82_2083" \
  [124]="S82_2085" [125]="S82_2087" [126]="S82_2088" \
  [127]="S82_2089" [128]="S82_2090" [129]="S82_2092" \
  [130]="S82_2095" [131]="S82_2096" [132]="S82_2097" \
  [133]="S82_2098" [134]="S82_2099" [135]="S82_2100" \
  [136]="S82_2101" [137]="S82_2103" [138]="S82_2104" \
  [139]="S82_2105" [140]="S82_2107" [141]="S82_2108" \
  [142]="S82_2109" [143]="S82_2110" [144]="S82_2111" \
  [145]="S82_2116" [146]="S82_2117" [147]="S82_3001" \
  [148]="S82_3002" [149]="S82_3004" [150]="S82_3005" \
  [151]="S82_3006" [152]="S82_3007" [153]="S82_3008" \
  [154]="S82_3009" [155]="S82_3015" [156]="S82_3019" \
  [157]="S82_3022" [158]="S82_3024" [159]="S82_3025" \
  [160]="S82_3026" [161]="S82_3027" [162]="S82_3028" \
  [163]="S82_3029" [164]="S82_3030" [165]="S82_3031" \
  [166]="S82_3032" [167]="S82_3033" [168]="S82_3035" \
  [169]="S82_3038" [170]="S82_3039" [171]="S82_3040" \
  [172]="S82_3042" [173]="S82_3045" [174]="S82_3046" \
  [175]="S82_3049" [176]="S82_3050" [177]="S82_3052" \
  [178]="S82_3053" [179]="S82_3054" [180]="S82_3056" \
  [181]="S82_3059" [182]="S82_3060" [183]="S82_3061" \
  [184]="S82_3062" [185]="S82_3064" [186]="S82_3065" \
  [187]="S82_3066" [188]="S82_3067" [189]="S82_3068" \
  [190]="S82_3069" [191]="S82_3070" [192]="S82_3075" \
  [193]="S82_3076" [194]="S82_3077" [195]="S82_3078" \
  [196]="S82_3079" [197]="S82_3080" [198]="S82_3084" \
  [199]="S82_3086" [200]="S82_3087" [201]="S82_3088" \
  [202]="S82_3089" [203]="S82_3090" [204]="S82_3091" \
  [205]="S82_3092" [206]="S82_3093" [207]="S82_3094" \
  [208]="S82_3095" [209]="S82_3096" [210]="S82_3097" \
  [211]="S82_3098" [212]="S82_3100" [213]="S82_3101" \
  [214]="S82_3102" [215]="S82_3103" [216]="S82_3104" \
  [217]="S82_3105" [218]="S82_3106" [219]="S82_3107" \
  [220]="S82_3110" [221]="S82_3111" [222]="S82_3114" \
  [223]="S82_3115" [224]="S82_3118" [225]="S82_3119")
  
  RA=( [1]=312.39996000 [2]=314.20000000 [3]=315.10000000 \
  [4]=318.80000000 [5]=320.70000000 [6]=322.49996000 \
  [7]=323.39996000 [8]=325.30000000 [9]=326.20000000 \
  [10]=327.10000000 [11]=328.00000000 [12]=328.90000000 \
  [13]=329.90000000 [14]=330.80000000 [15]=331.70000000 \
  [16]=334.50000000 [17]=336.30000000 [18]=337.19996000 \
  [19]=339.09996000 [20]=340.00000000 [21]=340.90000000 \
  [22]=341.80000000 [23]=344.60000000 [24]=345.50000000 \
  [25]=349.20000000 [26]=350.10000000 [27]=351.00000000 \
  [28]=351.90000000 [29]=352.90000000 [30]=354.70000000 \
  [31]=357.50000000 [32]=358.40000000 [33]=359.30000000 \
  [34]=0.20000000 [35]=2.10000000 [36]=3.90000000 \
  [37]=4.80000000 [38]=5.70000000 [39]=7.60000000 \
  [40]=8.50000000 [41]=9.40000000 [42]=11.30000000 \
  [43]=13.10000000 [44]=14.00000000 [45]=14.90000000 \
  [46]=15.90000000 [47]=16.80000000 [48]=17.70000000 \
  [49]=18.60000000 [50]=19.50000000 [51]=20.50000000 \
  [52]=21.40000000 [53]=23.20000000 [54]=24.10000000 \
  [55]=25.10000000 [56]=26.90000000 [57]=27.80000000 \
  [58]=28.70000000 [59]=29.70000000 [60]=31.50000000 \
  [61]=32.40000000 [62]=34.30000000 [63]=35.20000000 \
  [64]=36.10000000 [65]=37.00000000 [66]=37.90000000 \
  [67]=38.89996000 [68]=41.60000000 [69]=42.49996000 \
  [70]=46.20000000 [71]=47.10000000 [72]=48.10000000 \
  [73]=49.00000000 [74]=49.90000000 [75]=50.80000000 \
  [76]=51.70000000 [77]=52.70000000 [78]=55.40000000 \
  [79]=56.30000000 [80]=57.30000000 [81]=58.20000000 \
  [82]=313.30000000 [83]=316.10000000 [84]=322.49996000 \
  [85]=323.40000000 [86]=324.30000000 [87]=325.30000000 \
  [88]=327.10000000 [89]=329.90000000 [90]=331.70000000 \
  [91]=332.60000000 [92]=333.50000000 [93]=335.40000000 \
  [94]=336.30000000 [95]=338.10000000 [96]=339.10000000 \
  [97]=339.99996000 [98]=343.70000000 [99]=345.50000000 \
  [100]=352.90000000 [101]=353.79996000 [102]=354.70000000 \
  [103]=355.60000000 [104]=356.50000000 [105]=357.50000000 \
  [106]=358.40000000 [107]=359.30000000 [108]=2.10000000 \
  [109]=4.80000000 [110]=5.70000000 [111]=7.60000000 \
  [112]=8.50000000 [113]=9.40000000 [114]=10.30000000 \
  [115]=11.30000000 [116]=13.10000000 [117]=16.80000000 \
  [118]=18.60000000 [119]=19.50000000 [120]=20.50000000 \
  [121]=21.40000000 [122]=23.20000000 [123]=25.10000000 \
  [124]=26.90000000 [125]=28.70000000 [126]=29.70000000 \
  [127]=30.60000000 [128]=31.50000000 [129]=33.30000000 \
  [130]=36.10000000 [131]=37.00000000 [132]=37.90000000 \
  [133]=38.90000000 [134]=39.80000000 [135]=40.70000000 \
  [136]=41.59996000 [137]=43.50000000 [138]=44.40000000 \
  [139]=45.30000000 [140]=47.10000000 [141]=48.10000000 \
  [142]=48.99996000 [143]=49.90000000 [144]=50.80000000 \
  [145]=55.40000000 [146]=56.30000000 [147]=309.60000000 \
  [148]=310.50000000 [149]=312.40000000 [150]=313.30000000 \
  [151]=314.20000000 [152]=315.10000000 [153]=316.10000000 \
  [154]=316.99996000 [155]=322.50000000 [156]=326.20000000 \
  [157]=328.90000000 [158]=330.80000000 [159]=331.70000000 \
  [160]=332.60000000 [161]=333.50000000 [162]=334.50000000 \
  [163]=335.40000000 [164]=336.30000000 [165]=337.19996000 \
  [166]=338.10000000 [167]=339.10000000 [168]=340.90000000 \
  [169]=343.70000000 [170]=344.60000000 [171]=345.50000000 \
  [172]=347.30000000 [173]=350.10000000 [174]=351.00000000 \
  [175]=353.79996000 [176]=354.70000000 [177]=356.50000000 \
  [178]=357.50000000 [179]=358.40000000 [180]=0.20000000 \
  [181]=3.00000000 [182]=3.90000000 [183]=4.80000000 \
  [184]=5.70000000 [185]=7.60000000 [186]=8.50000000 \
  [187]=9.40000000 [188]=10.30000000 [189]=11.30000000 \
  [190]=12.20000000 [191]=13.10000000 [192]=17.70000000 \
  [193]=18.60000000 [194]=19.50000000 [195]=20.50000000 \
  [196]=21.40000000 [197]=22.30000000 [198]=26.00000000 \
  [199]=27.80000000 [200]=28.70000000 [201]=29.70000000 \
  [202]=30.60000000 [203]=31.50000000 [204]=32.40000000 \
  [205]=33.30000000 [206]=34.30000000 [207]=35.20000000 \
  [208]=36.10000000 [209]=37.00000000 [210]=37.90000000 \
  [211]=38.89996000 [212]=40.70000000 [213]=41.60004000 \
  [214]=42.49996000 [215]=43.50000000 [216]=44.40000000 \
  [217]=45.30000000 [218]=46.20000000 [219]=47.10000000 \
  [220]=49.90000000 [221]=50.80000000 [222]=53.60000000 \
  [223]=54.50000000 [224]=57.30000000 [225]=58.20000000)
  
  DEC=( [1]=-0.76997000 [2]=-0.76997000 [3]=-0.77000000 \
  [4]=-0.77000000 [5]=-0.77000000 [6]=-0.76997000 \
  [7]=-0.76997000 [8]=-0.76997000 [9]=-0.77000000 \
  [10]=-0.77000000 [11]=-0.77000000 [12]=-0.77000000 \
  [13]=-0.76997000 [14]=-0.77000000 [15]=-0.77000000 \
  [16]=-0.76997000 [17]=-0.77000000 [18]=-0.77003000 \
  [19]=-0.76997000 [20]=-0.77000000 [21]=-0.77000000 \
  [22]=-0.77000000 [23]=-0.77000000 [24]=-0.77000000 \
  [25]=-0.76997000 [26]=-0.77000000 [27]=-0.77000000 \
  [28]=-0.76997000 [29]=-0.77000000 [30]=-0.77000000 \
  [31]=-0.77000000 [32]=-0.77000000 [33]=-0.77000000 \
  [34]=-0.77000000 [35]=-0.77000000 [36]=-0.77000000 \
  [37]=-0.77000000 [38]=-0.77000000 [39]=-0.76997000 \
  [40]=-0.77000000 [41]=-0.77000000 [42]=-0.77000000 \
  [43]=-0.77000000 [44]=-0.77000000 [45]=-0.77000000 \
  [46]=-0.77000000 [47]=-0.77000000 [48]=-0.77000000 \
  [49]=-0.77000000 [50]=-0.77000000 [51]=-0.77003000 \
  [52]=-0.77003000 [53]=-0.77000000 [54]=-0.77000000 \
  [55]=-0.77000000 [56]=-0.77000000 [57]=-0.77000000 \
  [58]=-0.77000000 [59]=-0.76997000 [60]=-0.77000000 \
  [61]=-0.77000000 [62]=-0.77000000 [63]=-0.76997000 \
  [64]=-0.77000000 [65]=-0.77000000 [66]=-0.77000000 \
  [67]=-0.77003000 [68]=-0.77000000 [69]=-0.77000000 \
  [70]=-0.77000000 [71]=-0.77000000 [72]=-0.77000000 \
  [73]=-0.77000000 [74]=-0.76997000 [75]=-0.76997000 \
  [76]=-0.77000000 [77]=-0.77000000 [78]=-0.77000000 \
  [79]=-0.77000000 [80]=-0.77000000 [81]=-0.77000000 \
  [82]=0.00000000 [83]=-0.00003000 [84]=0.00000000 \
  [85]=0.00000000 [86]=0.00000000 [87]=0.00000000 \
  [88]=0.00000000 [89]=-0.00003000 [90]=0.00000000 \
  [91]=0.00000000 [92]=0.00000000 [93]=0.00000000 \
  [94]=0.00000000 [95]=0.00000000 [96]=0.00000000 \
  [97]=-0.00003000 [98]=0.00000000 [99]=0.00000000 \
  [100]=0.00000000 [101]=0.00000000 [102]=0.00000000 \
  [103]=0.00000000 [104]=0.00000000 [105]=0.00000000 \
  [106]=0.00000000 [107]=0.00000000 [108]=0.00000000 \
  [109]=-0.00003000 [110]=0.00000000 [111]=0.00000000 \
  [112]=-0.00003000 [113]=0.00000000 [114]=-0.00003000 \
  [115]=0.00000000 [116]=0.00000000 [117]=0.00000000 \
  [118]=-0.00003000 [119]=0.00000000 [120]=0.00000000 \
  [121]=0.00000000 [122]=0.00000000 [123]=0.00000000 \
  [124]=0.00000000 [125]=0.00000000 [126]=0.00000000 \
  [127]=0.00000000 [128]=0.00000000 [129]=0.00000000 \
  [130]=0.00000000 [131]=0.00000000 [132]=0.00000000 \
  [133]=0.00000000 [134]=0.00000000 [135]=0.00000000 \
  [136]=0.00003000 [137]=0.00000000 [138]=0.00000000 \
  [139]=-0.00003000 [140]=0.00000000 [141]=0.00000000 \
  [142]=0.00003000 [143]=0.00000000 [144]=0.00000000 \
  [145]=0.00000000 [146]=0.00000000 [147]=0.77003000 \
  [148]=0.77000000 [149]=0.77003000 [150]=0.77000000 \
  [151]=0.77000000 [152]=0.76997000 [153]=0.77000000 \
  [154]=0.77003000 [155]=0.77000000 [156]=0.77000000 \
  [157]=0.77000000 [158]=0.77000000 [159]=0.76997000 \
  [160]=0.77000000 [161]=0.77000000 [162]=0.77000000 \
  [163]=0.77000000 [164]=0.76997000 [165]=0.77000000 \
  [166]=0.76994000 [167]=0.76997000 [168]=0.77000000 \
  [169]=0.77000000 [170]=0.77000000 [171]=0.77000000 \
  [172]=0.77000000 [173]=0.76997000 [174]=0.77000000 \
  [175]=0.77000000 [176]=0.77000000 [177]=0.77000000 \
  [178]=0.77000000 [179]=0.77000000 [180]=0.77000000 \
  [181]=0.77000000 [182]=0.77003000 [183]=0.77000000 \
  [184]=0.77000000 [185]=0.77000000 [186]=0.77000000 \
  [187]=0.77000000 [188]=0.77000000 [189]=0.77000000 \
  [190]=0.77000000 [191]=0.77000000 [192]=0.77000000 \
  [193]=0.76997000 [194]=0.77000000 [195]=0.77000000 \
  [196]=0.76997000 [197]=0.77000000 [198]=0.77000000 \
  [199]=0.77000000 [200]=0.77000000 [201]=0.77000000 \
  [202]=0.77000000 [203]=0.77000000 [204]=0.76997000 \
  [205]=0.77000000 [206]=0.76997000 [207]=0.77000000 \
  [208]=0.77000000 [209]=0.77000000 [210]=0.77000000 \
  [211]=0.77000000 [212]=0.77000000 [213]=0.77000000 \
  [214]=0.77003000 [215]=0.76997000 [216]=0.76997000 \
  [217]=0.77000000 [218]=0.77000000 [219]=0.77000000 \
  [220]=0.77000000 [221]=0.77000000 [222]=0.77000000 \
  [223]=0.77000000 [224]=0.77003000 [225]=0.77000000)
fi

if [[ $6 =~ RCS* ]]; then
  NFIELDS=799

  FIELD=( [1]="CDE0047A0" [2]="CDE0047A1" [3]="CDE0047A2" \
  [4]="CDE0047A3" [5]="CDE0047A4" [6]="CDE0047A5" \
  [7]="CDE0047A6" [8]="CDE0047A7" [9]="CDE0047A8" \
  [10]="CDE0047B0" [11]="CDE0047B1" [12]="CDE0047B2" \
  [13]="CDE0047B3" [14]="CDE0047B4" [15]="CDE0047B5" \
  [16]="CDE0047B6" [17]="CDE0047B7" [18]="CDE0047B8" \
  [19]="CDE0047C0" [20]="CDE0047C1" [21]="CDE0047C2" \
  [22]="CDE0047C3" [23]="CDE0047C4" [24]="CDE0047C5" \
  [25]="CDE0047C6" [26]="CDE0047C7" [27]="CDE0047C8" \
  [28]="CDE0047D0" [29]="CDE0047D1" [30]="CDE0047D2" \
  [31]="CDE0047D3" [32]="CDE0047D4" [33]="CDE0047D5" \
  [34]="CDE0047D6" [35]="CDE0047D7" [36]="CDE0047D8" \
  [37]="CDE0047E0" [38]="CDE0047E1" [39]="CDE0047E2" \
  [40]="CDE0047E3" [41]="CDE0047E4" [42]="CDE0047E5" \
  [43]="CDE0047E7" [44]="CDE0047E8" [45]="CDE0047F0" \
  [46]="CDE0047F1" [47]="CDE0047F2" [48]="CDE0047F3" \
  [49]="CDE0047F4" [50]="CDE0047F5" [51]="CDE0047F8" \
  [52]="CDE0047G0" [53]="CDE0047G1" [54]="CDE0047G2" \
  [55]="CDE0047G3" [56]="CDE0047G4" [57]="CDE0047G5" \
  [58]="CDE0047G6" [59]="CDE0047G7" [60]="CDE0047G8" \
  [61]="CDE0047H0" [62]="CDE0047H1" [63]="CDE0047H2" \
  [64]="CDE0047H3" [65]="CDE0047H4" [66]="CDE0047H5" \
  [67]="CDE0047H6" [68]="CDE0047H7" [69]="CDE0047H8" \
  [70]="CDE0047I0" [71]="CDE0047I1" [72]="CDE0047I2" \
  [73]="CDE0047I3" [74]="CDE0047I4" [75]="CDE0047I5" \
  [76]="CDE0047I6" [77]="CDE0047I7" [78]="CDE0047I8" \
  [79]="CDE0133A0" [80]="CDE0133A1" [81]="CDE0133A2" \
  [82]="CDE0133A3" [83]="CDE0133A4" [84]="CDE0133A5" \
  [85]="CDE0133B0" [86]="CDE0133B1" [87]="CDE0133B2" \
  [88]="CDE0133B3" [89]="CDE0133B4" [90]="CDE0133B5" \
  [91]="CDE0133C0" [92]="CDE0133C1" [93]="CDE0133C2" \
  [94]="CDE0133C3" [95]="CDE0133C4" [96]="CDE0133C5" \
  [97]="CDE0133D0" [98]="CDE0133D1" [99]="CDE0133D2" \
  [100]="CDE0133D3" [101]="CDE0133D4" [102]="CDE0133D5" \
  [103]="CDE0133E0" [104]="CDE0133E1" [105]="CDE0133E2" \
  [106]="CDE0133E3" [107]="CDE0133E4" [108]="CDE0133E5" \
  [109]="CDE0133F0" [110]="CDE0133F1" [111]="CDE0133F2" \
  [112]="CDE0133F3" [113]="CDE0133F4" [114]="CDE0133F5" \
  [115]="CDE0310A0" [116]="CDE0310A1" [117]="CDE0310A2" \
  [118]="CDE0310A3" [119]="CDE0310A4" [120]="CDE0310A5" \
  [121]="CDE0310A6" [122]="CDE0310A7" [123]="CDE0310A8" \
  [124]="CDE0310B0" [125]="CDE0310B1" [126]="CDE0310B2" \
  [127]="CDE0310B3" [128]="CDE0310B4" [129]="CDE0310B5" \
  [130]="CDE0310B6" [131]="CDE0310B7" [132]="CDE0310B8" \
  [133]="CDE0310C0" [134]="CDE0310C1" [135]="CDE0310C2" \
  [136]="CDE0310C3" [137]="CDE0310C4" [138]="CDE0310C5" \
  [139]="CDE0310C6" [140]="CDE0310C7" [141]="CDE0310C8" \
  [142]="CDE0310D0" [143]="CDE0310D1" [144]="CDE0310D2" \
  [145]="CDE0310D3" [146]="CDE0310D4" [147]="CDE0310D5" \
  [148]="CDE0310D6" [149]="CDE0310D7" [150]="CDE0310D8" \
  [151]="CDE0310E0" [152]="CDE0310E1" [153]="CDE0310E2" \
  [154]="CDE0310E3" [155]="CDE0310E4" [156]="CDE0310E5" \
  [157]="CDE0310E6" [158]="CDE0310E7" [159]="CDE0310E8" \
  [160]="CDE0310F0" [161]="CDE0310F1" [162]="CDE0310F2" \
  [163]="CDE0310F3" [164]="CDE0310F4" [165]="CDE0310F5" \
  [166]="CDE0310F6" [167]="CDE0310F7" [168]="CDE0310F8" \
  [169]="CDE0310G0" [170]="CDE0310G1" [171]="CDE0310G2" \
  [172]="CDE0310G3" [173]="CDE0310G4" [174]="CDE0310G5" \
  [175]="CDE0310G6" [176]="CDE0310G7" [177]="CDE0310G8" \
  [178]="CDE0310H0" [179]="CDE0310H1" [180]="CDE0310H2" \
  [181]="CDE0310H3" [182]="CDE0310H4" [183]="CDE0310H5" \
  [184]="CDE0310H6" [185]="CDE0310H7" [186]="CDE0310H8" \
  [187]="CDE0310I0" [188]="CDE0310I1" [189]="CDE0310I2" \
  [190]="CDE0310I3" [191]="CDE0310I4" [192]="CDE0310I5" \
  [193]="CDE0310I6" [194]="CDE0310I7" [195]="CDE0310I8" \
  [196]="CDE0357A0" [197]="CDE0357A1" [198]="CDE0357A2" \
  [199]="CDE0357A3" [200]="CDE0357A4" [201]="CDE0357A5" \
  [202]="CDE0357B0" [203]="CDE0357B1" [204]="CDE0357B2" \
  [205]="CDE0357B3" [206]="CDE0357B4" [207]="CDE0357B5" \
  [208]="CDE0357C0" [209]="CDE0357C1" [210]="CDE0357C2" \
  [211]="CDE0357C3" [212]="CDE0357C4" [213]="CDE0357C5" \
  [214]="CDE0357D0" [215]="CDE0357D1" [216]="CDE0357D2" \
  [217]="CDE0357D3" [218]="CDE0357D4" [219]="CDE0357D5" \
  [220]="CDE0357E0" [221]="CDE0357E1" [222]="CDE0357E2" \
  [223]="CDE0357E3" [224]="CDE0357E4" [225]="CDE0357E5" \
  [226]="CDE0357F0" [227]="CDE0357F1" [228]="CDE0357F2" \
  [229]="CDE0357F3" [230]="CDE0357F4" [231]="CDE0357F5" \
  [232]="CDE1040A0" [233]="CDE1040A1" [234]="CDE1040A2" \
  [235]="CDE1040A3" [236]="CDE1040A4" [237]="CDE1040A5" \
  [238]="CDE1040B0" [239]="CDE1040B1" [240]="CDE1040B2" \
  [241]="CDE1040B3" [242]="CDE1040B4" [243]="CDE1040B5" \
  [244]="CDE1040C0" [245]="CDE1040C1" [246]="CDE1040C2" \
  [247]="CDE1040C3" [248]="CDE1040C4" [249]="CDE1040C5" \
  [250]="CDE1040D0" [251]="CDE1040D1" [252]="CDE1040D2" \
  [253]="CDE1040D3" [254]="CDE1040D4" [255]="CDE1040D5" \
  [256]="CDE1040E0" [257]="CDE1040E1" [258]="CDE1040E2" \
  [259]="CDE1040E3" [260]="CDE1040E4" [261]="CDE1040E5" \
  [262]="CDE1040F0" [263]="CDE1040F1" [264]="CDE1040F2" \
  [265]="CDE1040F3" [266]="CDE1040F4" [267]="CDE1040F5" \
  [268]="CDE1111A0" [269]="CDE1111A1" [270]="CDE1111A2" \
  [271]="CDE1111A3" [272]="CDE1111A4" [273]="CDE1111A5" \
  [274]="CDE1111A6" [275]="CDE1111A7" [276]="CDE1111A8" \
  [277]="CDE1111B0" [278]="CDE1111B1" [279]="CDE1111B2" \
  [280]="CDE1111B3" [281]="CDE1111B4" [282]="CDE1111B5" \
  [283]="CDE1111B6" [284]="CDE1111B7" [285]="CDE1111B8" \
  [286]="CDE1111C0" [287]="CDE1111C1" [288]="CDE1111C2" \
  [289]="CDE1111C3" [290]="CDE1111C4" [291]="CDE1111C5" \
  [292]="CDE1111C6" [293]="CDE1111C7" [294]="CDE1111C8" \
  [295]="CDE1111D0" [296]="CDE1111D1" [297]="CDE1111D2" \
  [298]="CDE1111D3" [299]="CDE1111D4" [300]="CDE1111D5" \
  [301]="CDE1111D6" [302]="CDE1111D7" [303]="CDE1111D8" \
  [304]="CDE1111E0" [305]="CDE1111E1" [306]="CDE1111E2" \
  [307]="CDE1111E3" [308]="CDE1111E4" [309]="CDE1111E5" \
  [310]="CDE1111E6" [311]="CDE1111E7" [312]="CDE1111E8" \
  [313]="CDE1111F0" [314]="CDE1111F1" [315]="CDE1111F2" \
  [316]="CDE1111F3" [317]="CDE1111F4" [318]="CDE1111F5" \
  [319]="CDE1111F6" [320]="CDE1111F7" [321]="CDE1111F8" \
  [322]="CDE1111G0" [323]="CDE1111G1" [324]="CDE1111G2" \
  [325]="CDE1111G3" [326]="CDE1111G4" [327]="CDE1111G5" \
  [328]="CDE1111G6" [329]="CDE1111G7" [330]="CDE1111G8" \
  [331]="CDE1111H0" [332]="CDE1111H1" [333]="CDE1111H2" \
  [334]="CDE1111H3" [335]="CDE1111H4" [336]="CDE1111H5" \
  [337]="CDE1111H6" [338]="CDE1111H7" [339]="CDE1111H8" \
  [340]="CDE1111I0" [341]="CDE1111I1" [342]="CDE1111I2" \
  [343]="CDE1111I3" [344]="CDE1111I4" [345]="CDE1111I5" \
  [346]="CDE1111I6" [347]="CDE1111I7" [348]="CDE1111I8" \
  [349]="CDE1303A3" [350]="CDE1303A4" [351]="CDE1303B3" \
  [352]="CDE1303C0" [353]="CDE1303C3" [354]="CDE1303C4" \
  [355]="CDE1303D0" [356]="CDE1303D3" [357]="CDE1303D4" \
  [358]="CDE1303E0" [359]="CDE1303E4" [360]="CDE1303E8" \
  [361]="CDE1303F0" [362]="CDE1303F4" [363]="CDE1303F8" \
  [364]="CDE1303G0" [365]="CDE1303G4" [366]="CDE1303G8" \
  [367]="CDE1303H0" [368]="CDE1303H4" [369]="CDE1303H8" \
  [370]="CDE1303I0" [371]="CDE1303I1" [372]="CDE1303I4" \
  [373]="CDE1303I7" [374]="CDE1303I8" [375]="CDE1514A9" \
  [376]="CDE1514A0" [377]="CDE1514A1" [378]="CDE1514A2" \
  [379]="CDE1514A3" [380]="CDE1514A4" [381]="CDE1514A5" \
  [382]="CDE1514A6" [383]="CDE1514A7" [384]="CDE1514A8" \
  [385]="CDE1514B9" [386]="CDE1514B0" [387]="CDE1514B1" \
  [388]="CDE1514B2" [389]="CDE1514B3" [390]="CDE1514B4" \
  [391]="CDE1514B5" [392]="CDE1514B6" [393]="CDE1514B7" \
  [394]="CDE1514B8" [395]="CDE1514C9" [396]="CDE1514C0" \
  [397]="CDE1514C1" [398]="CDE1514C2" [399]="CDE1514C3" \
  [400]="CDE1514C4" [401]="CDE1514C5" [402]="CDE1514C6" \
  [403]="CDE1514C7" [404]="CDE1514C8" [405]="CDE1514D9" \
  [406]="CDE1514D0" [407]="CDE1514D1" [408]="CDE1514D2" \
  [409]="CDE1514D3" [410]="CDE1514D4" [411]="CDE1514D5" \
  [412]="CDE1514D6" [413]="CDE1514D7" [414]="CDE1514D8" \
  [415]="CDE1514E9" [416]="CDE1514E0" [417]="CDE1514E1" \
  [418]="CDE1514E2" [419]="CDE1514E3" [420]="CDE1514E4" \
  [421]="CDE1514E5" [422]="CDE1514E6" [423]="CDE1514E7" \
  [424]="CDE1514E8" [425]="CDE1514F9" [426]="CDE1514F0" \
  [427]="CDE1514F1" [428]="CDE1514F2" [429]="CDE1514F3" \
  [430]="CDE1514F4" [431]="CDE1514F5" [432]="CDE1514F6" \
  [433]="CDE1514F7" [434]="CDE1514F8" [435]="CDE1514F9" \
  [436]="CDE1514G9" [437]="CDE1514G0" [438]="CDE1514G1" \
  [439]="CDE1514G2" [440]="CDE1514G3" [441]="CDE1514G4" \
  [442]="CDE1514G5" [443]="CDE1514G6" [444]="CDE1514G7" \
  [445]="CDE1514G8" [446]="CDE1514H9" [447]="CDE1514H0" \
  [448]="CDE1514H1" [449]="CDE1514H2" [450]="CDE1514H3" \
  [451]="CDE1514H4" [452]="CDE1514H5" [453]="CDE1514H6" \
  [454]="CDE1514H7" [455]="CDE1514H8" [456]="CDE1514I9" \
  [457]="CDE1514I0" [458]="CDE1514I1" [459]="CDE1514I2" \
  [460]="CDE1514I3" [461]="CDE1514I4" [462]="CDE1514I5" \
  [463]="CDE1514I6" [464]="CDE1514I7" [465]="CDE1514I8" \
  [466]="CDE1613A0" [467]="CDE1613A1" [468]="CDE1613A2" \
  [469]="CDE1613A3" [470]="CDE1613A4" [471]="CDE1613A5" \
  [472]="CDE1613B0" [473]="CDE1613B1" [474]="CDE1613B2" \
  [475]="CDE1613B3" [476]="CDE1613B4" [477]="CDE1613B5" \
  [478]="CDE1613C0" [479]="CDE1613C1" [480]="CDE1613C2" \
  [481]="CDE1613C3" [482]="CDE1613C4" [483]="CDE1613C5" \
  [484]="CDE1613D0" [485]="CDE1613D1" [486]="CDE1613D2" \
  [487]="CDE1613D3" [488]="CDE1613D3P23" [489]="CDE1613D4" \
  [490]="CDE1613D5" [491]="CDE1613E0" [492]="CDE1613E1" \
  [493]="CDE1613E2" [494]="CDE1613E3" [495]="CDE1613E4" \
  [496]="CDE1613E5" [497]="CDE1613F0" [498]="CDE1613F1" \
  [499]="CDE1613F2" [500]="CDE1613F3" [501]="CDE1613F4" \
  [502]="CDE1613F5" [503]="CDE1645A0" [504]="CDE1645A1" \
  [505]="CDE1645A2" [506]="CDE1645A3" [507]="CDE1645A4" \
  [508]="CDE1645A5" [509]="CDE1645B0" [510]="CDE1645B1" \
  [511]="CDE1645B2" [512]="CDE1645B3" [513]="CDE1645B4" \
  [514]="CDE1645B5" [515]="CDE1645C0" [516]="CDE1645C1" \
  [517]="CDE1645C2" [518]="CDE1645C3" [519]="CDE1645C4" \
  [520]="CDE1645C5" [521]="CDE1645D0" [522]="CDE1645D1" \
  [523]="CDE1645D3" [524]="CDE1645D4" [525]="CDE1645D5" \
  [526]="CDE1645E0" [527]="CDE1645E1" [528]="CDE1645E2" \
  [529]="CDE1645E3" [530]="CDE1645E4" [531]="CDE1645E5" \
  [532]="CDE1645F0" [533]="CDE1645F1" [534]="CDE1645F2" \
  [535]="CDE1645F3" [536]="CDE1645F4" [537]="CDE1645F5" \
  [538]="CDE2143A0" [539]="CDE2143A1" [540]="CDE2143A2" \
  [541]="CDE2143A3" [542]="CDE2143A3P01" [543]="CDE2143A4" \
  [544]="CDE2143A5" [545]="CDE2143A6" [546]="CDE2143A7" \
  [547]="CDE2143A8" [548]="CDE2143AA" [549]="CDE2143B0" \
  [550]="CDE2143B1" [551]="CDE2143B2" [552]="CDE2143B2P01" \
  [553]="CDE2143B3" [554]="CDE2143B4" [555]="CDE2143B5" \
  [556]="CDE2143B6" [557]="CDE2143B7" [558]="CDE2143B8" \
  [559]="CDE2143BA" [560]="CDE2143C0" [561]="CDE2143C1" \
  [562]="CDE2143C2" [563]="CDE2143C3" [564]="CDE2143C4" \
  [565]="CDE2143C5" [566]="CDE2143C6" [567]="CDE2143C7" \
  [568]="CDE2143C7P18" [569]="CDE2143C8" [570]="CDE2143CA" \
  [571]="CDE2143D0" [572]="CDE2143D1" [573]="CDE2143D2" \
  [574]="CDE2143D3" [575]="CDE2143D4" [576]="CDE2143D5" \
  [577]="CDE2143D6" [578]="CDE2143D7" [579]="CDE2143D8" \
  [580]="CDE2143DA" [581]="CDE2143E0" [582]="CDE2143E1" \
  [583]="CDE2143E2" [584]="CDE2143E3" [585]="CDE2143E4" \
  [586]="CDE2143E5" [587]="CDE2143E6" [588]="CDE2143E7" \
  [589]="CDE2143E8" [590]="CDE2143EA" [591]="CDE2143F0" \
  [592]="CDE2143F1" [593]="CDE2143F2" [594]="CDE2143F3" \
  [595]="CDE2143F4" [596]="CDE2143F5" [597]="CDE2143F6" \
  [598]="CDE2143F7" [599]="CDE2143F8" [600]="CDE2143FA" \
  [601]="CDE2143G0" [602]="CDE2143G1" [603]="CDE2143G2" \
  [604]="CDE2143G3" [605]="CDE2143G4" [606]="CDE2143G5" \
  [607]="CDE2143G6" [608]="CDE2143G7" [609]="CDE2143G8" \
  [610]="CDE2143GA" [611]="CDE2143H0" [612]="CDE2143H1" \
  [613]="CDE2143H2" [614]="CDE2143H3" [615]="CDE2143H4" \
  [616]="CDE2143H5" [617]="CDE2143H6" [618]="CDE2143H7" \
  [619]="CDE2143H8" [620]="CDE2143HA" [621]="CDE2143I0" \
  [622]="CDE2143I1" [623]="CDE2143I2" [624]="CDE2143I3" \
  [625]="CDE2143I4" [626]="CDE2143I5" [627]="CDE2143I6" \
  [628]="CDE2143I7" [629]="CDE2143I8" [630]="CDE2143IA" \
  [631]="CDE2143J0" [632]="CDE2143J1" [633]="CDE2143J2" \
  [634]="CDE2143J2P17" [635]="CDE2143J3" [636]="CDE2143J4" \
  [637]="CDE2143J5" [638]="CDE2143J6" [639]="CDE2143J6P28" \
  [640]="CDE2143J7" [641]="CDE2143J8" [642]="CDE2143JA" \
  [643]="CDE2329A0" [644]="CDE2329A1" [645]="CDE2329A2" \
  [646]="CDE2329A3" [647]="CDE2329A4" [648]="CDE2329A5" \
  [649]="CDE2329B0" [650]="CDE2329B1" [651]="CDE2329B2" \
  [652]="CDE2329B3" [653]="CDE2329B4" [654]="CDE2329B5" \
  [655]="CDE2329C0" [656]="CDE2329C1" [657]="CDE2329C2" \
  [658]="CDE2329C3" [659]="CDE2329C4" [660]="CDE2329C5" \
  [661]="CDE2329D0" [662]="CDE2329D1" [663]="CDE2329D2" \
  [664]="CDE2329D3" [665]="CDE2329D4" [666]="CDE2329D5" \
  [667]="CDE2329E0" [668]="CDE2329E1" [669]="CDE2329E2" \
  [670]="CDE2329E3" [671]="CDE2329E4" [672]="CDE2329E5" \
  [673]="CDE2329F0" [674]="CDE2329F1" [675]="CDE2329F2" \
  [676]="CDE2329F3" [677]="CDE2329F4" [678]="CDE2329F5" \
  [679]="CDE2329G0" [680]="CDE2329G1" [681]="CDE2329G2" \
  [682]="CDE2329G3" [683]="CDE2329G4" [684]="CDE2329G5" \
  [685]="CDE2329H0" [686]="CDE2329H1" [687]="CDE2329H2" \
  [688]="CDE2329H3" [689]="CDE2329H4" [690]="CDE2329H5" \
  [691]="CDE2338A0" [692]="CDE2338A1" [693]="CDE2338A2" \
  [694]="CDE2338A3" [695]="CDE2338A4" [696]="CDE2338A5" \
  [697]="CDE2338A6" [698]="CDE2338A7" [699]="CDE2338A8" \
  [700]="CDE2338B0" [701]="CDE2338B1" [702]="CDE2338B2" \
  [703]="CDE2338B3" [704]="CDE2338B4" [705]="CDE2338B5" \
  [706]="CDE2338B6" [707]="CDE2338B7" [708]="CDE2338B8" \
  [709]="CDE2338C0" [710]="CDE2338C1" [711]="CDE2338C2" \
  [712]="CDE2338C3" [713]="CDE2338C4" [714]="CDE2338C5" \
  [715]="CDE2338C6" [716]="CDE2338C7" [717]="CDE2338C8" \
  [718]="CDE2338D0" [719]="CDE2338D1" [720]="CDE2338D2" \
  [721]="CDE2338D3" [722]="CDE2338D4" [723]="CDE2338D6" \
  [724]="CDE2338D7" [725]="CDE2338E0" [726]="CDE2338E1" \
  [727]="CDE2338E2" [728]="CDE2338E3" [729]="CDE2338E4" \
  [730]="CDE2338E5" [731]="CDE2338E6" [732]="CDE2338E7" \
  [733]="CDE2338E8" [734]="CDE2338F0" [735]="CDE2338F1" \
  [736]="CDE2338F2" [737]="CDE2338F3" [738]="CDE2338F4" \
  [739]="CDE2338F5" [740]="CDE2338F6" [741]="CDE2338F7" \
  [742]="CDE2338F8" [743]="CDE2338G0" [744]="CDE2338G1" \
  [745]="CDE2338G2" [746]="CDE2338G3" [747]="CDE2338G4" \
  [748]="CDE2338G5" [749]="CDE2338G6" [750]="CDE2338G7" \
  [751]="CDE2338G8" [752]="CDE2338H0" [753]="CDE2338H1" \
  [754]="CDE2338H2" [755]="CDE2338H3" [756]="CDE2338H4" \
  [757]="CDE2338H5" [758]="CDE2338H6" [759]="CDE2338H7" \
  [760]="CDE2338H8" [761]="CDE2338I0" [762]="CDE2338I1" \
  [763]="CDE2338I2" [764]="CDE2338I3" [765]="CDE2338I4" \
  [766]="CDE2338I5" [767]="CDE2338I6" [768]="CDE2338I7" \
  [769]="CDE2338I8" [770]="CSP0320A3" [771]="CSP0320A4" \
  [772]="CSP0320A5" [773]="CSP0320B2" [774]="CSP0320B3" \
  [775]="CSP0320B4" [776]="CSP0320B5" [777]="CSP0320C1" \
  [778]="CSP0320C2" [779]="CSP0320C3" [780]="CSP0320C4" \
  [781]="CSP0320C5" [782]="CSP0320D0" [783]="CSP0320D4" \
  [784]="CSP0320D5" [785]="CSP0320E4" [786]="CSP0320E5" \
  [787]="CSP0320F3" [788]="CSP0320F4" [789]="CSP0320F5" \
  [790]="CSP0320G3" [791]="CSP0320G4" [792]="CSP0320G5" \
  [793]="CSP0320H0" [794]="CSP0320H1" [795]="CSP0320H2" \
  [796]="CSP0320H3" [797]="CSP0320H4" [798]="CSP0320H5" \
  [799]="CSP0320I5")
  
  RA=( [1]=15.70370000 [2]=15.70070000 [3]=15.69880000 \
  [4]=15.69780000 [5]=15.69800000 [6]=15.69910000 \
  [7]=15.70130000 [8]=15.70130000 [9]=15.70880000 \
  [10]=14.74220000 [11]=14.74000000 [12]=14.73850000 \
  [13]=14.73780000 [14]=14.73790000 [15]=14.73870000 \
  [16]=14.74041708 [17]=14.74041708 [18]=14.74600000 \
  [19]=13.78070000 [20]=13.77920000 [21]=13.77820000 \
  [22]=13.77780000 [23]=13.77790000 [24]=13.77840000 \
  [25]=13.77840000 [26]=13.77840000 [27]=13.78330000 \
  [28]=12.81930000 [29]=12.81850000 [30]=12.81800000 \
  [31]=12.81780000 [32]=12.81780000 [33]=12.81810000 \
  [34]=12.81810000 [35]=12.81810000 [36]=12.82050000 \
  [37]=11.85770000 [38]=11.85770000 [39]=11.85780000 \
  [40]=11.85770000 [41]=11.85770000 [42]=11.85770000 \
  [43]=11.85770000 [44]=11.85780000 [45]=10.89630000 \
  [46]=10.89700000 [47]=10.89750000 [48]=10.89780000 \
  [49]=10.89770000 [50]=10.89740000 [51]=10.89500000 \
  [52]=9.93480000 [53]=9.93630000 [54]=9.93730000 \
  [55]=9.93770000 [56]=9.93770000 [57]=9.93770000 \
  [58]=9.93600000 [59]=9.93440000 [60]=9.93220000 \
  [61]=8.97330000 [62]=8.97550000 [63]=8.97700000 \
  [64]=8.97770000 [65]=8.97760000 [66]=8.97670000 \
  [67]=8.97510000 [68]=8.97270000 [69]=8.96950000 \
  [70]=8.01180000 [71]=8.01480000 [72]=8.01670000 \
  [73]=8.01770000 [74]=8.01760000 [75]=8.01640000 \
  [76]=8.01430000 [77]=8.01100000 [78]=8.00680000 \
  [79]=25.71490000 [80]=25.71340000 [81]=25.71270000 \
  [82]=25.71250000 [83]=25.71300000 [84]=25.71420000 \
  [85]=24.75390000 [86]=24.75300000 [87]=24.75260000 \
  [88]=24.75250000 [89]=24.75280000 [90]=24.75280000 \
  [91]=23.79270000 [92]=23.79270000 [93]=23.79250000 \
  [94]=23.79250000 [95]=23.79260000 [96]=23.79280000 \
  [97]=22.83200000 [98]=22.83230000 [99]=22.83250000 \
  [100]=22.83250000 [101]=22.83240000 [102]=22.83220000 \
  [103]=21.87110000 [104]=21.87200000 [105]=21.87240000 \
  [106]=21.87250000 [107]=21.87220000 [108]=21.87150000 \
  [109]=20.91010000 [110]=20.91160000 [111]=20.91230000 \
  [112]=20.91250000 [113]=20.91200000 [114]=20.91080000 \
  [115]=51.62250000 [116]=51.60150000 [117]=51.58190000 \
  [118]=51.56350000 [119]=51.54640000 [120]=51.53050000 \
  [121]=51.53050000 [122]=51.50210000 [123]=51.48970000 \
  [124]=50.61290000 [125]=50.59720000 [126]=50.58250000 \
  [127]=50.56870000 [128]=50.55590000 [129]=50.54390000 \
  [130]=50.53280000 [131]=50.52260000 [132]=50.51330000 \
  [133]=49.60330000 [134]=49.59290000 [135]=49.58300000 \
  [136]=49.57390000 [137]=49.56530000 [138]=49.55730000 \
  [139]=49.55000000 [140]=49.54320000 [141]=49.53690000 \
  [142]=48.59380000 [143]=48.58850000 [144]=48.58360000 \
  [145]=48.57900000 [146]=48.57480000 [147]=48.57070000 \
  [148]=48.56710000 [149]=48.56370000 [150]=48.56050000 \
  [151]=47.58420000 [152]=47.58420000 [153]=47.58420000 \
  [154]=47.58420000 [155]=47.58420000 [156]=47.58420000 \
  [157]=47.58420000 [158]=47.58420000 [159]=47.58420000 \
  [160]=46.57460000 [161]=46.57980000 [162]=46.58470000 \
  [163]=46.58930000 [164]=46.59360000 [165]=46.59760000 \
  [166]=46.60130000 [167]=46.60470000 [168]=46.60780000 \
  [169]=45.56500000 [170]=45.57550000 [171]=45.58530000 \
  [172]=45.59450000 [173]=45.60300000 [174]=45.61100000 \
  [175]=45.61840000 [176]=45.62520000 [177]=45.63140000 \
  [178]=44.55550000 [179]=44.57120000 [180]=44.58590000 \
  [181]=44.59970000 [182]=44.61250000 [183]=44.62450000 \
  [184]=44.63550000 [185]=44.64570000 [186]=44.65500000 \
  [187]=43.54590000 [188]=43.56680000 [189]=43.58640000 \
  [190]=43.60480000 [191]=43.62200000 [192]=43.63790000 \
  [193]=43.65260000 [194]=43.66620000 [195]=43.67870000 \
  [196]=61.75880000 [197]=61.75120000 [198]=61.74430000 \
  [199]=61.73820000 [200]=61.73270000 [201]=61.72780000 \
  [202]=60.78030000 [203]=60.77570000 [204]=60.77160000 \
  [205]=60.76790000 [206]=60.76460000 [207]=60.76170000 \
  [208]=59.80170000 [209]=59.80020000 [210]=59.79890000 \
  [211]=59.79760000 [212]=59.79650000 [213]=59.79560000 \
  [214]=58.82330000 [215]=58.82480000 [216]=58.82610000 \
  [217]=58.82740000 [218]=58.82850000 [219]=58.82940000 \
  [220]=57.84470000 [221]=57.84930000 [222]=57.85340000 \
  [223]=57.85710000 [224]=57.86040000 [225]=57.86330000 \
  [226]=56.86620000 [227]=56.87380000 [228]=56.88070000 \
  [229]=56.88680000 [230]=56.89230000 [231]=56.89720000 \
  [232]=164.47010000 [233]=164.57360000 [234]=164.68360000 \
  [235]=164.80050000 [236]=164.92500000 [237]=165.05800000 \
  [238]=162.77960000 [239]=162.84170000 [240]=162.90770000 \
  [241]=162.97790000 [242]=163.05260000 [243]=163.13230000 \
  [244]=161.08910000 [245]=161.10980000 [246]=161.13180000 \
  [247]=161.15510000 [248]=161.18010000 [249]=161.20670000 \
  [250]=159.39860000 [251]=159.37790000 [252]=159.35590000 \
  [253]=159.33250000 [254]=159.30760000 [255]=159.28100000 \
  [256]=157.70810000 [257]=157.64600000 [258]=157.58000000 \
  [259]=157.50980000 [260]=157.43550000 [261]=157.35530000 \
  [262]=156.01760000 [263]=155.91400000 [264]=155.80410000 \
  [265]=155.68710000 [266]=155.56200000 [267]=155.42960000 \
  [268]=171.89550000 [269]=171.88500000 [270]=171.87600000 \
  [271]=171.86700000 [272]=171.86100000 [273]=171.85500000 \
  [274]=171.84900000 [275]=171.84600000 [276]=171.84300000 \
  [277]=170.92050000 [278]=170.91300000 [279]=170.90700000 \
  [280]=170.90100000 [281]=170.89500000 [282]=170.89050000 \
  [283]=170.88750000 [284]=170.88450000 [285]=170.88150000 \
  [286]=169.94700000 [287]=169.94250000 [288]=169.93800000 \
  [289]=169.93350000 [290]=169.93050000 [291]=169.92750000 \
  [292]=169.92450000 [293]=169.92300000 [294]=169.92150000 \
  [295]=168.97350000 [296]=168.97050000 [297]=168.96900000 \
  [298]=168.96750000 [299]=168.96450000 [300]=168.96300000 \
  [301]=168.96300000 [302]=168.96150000 [303]=168.96000000 \
  [304]=168.00000000 [305]=168.00000000 [306]=168.00000000 \
  [307]=168.00000000 [308]=168.00000000 [309]=168.00000000 \
  [310]=168.00000000 [311]=168.00000000 [312]=168.00000000 \
  [313]=167.02650000 [314]=167.02950000 [315]=167.03100000 \
  [316]=167.03250000 [317]=167.03550000 [318]=167.03700000 \
  [319]=167.03700000 [320]=167.03850000 [321]=167.04000000 \
  [322]=166.05300000 [323]=166.05750000 [324]=166.06200000 \
  [325]=166.06650000 [326]=166.06950000 [327]=166.07290000 \
  [328]=166.07530000 [329]=166.07730000 [330]=166.07850000 \
  [331]=165.07950000 [332]=165.08700000 [333]=165.09300000 \
  [334]=165.09900000 [335]=165.10500000 [336]=165.10930000 \
  [337]=165.11300000 [338]=165.11590000 [339]=165.11850000 \
  [340]=164.10450000 [341]=164.11500000 [342]=164.12400000 \
  [343]=164.13300000 [344]=164.13900000 [345]=164.14570000 \
  [346]=164.15070000 [347]=164.15450000 [348]=164.15700000 \
  [349]=199.72200000 [350]=199.72050000 [351]=198.76050000 \
  [352]=197.80640000 [353]=197.80050000 [354]=197.79900000 \
  [355]=196.84270000 [356]=196.84050000 [357]=196.83900000 \
  [358]=195.87920000 [359]=195.87900000 [360]=195.87920000 \
  [361]=194.91600000 [362]=194.91900000 [363]=194.91820000 \
  [364]=193.95200000 [365]=193.95900000 [366]=193.95720000 \
  [367]=192.98840000 [368]=192.99900000 [369]=192.99630000 \
  [370]=192.02480000 [371]=192.03000000 [372]=192.03900000 \
  [373]=192.03750000 [374]=192.03530000 [375]=232.50520000 \
  [376]=232.50520000 [377]=232.51250000 [378]=232.52100000 \
  [379]=232.53050000 [380]=232.54110000 [381]=232.55280000 \
  [382]=232.56600000 [383]=232.57950000 [384]=232.59450000 \
  [385]=231.53960000 [386]=231.53960000 [387]=231.54520000 \
  [388]=231.55150000 [389]=231.55860000 [390]=231.56660000 \
  [391]=231.57540000 [392]=231.58500000 [393]=231.59550000 \
  [394]=231.56550000 [395]=230.57410000 [396]=230.57410000 \
  [397]=230.57770000 [398]=230.58200000 [399]=230.58670000 \
  [400]=230.59200000 [401]=230.59790000 [402]=230.60400000 \
  [403]=230.61150000 [404]=230.59120000 [405]=229.60850000 \
  [406]=229.60850000 [407]=229.61040000 [408]=229.61250000 \
  [409]=229.61490000 [410]=229.61750000 [411]=229.62040000 \
  [412]=229.62300000 [413]=229.62750000 [414]=229.61990000 \
  [415]=228.64290000 [416]=228.64290000 [417]=228.64300000 \
  [418]=228.64300000 [419]=228.64300000 [420]=228.64290000 \
  [421]=228.64290000 [422]=228.64350000 [423]=228.64350000 \
  [424]=228.64320000 [425]=227.67740000 [426]=227.67740000 \
  [427]=227.67560000 [428]=227.67350000 [429]=227.67110000 \
  [430]=227.66840000 [431]=227.66550000 [432]=227.66250000 \
  [433]=227.65950000 [434]=227.66110000 [435]=227.67920000 \
  [436]=226.71190000 [437]=226.71190000 [438]=226.70820000 \
  [439]=226.70400000 [440]=226.69920000 [441]=226.69390000 \
  [442]=226.68750000 [443]=226.68150000 [444]=226.67400000 \
  [445]=226.69100000 [446]=225.74630000 [447]=225.74630000 \
  [448]=225.74080000 [449]=225.73440000 [450]=225.72730000 \
  [451]=225.71940000 [452]=225.71100000 [453]=225.70050000 \
  [454]=225.69000000 [455]=225.71540000 [456]=224.78070000 \
  [457]=224.78070000 [458]=224.77340000 [459]=224.76500000 \
  [460]=224.75540000 [461]=224.74480000 [462]=224.73300000 \
  [463]=224.71950000 [464]=224.70600000 [465]=224.73960000 \
  [466]=247.35600000 [467]=247.44300000 [468]=247.53600000 \
  [469]=247.63350000 [470]=247.73850000 [471]=247.73850000 \
  [472]=245.77360000 [473]=245.82600000 [474]=245.88160000 \
  [475]=245.94040000 [476]=246.00280000 [477]=246.06910000 \
  [478]=244.22720000 [479]=244.22720000 [480]=244.22720000 \
  [481]=244.24680000 [482]=244.26760000 [483]=244.24680000 \
  [484]=242.60850000 [485]=242.59200000 [486]=242.57280000 \
  [487]=242.46770000 [488]=242.32510000 [489]=242.53240000 \
  [490]=242.53240000 [491]=240.97350000 [492]=240.97350000 \
  [493]=240.91840000 [494]=240.85960000 [495]=240.79720000 \
  [496]=240.79720000 [497]=239.44350000 [498]=239.35650000 \
  [499]=239.26350000 [500]=239.26350000 [501]=239.06199583 \
  [502]=238.95150000 [503]=254.48400000 [504]=254.52370000 \
  [505]=254.56330000 [506]=254.60440000 [507]=254.64940000 \
  [508]=254.69580000 [509]=253.27980000 [510]=253.30380000 \
  [511]=253.32780000 [512]=253.35310000 [513]=253.37920000 \
  [514]=253.40730000 [515]=252.07550000 [516]=252.08430000 \
  [517]=252.09190000 [518]=252.10190000 [519]=252.11000000 \
  [520]=252.11930000 [521]=250.87130000 [522]=250.86520000 \
  [523]=250.84790000 [524]=250.83940000 [525]=250.83030000 \
  [526]=249.66710000 [527]=249.64520000 [528]=249.62090000 \
  [529]=249.59490000 [530]=249.56840000 [531]=249.54070000 \
  [532]=248.46290000 [533]=248.42460000 [534]=248.38450000 \
  [535]=248.34250000 [536]=248.29840000 [537]=248.25220000 \
  [538]=329.60850000 [539]=329.60530000 [540]=329.60320000 \
  [541]=329.60211208 [542]=329.93300000 [543]=329.60210000 \
  [544]=329.60300000 [545]=329.60510000 [546]=329.60810000 \
  [547]=329.61220000 [548]=329.61140000 [549]=328.64680000 \
  [550]=328.64450000 [551]=328.64450000 [552]=329.01100000 \
  [553]=328.64210000 [554]=328.64200000 [555]=328.64270000 \
  [556]=328.64430000 [557]=328.64660000 [558]=328.64970000 \
  [559]=328.64890000 [560]=327.68520000 [561]=327.68370000 \
  [562]=327.68260000 [563]=327.68200000 [564]=327.68200000 \
  [565]=327.68250000 [566]=327.68350000 [567]=327.68350000 \
  [568]=327.13450000 [569]=327.68710000 [570]=327.68650000 \
  [571]=326.72360000 [572]=326.72280000 [573]=326.72220000 \
  [574]=326.72200000 [575]=326.72200000 [576]=326.72220000 \
  [577]=326.71990000 [578]=326.72350000 [579]=326.72450000 \
  [580]=326.72400000 [581]=325.76190000 [582]=325.76200000 \
  [583]=325.76200000 [584]=325.76200000 [585]=325.76200000 \
  [586]=325.76190000 [587]=325.76200000 [588]=325.76200000 \
  [589]=325.76200000 [590]=325.76090000 [591]=324.80030000 \
  [592]=324.80110000 [593]=324.80170000 [594]=324.80190000 \
  [595]=324.80200000 [596]=324.80170000 [597]=324.80110000 \
  [598]=324.80040000 [599]=324.79940000 [600]=324.80060000 \
  [601]=323.83870000 [602]=323.84030000 [603]=323.84130000 \
  [604]=323.84190000 [605]=323.84190000 [606]=323.84140000 \
  [607]=323.84040000 [608]=323.83890000 [609]=323.83680000 \
  [610]=323.83770000 [611]=322.87710000 [612]=322.87940000 \
  [613]=322.88100000 [614]=322.88180000 [615]=322.88190000 \
  [616]=322.88120000 [617]=322.87960000 [618]=322.87730000 \
  [619]=322.87430000 [620]=322.87460000 [621]=321.91540000 \
  [622]=321.91860000 [623]=321.92070000 [624]=321.92180000 \
  [625]=321.92180000 [626]=321.92090000 [627]=321.91880000 \
  [628]=321.91580000 [629]=321.91170000 [630]=321.91230000 \
  [631]=320.95350000 [632]=320.95650000 [633]=320.92680000 \
  [634]=320.53480000 [635]=320.92680000 [636]=320.92680000 \
  [637]=320.92170000 [638]=320.92170000 [639]=321.24400000 \
  [640]=320.91660000 [641]=320.91250000 [642]=320.95050000 \
  [643]=354.90470000 [644]=354.90190000 [645]=354.90100000 \
  [646]=354.90020000 [647]=354.90000000 [648]=354.90040000 \
  [649]=353.94280000 [650]=353.94150000 [651]=353.94060000 \
  [652]=353.94010000 [653]=353.93990000 [654]=353.94020000 \
  [655]=352.98090000 [656]=352.98050000 [657]=352.98020000 \
  [658]=352.98000000 [659]=352.97990000 [660]=352.98000000 \
  [661]=352.01900000 [662]=352.01940000 [663]=352.01970000 \
  [664]=352.01990000 [665]=352.01990000 [666]=352.01990000 \
  [667]=351.05700000 [668]=351.05840000 [669]=351.05930000 \
  [670]=351.05980000 [671]=351.05990000 [672]=351.05970000 \
  [673]=350.09510000 [674]=350.09730000 [675]=350.09880000 \
  [676]=350.09970000 [677]=350.10000000 [678]=350.09950000 \
  [679]=349.13450000 [680]=349.13450000 [681]=349.13550000 \
  [682]=349.13590000 [683]=349.13610000 [684]=349.13450000 \
  [685]=348.17260000 [686]=348.17260000 [687]=348.17350000 \
  [688]=348.17400000 [689]=348.17420000 [690]=348.17260000 \
  [691]=358.56420000 [692]=358.55000000 [693]=358.53690000 \
  [694]=358.52500000 [695]=358.51420000 [696]=358.51420000 \
  [697]=358.51420000 [698]=358.51420000 [699]=358.51420000 \
  [700]=357.57940000 [701]=357.56870000 [702]=357.55900000 \
  [703]=357.55000000 [704]=357.55000000 [705]=357.55000000 \
  [706]=357.55000000 [707]=357.55000000 [708]=357.55000000 \
  [709]=356.59460000 [710]=356.59460000 [711]=356.58100000 \
  [712]=356.57500000 [713]=356.59460000 [714]=356.59460000 \
  [715]=356.59460000 [716]=356.59460000 [717]=356.59460000 \
  [718]=355.60980000 [719]=355.60980000 [720]=355.60300000 \
  [721]=355.60000000 [722]=355.59730000 [723]=355.60980000 \
  [724]=355.60980000 [725]=354.62500000 [726]=354.62500000 \
  [727]=354.62500000 [728]=354.62500000 [729]=354.62500000 \
  [730]=354.62500000 [731]=354.62500000 [732]=354.62500000 \
  [733]=354.62500000 [734]=353.64020000 [735]=353.64380000 \
  [736]=353.64700000 [737]=353.65000000 [738]=353.65270000 \
  [739]=353.65270000 [740]=353.65270000 [741]=353.65270000 \
  [742]=353.66080000 [743]=352.65540000 [744]=352.66250000 \
  [745]=352.66900000 [746]=352.67500000 [747]=352.68040000 \
  [748]=352.68040000 [749]=352.68040000 [750]=352.68040000 \
  [751]=352.68040000 [752]=351.67060000 [753]=351.68120000 \
  [754]=351.69100000 [755]=351.70000000 [756]=351.70810000 \
  [757]=351.70810000 [758]=351.70810000 [759]=351.70810000 \
  [760]=351.73230000 [761]=350.68580000 [762]=350.70000000 \
  [763]=350.71300000 [764]=350.72500000 [765]=350.73580000 \
  [766]=350.73580000 [767]=350.73580000 [768]=350.73580000 \
  [769]=350.76810000 [770]=52.68100000 [771]=52.66220000 \
  [772]=52.64280000 [773]=51.67050000 [774]=51.65680000 \
  [775]=51.64270000 [776]=51.62820000 [777]=50.65170000 \
  [778]=50.64180000 [779]=50.63260000 [780]=50.62320000 \
  [781]=50.61350000 [782]=49.60330000 [783]=49.60330000 \
  [784]=49.60330000 [785]=48.60370000 [786]=48.59880000 \
  [787]=47.58420000 [788]=47.58420000 [789]=47.58420000 \
  [790]=46.56000000 [791]=46.56470000 [792]=46.56950000 \
  [793]=45.50720000 [794]=45.51670000 [795]=45.52660000 \
  [796]=45.53580000 [797]=45.54520000 [798]=45.55480000 \
  [799]=44.53850000)
  
  DEC=( [1]=-3.18920000 [2]=-2.20200000 [3]=-1.21470000 \
  [4]=-0.22750000 [5]=0.50760000 [6]=1.74690000 \
  [7]=2.73410000 [8]=3.39080000 [9]=4.70860000 \
  [10]=-3.18920000 [11]=-2.20200000 [12]=-1.21470000 \
  [13]=-0.22750000 [14]=0.50760000 [15]=1.74690000 \
  [16]=2.45080000 [17]=3.39080000 [18]=4.70850000 \
  [19]=-3.18920000 [20]=-2.20200000 [21]=-1.21470000 \
  [22]=-0.22750000 [23]=0.75970000 [24]=1.74690000 \
  [25]=2.45080000 [26]=3.39080000 [27]=4.70850000 \
  [28]=-3.18920000 [29]=-2.20200000 [30]=-1.21480000 \
  [31]=-0.22750000 [32]=0.75970000 [33]=1.74690000 \
  [34]=2.45080000 [35]=3.39080000 [36]=4.70850000 \
  [37]=-3.18920000 [38]=-2.20200000 [39]=-1.21470000 \
  [40]=-0.22750000 [41]=0.75970000 [42]=1.74690000 \
  [43]=3.39080000 [44]=4.70860000 [45]=-3.18920000 \
  [46]=-2.20200000 [47]=-1.21480000 [48]=-0.22750000 \
  [49]=0.75970000 [50]=1.74690000 [51]=4.70860000 \
  [52]=-3.18920000 [53]=-2.20200000 [54]=-1.21470000 \
  [55]=-0.22750000 [56]=0.75970000 [57]=1.51080000 \
  [58]=2.73410000 [59]=3.72130000 [60]=4.70860000 \
  [61]=-3.18920000 [62]=-2.20200000 [63]=-1.21470000 \
  [64]=-0.22750000 [65]=0.75970000 [66]=1.74690000 \
  [67]=2.73410000 [68]=3.72130000 [69]=4.70860000 \
  [70]=-3.18920000 [71]=-2.24920000 [72]=-1.30920000 \
  [73]=-0.36922222 [74]=0.57080000 [75]=1.51080000 \
  [76]=2.45080000 [77]=3.39080000 [78]=4.37800000 \
  [79]=-2.53750000 [80]=-1.59750000 [81]=-0.65750000 \
  [82]=0.28250000 [83]=1.22250000 [84]=2.16250000 \
  [85]=-2.53750000 [86]=-1.59750000 [87]=-0.65750000 \
  [88]=0.28250000 [89]=1.22250000 [90]=2.16250000 \
  [91]=-2.53750000 [92]=-1.59750000 [93]=-0.65750000 \
  [94]=0.28250000 [95]=1.22250000 [96]=2.16250000 \
  [97]=-2.53750000 [98]=-1.59750000 [99]=-0.65750000 \
  [100]=0.28250000 [101]=1.22250000 [102]=2.16250000 \
  [103]=-2.53750000 [104]=-1.59750000 [105]=-0.65750000 \
  [106]=0.28250000 [107]=1.22250000 [108]=2.16250000 \
  [109]=-2.53750000 [110]=-1.59750000 [111]=-0.65750000 \
  [112]=0.28250000 [113]=1.22250000 [114]=2.16250000 \
  [115]=-18.07620000 [116]=-17.08900000 [117]=-16.14890000 \
  [118]=-15.20890000 [119]=-14.26890000 [120]=-13.28170000 \
  [121]=-12.29450000 [122]=-11.44890000 [123]=-10.32000000 \
  [124]=-18.07620000 [125]=-17.08890000 [126]=-16.14890000 \
  [127]=-15.20890000 [128]=-14.26900000 [129]=-13.28170000 \
  [130]=-12.29450000 [131]=-11.30730000 [132]=-10.32010000 \
  [133]=-18.07620000 [134]=-17.08890000 [135]=-16.14890000 \
  [136]=-15.20890000 [137]=-14.26890000 [138]=-13.28170000 \
  [139]=-12.29450000 [140]=-11.30730000 [141]=-10.32010000 \
  [142]=-18.07620000 [143]=-17.08890000 [144]=-16.14890000 \
  [145]=-15.20900000 [146]=-14.26890000 [147]=-13.28170000 \
  [148]=-12.29450000 [149]=-11.30730000 [150]=-10.32010000 \
  [151]=-18.07620000 [152]=-17.08890000 [153]=-16.14890000 \
  [154]=-15.20890000 [155]=-14.26890000 [156]=-13.28170000 \
  [157]=-12.29450000 [158]=-11.30730000 [159]=-10.32010000 \
  [160]=-18.07620000 [161]=-17.08890000 [162]=-16.14890000 \
  [163]=-15.20890000 [164]=-14.26890000 [165]=-13.28170000 \
  [166]=-12.29450000 [167]=-11.30730000 [168]=-10.32010000 \
  [169]=-18.07620000 [170]=-17.08890000 [171]=-16.14890000 \
  [172]=-15.20900000 [173]=-14.26900000 [174]=-13.28170000 \
  [175]=-12.29450000 [176]=-11.30730000 [177]=-10.32010000 \
  [178]=-18.07620000 [179]=-17.08890000 [180]=-16.14890000 \
  [181]=-15.20890000 [182]=-14.26890000 [183]=-13.28170000 \
  [184]=-12.29450000 [185]=-11.30730000 [186]=-10.32000000 \
  [187]=-18.07620000 [188]=-17.08890000 [189]=-16.14890000 \
  [190]=-15.20900000 [191]=-14.26890000 [192]=-13.28170000 \
  [193]=-12.29450000 [194]=-11.30730000 [195]=-10.32010000 \
  [196]=-11.16250000 [197]=-10.22250000 [198]=-9.28250000 \
  [199]=-8.34250000 [200]=-7.40250000 [201]=-6.46250000 \
  [202]=-11.16250000 [203]=-10.22250000 [204]=-9.28250000 \
  [205]=-8.34250000 [206]=-7.40250000 [207]=-6.46250000 \
  [208]=-11.16250000 [209]=-10.22250000 [210]=-9.28250000 \
  [211]=-8.34250000 [212]=-7.40250000 [213]=-6.46250000 \
  [214]=-11.16250000 [215]=-10.22250000 [216]=-9.28250000 \
  [217]=-8.34250000 [218]=-7.40250000 [219]=-6.46250000 \
  [220]=-11.16250000 [221]=-10.22250000 [222]=-9.28250000 \
  [223]=-8.34250000 [224]=-7.40250000 [225]=-6.46240000 \
  [226]=-11.16250000 [227]=-10.22250000 [228]=-9.28250000 \
  [229]=-8.34250000 [230]=-7.40250000 [231]=-6.46250000 \
  [232]=55.39750000 [233]=56.33750000 [234]=57.27750000 \
  [235]=58.26470000 [236]=59.15750000 [237]=60.22250000 \
  [238]=55.39750000 [239]=56.33750000 [240]=57.27750000 \
  [241]=58.26470000 [242]=59.25190000 [243]=60.22250000 \
  [244]=55.39750000 [245]=56.33750000 [246]=57.27750000 \
  [247]=58.26470000 [248]=59.25190000 [249]=60.22250000 \
  [250]=55.39750000 [251]=56.33740000 [252]=57.27750000 \
  [253]=58.26470000 [254]=59.25190000 [255]=60.22250000 \
  [256]=55.39750000 [257]=56.33750000 [258]=57.27750000 \
  [259]=58.26470000 [260]=59.15750000 [261]=60.22250000 \
  [262]=55.39750000 [263]=56.33750000 [264]=57.27750000 \
  [265]=58.26470000 [266]=59.15750000 [267]=60.22250000 \
  [268]=-9.63500000 [269]=-8.69500000 [270]=-7.75500000 \
  [271]=-6.81500000 [272]=-5.87500000 [273]=-4.93500000 \
  [274]=-3.99500000 [275]=-3.05500000 [276]=-2.11500000 \
  [277]=-9.63500000 [278]=-8.69500000 [279]=-7.75500000 \
  [280]=-6.81500000 [281]=-5.87500000 [282]=-4.93500000 \
  [283]=-3.99500000 [284]=-3.05500000 [285]=-2.11500000 \
  [286]=-9.63500000 [287]=-8.69500000 [288]=-7.75500000 \
  [289]=-6.81500000 [290]=-5.87500000 [291]=-4.93500000 \
  [292]=-3.99500000 [293]=-3.05500000 [294]=-2.11500000 \
  [295]=-9.63500000 [296]=-8.69500000 [297]=-7.75500000 \
  [298]=-6.81500000 [299]=-5.87500000 [300]=-4.93500000 \
  [301]=-3.99500000 [302]=-3.05500000 [303]=-2.11500000 \
  [304]=-9.63500000 [305]=-8.69500000 [306]=-7.75500000 \
  [307]=-6.81500000 [308]=-5.87500000 [309]=-4.93500000 \
  [310]=-3.99500000 [311]=-3.05500000 [312]=-2.11500000 \
  [313]=-9.63500000 [314]=-8.69500000 [315]=-7.75500000 \
  [316]=-6.81500000 [317]=-5.87500000 [318]=-4.93500000 \
  [319]=-3.99500000 [320]=-3.05500000 [321]=-2.11500000 \
  [322]=-9.63500000 [323]=-8.69500000 [324]=-7.75500000 \
  [325]=-6.81500000 [326]=-5.87500000 [327]=-4.93490000 \
  [328]=-3.99500000 [329]=-3.05500000 [330]=-2.11500000 \
  [331]=-9.63500000 [332]=-8.69500000 [333]=-7.75500000 \
  [334]=-6.81500000 [335]=-5.87500000 [336]=-4.93500000 \
  [337]=-3.99500000 [338]=-3.05500000 [339]=-2.11500000 \
  [340]=-9.63500000 [341]=-8.69500000 [342]=-7.75500000 \
  [343]=-6.81500000 [344]=-5.87500000 [345]=-4.93500000 \
  [346]=-3.99500000 [347]=-3.05490000 [348]=-2.11500000 \
  [349]=-2.13720000 [350]=-1.19720000 [351]=-2.13720000 \
  [352]=-4.95720000 [353]=-2.13720000 [354]=-1.19720000 \
  [355]=-4.95720000 [356]=-2.13720000 [357]=-1.19720000 \
  [358]=-4.95720000 [359]=-1.19720000 [360]=2.56280000 \
  [361]=-4.95720000 [362]=-1.19720000 [363]=2.56280000 \
  [364]=-4.95720000 [365]=-1.19720000 [366]=2.56280000 \
  [367]=-4.95720000 [368]=-1.19720000 [369]=2.56280000 \
  [370]=-4.95720000 [371]=-4.01720000 [372]=-1.19720000 \
  [373]=1.62280000 [374]=2.56280000 [375]=4.17300000 \
  [376]=6.14830000 [377]=7.08830000 [378]=8.07550000 \
  [379]=9.06280000 [380]=10.05000000 [381]=11.03720000 \
  [382]=11.78830000 [383]=12.72830000 [384]=13.66830000 \
  [385]=4.17300000 [386]=6.14830000 [387]=7.08830000 \
  [388]=8.07550000 [389]=9.06270000 [390]=9.90830000 \
  [391]=11.03720000 [392]=11.78830000 [393]=12.72830000 \
  [394]=13.66830000 [395]=4.17300000 [396]=6.14830000 \
  [397]=7.08830000 [398]=8.07550000 [399]=9.06270000 \
  [400]=9.90830000 [401]=11.03720000 [402]=11.78830000 \
  [403]=12.72830000 [404]=13.66830000 [405]=4.17300000 \
  [406]=6.14830000 [407]=7.08830000 [408]=8.07550000 \
  [409]=9.06270000 [410]=9.95550000 [411]=11.03720000 \
  [412]=11.78830000 [413]=12.72830000 [414]=13.66830000 \
  [415]=4.17300000 [416]=6.14830000 [417]=7.08830000 \
  [418]=8.07550000 [419]=9.06270000 [420]=9.90830000 \
  [421]=11.03720000 [422]=11.78830000 [423]=12.72830000 \
  [424]=13.66830000 [425]=4.17300000 [426]=6.14830000 \
  [427]=7.08830000 [428]=8.07550000 [429]=9.06270000 \
  [430]=10.05000000 [431]=11.03720000 [432]=11.78830000 \
  [433]=12.72830000 [434]=13.66830000 [435]=5.16050000 \
  [436]=4.17300000 [437]=6.14830000 [438]=7.08830000 \
  [439]=8.07560000 [440]=9.06280000 [441]=10.05000000 \
  [442]=10.84830000 [443]=11.78830000 [444]=12.72830000 \
  [445]=13.66830000 [446]=4.17300000 [447]=6.14830000 \
  [448]=7.08830000 [449]=8.07550000 [450]=9.06280000 \
  [451]=10.05000000 [452]=10.84830000 [453]=11.78830000 \
  [454]=12.72830000 [455]=13.66830000 [456]=4.17300000 \
  [457]=6.14830000 [458]=7.08830000 [459]=8.07550000 \
  [460]=9.06270000 [461]=10.05000000 [462]=10.84830000 \
  [463]=11.78830000 [464]=12.72830000 [465]=13.66830000 \
  [466]=52.65000000 [467]=53.59000000 [468]=54.53000000 \
  [469]=55.47000000 [470]=56.41000000 [471]=57.35000000 \
  [472]=52.65000000 [473]=53.59000000 [474]=54.53000000 \
  [475]=55.47000000 [476]=56.41000000 [477]=57.35000000 \
  [478]=52.65000000 [479]=53.59000000 [480]=54.53000000 \
  [481]=55.47000000 [482]=56.41000000 [483]=57.35000000 \
  [484]=52.65000000 [485]=53.59000000 [486]=54.53000000 \
  [487]=55.36030000 [488]=55.17750000 [489]=56.41000000 \
  [490]=57.35000000 [491]=52.65000000 [492]=53.59000000 \
  [493]=54.53000000 [494]=55.47000000 [495]=56.41000000 \
  [496]=57.35000000 [497]=52.65000000 [498]=53.59000000 \
  [499]=54.53000000 [500]=55.47000000 [501]=56.41000000 \
  [502]=57.35000000 [503]=37.13610000 [504]=38.07490000 \
  [505]=39.06260000 [506]=40.05050000 [507]=41.03710000 \
  [508]=42.02410000 [509]=37.13610000 [510]=38.07530000 \
  [511]=39.06250000 [512]=40.04970000 [513]=41.03720000 \
  [514]=42.02410000 [515]=37.13610000 [516]=38.07520000 \
  [517]=39.06270000 [518]=40.04880000 [519]=41.03660000 \
  [520]=42.02380000 [521]=37.13610000 [522]=38.07490000 \
  [523]=40.05000000 [524]=41.03700000 [525]=42.02410000 \
  [526]=37.13610000 [527]=38.07530000 [528]=39.06270000 \
  [529]=40.05050000 [530]=41.03780000 [531]=42.02500000 \
  [532]=37.13610000 [533]=38.07610000 [534]=39.06330000 \
  [535]=40.05050000 [536]=41.03780000 [537]=42.02500000 \
  [538]=-3.52740000 [539]=-2.54020000 [540]=-1.55300000 \
  [541]=-0.56575000 [542]=-0.30820000 [543]=0.42140000 \
  [544]=1.36140000 [545]=2.30140000 [546]=3.24140000 \
  [547]=4.22870000 [548]=-4.46740000 [549]=-3.52740000 \
  [550]=-2.54020000 [551]=-1.55300000 [552]=-1.31230000 \
  [553]=-0.56570000 [554]=0.42140000 [555]=1.36140000 \
  [556]=2.30140000 [557]=3.24140000 [558]=3.72447200 \
  [559]=-4.46740000 [560]=-3.52740000 [561]=-2.54020000 \
  [562]=-1.55300000 [563]=-0.56570000 [564]=0.42140000 \
  [565]=1.36140000 [566]=2.30140000 [567]=3.24040000 \
  [568]=3.23860000 [569]=3.72447200 [570]=-4.46740000 \
  [571]=-3.52740000 [572]=-2.54020000 [573]=-1.55300000 \
  [574]=-0.56570000 [575]=0.42140000 [576]=1.36140000 \
  [577]=2.28200000 [578]=3.24140000 [579]=4.22870000 \
  [580]=-4.46740000 [581]=-3.52740000 [582]=-2.54020000 \
  [583]=-1.55300000 [584]=-0.56580000 [585]=0.42140000 \
  [586]=1.36150000 [587]=2.30150000 [588]=3.24140000 \
  [589]=4.22870000 [590]=-4.46741667 [591]=-3.52740000 \
  [592]=-2.54020000 [593]=-1.55300000 [594]=-0.56570000 \
  [595]=0.42150000 [596]=1.36140000 [597]=2.30140000 \
  [598]=3.24150000 [599]=4.22870000 [600]=-4.46741667 \
  [601]=-3.52740000 [602]=-2.54020000 [603]=-1.55300000 \
  [604]=-0.56570000 [605]=0.42140000 [606]=1.36150000 \
  [607]=2.30150000 [608]=3.24140000 [609]=4.22870000 \
  [610]=-4.46741667 [611]=-3.52740000 [612]=-2.54020000 \
  [613]=-1.55300000 [614]=-0.56570000 [615]=0.42150000 \
  [616]=1.36140000 [617]=2.30150000 [618]=3.24140000 \
  [619]=4.22870000 [620]=-4.46741667 [621]=-3.52740000 \
  [622]=-2.54020000 [623]=-1.55300000 [624]=-0.56570000 \
  [625]=0.42140000 [626]=1.36140000 [627]=2.30150000 \
  [628]=3.24140000 [629]=4.22870000 [630]=-4.46741667 \
  [631]=-3.52740000 [632]=-2.54020000 [633]=-1.56700000 \
  [634]=-1.57830000 [635]=-0.56570000 [636]=0.42140000 \
  [637]=1.36150000 [638]=2.30150000 [639]=1.79120000 \
  [640]=3.24140000 [641]=4.22870000 [642]=-4.46740000 \
  [643]=-3.72100000 [644]=-2.73377778 [645]=-1.74650000 \
  [646]=-0.75930000 [647]=0.22790000 [648]=1.21510000 \
  [649]=-3.72100000 [650]=-2.73380000 [651]=-1.74650000 \
  [652]=-0.75930000 [653]=0.22790000 [654]=1.21510000 \
  [655]=-3.72100000 [656]=-2.73380000 [657]=-1.74650000 \
  [658]=-0.75930000 [659]=0.22790000 [660]=1.21510000 \
  [661]=-3.72100000 [662]=-2.73380000 [663]=-1.74650000 \
  [664]=-0.75930000 [665]=0.22790000 [666]=1.21510000 \
  [667]=-3.72110000 [668]=-2.73380000 [669]=-1.74660000 \
  [670]=-0.75930000 [671]=0.22790000 [672]=1.21510000 \
  [673]=-3.72100000 [674]=-2.73380000 [675]=-1.74650000 \
  [676]=-0.75930000 [677]=0.22790000 [678]=1.14420000 \
  [679]=-3.72100000 [680]=-2.73380000 [681]=-1.74660000 \
  [682]=-0.75930000 [683]=0.22790000 [684]=1.21510000 \
  [685]=-3.72100000 [686]=-2.73380000 [687]=-1.74650000 \
  [688]=-0.75930000 [689]=0.22780000 [690]=1.21510000 \
  [691]=-12.88500000 [692]=-11.94500000 [693]=-11.00500000 \
  [694]=-10.06500000 [695]=-9.12500000 [696]=-8.18500000 \
  [697]=-7.24500000 [698]=-6.30500000 [699]=-5.36500000 \
  [700]=-12.88500000 [701]=-11.94500000 [702]=-11.00500000 \
  [703]=-10.06500000 [704]=-9.12500000 [705]=-8.18500000 \
  [706]=-7.24500000 [707]=-6.30500000 [708]=-5.36500000 \
  [709]=-12.88500000 [710]=-11.94500000 [711]=-11.00500000 \
  [712]=-10.06500000 [713]=-9.12500000 [714]=-8.18500000 \
  [715]=-7.24500000 [716]=-6.30500000 [717]=-5.36500000 \
  [718]=-12.88500000 [719]=-11.94500000 [720]=-11.00500000 \
  [721]=-10.06500000 [722]=-9.12500000 [723]=-7.24500000 \
  [724]=-6.30500000 [725]=-12.88500000 [726]=-11.94500000 \
  [727]=-11.00500000 [728]=-10.06500000 [729]=-9.12500000 \
  [730]=-8.18500000 [731]=-7.24500000 [732]=-6.30500000 \
  [733]=-5.36500000 [734]=-12.88500000 [735]=-11.94500000 \
  [736]=-11.00500000 [737]=-10.06500000 [738]=-9.12500000 \
  [739]=-8.18500000 [740]=-7.24500000 [741]=-6.30500000 \
  [742]=-5.36500000 [743]=-12.88500000 [744]=-11.94500000 \
  [745]=-11.00500000 [746]=-10.06500000 [747]=-9.12500000 \
  [748]=-8.18500000 [749]=-7.24500000 [750]=-6.30500000 \
  [751]=-5.36500000 [752]=-12.88500000 [753]=-11.94500000 \
  [754]=-11.00490000 [755]=-10.06500000 [756]=-9.12500000 \
  [757]=-8.18500000 [758]=-7.24500000 [759]=-6.30500000 \
  [760]=-5.36500000 [761]=-12.88500000 [762]=-11.94500000 \
  [763]=-11.00500000 [764]=-10.06500000 [765]=-9.12500000 \
  [766]=-8.18500000 [767]=-7.24500000 [768]=-6.30500000 \
  [769]=-5.36500000 [770]=-20.85400000 [771]=-19.91230000 \
  [772]=-18.97060000 [773]=-21.79560000 [774]=-20.85390000 \
  [775]=-19.91230000 [776]=-18.97060000 [777]=-22.73730000 \
  [778]=-21.79560000 [779]=-20.85390000 [780]=-19.91230000 \
  [781]=-18.97060000 [782]=-23.67890000 [783]=-19.91230000 \
  [784]=-18.97060000 [785]=-19.91230000 [786]=-18.97060000 \
  [787]=-20.85390000 [788]=-19.91230000 [789]=-18.97060000 \
  [790]=-20.85390000 [791]=-19.91230000 [792]=-18.97060000 \
  [793]=-23.67890000 [794]=-22.73730000 [795]=-21.79560000 \
  [796]=-20.85400000 [797]=-19.91230000 [798]=-18.97060000 \
  [799]=-18.97060000)
fi

for CHIP in ${!#}
do
  ${P_FIND} /$1/$2 -name \*_${CHIP}$3.fits > ${TEMPDIR}/images.dat_$$

  test -f ${TEMPDIR}/images_tmp.dat_$$ && rm ${TEMPDIR}/images_tmp.dat_$$  
  
  while read IMAGE
  do
    NAME=`basename ${IMAGE}`
    RA=`${P_DFITS}  ${IMAGE} | ${P_FITSORT} ${RAKEY} |\
        ${P_GAWK} '($1!="FILE") {print $2}'`
    DEC=`${P_DFITS}  ${IMAGE} | ${P_FITSORT} ${DECKEY} |\
         ${P_GAWK} '($1!="FILE") {print $2}'`

    echo ${NAME} ${RA} ${DEC} >> ${TEMPDIR}/images_tmp.dat_$$
  done < ${TEMPDIR}/images.dat_$$
  
  while read NAME RA DEC
  do
    i=1
    MIN=10000
    INDEX=1
    while [ ${i} -le ${NFIELDS} ]
    do
      # to determine the set an image belongs to we
      # consider the minimum distance to the 
      # positions of the 'listed sets' defined above.
      #
      TEMPRA=${RA[${i}]}
      TEMPDEC=${DEC[${i}]}
      DIST=`awk 'BEGIN {print int(sqrt(('${RA}'-'${TEMPRA}')*('${RA}'-'${TEMPRA}')+('${DEC}'-('${TEMPDEC}'))*('${DEC}'-('${TEMPDEC}')))*10.)}'`
      if [ ${DIST} -le ${MIN} ]; then
	  MIN=${DIST}  
	  INDEX=${i}
      fi 
      i=$(( $i + 1 ))
    done < ${TEMPDIR}/images_tmp.dat_$$

    # only move if the distance is within the
    # listed sets (see above).
    if [ ${MIN} -le ${MAXDIST} ]; then
      BASE=`basename ${NAME} .fits`

      if [ -L /$5/${FIELD[${INDEX}]}/$4/${NAME} ]; then
        rm /$5/${FIELD[${INDEX}]}/$4/${NAME}
      fi
      ln -s /$1/$2/${NAME} /$5/${FIELD[${INDEX}]}/$4/${NAME} 

      if [ -L /$5/${FIELD[${INDEX}]}/$4/${BASE}.sub.fits ]; then
        rm /$5/${FIELD[${INDEX}]}/$4/${BASE}.sub.fits   
      fi
      ln -s /$1/$2/${BASE}.sub.fits \
            /$5/${FIELD[${INDEX}]}/$4/${BASE}.sub.fits  

      if [ -L /$5/${FIELD[${INDEX}]}/WEIGHTS_$4/${BASE}.weight.fits ]; then
        rm /$5/${FIELD[${INDEX}]}/WEIGHTS_$4/${BASE}.weight.fits  
      fi
      ln -s /$1/WEIGHTS/${BASE}.weight.fits \
            /$5/${FIELD[${INDEX}]}/WEIGHTS_$4/${BASE}.weight.fits  	 

      # just copy catalogs from the RUN singleastrom step; there is no
      # need to repeat all those SExtractor runs!
      if [ ! -d /$5/${FIELD[${INDEX}]}/$4/cat ]; then
        mkdir -p /$5/${FIELD[${INDEX}]}/$4/cat/PSFcheck
      fi
      if [ -f /$1/$2/cat/${BASE}.cat ]; then
        cp /$1/$2/cat/${BASE}.cat /$5/${FIELD[${INDEX}]}/$4/cat
        # The following sed command works for CFHT images correctly
        # because the only underscore in imagenames is that before
        # the chip number:
        IMAGENAME=`echo ${BASE} | sed -e 's/_.*$//'`
        cp /$1/$2/cat/PSFcheck/${IMAGENAME}*ps \
           /$5/${FIELD[${INDEX}]}/$4/cat/PSFcheck 
      else
        echo "no catalogue for image ${BASE}.fits in run directories found!!"
      fi
    fi
  done < ${TEMPDIR}/images_tmp.dat_$$
done

# clean up:
test -f images.dat_$$     && rm images.dat_$$
test -f images_tmp.dat_$$ && rm images_tmp.dat_$$

exit 0;
