#!/bin/bash -xv

# wrapper script to process multi-colour observations of
# an individual target. The main difference to the philosophy
# behind 'process_field.sh' is the missing 'patch' context.
# The script considered here deals with a survey consisting
# of isolated pointings.

# IMPORTANT:
# See below for some hardcoded paths that you probably need to adapt!!

#$1: survey
#$2: survey field
#$3: filters (give several filters in quotes)

# TODO:
# =====
#
# Probably this script can easily be merged with similar ones from
# othe rinstruments - TBD!!

# HISTORY COMMENTS
# ================
#
# 18.09.2013:
# script started from the 'proc_single_KIDS.sh' as template.
#
# 18.11.2013:
# The function mean_sigma (selection of images according to stellar
# ellipticity) now ensures a minmum error on the elliticity dispersion.
# This ensures image processing if, for instance, only a single frame
# is present. Before, no images were processed in this case.

. ./bash_functions.include

export INSTRUMENT=MEGAPRIME

SURVEY=$1
FIELD=$2
ALLFILT="$3"

# main processing directory
export MD=/RAID/terben/
# master directory with raw images
export MAD=/RAID/terben/CODEX_images/
# temporary directory for images (only links)
export IMATMP=/RAID/terben/CODEX_tmp/

WWWDIR=/RAID/terben/

RELEASEDIR=/RAID/terben/${SURVEY}COLLAB
COADDVER=V2.7A

# setup THELI logging:
: ${THELI_LOGGING:="Y"}
: ${THELI_LOGLEVEL="1"}
export THELI_LOGGING
export THELI_LOGLEVEL

for FILT in ${ALLFILT}
do
  export THELI_LOGDIR=`pwd`/logs_RUN_${FIELD}_${FILT}

  # delete files from previous processings:
  test -d ${MD}/${SURVEY}/${FILT} && \
    rm -rf ${MD}/${SURVEY}/${FILT}

  mkdir -p ${MD}/${SURVEY}/${FILT}

  test -d ${MD}/${SURVEY}/${FIELD}/${FILT} && \
    rm -rf ${MD}/${SURVEY}/${FIELD}/${FILT}/*
  test -d ${MD}/${SURVEY}/${FIELD}/WEIGHTS_${FILT} && \
    rm -rf ${MD}/${SURVEY}/${FIELD}/WEIGHTS_${FILT}/*

  #
  # link necessary images; the idea in the following is that there
  # is one directory (MAD) containing all the (Elixir preprocessed)
  # images of the survey (in uncompressed form). The images for
  # the specific field under consideration are first linked into
  # a temporary directory (IMATMP) and from there sorted into
  # the survey structure with 'sort_MEGAPRIME_survey.sh'. After that
  # the images are run processed with 'CFHTLS_runprocess.sh'

  # The file 'summary_images_${SURVEY}_${FILT}.txt' contains
  # the columns 'survey_field image_name'
  if [ ! -s summary_images_${SURVEY}_${FILT}.txt ]; then
    echo "File  summary_images_${SURVEY}_${FILT}.txt not present! Exiting!"
    exit 1;
  fi

  grep ${FIELD} summary_images_${SURVEY}_${FILT}.txt | \
      awk '{print $2}' > toprocess.txt_$$

  # clean up link directory from previous processings:
  test -d ${IMATMP} && rm ${IMATMP}/*

  while read IMA
  do
    if [ -e ${MAD}/${IMA} ]; then
      ln -s ${MAD}/${IMA} ${IMATMP}
    else
      echo "Warning: ${MAD}/${IMA} not present!"  
    fi
  done < toprocess.txt_$$

  ./sort_MEGAPRIME_survey.sh ${IMATMP} ${MD}/${SURVEY} ${SURVEY}
  
  # process the RUNS:
  ./CFHTLS_runprocess.sh ${MD} ${FILT} ${SURVEY} ${SURVEY} RUN \
       CLEAN NOTRACK NOZIP
done

# do the necessary SET processing.

# The mode ASTROMPHOTOM needs to be run simultaneously for all
# filters:
export THELI_LOGDIR=`pwd`/logs_${FIELD}_ASTROMPHOTOM

./doall_set_CFHTLS_single.sh -am SCAMP\
       -a 2MASS -b ${MD} -s ${SURVEY} -fi ${FIELD} \
       -mf "${ALLFILT}" -m "ASTROMPHOTOM"

# now do co-addition again one filter after the other:
for FILT in ${ALLFILT}
do
  export THELI_LOGDIR=`pwd`/logs_${FIELD}_${FILT}

  ./doall_set_CFHTLS_single.sh -am SCAMP\
       -a 2MASS -b ${MD} -s ${SURVEY} -fi ${FIELD} -f ${FILT} \
       -m "SETCHECKPLOT"

  # select frames that need to enter the co-addition process:

  # filter according to relative zeropoint:
  RELZPLIMIT=-0.1
  RELZP=-1.0
  ldactoasc -i ${MD}/${SURVEY}/${FIELD}/${FILT}/cat/chips.cat5 \
            -b -t STATS -k RZP EXPTIME |\
            awk '($2 > 100) {print $1}' > rzp.asc_$$
  modified_median rzp.asc_$$ "${RELZPLIMIT}" "-1.0"
  RELZP=${G_MODMEDIAN}

  # filter according for ellipticity distribution:
  ELLIPSIGMALIMIT=3.0
  ldactoasc -i ${MD}/${SURVEY}/${FIELD}/${FILT}/cat/chips.cat6 -b \
            -t STATS -k e1 > e1.asc_$$

  mean_sigma e1.asc_$$ -1.0 1.0 ${ELLIPSIGMALIMIT} 0.01
  E1MIN=`echo ${G_MEAN_SIGMA} | awk '{printf("%.3f", $1)}'` 
  E1MAX=`echo ${G_MEAN_SIGMA} | awk '{printf("%.3f", $2)}'` 
  ldactoasc -i ${MD}/${SURVEY}/${FIELD}/${FILT}/cat/chips.cat6 -b \
            -t STATS -k e2 > e2.asc_$$

  mean_sigma e2.asc_$$ -1.0 1.0 ${ELLIPSIGMALIMIT} 0.01
  E2MIN=`echo ${G_MEAN_SIGMA} | awk '{printf("%.3f", $1)}'` 
  E2MAX=`echo ${G_MEAN_SIGMA} | awk '{printf("%.3f", $2)}'` 

  # filter according to seeing:
  ldactoasc -i ${MD}/${SURVEY}/${FIELD}/${FILT}/cat/chips.cat6 -b \
            -t STATS -k SEEING > seeing.asc_$$ 

  modified_median seeing.asc_$$ 0.25 2.0
  SEEINGLIMIT=${G_MODMEDIAN}

  # filter according to sky-background:
  BACKMAX=100
  BACKSDEVMAX=10
  if [ "${FILT}" = "r_SDSS" ]; then
    BACKMAX=4
    BACKSDEVMAX=0.5
  fi

  echo ${FIELD}, ${RELZP}, ${E1MIN}, ${E1MAX}, ${E2MIN}, ${E2MAX}, ${SEEINGLIMIT}, ${BACKMAX}, ${BACKSDEVMAX}

  rm *_$$

  ./doall_set_CFHTLS_single.sh -am SCAMP\
     -a 2MASS -b ${MD} -s ${SURVEY} -fi ${FIELD} -f ${FILT} \
     -cc "((((((((SEEING<${SEEINGLIMIT})AND(EXPTIME>100))AND(RZP>${RELZP}))AND(e1>${E1MIN}))AND(e1<${E1MAX}))AND(e2>${E2MIN}))AND(e2<${E2MAX}))AND(BACKGR<${BACKMAX}))AND(BACKGR_SDEV<${BACKSDEVMAX});" \
     -ci ${COADDVER} -cm WEIGHTED -www ${WWWDIR} \
     -m "COADD COADDHEADERUPDATE CUTCOADD POSTCOADD SETPAGES"

  # copy products to release directory
  ./copy_shearcollab.sh ${FIELD} ${FILT} ${COADDVER} "i y" \
     ${MD}/${SURVEY} \
     ${RELEASEDIR} ZIPWEIGHTS COPY

  ./doall_set_CFHTLS_single.sh \
     -a 2MASS -b ${MD} -s ${SURVEY} -fi ${FIELD} -f ${FILT} \
     -ci ${COADDVER} -cm WEIGHTED -www ${WWWDIR} \
     -m "FINALCLEAN"
done


