#!/bin/bash

# wrapper script to do all steps of field processing
# for the shear collaboration at UBC and at TERAPIX.
# many things are hardwired for use at these two locations. 

# NOTES:
#
# 1. !! CHECK especially hardwired directories !!
#    These are /RAID/terben for UBC and /data/mix11/raid/erben
#    for TERAPIX.
# 2. The script directly needs the file process_fields_zps.txt which contains
#    mangnitude zeropoints for the various surves and data sets.

# HISTORY COMMENTS:
# =================
#
# 16.04.2009:
# Some modfications to include fixed field magnitude zeropoints
# in case fields have been astrometrically and photometrically 
# calibrated on a global basis.
#
# 27.04.2009:
# - addition of zeropoints for all Wide fields
# - copying astrometric headers - bug fix:
#   if headers are not present we need to check whether they have
#   the 'BADCCD' flag set before quitting the script.
#
# 28.12.2009:
# I extended the script to include Deep photo-z processing at Terapix
#
# 05.01.2010:
# - I updated the script for NGVS data processing.
# - I adapted the call to CFHTLS_collab_setprocess.sh to an extended
#   set of script command line arguments.
#
# 25.01.2010:
# - I updated the script for processing Deep/COSMOS SLIP data.
# - Update for NGVS data processing in BONN (get images from local disk
#   instead of querying CADC)
#
# 01.02.2010:
# - The main directory and the release directory are now command line
#   arguments.
# - I adapted the call to CFHTLS_collab_setprocess.sh to a new command 
#   line argument.
#
# 15.02.2010:
# - Bug fix due to the new command line arguments (changes from 01.02.2010)
# - adaption of call to CFHTLS_datarequest.sh to new script command line
#   syntax
#
# 12.09.2010:
# coaddition result are removed from the THELI directories after they
# have been copied to the release location. They (unnecessarily) 
# took away too much disk space.
#
# 21.09.2010:
# I adapted the call to 'copy_shearcollab.sh' to the new syntax of the
# script; there is now the possibility to copy or to move single-frame
# data from the THELI to the release data structure.
#
# 05.10.2010:
# SDSS-R6 -> SDSS-R7
#
# 06.10.2010:
# Bug fix in querying the astrometric standardstar catalogue for D3, W3
# and Virgo
#
# 27.04.2011:
# Addition of the Stripe82 survey
#
# 23.09.2011:
# Addition of (parts of) the RCS2 survey
#
# 12.10.2011:
# correction of a bug in the treatment of gawk regular expressions.
#
# 21.12.2011:
# addition of the RCS2 CDE2143 patch with SDSS-R8 as astrometric catalogue
#
# 23.12.2011:
# Another bug fix concerning regexps with gawk.
#
# 05.04.2012:
# addition of the SPARCS survey
#
# 11.02.2013:
# The script copy_shearcollab.sh has a new command line syntax. I adapted
# the call to this script.

#$1: main directory
#$2: field to process
#$3: for the Wide-fields: filters to process
#    for the Deep fields: a list of images to process plus
#    the filter! (this argument has to be given within quotes!)
#$4: coadd identifier to use for co-added images
#$5: location (BONN, UBC or TERAPIX)
#$6: collaboration data kind (if this is PHOTOZ, no data from individual 
#    frames are copied to release directories)
#$7: release directory; the final data will be copied to ${7}
#$8: processing mode: FULL or SET
#$9: directory with scamp headers (OPTIONAL; by default
#    scamp is run within this script on surrounding fields)
#    The header files are in subdirectories 
#    $6/u/headers_scamp..., $6/g/headers_scamp_... etc.

# photometric zeropoints:
source process_fields_zps.txt

# function definitions:
# try to get the number of processors on the current machine.
# The function currently implements a possibility for Linux machines:
function getnproc() {
  NPROC=1

  if [ -f /proc/cpuinfo ]; then
    NPROC=`grep "process" /proc/cpuinfo | wc -l`
  fi

  return ${NPROC}
}

# directories to process data; please adapt!
MD=$1
RETRIEVEDIR=${MD}/WIDE
MASKDIR=${MD}/WIDE_masks
SURVEY=CFHTLSWIDE
IMAGECAT=Deep_Wide_VeryWide_Phot.cat
FIELD=$2
FILTERS="$3"
COADDIDENT=$4
LOCATION=$5
COLLABDATA=$6
RELEASEDIR=$7
PROCESSMODE=$8
HEADERDIR=""
if [ $# -eq 9 ]; then
  HEADERDIR=$9
fi

LENSINGBANDS="i y r"
if [ "${COLLABDATA}" = "PHOTOZ" ]; then
  # Just set a dummy to avoid potential issues 
  # with empty arguments
  LENSINGBANDS="AA"
fi

# do we create a DEEP, or COSMOS stack:
DEEPCOSMOS=0
if [ "${FIELD}" = "D1" ] || [ "${FIELD}" = "D2" ] ||\
   [ "${FIELD}" = "D3" ] || [ "${FIELD}" = "D4" ] ||\
   [ "${FIELD}" = "COSMOS_C" ]; then
  DEEPCOSMOS=1
fi

FILELIST=""
# directories to process DEEP/COSMOS/SLIP data
if [ ${DEEPCOSMOS} -eq 1 ]; then
  if [ "${LOCATION}" = "UBC" ]; then
    RETRIEVEDIR=${MD}/DEEP
  else
    RETRIEVEDIR=${MD}/data
  fi 
  SURVEY=CFHTLSDEEP
  MASKDIR=""
  FILELIST="`echo $2 | awk '{print $1}'`"
  FILTERS="`echo $2 | awk '{print $2}'`"
fi

# directories for NGVS:
if [[ "${FIELD}" =~ "NGVS" ]]; then
  SURVEY=NGVS
  RETRIEVEDIR=${MD}/NGVS_requests
  IMAGECAT=NGVS_05_01_10.cat
  MASKDIR="" # needs to be changed at some point!
fi

# directories for STRIPE82:
if [[ "${FIELD}" =~ "S82" ]]; then
  SURVEY=STRIPE82
  RETRIEVEDIR=${MD}/STRIPE82_requests
  IMAGECAT=STRIPE82_qual.cat
  MASKDIR="" # needs to be changed at some point!
fi

# directories for RCS2:
if [[ "${FIELD}" =~ "CSP" ]] || [[ "${FIELD}" =~ "CDE" ]]; then
  SURVEY=RCS
  RETRIEVEDIR=${MD}/RCS_requests
  IMAGECAT=RCS_qual.cat
  MASKDIR="" # needs to be changed at some point!
fi

# directories for SPARCS:
if [[ "${FIELD}" =~ "Lockmann" ]] || [[ "${FIELD}" =~ "XMM" ]]; then
  SURVEY=SPARCS
  RETRIEVEDIR=${MD}/SPARCS_requests
  IMAGECAT=""
  MASKDIR="" # needs to be changed at some point!
fi

DIR=`pwd`

REGION=`echo ${FIELD} | awk '{ if ($1 ~ /W1/ ) {region = "W1";}
                         if ($1 ~ /W2/ ) {region = "W2";}
                         if ($1 ~ /W3/ ) {region = "W3";}
                         if ($1 ~ /W4/ ) {region = "W4";}
                         if ($1 ~ /D1/ ) {region = "D1";}
                         if ($1 ~ /D2/ ) {region = "D2";}
                         if ($1 ~ /D3/ ) {region = "D3";}
                         if ($1 ~ /D4/ ) {region = "D4";}
                         if ($1 ~ /COSMOS_C/ ) {region = "COSMOS";}
                         if ($1 ~ /NGVS/ ) {region = "NGVS";}
                         if ($1 ~ /NGVS_BG_1/ ) {region = "NGVS_BG_1";}
                         if ($1 ~ /NGVS_BG_2/ ) {region = "NGVS_BG_2";}
                         if ($1 ~ /NGVS_BG_3/ ) {region = "NGVS_BG_3";}
                         if ($1 ~ /NGVS_BG_4/ ) {region = "NGVS_BG_4";}
                         if ($1 ~ /S82/ ) {region = "STRIPE82";}
                         if ($1 ~ /CDE0047/ ) {region = "CDE0047";}
                         if ($1 ~ /CDE0133/ ) {region = "CDE0133";}
                         if ($1 ~ /CDE0310/ ) {region = "CDE0310";}
                         if ($1 ~ /CDE0357/ ) {region = "CDE0357";}
                         if ($1 ~ /CDE1040/ ) {region = "CDE1040";}
                         if ($1 ~ /CDE1111/ ) {region = "CDE1111";}
                         if ($1 ~ /CDE1303/ ) {region = "CDE1303";}
                         if ($1 ~ /CDE1514/ ) {region = "CDE1514";}
                         if ($1 ~ /CDE1613/ ) {region = "CDE1613";}
                         if ($1 ~ /CDE1645/ ) {region = "CDE1645";}
                         if ($1 ~ /CDE2143/ ) {region = "CDE2143";}
                         if ($1 ~ /CDE2329/ ) {region = "CDE2329";}
                         if ($1 ~ /CDE2338/ ) {region = "CDE2338";}
                         if ($1 ~ /CSP0320/ ) {region = "CSP0320";}
                         if ($1 ~ /Lockmann/ ) {region = "Lockmann";}
                         if ($1 ~ /XMM/ ) {region = "XMM";}

                         print region;
                       }'`

STANDARDCAT=`gawk 'BEGIN {field = "'${FIELD}'";
                           if (field ~ /W3/ || field ~ /D3/ ||\
                               field ~ /NGVS/ || field ~ /S82/ ||\
                               field ~ /CDE1645/ ) {
                            print "SDSS-R7"
                          } else {
                            if (field ~ /CDE2143/) {
                               print "SDSS-R8"
                            } else {   
                              print "2MASS" }}}'`

# clean up  and copy masks; those tasks need to be done for all
# processing modes:
for FILTER in ${FILTERS}
do
  if [ -d ${MD}/${SURVEY}/${FIELD}/${FILTER} ]; then
    cd ${MD}/${SURVEY}/${FIELD}/${FILTER}
    rm -rf headers*
    rm -rf postcoadd
    rm -rf plots
    rm -rf coadd_${COADDIDENT}
    find . -wholename ./masks\*/\*resamp.reg | xargs rm
  fi
done

# copy mask files:
if [ "${MASKDIR}" != "" ]; then
  for FILTER in ${FILTERS}
  do
    mkdir -p ${MD}/${SURVEY}/${FIELD}/${FILTER}/masks_${COADDIDENT}
    cp ${MASKDIR}/${FIELD}* \
      ${MD}/${SURVEY}/${FIELD}/${FILTER}/masks_${COADDIDENT}
  done 
fi

if [ "${PROCESSMODE}" = "FULL" ]; then
  # First clean up directories. We assume that all previous
  # reductions have been finished before this script is called!!
  # Hence, we can clean up completely!
  for FILTER in ${FILTERS}
  do
    if [ -d ${MD}/${SURVEY}/${FILTER} ]; then
      cd ${MD}/${SURVEY}/${FILTER}
      rm -rf *
    fi
    
    for FILTER in ${FILTERS}
    do
      if [ -d ${MD}/${SURVEY}/${FIELD}/${FILTER} ]; then
        cd ${MD}/${SURVEY}/${FIELD}/${FILTER}
        rm *fits
        rm -rf cat
      fi
    done

    if [ -d ${MD}/${SURVEY}/${FIELD}/WEIGHTS_${FILTER} ]; then
      cd ${MD}/${SURVEY}/${FIELD}/WEIGHTS_${FILTER}
      rm *fits
    fi
  done
  
  # start with retrieving data:
  cd ${RETRIEVEDIR}
  
  DATE=`date '+%Y-%m-%dT%H:%M:%S'`
  if [ ${DEEPCOSMOS} -eq 1 ]; then
    if [ "${LOCATION}" = "UBC" ]; then   
      rm *fz
      # FILTERS only has '1' entry in the case of Deep fields!
      ./CFHTLS_datarequest.sh \
           -i ${FILELIST} \
           -d database_${FIELD}_${FILTERS}_${DATE}.txt \
           -in MEGAPRIME
      mkdir -p ${FIELD}/${FILTERS}
      mv *fz ${FIELD}/${FILTERS}
    else
      # FILTERS only has '1' entry in the case of Deep fields!
      ${DIR}/terapix_links.sh ${RETRIEVEDIR}/${FIELD}/${FILTERS} ${FILELIST} \
        ${DIR}/terapix_images.txt
    fi
  else
    if [ "${LOCATION}" = "BONN" ] && [ "${SURVEY}" = "NGVS" ]; then
      for FILTER in ${FILTERS}
      do  
        ldactoasc -s -b -i ${DIR}/${IMAGECAT} -t OBJECTS \
                     -k NGVSFIELD FILTER QUALITY EXPTIME IMAGENAME |\
          awk '($1 ~ /'${FIELD}'/ && $2 ~ /'${FILTER}'/ && $3 < 3 && $4 > 0) {
                 print $5}' > \
            ${RETRIEVEDIR}/NGVS_files.txt
  
        ${DIR}/terapix_links.sh ${RETRIEVEDIR}/${FIELD}/${FILTER} \
          ${RETRIEVEDIR}/NGVS_files.txt ${DIR}/bonn_ngvs_images.txt
        rm ${RETRIEVEDIR}/NGVS_files.txt
      done
    else
      for FILTER in ${FILTERS}
      do
        # Ludos user/password (lvan/eJytor74) should no longer be 
        # necessary as all CFHTLS data are public.  
        ./CFHTLS_datarequest.sh -f ${FILTER} \
                                -fi ${FIELD} -u erben -p Falum\
                                -d database_${FIELD}_${DATE}.txt \
                                -e 50 -c ${IMAGECAT} \
                                -in MEGAPRIME
      done
    fi
  fi
  
  # uncompress and distribute:
  for FILTER in ${FILTERS}
  do
    cd ${RETRIEVEDIR}/${FIELD}/${FILTER}
    if [ "${LOCATION}" = "UBC" ]; then
      getnproc
      NPROC=$?
  
      ${DIR}/uncompress.sh -s `pwd` -p ${NPROC}
      rm *fz
    fi
    ${DIR}/sort_MEGAPRIME_survey.sh `pwd` ${MD}/${SURVEY} ${REGION}
    cd ../..
  done
  
  cd ${DIR}

  # now do RUN processing:
  for FILTER in ${FILTERS}
  do
    ./CFHTLS_runprocess.sh ${MD} ${FILTER} ${REGION} ${SURVEY} \
      NOCLEAN NOTRACK NOZIP
  done
fi # of PROCESSMODE FULL

if [ "${HEADERDIR}" = "" ]; then
  ./doscamp_field_surround.sh ${MD}/${SURVEY} ${FIELD} "${FILTERS}" \
     /RAID/terben/CFHTLSPRESURVEY/allcats/
else
  for FILTER in ${FILTERS}
  do  
    cd ${MD}/${SURVEY}/${FIELD}/${FILTER}

    test -d headers_scamp_${STANDARDCAT} && rm -rf headers_scamp_${STANDARDCAT}

    mkdir headers_scamp_${STANDARDCAT}
    FILES=`find . -name \*C.sub.fits`

    for FILE in ${FILES}
    do
      BASE=`basename ${FILE} C.sub.fits`
      
      if [ -f ${HEADERDIR}/${FILTER}/headers_scamp_${STANDARDCAT}/${BASE}.head ]
      then
        cp ${HEADERDIR}/${FILTER}/headers_scamp_${STANDARDCAT}/${BASE}.head \
          ./headers_scamp_${STANDARDCAT}
      else
        BADCCD=`dfits ${FILE} | fitsort -d BADCCD | awk '{print $2}'`
        if [ ${BADCCD} -ne 1 ]; then
          echo "${HEADERDIR}/${FILTER}/${BASE}.head not present!"
          echo "Exiting!!"
          exit 1;  
        fi
      fi
    done
  done

  cd ${DIR}
fi

for FILTER in ${FILTERS}
do
  # hardwired magnitude zeropoints from global photometric calibration:
  ZPFIELD=${REGION}_${FILTER}_${COADDIDENT}_${LOCATION}
  # remove '.'s from ZPFIELD; these are not permitted in shell script
  # names:
  ZPFIELD=`echo ${ZPFIELD} | sed -e 's/\.//g'`
  MAGZP=${!ZPFIELD}

  # to avoid the use of an undefined variable in the following 
  # CFHTLS_collab_setprocess call:
  if [ -z ${MAGZP} ]; then
    MAGZP=""
  fi

  RELZPLIMIT=-0.1
  ELLIPSIGMALIMIT=3
  if [ "${COLLABDATA}" = "PHOTOZ" ]; then
    # no rejections according to relative zeropoint
    # or stellar ellipticity if we are in PHOTOZ mode.
    # we preselected Deep data beforehand. This happend
    # with the 'complete' Deep set of several hundred frames.
    # The lensing rejection criteria might get rid of some frames
    # if we apply them to Deep subsets. This is not wanted
    # for PHOTOZ SLIP.
    RELZPLIMIT=-1.0
    ELLIPSIGMALIMIT=100
  fi

  ./CFHTLS_collab_setprocess.sh ${MD} ${FILTER} ${SURVEY} \
    "${FIELD} ${STANDARDCAT}" ${COADDIDENT} "${LENSINGBANDS}" \
    ${RELZPLIMIT} ${ELLIPSIGMALIMIT} ${MAGZP}
done

# copy/move processed files to the release location; delete
# co-added products in the THELI processing directories.
# Otherwise they consume a large amount of disk space:

# the variable singlemove determines whether single-frame data
# are copied or moved at the end of processing to the release directories:
SINGLEMOVE="COPY"
if [ "${PROCESSMODE}" = "FULL" ]; then
  SINGLEMOVE="MOVE"
fi

for FILTER in ${FILTERS}
do
  # the variable COPYRESULT says whether the copying -
  # moving of data to release directories was sucessfull.
  # (1=failure) 
  COPYRESULT=1
  if [ ${DEEPCOSMOS} -eq 1 ]; then
    PREFIX=`basename ${FILELIST} .txt`
    ./copy_shearcollab.sh ${FIELD} ${FILTER} \
      ${COADDIDENT} "${LENSINGBANDS}" \
      ${MD}/${SURVEY} ${RELEASEDIR} ZIPWEIGHTS \
      ${SINGLEMOVE} ${PREFIX}
    COPYRESULT=$?
  else
    ./copy_shearcollab.sh ${FIELD} ${FILTER} \
      ${COADDIDENT} "${LENSINGBANDS}" \
      ${MD}/${SURVEY} ${RELEASEDIR} ZIPWEIGHTS \
      ${SINGLEMOVE}
    COPYRESULT=$?
  fi

  # only remove co-addition products from the
  # THELI directories if the copying was fine:
  if [ ${COPYRESULT} -eq 0 ]; then
    find ${MD}/${SURVEY}/${FIELD}/${FILTER}/coadd_${COADDIDENT} \
         -name \*swarp\*fits -type f | xargs rm  
  fi
done

