#!/bin/bash -xv

# Splits Elixir processed CFHT Megaprime Fits 
# extension images into the 36 chips. Uses the 
# eclipse utilities and also updates the image headers.
# Assumes that ONLY unsplit images are in the directory.
#
# This version is special for images from the CFHTS survey.
# It uses Skyprobe information to decide whether an image
# was obtained under photometric conditions and to transfer
# Elixir/QSO quality information to the image headers.

# History comments:
# 20.07.06:
# I add Elixir/QSO quality information to the
# image headers.

# $1: main directory
# $2: science directory
# $3: LDAC catalog with SkyProbe information

. MEGAPRIME.ini
. bash_functions.include

# Create image list: we assume that ONLY unsplit
# images are in the directory.

FILES=`ls $1/$2/ORIGINALS/*p.fits`

${P_LDACTOASC} -b -i $3 -t OBJECTS -s -k IMAGENAME PHOTOMETRIC > phot_$$.asc
${P_LDACTOASC} -b -i $3 -t OBJECTS -s -k IMAGENAME QUALITY > qual_$$.asc
${P_LDACTOASC} -b -i $3 -t OBJECTS -s -k IMAGENAME SEEINGCENTRE > seeingcentre_$$.asc
${P_LDACTOASC} -b -i $3 -t OBJECTS -s -k IMAGENAME SEEINGCORNER > seeingcorner_$$.asc

DIR=`pwd`

cd /$1/$2/ORIGINALS

for FILE in ${FILES}
do
  # first check whether we have an image from the CFHTLS;
  # if not, perform no action
  BASEELIXIR=`basename ${FILE} p.fits`

  ISCFHTLS=""
  ISCFHTLS=`${P_GAWK} '($1 == "'${BASEELIXIR}'") {print $1}' ${DIR}/phot_$$.asc`

  if [ "${ISCFHTLS}_A" != "_A" ]; then
    FILTNAM=`${P_DFITS} -x 1 ${FILE} | ${P_FITSORT} FILTER  | awk '($1!="FILE") {print $2}'`
    OBJECT=`${P_DFITS} -x 1  ${FILE} | ${P_FITSORT} OBJECT  | awk '($1!="FILE") {print $2}'`
    RA=`${P_DFITS} -x 1  ${FILE} | ${P_FITSORT} RA_DEG  | awk '($1!="FILE") {print $2}'`
    DEC=`${P_DFITS} -x 1 ${FILE} | ${P_FITSORT} DEC_DEG | awk '($1!="FILE") {print $2}'`
    LST=`${P_DFITS} -x 1 ${FILE} | ${P_FITSORT} LST-OBS | awk '($1!="FILE") {print $2}' | awk -F: '{print $1*3600+$2*60+$3}'`
    MJD=`${P_DFITS} -x 1 ${FILE} | ${P_FITSORT} MJD-OBS  | awk '($1!="FILE") {print $2}'`
    EXPTIME=`${P_DFITS} -x 1 ${FILE} | ${P_FITSORT} EXPTIME | awk '($1!="FILE") {print $2}'`
    AIRMASS=`${P_AIRMASS} -t ${LST} -e ${EXPTIME} -r ${RA} -d ${DEC} -l ${OBSLAT}`
    GABODSID=`${P_NIGHTID} -t ${REFERENCETIME} -d 31/12/1998 -m ${MJD} |\
        awk ' ($1 ~ /Days/) {print $6}' | awk 'BEGIN{ FS="."} {print $1}'`
  
    # RUN information
    RUN=`${P_DFITS} ${FILE} | ${P_FITSORT} QRUNID  | awk '($1!="FILE") {print $2}'`
  
    # Photoemtry information; all images will be markes as photometric!!
    PHOTINFO=1 # by default we have photometric information; this may not be the
               # case for special filters
    PHOT_C=`${P_DFITS} ${FILE} | ${P_FITSORT} PHOT_C  | awk '($1!="FILE") {print $2}'`
    PHOT_K=`${P_DFITS} ${FILE} | ${P_FITSORT} PHOT_K  | awk '($1!="FILE") {print $2}'`
  
    if [ "${PHOT_C}" != "KEY_N/A" ] && [ "${PHOT_K}" != "KEY_N/A" ]; then 
      # our magnitude zeropoint (at airmass 0) is PHOT_C-PHOT_K
      ZP=`awk 'BEGIN {print '${PHOT_C}'-('${PHOT_K}')}'`
    else
      PHOTINFO=0  
    fi
  
    ${P_FITSSPLIT_ECL} -CRPIX1 \
    "${REFPIXX[1]},${REFPIXX[2]},${REFPIXX[3]},${REFPIXX[4]},${REFPIXX[5]},${REFPIXX[6]},${REFPIXX[7]},${REFPIXX[8]},${REFPIXX[9]},${REFPIXX[10]},${REFPIXX[11]},${REFPIXX[12]},${REFPIXX[13]},${REFPIXX[14]},${REFPIXX[15]},${REFPIXX[16]},${REFPIXX[17]},${REFPIXX[18]},${REFPIXX[19]},${REFPIXX[20]},${REFPIXX[21]},${REFPIXX[22]},${REFPIXX[23]},${REFPIXX[24]},${REFPIXX[25]},${REFPIXX[26]},${REFPIXX[27]},${REFPIXX[28]},${REFPIXX[29]},${REFPIXX[30]},${REFPIXX[31]},${REFPIXX[32]},${REFPIXX[33]},${REFPIXX[34]},${REFPIXX[35]},${REFPIXX[36]}"\
                       -CRPIX2 \
    "${REFPIXY[1]},${REFPIXY[2]},${REFPIXY[3]},${REFPIXY[4]},${REFPIXY[5]},${REFPIXY[6]},${REFPIXY[7]},${REFPIXY[8]},${REFPIXY[9]},${REFPIXY[10]},${REFPIXY[11]},${REFPIXY[12]},${REFPIXY[13]},${REFPIXY[14]},${REFPIXY[15]},${REFPIXY[16]},${REFPIXY[17]},${REFPIXY[18]},${REFPIXY[19]},${REFPIXY[20]},${REFPIXY[21]},${REFPIXY[22]},${REFPIXY[23]},${REFPIXY[24]},${REFPIXY[25]},${REFPIXY[26]},${REFPIXY[27]},${REFPIXY[28]},${REFPIXY[29]},${REFPIXY[30]},${REFPIXY[31]},${REFPIXY[32]},${REFPIXY[33]},${REFPIXY[34]},${REFPIXY[35]},${REFPIXY[36]}"\
                       -CD11 \
    "${CD11[1]},${CD11[2]},${CD11[3]},${CD11[4]},${CD11[5]},${CD11[6]},${CD11[7]},${CD11[8]},${CD11[9]},${CD11[10]},${CD11[11]},${CD11[12]},${CD11[13]},${CD11[14]},${CD11[15]},${CD11[16]},${CD11[17]},${CD11[18]},${CD11[19]},${CD11[20]},${CD11[21]},${CD11[22]},${CD11[23]},${CD11[24]},${CD11[25]},${CD11[26]},${CD11[27]},${CD11[28]},${CD11[29]},${CD11[30]},${CD11[31]},${CD11[32]},${CD11[33]},${CD11[34]},${CD11[35]},${CD11[36]}"\
                       -CD22 \
    "${CD22[1]},${CD22[2]},${CD22[3]},${CD22[4]},${CD22[5]},${CD22[6]},${CD22[7]},${CD22[8]},${CD22[9]},${CD22[10]},${CD22[11]},${CD22[12]},${CD22[13]},${CD22[14]},${CD22[15]},${CD22[16]},${CD22[17]},${CD22[18]},${CD22[19]},${CD22[20]},${CD22[21]},${CD22[22]},${CD22[23]},${CD22[24]},${CD22[25]},${CD22[26]},${CD22[27]},${CD22[28]},${CD22[29]},${CD22[30]},${CD22[31]},${CD22[32]},${CD22[33]},${CD22[34]},${CD22[35]},${CD22[36]}"\
                       -CD12 \
    "${CD12[1]},${CD12[2]},${CD12[3]},${CD12[4]},${CD12[5]},${CD12[6]},${CD12[7]},${CD12[8]},${CD12[9]},${CD12[10]},${CD12[11]},${CD12[12]},${CD12[13]},${CD12[14]},${CD12[15]},${CD12[16]},${CD12[17]},${CD12[18]},${CD12[19]},${CD12[20]},${CD12[21]},${CD12[22]},${CD12[23]},${CD12[24]},${CD12[25]},${CD12[26]},${CD12[27]},${CD12[28]},${CD12[29]},${CD12[30]},${CD12[31]},${CD12[32]},${CD12[33]},${CD12[34]},${CD12[35]},${CD12[36]}"\
                       -CD21 \
    "${CD21[1]},${CD21[2]},${CD21[3]},${CD21[4]},${CD21[5]},${CD21[6]},${CD21[7]},${CD21[8]},${CD21[9]},${CD21[10]},${CD21[11]},${CD21[12]},${CD21[13]},${CD21[14]},${CD21[15]},${CD21[16]},${CD21[17]},${CD21[18]},${CD21[19]},${CD21[20]},${CD21[21]},${CD21[22]},${CD21[23]},${CD21[24]},${CD21[25]},${CD21[26]},${CD21[27]},${CD21[28]},${CD21[29]},${CD21[30]},${CD21[31]},${CD21[32]},${CD21[33]},${CD21[34]},${CD21[35]},${CD21[36]}"\
                        -M11 \
   "${M11[1]},${M11[2]},${M11[3]},${M11[4]},${M11[5]},${M11[6]},${M11[7]},${M11[8]},${M11[9]},${M11[10]},${M11[11]},${M11[12]},${M11[13]},${M11[14]},${M11[15]},${M11[16]},${M11[17]},${M11[18]},${M11[19]},${M11[20]},${M11[21]},${M11[22]},${M11[23]},${M11[24]},${M11[25]},${M11[26]},${M11[27]},${M11[28]},${M11[29]},${M11[30]},${M11[31]},${M11[32]},${M11[33]},${M11[34]},${M11[35]},${M11[36]}"\
                        -M22 \
   "${M22[1]},${M22[2]},${M22[3]},${M22[4]},${M22[5]},${M22[6]},${M22[7]},${M22[8]},${M22[9]},${M22[10]},${M22[11]},${M22[12]},${M22[13]},${M22[14]},${M22[15]},${M22[16]},${M22[17]},${M22[18]},${M22[19]},${M22[20]},${M22[21]},${M22[22]},${M22[23]},${M22[24]},${M22[25]},${M22[26]},${M22[27]},${M22[28]},${M22[29]},${M22[30]},${M22[31]},${M22[32]},${M22[33]},${M22[34]},${M22[35]},${M22[36]}"\
                        -M12 \
   "${M12[1]},${M12[2]},${M12[3]},${M12[4]},${M12[5]},${M12[6]},${M12[7]},${M12[8]},${M12[9]},${M12[10]},${M12[11]},${M12[12]},${M12[13]},${M12[14]},${M12[15]},${M12[16]},${M12[17]},${M12[18]},${M12[19]},${M12[20]},${M12[21]},${M12[22]},${M12[23]},${M12[24]},${M12[25]},${M12[26]},${M12[27]},${M12[28]},${M12[29]},${M12[30]},${M12[31]},${M12[32]},${M12[33]},${M12[34]},${M12[35]},${M12[36]}"\
                        -M21 \
   "${M21[1]},${M21[2]},${M21[3]},${M21[4]},${M21[5]},${M21[6]},${M21[7]},${M21[8]},${M21[9]},${M21[10]},${M21[11]},${M21[12]},${M21[13]},${M21[14]},${M21[15]},${M21[16]},${M21[17]},${M21[18]},${M21[19]},${M21[20]},${M21[21]},${M21[22]},${M21[23]},${M21[24]},${M21[25]},${M21[26]},${M21[27]},${M21[28]},${M21[29]},${M21[30]},${M21[31]},${M21[32]},${M21[33]},${M21[34]},${M21[35]},${M21[36]}"\
                        -IMAGEID \
   "${IMAGEID[1]},${IMAGEID[2]},${IMAGEID[3]},${IMAGEID[4]},${IMAGEID[5]},${IMAGEID[6]},${IMAGEID[7]},${IMAGEID[8]},${IMAGEID[9]},${IMAGEID[10]},${IMAGEID[11]},${IMAGEID[12]},${IMAGEID[13]},${IMAGEID[14]},${IMAGEID[15]},${IMAGEID[16]},${IMAGEID[17]},${IMAGEID[18]},${IMAGEID[19]},${IMAGEID[20]},${IMAGEID[21]},${IMAGEID[22]},${IMAGEID[23]},${IMAGEID[24]},${IMAGEID[25]},${IMAGEID[26]},${IMAGEID[27]},${IMAGEID[28]},${IMAGEID[29]},${IMAGEID[30]},${IMAGEID[31]},${IMAGEID[32]},${IMAGEID[33]},${IMAGEID[34]},${IMAGEID[35]},${IMAGEID[36]}"\
                        -CRVAL1 ${RA} -CRVAL2 ${DEC}\
                        -EXPTIME ${EXPTIME}\
                        -AIRMASS ${AIRMASS}\
                        -GABODSID ${GABODSID}\
                        -FILTER ${FILTNAM}  \
                        -OBJECT ${OBJECT}  \
                        -OUTPUT_DIR .. \
                        ${FILE}
   
    BASE=`basename ${FILE} .fits`

    # get Elixir/QSO data and save it, together with
    # photometric infomration,to the headers:
    PHOTOMETRIC=`${P_GAWK} '($1 == "'${BASEELIXIR}'") {print $2}' ${DIR}/phot_$$.asc`
   
    if [ "${PHOTOMETRIC}_A" = "_A" ]; then
      PHOTOMETRIC=0
    fi

    ELQUAL=`${P_GAWK} '($1 == "'${BASEELIXIR}'") {print $2}' ${DIR}/qual_$$.asc`

    if [ "${ELQUAL}_A" = "_A" ]; then
      ELQUAL=-1
    fi
   
    ELSEECEN=`${P_GAWK} '($1 == "'${BASEELIXIR}'") {print $2}' ${DIR}/seeingcentre_$$.asc`

    if [ "${ELSEECEN}_A" = "_A" ]; then
      ELSEECEN=-1.0
    fi
   
    ELSEECOR=`${P_GAWK} '($1 == "'${BASEELIXIR}'") {print $2}' ${DIR}/seeingcorner_$$.asc`

    if [ "${ELSEECOR}_A" = "_A" ]; then
      ELSEECOR=-1.0
    fi
   
    RUNKEY="'${RUN}'"
   
    i=1
    while [ ${i} -le 36 ]
    do
      writekey ../${BASE}_${i}.fits RUN ${RUNKEY} REPLACE
      value ${ELQUAL}
      writekey ../${BASE}_${i}.fits ELQUAL "${VALUE}" REPLACE
      value ${ELSEECEN}
      writekey ../${BASE}_${i}.fits ELSEECEN "${VALUE}" REPLACE
      value ${ELSEECOR}
      writekey ../${BASE}_${i}.fits ELSEECOR "${VALUE}" REPLACE

      if [ ${PHOTINFO} -eq 0 ]; then 
        # if no photometric information is available we set the
        # zeropoints to '-1.0' and the extinction to '0.0'  
        ZP=-1.0
        PHOT_K=0.0
        PHOTOMETRIC=0
      fi
   
      if [ ${PHOTOMETRIC} -eq 0 ]; then
        value "-1.0"
        writekey ../${BASE}_${i}.fits ZP "${VALUE}" REPLACE
        value "0.0"
        writekey ../${BASE}_${i}.fits COEFF "${VALUE}" REPLACE
      else
        value ${ZP}
        writekey ../${BASE}_${i}.fits ZP "${VALUE}" REPLACE
        value ${PHOT_K}
        writekey ../${BASE}_${i}.fits COEFF "${VALUE}" REPLACE
      fi
   
      value ${ZP}
      writekey ../${BASE}_${i}.fits ZP1 "${VALUE}" REPLACE
      writekey ../${BASE}_${i}.fits ZP2 "${VALUE}" REPLACE
      writekey ../${BASE}_${i}.fits ZP3 "${VALUE}" REPLACE
      value ${PHOT_K}
      writekey ../${BASE}_${i}.fits COEFF1 "${VALUE}" REPLACE
      writekey ../${BASE}_${i}.fits COEFF2 "${VALUE}" REPLACE
      writekey ../${BASE}_${i}.fits COEFF3 "${VALUE}" REPLACE
      value ${PHOTOMETRIC}
      writekey ../${BASE}_${i}.fits ZPCHOICE "${VALUE}" REPLACE
      value 0
      writekey ../${BASE}_${i}.fits BADCCD "${VALUE}" REPLACE
   
      i=$(( $i + 1 ))
    done

    # if the Elixir quality flag is '-1' or larger than 2 we move
    # the image immedialtely to a 'BADELQUAL' subdirectory.
    if [ ${ELQUAL} -eq -1 ] || [ ${ELQUAL} -gt 2 ]; then
      if [ ! -d ../BADELQUAL ]; then
	mkdir ../BADELQUAL  
      fi

      i=1
      while [ ${i} -le 36 ]
      do
	mv ../${BASE}_${i}.fits ../BADELQUAL
	i=$(( $i + 1 ))
      done
    fi
  else
    echo "Image ${FILE} does not belong to the CFHTLS."
    echo "No splitting performed!!"  
  fi
done

cd ${DIR}
rm phot_$$.asc
rm qual_$$.asc
rm seeingcentre_$$.asc
rm seeingcorner_$$.asc