#!/bin/bash

# script to identify and to move 'bad' images in the CFHTLS and NGVS
# surveys. This script should be used after a first run of 'so_scamp.sh'.
# AFter this script has identified problematic images 'do_scamp.sh'
# should be rerun to get the final scamp image headers and photometric
# calibration. 

# Bad images are identified here via (high) stellar ellipticity,
# (strongly negative) relative zeropoints, (high) sky-background. For
# NGVS and CFHTLS Wide this script considers all catalogues from a
# patch simultaneously!  The required directory structure is described
# in the script 'so_scamp.sh'. Identified, bad images are moves
# to directories with names .../W1/r/cat/BAD etc.  The identified
# exposures are also listed in a file `pwd`/badima_W1_r.txt, etc.  Note
# that you should use the information of this script to mark identified 
# BAD images in the survey quality catalogue to ensure a consistent processing 
# (images that are handled in co-additions etc.) lateron.

#$1: main directory; below are directories W1-W4, D1-D4, COSMOS, NGVS...!
#$2: field name (W1-W4, D1-D4, .....)
#$3: filters to consider

MD=$1
FIELD=$2
FILTERS="$3"
SUBFIELDS=$2

# COSMOS consists of four pointings that overlap to a significant
# fraction. Hence, we want to do astrometry/photometry with all these
# 'subfields' simultaneously! Yes, we can say that this is the case
# for all the Wide patches as well, but nevertheless some special
# treatment for COSMOS here!
if [ "${FIELD}" = "COSMOS" ]; then
  SUBFIELDS="COSMOS_C COSMOS_UL COSMOS_UR COSMOS_LL COSMOS_LR"
fi


# get list of problematic images; for the moment criteria
# to reject images are (survey and field dependent):
#
# - e1, e2: stellar ellipticity components 
# - relative zeropooint boundaries: < -0.2 or > 0.8
# - sky-background per second

ELLIPLOW=-0.15
ELLIPHIGH=0.15
RELZPLOW=-0.2
RELZPHIGH=0.8

# general background limits:
u=100; g=100; r=100; i=100; y=100; z=100

# limits for sky-background in the Deep:
if [[ "${FIELD}" =~ 'D[1-4]' ]] || [[ "${FIELD}" =~ 'COSMOS' ]]; then
  u=1.5; g=5; r=6; i=10; y=10; z=12
fi

# limits for NGVS and RCS2 fields:
if [[ "${FIELD}" =~ 'NGVS' ]] || [[ "${FIELD}" =~ 'CSP' ]] ||\
   [[ "${FIELD}" =~ 'CDE' ]]; then
  u=2.0; g=7; r=8; i=15; y=15; z=17
fi

# seeing limit:
SEEING=3.0

if [[ "${FIELD}" =~ 'D[1-4]' ]] || [[ "${FIELD}" =~ 'COSMOS' ]]; then
  if [ "${FILTER}" = "u" ]; then
    SEEING=1.1
  else
    SEEING=1.0
  fi
fi

if [[ "${FIELD}" =~ 'NGVS' ]] || [[ "${FIELD}" =~ 'CSP' ]] ||\
   [[ "${FIELD}" =~ 'CDE' ]]; then
  SEEING=1.3
fi

# for CFHTLS-Wide and NGVS, we want to reject bad seeing images only
# if they are science images (long exposure times). Of course
# we want to keep short exposed photometric pegs:
EXPTIME=0
if [[ "${FIELD}" =~ 'NGVS' ]] || [[ "${FIELD}" =~ 'W[1-4]' ]]; then
  EXPTIME=200
fi


for FILTER in ${FILTERS}
do
  BACKGR=${!FILTER}
  
  for SUBFIELD in ${SUBFIELDS}
  do
    if [ -f ${MD}/${SUBFIELD}/${FILTER}/cat/chips.cat6 ]; then
      ldactoasc -i ${MD}/${SUBFIELD}/${FILTER}/cat/chips.cat6 -t STATS \
                -s -b -k IMAGENAME SEEING e1 e2 BACKGR RZP EXPTIME|\
        awk '($2 > '${SEEING}' && $7 > '${EXPTIME}') || \
              $3 < '${ELLIPLOW}' || $3 > '${ELLIPHIGH}' ||\
              $4 < '${ELLIPLOW}' || $4 > '${ELLIPHIGH}' ||\
              $6 < '${RELZPLOW}' || $6 > '${RELZPHIGH}' ||\
              $5 > '${BACKGR}' {print $1}' > \
        badima_${SUBFIELD}_${FILTER}.asc 

      CURRDIR=`pwd`
      for DIR in ${MD}/${SUBFIELD}/${FILTER} ${MD}/${SUBFIELD}/${FILTER}/cat
      do
        test -d ${DIR}/BAD || mkdir ${DIR}/BAD
        while read IMAGE
        do
          # the following 'nullglob' construct avoids error messages
          # if no files with the pattern '${DIR}/${IMAGE}*' exist.
          shopt -s nullglob
          for FILE in ${DIR}/${IMAGE}*
          do
            mv ${FILE} ${DIR}/BAD
          done
          shopt -u nullglob
        done < ${CURRDIR}/badima_${SUBFIELD}_${FILTER}.asc         
      done
    else
      echo "Filter ${FILTER} for field ${SUBFIELD} not present!"  
    fi
  done
done

