#!/bin/bash -u

# ----------------------------------------------------------------
# File Name:           sort_MEGAPRIME_survey.sh           
# Author:              Thomas Erben (terben@astro.uni-bonn.de)
# Last modified on:    10.06.2015
# Description:         sort Elixir data to MEGAPRIME SURVEY strcture
# ----------------------------------------------------------------

# Script history information:
#
# 21.09.2009:
# Project started - transfer from the old
# sort_CFHTLS.sh script
#
# 04.07.2010:
# I added the possibility to link files to the ORIGINALS
# directories instead of moving them
#
# 10.06.2015:
# MEGAPRIME is now operated in two modes. The first ist he traditional
# 36-chip mode. The new one a 40-chip mode with a new set of filters.
# If we process new mode data (maybe together with old data) we use
# a new filter naming scheme. I updated this script accordingly!

##
## function definitions:
##
function printUsage 
{
  echo "SCRIPT NAME:"
  echo "    sort_MEGAPRIME_survey.sh - sort Elixir data in MEGAPRIME survey structure  "
  echo ""
  echo "ARGUMENTS:"
  echo "    sort_MEGAPRIME_survey.sh sourcedir surveydir identifier mode [LINK]"
  echo ""
  echo "DESCRIPTION:"
  echo "    The script considers all FITS files present in sourcedir.  It"
  echo "    sorts them within the THELI survey structure to process Elixir"
  echo "    preprocessed data from MEGAPRIME@CFHT. Before calling this script"
  echo "    you need to create the survey directory structure with"
  echo "    'create_CFHTLS_set_dirs.sh'. Within the survey directory the"
  echo "    script creates several subdirectories (see examples below) and"
  echo "    moves the data therein. If the optional 'LINK' argument is given"
  echo "    files are only linked instead of moved."
  echo ""
  echo "IMPORTANT NOTE:"
  echo "    'sourcedir' and 'surveydir' need to be given as complete, absolute"
  echo "    paths!"
  echo ""
  echo "EXAMPLES:"
  echo "    We have the 14 files 784537p.fits 784538p.fits 788576p.fits 788575p.fits "
  echo "    788577p.fits 788070p.fits 788579p.fits 788069p.fits 788578p.fits "
  echo "    784535p.fits 784536p.fits 788574p.fits 784539p.fits 784540p.fits   "
  echo "    within a sourcedir. They represent g and r-band exposures from"
  echo "    the galaxy cluster A1835. We want to process them within the CLUSTERS"
  echo "    survey. We created the CLUSTERS survey directory in somedir."
  echo ""
  echo "    We call:"
  echo "    sort_MEGAPRIME_survey.sh sourcedir somedir/CLUSTERS A1835 mode1"
  echo ""
  echo "    You are free to chosse the identifier - A1835 as third argument"
  echo "    in this case."
  echo ""
  echo "    Within the CLUSTERS directory the script will create the"
  echo "    structure:"
  echo ""
  echo "    CLUSTERS/g/run_05AQ02_A1835/SCIENCE_g/ORIGINALS/*p.fits"
  echo "    ......../g/run_05AQ02_A1835/WEIGHTS"
  echo "      ."
  echo "      ."
  echo "    ....... /r/run_05AQ02_A1835/SCIENCE_r/ORIGINALS/*p.fits"
  echo "    ......../r/run_05AQ02_A1835/WEIGHTS"
  echo ""
  echo "    The IDs in the run directory names represent the CFHT QRUNID within"
  echo "    which the data was obtained plus the chosen user identifier. "
  echo "    The CFHT QRUNIDs stand for a RUN in the THELI language."
  echo "    After this step you are ready to proceed with RUN processing "
  echo "    (e.g. with the doall_run_CFHTLS_single.sh script) of the"
  echo "    data."
  echo ""
  echo "AUTHOR:"
  echo "    Thomas Erben         (terben@astro.uni-bonn.de)"
  echo ""
}

##
## initial sanity checks
##

# check validity of command line arguments:
if [ $# -lt 4 ] || [ $# -gt 5 ]; then
  printUsage
  exit 1
fi

# check for absolute paths of $1 and $2
if [ "${1#/}" = "${1}" ] || [ "${2#/}" = "${2}" ]; then
  echo "You must provide absolute paths, not relative ones."
  exit 1
fi

LINK=0
if [ $# -eq 5 ] && [ "$5" = "LINK" ]; then
  LINK=1
fi
 
##
## Main script tasks
##

# we assume that all FITS files in the source directory belong to the
# survey under consideration:
FILES=`find $1 -name \*fits`

for file in ${FILES}
do
  # obtain filter name and CFHT RUNID
  FILTNAM=`dfits -x 1 ${file} | fitsort FILTER  | awk '($1!="FILE") {print $2}'`
  RUN=`dfits -x 1 ${file} | fitsort QRUNID  | awk '($1!="FILE") {print $2}'`

  # translate the CFHT filter IDs to one character values if we want
  # to process mode1 data:
  FILTER=${FILTNAM}
  if [ "$4" = "mode1" ]; then
    FILTER=""
    if [ "${FILTNAM}" = "u.MP9301" ]; then
      FILTER="u"
    fi
    if [ "${FILTNAM}" = "g.MP9401" ]; then
      FILTER="g"
    fi
    if [ "${FILTNAM}" = "r.MP9601" ]; then
      FILTER="r"
    fi
    if [ "${FILTNAM}" = "i.MP9701" ]; then
      FILTER="i"
    fi
    if [ "${FILTNAM}" = "i.MP9702" ]; then
      FILTER="y"
    fi
    if [ "${FILTNAM}" = "z.MP9801" ]; then
      FILTER="z"
    fi
  fi

  if [ "${FILTER}_A" = "_A" ]; then
    echo "Warning: Either the filter for ${file} is unknown"
    echo "or you try to use mode2 data in mode1!"
  else
    if [ "${RUN}_A" = "_A" ]; then
      echo "No QRUN for ${file}"
    else
      if [ ! -d $2/${FILTER}/run_${RUN}_$3/SCIENCE_${FILTER}/ORIGINALS ]; then
        echo "Creating $2/${FILTER}/run_${RUN}_$3/SCIENCE_${FILTER}/ORIGINALS"
	echo ""
        mkdir -p $2/${FILTER}/run_${RUN}_$3/SCIENCE_${FILTER}/ORIGINALS
      fi
      if [ ${LINK} -eq 0 ]; then
        echo "moving ${file} to $2/${FILTER}/run_${RUN}_$3/SCIENCE_${FILTER}/ORIGINALS"
        mv ${file} $2/${FILTER}/run_${RUN}_$3/SCIENCE_${FILTER}/ORIGINALS
      else
        echo "linking ${file} to $2/${FILTER}/run_${RUN}_$3/SCIENCE_${FILTER}/ORIGINALS"          
        ln -s ${file} $2/${FILTER}/run_${RUN}_$3/SCIENCE_${FILTER}/ORIGINALS
      fi
    fi
  fi  
done

# and bye
exit 0;
