#!/bin/bash -u

# ----------------------------------------------------------------
# File Name:           uncompress.sh
# Author:              Thomas Erben (terben@astro.uni-bonn.de)
# Last modified on:    16.08.2015
# Description:         Splits/compresses FITS images with the Rice algorithm
# ----------------------------------------------------------------

# Script history information:
# 06.12.2006: 
# I significantly rewrote the script to include
# multiprocessor usage and better command line
# processing.
#
# 26.07.2007:
# I extended the script to also allow data compression.
# If the 'new' command line option '-m' is set to
# 'COMPRESS' FITS images are compressed to the Rice
# format.
#
# 20.09.2009:
# I add the possibility to delete original files after
# (un)compression.
#
# 06.10.2009:
# update of documentation
#
# 17.06.2012:
# I added 16 to allowed error codes for compressed images
# (VISTA); I removed a typo in checking valid error codes
# before removing original data.
#
# 16.08.2015:
# I expanded the scripts functionality to allow (un)compressing
# only images listed in a file.
#
# 17.08.2015:
# I simplified the comparison between image list and present files
# in the source directory (update from 16.08.2015). The old
# implementation unnecessarily performed the same expensive comparison
# for each launched process.

# function definitions:
function print_usage() {
  echo "SCRIPT NAME"
  echo "    uncompress.sh - (un)compress FITS files with RICE algorithm"
  echo ""
  echo "SYNOPSIS"
  echo "    uncompress.sh   -s sourcedir            "
  echo "                  [ -t targetdir ]"
  echo "                  [ -p processors ]"
  echo "                  [ -f imagelist ]"
  echo "                  [ -m COMPRESS/UNCOMPRESS ]"
  echo "                  [ -d ]"
  echo ""
  echo "DESCRIPTION "
  echo "    The script (un)compresses FITS files with the Rice algorithm."
  echo "    Images treated with the Rice algorithm typically end with"
  echo "    '.fits.fz' and the script implicitely uses this ending.  The '-s'"
  echo "    (source) argument points to the directory which contains the"
  echo "    compressed data.  If a '-t' (target) argument is given the"
  echo "    uncompressed FITS files are put to it. Otherwise the"
  echo "    (un)compressed are put in the source directory. If '-d' is given"
  echo "    the original files are deleted after (un)compression. In this"
  echo "    case the newly created files are checked with 'fitsverify' before"
  echo "    original data are deleted. if '-f' is given images in the"
  echo "    sourcedir. are compared with those listed in 'imagelist'. Only"
  echo "    Only images present in 'imagelist' will be treated by the script."
  echo ""
  echo "    Give as '-p' the number of processors of your machine It is 1 as"
  echo "    default. The script will launch as many (un)compression jobs"
  echo "    simultaneously."
  echo ""
  echo "    If '-m' is not given the 'UNCOMPRESS' mode is assumed."
  echo ""
  echo "    The script needs the FITSIO tools 'imcopy' and 'fitsverify'"
  echo "    and the UNIX tools 'find', 'awk' and 'wc' in your path."
  echo ""
  echo "IMPORTANT NOTES"
  echo "    Note that the Rice compression is only lossless with FITS"
  echo "    files in integer precision, i.e. BITPIX=16. For float images,"
  echo "    compressing and uncompressing images DOES NOT result in exactly"
  echo "    the same pixel values."
  echo ""
  echo "    Images are also uncompressed if they carry the ending '.fz' but"
  echo "    were previously compressed with another compression algorithm."
  echo "    We noted that images distributed by CADC often are compressed"
  echo "    with gzip but carry the ending '.fz' nevertheless."
  echo ""
  echo "EXAMPLE"
  echo "    uncompress.sh -s /data/terben/images -p 4 -m COMPRESS -d"
  echo ""
  echo "    This command inspects the directory /data/terben/images for FITS"
  echo "    files with the ending '.fits'. These are Rice-compressed to images"
  echo "    with the ending '.fits.fz'. The compression is done with four"
  echo "    simultaneous jobs and the original FITS files are deleted at the"
  echo "    end of the process (if the newly created files pass fitsverify)."
  echo ""
  echo "AUTHOR"
  echo "    Thomas Erben (terben@astro.uni-bonn.de)"
  echo ""
}

# default values for variables
# All variables need to be defined ('-u' option)
NPROC=1
DELETEORIG=0
SOURCEDIR=""
TARGETDIR=""
IMAGELIST=""
PROCESSMODE=UNCOMPRESS
ORIG_ENDING=fits.fz
NEW_ENDING=fits

if [ $# -lt 2 ]; then
  print_usage
  exit 1
fi

# evaluate command line arguments:
while [ $# -gt 0 ]; do
  case $1 in
    -d) DELETEORIG=1
        shift
        ;;
    -f) IMAGELIST=${2}
        shift 2
        ;;
    -m) PROCESSMODE=${2}
        shift 2
        ;;
    -p) NPROC=${2}
        shift 2
        ;;
    -s) SOURCEDIR=${2}
        shift 2
        ;;
    -t) TARGETDIR=${2}
        shift 2
        ;;
    *)  echo -e "Unknown command line parameter: $1 \n"
        print_usage
        exit 1
        ;;
  esac
done

# check command line arguments
test -z ${SOURCEDIR} && { print_usage; exit 1; }
test -z ${TARGETDIR} && TARGETDIR=${SOURCEDIR}
test -d ${SOURCEDIR} || { echo "Directory ${SOURCEDIR} does not exist !"; 
                          exit 1; }

if [ "${IMAGELIST}" != "" ] && [ ! -s "${IMAGELIST}" ]; then
  echo "File ${IMAGELIST} does not exist or is empty!"
  exit 1;
fi

if [ "${PROCESSMODE}" = "COMPRESS" ]; then
  ORIG_ENDING=fits
  NEW_ENDING=fits.fz    

  tput bold
  echo "Compressing '.fits' images in ${SOURCEDIR}"
  tput sgr0
else
  tput bold
  echo "Uncompressing '.fits.fz' images in ${SOURCEDIR}"
  tput sgr0  
fi

if [ ${DELETEORIG} -eq 1 ]; then
  tput bold
  echo "I will delete original files at the end!"
  tput sgr0  
fi

# print out information and split the files to the available processors:
find ${SOURCEDIR} -maxdepth 1 -name \*${ORIG_ENDING} | sort > images.txt_$$
if [ "${IMAGELIST}" != "" ]; then
  echo "Comparing images in ${SOURCEDIR} with file list in ${IMAGELIST}"
  grep -f ${IMAGELIST} images.txt_$$ > images_tmp.txt_$$
  mv images_tmp.txt_$$ images.txt_$$
else
  echo "Considering all images in ${SOURCEDIR}" 
fi

NFILES=`wc -l images.txt_$$ | awk '{print $1}'`

# do we need to do something at all?
if [ ${NFILES} -gt 0 ]; then
  echo "${NFILES} images to process with ${NPROC} processors!"
  i=0
  while [ $i -lt ${NPROC} ]
  do
    # the 'sort' in the following pipelines ensures that the order of files is
    # always the same. This is not ensured by the 'find' command!
    FILES[$i]=`awk '(NR % '${NPROC}' == '$i')' images.txt_$$`
    NFILES[$i]=`echo ${FILES[$i]} | wc -w` 
  
    j=$(( $i + 1 ))
    echo -e "Starting Job $j. It has ${NFILES[$i]} files to process!\n"
  
    # launch uncompression job! For each processor we start a background job
    # by grouping several shell commands to a single one!
    {
      k=1
      for file in ${FILES[$i]}
      do
        BASE=`basename ${file} \.${ORIG_ENDING}`
        echo "Job ${j} (${k}/${NFILES[$i]}): (un)packing ${file} to ${TARGETDIR}/${BASE}.${NEW_ENDING}"
        if [ "${PROCESSMODE}" = "COMPRESS" ]; then
          NEWFILE="${TARGETDIR}/${BASE}.${NEW_ENDING}[compress]"
        else
          NEWFILE=${TARGETDIR}/${BASE}.${NEW_ENDING}
        fi
        imcopy ${file} "${NEWFILE}"
  
        if [ ${DELETEORIG} -eq 1 ]; then
  	# we only delete if the newly create file passes
          # fitsverify:
  	fitsverify -q "${NEWFILE}"  
  
  	# Elixir preprocessed files from CFHT can show some errors/warnings:
          CODE=$?
          if [ ${CODE} -eq 0 ] || [ ${CODE} -eq 4 ] || [ ${CODE} -eq 23 ] ||\
             [ ${CODE} -eq 41 ] || [ ${CODE} -eq 78 ] || \
             [ ${CODE} -eq 16 ]; then
            rm ${file}
          fi
        fi
  
        k=$(( $k + 1 ))
      done
    } &
    i=$(( $i + 1 ))
  done
else
  echo "Nothing to do!"
fi

# only finish the script if all lauched background jobs
# are finished!
wait

rm *_$$
exit 0
